-- MySQL dump 10.13  Distrib 5.1.47, for unknown-linux-gnu (x86_64)
--
-- Host: localhost    Database: hermeshi_8
-- ------------------------------------------------------
-- Server version	5.1.56-community-log

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `hmsh_ebay_eastar_sku_item`
--

DROP TABLE IF EXISTS `hmsh_ebay_eastar_sku_item`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_eastar_sku_item` (
  `id` int(8) NOT NULL AUTO_INCREMENT,
  `sku` varchar(255) NOT NULL,
  `item_id` bigint(20) NOT NULL,
  `quantity` int(8) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=553 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_eastar_sku_item`
--

LOCK TABLES `hmsh_ebay_eastar_sku_item` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_eastar_sku_item` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_eastar_sku_item` VALUES (1,'TRTS001',100001,1),(2,'TRTT002',100002,1),(3,'TRMX003',100003,1),(4,'CASS001',100004,1),(5,'CASS002',100005,1),(6,'CASS003',100006,1),(7,'CMLO001',100007,1),(8,'KBLO001',100008,1),(9,'SCLO001',100009,1),(10,'SCLO002',100010,1),(11,'RCLO001',100011,1),(12,'RCLO002',100012,1),(13,'RCLO003',100013,1),(14,'RCLO004',100014,1),(15,'RCLO005',100015,1),(16,'RCLO006',100016,1),(17,'POLO001',100017,1),(18,'CRLO002',100018,1),(19,'CRLO001',100019,1),(20,'BALO001',100020,1),(21,'BALO002',100021,1),(22,'BALO003',100022,1),(23,'BALO004',100023,1),(24,'BALO005',100024,1),(25,'BALO006',100025,1),(26,'BALO008',100026,1),(27,'RELE001',100027,1),(28,'RELO002',100028,1),(29,'MOLO001',100029,1),(30,'MOLO005',100030,1),(31,'BALO007',100031,1),(32,'HSLO001',100032,1),(33,'HSLO002',100033,1),(34,'RCMA001',100034,1),(35,'SHLO001',100035,1),(36,'MOLO002',100036,1),(37,'MOLO003',100037,1),(38,'SPAL001',100038,1),(39,'SPAL002',100039,1),(40,'ANYA001',100040,1),(41,'ANYA002',100041,1),(42,'ANWI001',100042,1),(43,'HSMO001',100043,1),(44,'HSMO002',100044,1),(45,'HSMO003',100045,1),(46,'HSMO004',100046,1),(47,'HSMO005',100047,1),(48,'HSMO006',100048,1),(49,'HSMO007',100049,1),(50,'HSMO008',100050,1),(51,'HSMO009',100051,1),(52,'HSMO010',100052,1),(53,'HSMO011',100053,1),(54,'HSMO012',100054,1),(55,'HSMO013',100055,1),(56,'HSMO014',100056,1),(57,'HSMO015',100057,1),(58,'HSMO016',100058,1),(59,'HSMO017',100059,1),(60,'HSMO018',100060,1),(61,'HSMO019',100061,1),(62,'HSMO020',100062,1),(63,'HSNO001',100063,1),(64,'HSNO002',100064,1),(65,'HSNO003',100065,1),(66,'HSNO004',100066,1),(67,'HSNO005',100067,1),(68,'HSNO006',100068,1),(69,'HSNO007',100069,1),(70,'HSNO008',100070,1),(71,'HSNO009',100071,1),(72,'HSNO010',100072,1),(73,'HSNO011',100073,1),(74,'HSNO013',100074,1),(75,'HSNO014',100075,1),(76,'HSNO015',100076,1),(77,'HSNO016',100077,1),(78,'HSNO017',100078,1),(79,'HSNO018',100079,1),(80,'HSNO019',100080,1),(81,'HSNO020',100081,1),(82,'HSNO021',100082,1),(83,'HSNO022',100083,1),(84,'HSNO023',100084,1),(85,'HSNO024',100085,1),(86,'HSNO025',100086,1),(87,'HSNO026',100087,1),(88,'HSNO027',100088,1),(89,'HSSA001',100089,1),(90,'HSSE001',100090,1),(91,'HSSE002',100091,1),(92,'HSSE007',100092,1),(93,'HSSE003',100093,1),(94,'HSSE004',100094,1),(95,'HSSE005',100095,1),(96,'HSSE006',100096,1),(97,'HSSE008',100097,1),(98,'HSPL001',100098,1),(99,'HSPL002',100099,1),(100,'HSPL003',100100,1),(101,'HSPL004',100101,1),(102,'HSPL005',100102,1),(103,'HSPL006',100103,1),(104,'HSPL007',100104,1),(105,'HSPL008',100105,1),(106,'HSPL009',100106,1),(107,'HSPL010',100107,1),(108,'HSPL011',100108,1),(109,'HSPL012',100109,1),(110,'HSPL013',100110,1),(111,'HSJA001',100111,1),(112,'HSJA002',100112,1),(113,'HSJA003',100113,1),(114,'HSUE001',100114,1),(115,'HSUE002',100115,1),(116,'HSUE003',100116,1),(117,'HSUE004',100117,1),(118,'HSSS001',100118,1),(119,'HSSS002',100119,1),(120,'HSSS003',100120,1),(121,'HSSS004',100121,1),(122,'HSSS005',100122,1),(123,'HSSS006',100123,1),(124,'HSSS007',100124,1),(125,'HSSS008',100125,1),(126,'HSSH001',100126,1),(127,'HSSH002',100127,1),(128,'OTHP001',100128,1),(129,'BAZA001',100129,1),(130,'CCZG001',100130,1),(131,'MOSA003',100131,1),(132,'MOSA002',100132,1),(133,'MOSA001',100133,1),(134,'OTSB001',100134,1),(135,'OTCR001',100135,1),(136,'OTRA001',100136,1),(137,'OTRA002',100137,1),(139,'OTGR001',100139,1),(140,'OTGR002',100140,1),(141,'OTHP003',100141,1),(142,'OTCN001',100142,1),(143,'OTCN002',100143,1),(144,'OTCN003',100144,1),(145,'OTCN004',100145,1),(146,'OTCA001',100146,1),(147,'TOIN001',100147,1),(148,'TOIN002',100148,1),(149,'BAIN001',100149,1),(150,'BAIN002',100150,1),(151,'OTJE001',100151,1),(152,'OTPH002',100152,1),(153,'OTKE001',100153,1),(154,'OTSO001',100154,1),(155,'OTSO002',100155,1),(156,'KBVI001',100156,1),(157,'KBVI002',100157,1),(158,'KBAP001',100158,1),(159,'KBAP002',100159,1),(160,'KBAP003',100160,1),(161,'MOMI001',100161,1),(162,'MOSU001',100162,1),(163,'MOSU002',100163,1),(164,'MOAJ001',100164,1),(165,'WWSI001',100165,1),(166,'WWSI002',100166,1),(167,'WWSI003',100167,1),(168,'WWSI004',100168,1),(169,'WWSI005',100169,1),(170,'WWSI006',100170,1),(171,'WWOT001',100171,1),(172,'WWOT002',100172,1),(173,'WWOP002',100173,1),(174,'WWOP003',100174,1),(175,'WWHU001',100175,1),(176,'WWHU002',100176,1),(177,'WWHU003',100177,1),(178,'WWOT003',100178,1),(179,'MOCN001',100179,1),(180,'ANCN001',100180,1),(181,'ANCN002',100181,1),(182,'ANCN003',100182,1),(183,'WLDL001',100183,1),(184,'WLAP001',100184,1),(185,'WLAP002',100185,1),(186,'WLAP003',100186,1),(187,'WLAP004',100187,1),(188,'WLAP005',100188,1),(189,'WLAP006',100189,1),(190,'WLAP007',100190,1),(191,'WLAP008',100191,1),(192,'WLAP009',100192,1),(193,'MOAP001',100193,1),(194,'MOAP002',100194,1),(195,'WLIN001',100195,1),(196,'WLIN002',100196,1),(197,'WLDE001',100197,1),(198,'WLDE002',100198,1),(199,'WLDE003',100199,1),(200,'WLHP001',100200,1),(201,'WLBR001',100201,1),(202,'WLHP002',100202,1),(203,'WLAT001',100203,1),(204,'WLAT002',100204,1),(205,'WLAT003',100205,1),(206,'WLAT004',100206,1),(207,'WLAT005',100207,1),(208,'WLAT006',100208,1),(209,'WLAT007',100209,1),(210,'WLAT008',100210,1),(211,'WLAT009',100211,1),(212,'WLAT010',100212,1),(213,'WLIN003  ',100213,1),(214,'WLIN004',100214,1),(215,'WLIN005',100215,1),(216,'WLIN006',100216,1),(217,'WLIN007',100217,1),(218,'WLIN008',100218,1),(219,'WLIN009',100219,1),(220,'WLIN010',100220,1),(221,'WLIN011',100221,1),(222,'WLIN012',100222,1),(223,'WLIN013',100223,1),(224,'WLPO001',100224,1),(225,'BTAC2000',100225,1),(226,'BTDE2001',100226,1),(227,'BTDE2002',100227,1),(228,'BTGA2001',100228,1),(229,'BTLE2001',100229,1),(230,'BTLE2002',100230,1),(231,'BTHU2001',100231,1),(232,'BTHU2002',100232,1),(233,'BTHU2003',100233,1),(234,'BTHU2004',100234,1),(235,'BTHU2005',100235,1),(236,'BTAC2001',100236,1),(237,'BTAC2002',100237,1),(238,'BTAC2003',100238,1),(239,'BTAC2004',100239,1),(240,'BTAC2005',100240,1),(241,'BTAC2006',100241,1),(242,'BTAC2007',100242,1),(243,'BTAC2008',100243,1),(244,'BTAC2009',100244,1),(245,'BTAC2010',100245,1),(246,'BTAC2011',100246,1),(247,'BTAC2012',100247,1),(248,'BTAC2013',100248,1),(249,'BTAC2014',100249,1),(250,'BTAC2015',100250,1),(251,'BTAC2016',100251,1),(252,'BTAC2017',100252,1),(253,'BTAC2018',100253,1),(254,'BTAC2019',100254,1),(255,'BTAC2020',100255,1),(256,'BTAC2021',100256,1),(257,'BTAC2022',100257,1),(258,'BTAC2023',100258,1),(259,'BTAC2024',100259,1),(260,'BTAC2025',100260,1),(261,'BTHP2001',100261,1),(262,'BTHP2002',100262,1),(263,'BTHP2003',100263,1),(264,'BTHP2004',100264,1),(265,'BTHP2005',100265,1),(266,'BTHP2006',100266,1),(267,'BTHP2007',100267,1),(268,'BTHP2008',100268,1),(269,'BTHP2009',100269,1),(270,'BTHP2010',100270,1),(271,'BTHP2011',100271,1),(272,'BTHP2012',100272,1),(273,'BTHP2013',100273,1),(274,'BTBE2001',100275,1),(275,'BTBE2002',100276,1),(276,'BTBE2003',100277,1),(277,'BTBE2004',100278,1),(278,'BTSA2001',100279,1),(279,'BTSA2002',100280,1),(280,'BTSA2003',100281,1),(281,'BTSA2004',100282,1),(282,'BTSA2005',100283,1),(283,'BTSA2006',100284,1),(284,'BTSA2007',100285,1),(285,'BTDE2100',100286,1),(286,'BTDE2101',100287,1),(287,'BTDE2102',100288,1),(288,'BTGA2101',100289,1),(289,'BTLE2101',100290,1),(290,'BTLE2102',100291,1),(291,'BTAC2101',100292,1),(292,'BTAC2102',100293,1),(293,'BTAC2103',100294,1),(294,'BTAC2104',100295,1),(295,'BTAC2105',100296,1),(296,'BTAC2106',100297,1),(297,'BTAC2107',100298,1),(298,'BTAC2108',100299,1),(299,'BTAC2109',100300,1),(300,'BTAC2110',100301,1),(301,'BTAC2111',100302,1),(302,'BTAC2112',100303,1),(303,'BTAC2113',100304,1),(304,'BTAC2114',100305,1),(305,'BTAC2115',100306,1),(306,'BTAC2116',100307,1),(307,'BTAC2117',100308,1),(308,'BTAC2118',100309,1),(309,'BTAC2119',100310,1),(310,'BTAC2120',100311,1),(311,'BTAC2121',100312,1),(312,'BTAC2122',100313,1),(313,'BTAC2123',100314,1),(314,'BTAC2124',100315,1),(315,'BTAC2125',100316,1),(316,'BTAC2126',100317,1),(317,'BTAC2127',100318,1),(318,'BTHP2101',100319,1),(319,'BTHP2102',100320,1),(320,'BTHP2103',100321,1),(321,'BTHP2104',100322,1),(322,'BTHP2105',100323,1),(323,'BTHP2106',100324,1),(324,'BTHP2107',100325,1),(325,'BTHP2108',100326,1),(326,'BTHP2109',100327,1),(327,'BTHP2110',100328,1),(328,'BTHP2111',100329,1),(329,'BTHP2112',100330,1),(330,'BTHP2113',100331,1),(331,'BTHP3000',100332,1),(332,'BTHP3001',100333,1),(333,'BTHP3002',100334,1),(334,'BTHP3003',100335,1),(335,'BTHP3004',100336,1),(336,'BTHP3005',100337,1),(337,'ADAK001',100338,1),(338,'ADAK002',100339,1),(339,'ADAK003',100340,1),(340,'CACN001',100341,1),(341,'CACN003',100342,1),(342,'CACN004',100343,1),(343,'OTAU001',100344,1),(344,'OTAP001',100345,1),(345,'OTAP002',100346,1),(346,'OTIN001',100347,1),(347,'OTIN002',100348,1),(348,'OTIN003',100349,1),(349,'OTIN004',100350,1),(350,'OTIN005',100351,1),(351,'OTIN006',100352,1),(352,'OMHJ001',100353,1),(353,'ANTY001',100354,1),(354,'ANTY002',100355,1),(356,'ANAP001',100357,1),(357,'CALO001',100358,1),(358,'CCPL001',100359,1),(359,'CCPL002',100360,1),(360,'CCMO001',100361,1),(361,'CCMO002',100362,1),(362,'CCNO001',100363,1),(363,'TRTS001*10',100001,10),(364,'TRTT002*10',100002,10),(365,'TRMX003*10',100003,10),(366,'CRLO001+POLO001',100019,1),(367,'CRLO001+POLO001',100017,1),(368,'BALO001+BAIN002',100020,1),(369,'BALO001+BAIN002',100150,1),(370,'BALO005+BALO006',100024,1),(371,'BALO005+BALO006',100025,1),(372,'HSMO001+CCMO001',100043,1),(373,'HSMO001+CCMO001',100361,1),(374,'HSMO002+CCMO001',100044,1),(375,'HSMO002+CCMO001',100361,1),(376,'HSMO011+CCMO001',100053,1),(377,'HSMO011+CCMO001',100361,1),(378,'HSMO012+CCMO001',100054,1),(379,'HSMO012+CCMO001',100361,1),(380,'HSNO005+CCNO001',100067,1),(381,'HSNO005+CCNO001',100363,1),(382,'HSNO006+CCNO001',100068,1),(383,'HSNO006+CCNO001',100363,1),(384,'HSNO016+CCNO001',100077,1),(385,'HSNO016+CCNO001',100363,1),(386,'HSNO019+CCNO001',100080,1),(387,'HSNO019+CCNO001',100363,1),(388,'HSPL001+CCPL001',100098,1),(389,'HSPL001+CCPL001',100359,1),(390,'HSPL009+CCPL001',100106,1),(391,'HSPL009+CCPL001',100359,1),(392,'HSPL013+CCPL001',100110,1),(393,'HSPL013+CCPL001',100359,1),(394,'OTGR001+OTGR002',100139,1),(395,'OTGR001+OTGR002',100140,1),(396,'OTCN004*10',100145,10),(397,'BAIN001+BAIN002+TOIN002',100149,1),(398,'BAIN001+BAIN002+TOIN002',100150,1),(399,'BAIN001+BAIN002+TOIN002',100148,1),(400,'WWSI001+ANCN001',100165,1),(401,'WWSI001+ANCN001',100180,1),(402,'WWSI002+ANCN001',100166,1),(403,'WWSI002+ANCN001',100180,1),(404,'WWSI003+ANCN001',100167,1),(405,'WWSI003+ANCN001',100180,1),(406,'WWSI004+ANCN001',100168,1),(407,'WWSI004+ANCN001',100180,1),(408,'WWSI005+ANCN001',100169,1),(409,'WWSI005+ANCN001',100180,1),(410,'WWSI006+ANCN001',100170,1),(411,'WWSI006+ANCN001',100180,1),(412,'WWOT001+ANCN001',100171,1),(413,'WWOT001+ANCN001',100180,1),(414,'WWOT002+ANCN001',100172,1),(415,'WWOT002+ANCN001',100180,1),(416,'WWOP002+ANCN001',100173,1),(417,'WWOP002+ANCN001',100180,1),(418,'WWOP003+ANCN001',100174,1),(419,'WWOP003+ANCN001',100180,1),(420,'WWOT003+ANCN001',100178,1),(421,'WWOT003+ANCN001',100180,1),(422,'WLAP001+WLAP004',100184,1),(423,'WLAP001+WLAP004',100187,1),(424,'WLAP004*10',100187,10),(425,'WLDE001+ANTY001',100197,1),(426,'WLDE001+ANTY001',100354,1),(427,'WLDE002+ANTY001',100198,1),(428,'WLDE002+ANTY001',100354,1),(429,'WLDE003+ANTY001',100199,1),(430,'WLDE003+ANTY001',100354,1),(431,'WLHP002+ANTY001',100202,1),(432,'WLHP002+ANTY001',100354,1),(433,'WLAT001+ANTY002',100203,1),(434,'WLAT001+ANTY002',100355,1),(435,'WLAT002+ANTY002',100204,1),(436,'WLAT002+ANTY002',100355,1),(437,'WLAT003+ANTY002',100205,1),(438,'WLAT003+ANTY002',100355,1),(439,'WLAT004+ANTY002',100206,1),(440,'WLAT004+ANTY002',100355,1),(441,'WLAT005+ANTY001',100207,1),(442,'WLAT005+ANTY001',100354,1),(443,'WLAT007+ANTY001',100209,1),(444,'WLAT007+ANTY001',100354,1),(445,'WLAT008+ANTY001',100210,1),(446,'WLAT008+ANTY001',100354,1),(447,'WLAT009+ANTY001',100211,1),(448,'WLAT009+ANTY001',100354,1),(449,'WLAT010+ANTY001',100212,1),(450,'WLAT010+ANTY001',100354,1),(451,'WLIN004+ANTY001',100214,1),(452,'WLIN004+ANTY001',100354,1),(453,'WLIN005+ANTY001',100215,1),(454,'WLIN005+ANTY001',100354,1),(455,'WLIN006+ANTY001',100216,1),(456,'WLIN006+ANTY001',100354,1),(457,'WLIN007+ANTY002',100217,1),(458,'WLIN007+ANTY002',100355,1),(459,'WLIN008+ANTY001',100218,1),(460,'WLIN008+ANTY001',100354,1),(461,'WLIN009+ANTY002',100219,1),(462,'WLIN009+ANTY002',100355,1),(463,'WLIN010+ANTY002',100220,1),(464,'WLIN010+ANTY002',100355,1),(465,'WLIN011+ANTY002',100221,1),(466,'WLIN011+ANTY002',100355,1),(467,'WLIN012+ANTY002',100222,1),(468,'WLIN012+ANTY002',100355,1),(469,'CACN001+CACN003',100341,1),(470,'CACN001+CACN003',100342,1),(471,'UDAP001',100364,1),(472,'UDAP002',100365,1),(473,'NTLO001',100366,1),(474,'HSPL014',100367,1),(475,'WLAP005+ANAP001',100188,1),(476,'WLAP005+ANAP001',100357,1),(477,'OT3M001',100368,1),(478,'OTFY001',100369,1),(479,'OT3M001×10',100368,10),(480,'HSNO028',100370,1),(481,'HSSE009',100371,1),(482,'RELO003',100372,1),(483,'MOVI001',100373,1),(484,'',0,0),(485,'MOVI002',100374,1),(486,'MOVI003',100375,1),(487,'MOVI004',100376,1),(488,'RCLO007',100377,1),(489,'OTCN005',100378,1),(490,'OTCN005×10',100378,10),(491,'EXLO001',100379,1),(492,'MOLO004',100380,1),(493,'OTMP001',100381,1),(494,'OTHP004',100382,1),(495,'RCLO008',100383,1),(496,'RCLO008*4',100383,4),(497,'RCLO007+POLO001+RCLO008*4',100377,1),(498,'RCLO007+POLO001+RCLO008*4',100017,1),(499,'RCLO007+POLO001+RCLO008*4',100383,4),(500,'WLIN014',100384,1),(501,'OTHP005',100385,1),(502,'MOMI002',100386,1),(509,'OTES001',100389,1),(508,'KBNO001',100388,1),(507,'OTTP001',100387,1),(510,'HSJA004',100390,1),(511,'REPL001',100391,1),(512,'NTLO002',100392,1),(513,'NTLO001+NTLO002',100366,1),(514,'NTLO001+NTLO002',100392,1),(515,'MOSA005',100393,1),(516,'GLSG001',100394,1),(517,'WLIN015',100395,1),(518,'GLSG001×2',100394,2),(519,'OTSO003',100396,1),(520,'RCDE001',100397,1),(521,'SHLO002',100398,1),(522,'SHLO003',100399,1),(523,'SHLO004',100400,1),(524,'SHLO005',100401,1),(525,'SHLO006',100402,1),(526,'TRMX004',100403,1),(527,'HSJA005',100404,1),(528,'GLSG002',100405,1),(530,'GLSG003',100406,1),(531,'KBFF001',100407,1),(532,'HSSA002',100408,1),(533,'BR3D001',100409,1),(534,'HSJA006',100410,1),(535,'HSJA007',100411,1),(536,'HSJA008',100412,1),(537,'HSJA009',100413,1),(538,'HSPL015',100414,1),(539,'OTPL001',100415,1),(540,'HSPH001',100416,1),(541,'MOAS001',100417,1),(542,'OTLK001',100418,1),(543,'HSSA003',100419,1),(544,'HSSA004',100420,1),(545,'HSNO029',100421,1),(546,'HSMO021',100422,1),(547,'OTSO004',100423,1),(548,'GLSG004',100424,1),(549,'OTGR003',100425,1),(550,'OTGR001+OTGR002+OTGR003',100139,1),(551,'OTGR001+OTGR002+OTGR003',100140,1),(552,'OTGR001+OTGR002+OTGR003',100425,1);
/*!40000 ALTER TABLE `hmsh_ebay_eastar_sku_item` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_eastar_stock`
--

DROP TABLE IF EXISTS `hmsh_ebay_eastar_stock`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_eastar_stock` (
  `item_id` bigint(20) NOT NULL,
  `item_name` varchar(2048) NOT NULL,
  `item_condition` varchar(255) DEFAULT NULL,
  `item_type` varchar(255) DEFAULT NULL,
  `item_stock` int(8) NOT NULL,
  `item_price` double DEFAULT NULL,
  `update_time` datetime DEFAULT NULL,
  PRIMARY KEY (`item_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_eastar_stock`
--

LOCK TABLES `hmsh_ebay_eastar_stock` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_eastar_stock` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_eastar_stock` VALUES (100001,'AUI Transceiver  210TS','New','Computer',107,0,'2011-05-04 21:09:24'),(100002,'AUI Transceiver  210T','New','Computer',5,0,'2011-05-11 19:58:38'),(100003,'AUI Transceiver  MX20T','New','Computer',55,0,'2011-05-08 19:40:54'),(100004,'CAB-SS-2626','New','Computer',118,0,'2011-05-05 23:23:43'),(100005,'CAB-SS-2660','New','Computer',128,0,'2011-05-12 19:40:32'),(100006,'CAB-6060','New','Computer',91,0,'2011-05-11 20:18:52'),(100007,'罗技PRO4000 摄像头（原装）','New','Computer',14,0,'2011-05-10 02:21:20'),(100008,'罗技 diNovo Keyboard+ MediaPad+ dongle used','New','Computer',4,0,'2011-04-07 19:26:27'),(100009,'罗技 880 880pro 890 890pro 屏幕','New','Computer',344,0,'2011-05-09 19:46:28'),(100010,'罗技 MX 鼠标 mat','New','Computer',45,0,'2011-05-10 20:04:12'),(100011,'罗技 880 遥控 新的','New','Computer',0,0,'0000-00-00 00:00:00'),(100012,'罗技 880 遥控  旧的','New','Computer',7,0,'2011-04-19 20:23:28'),(100013,'罗技 890 新的','New','Computer',11,0,'2011-05-04 20:01:31'),(100014,'罗技 515遥控','New','Computer',25,0,'2011-04-28 20:02:49'),(100015,'罗技 525遥控 旧','New','Computer',0,0,'2011-05-05 02:16:25'),(100016,'罗技 628遥控 新 ','New','Computer',82,0,'2011-05-11 20:03:50'),(100017,'罗技 remote adapter US','New','Computer',72,0,'2011-05-14 04:31:25'),(100018,'罗技 harmony 880 890 cradle 旧','New','Computer',0,0,'2011-05-05 19:46:14'),(100019,'罗技 harmony 880 890 cradle 新','New','Computer',57,0,'2011-05-11 22:12:57'),(100020,'罗技遥控电池 蓝色 新 950mah','New','Computer',80,0,'2011-05-11 21:13:35'),(100021,'罗技遥控电池 白色 旧 930mah','New','Computer',23,0,'2011-05-03 07:06:24'),(100022,'罗技遥控电池 白色  1250mah','New','Computer',0,0,'0000-00-00 00:00:00'),(100023,'diNovo 880 890电池 黑色 930mah新','New','Computer',20,0,'0000-00-00 00:00:00'),(100024,'罗技G7 鼠标电池  used','New','Computer',8,0,'2011-05-10 20:38:14'),(100025,'罗技G7 充电器 旧的','New','Computer',0,0,'2011-05-10 20:38:14'),(100026,'罗技遥控电池 蓝色 旧 950mah','New','Computer',28,0,'2011-05-10 20:26:37'),(100027,'Lenovo标志的罗技接收器','New','Computer',-3,0,'2011-05-14 04:41:50'),(100028,'罗技 unifying receiver 优联','New','Computer',93,0,'2011-05-14 05:02:07'),(100029,'罗技 MX1000 mouse 新','New','Computer',11,0,'2011-05-12 19:30:53'),(100030,'罗技 MX1000 蓝牙版 used','New','Computer',2,0,'2011-05-04 19:57:53'),(100031,'罗技 MX1000 电池','New','Computer',79,0,'2011-05-14 05:09:06'),(100032,'罗技H555头戴式耳机','New','Computer',7,0,'2011-04-14 20:08:11'),(100033,'罗技H530盒装耳机','New','Computer',0,0,'2011-04-30 21:45:43'),(100034,'MarantzRC3001型智能摇控','New','Computer',1,0,'2011-04-17 20:16:12'),(100035,'罗技 AIR鼠标外壳','New','Computer',3,0,'2011-04-24 19:19:58'),(100036,'logitech MX518 鼠标 new','New','Computer',8,0,'2011-05-05 19:39:19'),(100037,'logitech MX518 鼠标 used','New','Computer',1,0,'2011-04-30 07:11:58'),(100038,'Altec Lansing im602 白色 US标 电源 全套','New','Computer',3,0,'0000-00-00 00:00:00'),(100039,'Altec Lansing T612','New','Computer',0,0,'2011-04-01 00:48:59'),(100040,'yagi antenna 16dBi','New','Computer',24,0,'2011-05-12 19:44:31'),(100041,'yagi antenna 18dBi','New','Computer',4,0,'2011-05-10 19:53:08'),(100042,'wifly-city IDU-2850UG-U20 plus','New','Computer',0,0,'2011-04-18 19:40:12'),(100043,'motorola S9 单机 红色','New','Computer',21,0,'0000-00-00 00:00:00'),(100044,'motorola S9 单机 黑色','New','Computer',8,0,'2011-04-19 20:13:59'),(100045,'motorola H3单机','New','Computer',20,0,'2011-04-26 19:55:14'),(100046,'motorola H300单机','New','Computer',0,0,'0000-00-00 00:00:00'),(100047,'motorola H350单机','New','Computer',0,0,'0000-00-00 00:00:00'),(100048,'motorola H500单机 ','New','Computer',14,0,'2011-05-14 05:05:41'),(100049,'motorola H550单机','New','Computer',22,0,'2011-05-12 01:23:48'),(100050,'motorola H555单机','New','Computer',49,0,'2011-05-10 20:16:25'),(100051,'motorola H605单机','New','Computer',0,0,'0000-00-00 00:00:00'),(100052,'motorola H670单机 黑色','New','Computer',13,0,'2011-05-14 05:06:09'),(100053,'motorola H700单机','New','Computer',39,0,'2011-05-14 05:04:43'),(100054,'motorola H700 黄金版','New','Computer',0,0,'2011-05-04 21:10:23'),(100055,'motorola H700盒装','New','Computer',13,0,'2011-04-12 20:05:25'),(100056,'motorola H710单机 used','New','Computer',24,0,'2011-05-10 20:01:33'),(100057,'motorola H721单机 used','New','Computer',0,0,'0000-00-00 00:00:00'),(100058,'motorola H800 单机','New','Computer',26,0,'2011-04-19 20:23:56'),(100059,'motorola HS810 单机 电源不同 绿色','New','Computer',9,0,'2011-05-14 04:42:52'),(100060,'motorola HS820 单机 电源不同 黑色 绿色','New','Computer',32,0,'2011-05-10 22:55:50'),(100061,'motorola HS850','New','Computer',70,0,'2011-05-12 20:10:26'),(100062,'motorola S705 ','New','Computer',5,0,'2011-05-08 19:42:01'),(100063,'Nokia BH-102  单机','New','Computer',5,0,'2011-04-24 19:23:22'),(100064,'Nokia BH-102 盒装','New','Computer',2,0,'0000-00-00 00:00:00'),(100065,'Nokia BH-103','New','Computer',10,0,'2011-05-12 03:35:58'),(100066,'Nokia BH-106','New','Computer',10,0,'2011-05-11 04:50:59'),(100067,'Nokia BH-200','New','Computer',54,0,'2011-05-11 19:44:38'),(100068,'Nokia BH-202单机','New','Computer',49,0,'2011-05-12 19:51:20'),(100069,'Nokia BH-203','New','Computer',9,0,'2011-04-30 06:38:00'),(100070,'Nokia BH-204','New','Computer',2,0,'2011-05-11 22:33:17'),(100071,'Nokia BH-205','New','Computer',6,0,'2011-04-19 01:33:59'),(100072,'nokia BH-207 全套 盒装','New','Computer',2,0,'2011-04-08 01:20:22'),(100073,'Nokia BH-209','New','Computer',8,0,'2011-04-20 19:25:21'),(100074,'nokia BH-300单机','New','Computer',7,0,'2011-05-03 04:27:43'),(100075,'nokia BH-302单机','New','Computer',3,0,'2011-04-07 01:04:48'),(100076,'nokia BH-500单机','New','Computer',1,0,'2011-05-11 22:05:38'),(100077,'nokia BH-600单机','New','Computer',5,0,'2011-05-02 23:04:59'),(100078,'nokia BH-800 单机','New','Computer',22,0,'2011-05-07 03:35:42'),(100079,'nokia BH-803','New','Computer',0,0,'0000-00-00 00:00:00'),(100080,'nokia BH-900单机','New','Computer',22,0,'2011-05-09 20:13:07'),(100081,'nokia BH-902 ','New','Computer',0,0,'0000-00-00 00:00:00'),(100082,'Nokia HS-3W','New','Computer',5,0,'2011-04-14 20:40:36'),(100083,'Nokia HS-4W','New','Computer',40,0,'2011-05-13 02:35:16'),(100084,'Nokia HS-11W 单机','New','Computer',5,0,'2011-04-30 21:53:11'),(100085,'Nokia HS-11W 盒装','New','Computer',2,0,'2011-05-09 19:26:37'),(100086,'Nokia HS-12W 单机','New','Computer',5,0,'2011-05-09 19:28:14'),(100087,'Nokia HS-36W 单机 三星电源','New','Computer',3,0,'2011-04-10 08:51:33'),(100088,'Nokia HF-31W','New','Computer',1,0,'0000-00-00 00:00:00'),(100089,'samsung WEP200  盒装','New','Computer',23,0,'2011-04-26 19:30:49'),(100090,'索爱 HBH-600 深蓝 单机','New','Computer',0,0,'0000-00-00 00:00:00'),(100091,'索爱 HBH-608 盒装','New','Computer',0,0,'0000-00-00 00:00:00'),(100092,'索爱 HBH-608 单机','New','Computer',2,0,'2011-05-12 04:20:56'),(100093,'索爱 HBH-PV702','New','Computer',11,0,'2011-05-09 19:35:47'),(100094,'索爱 HBH-PV703','New','Computer',8,0,'2011-05-07 03:42:44'),(100095,'索爱 HBH-PV705','New','Computer',23,0,'2011-05-08 19:28:45'),(100096,'索爱 HBH-DS220 盒装 欧标转换器','New','Computer',5,0,'2011-05-09 19:28:52'),(100097,'索爱 HBH-PV710','New','Computer',3,0,'0000-00-00 00:00:00'),(100098,'PLANTRONICS220 全新单机','New','Computer',69,0,'2011-05-14 04:35:33'),(100099,'PLANTRONICS320 单机+USB线','New','Computer',6,0,'2011-04-26 19:55:53'),(100100,'PLANTRONICS320 盒装','New','Computer',0,0,'2011-04-17 04:48:22'),(100101,'PLANTRONICS330 盒装','New','Computer',1,0,'2011-05-04 19:31:53'),(100102,'PLANTRONICS330 单机','New','Computer',46,0,'2011-05-14 04:08:18'),(100103,'PLANTRONICS340 盒装','New','Computer',0,0,'0000-00-00 00:00:00'),(100104,'PLANTRONICS340 单机','New','Computer',1,0,'2011-05-09 19:22:07'),(100105,'PLANTRONICS925 全新单机 ','New','Computer',0,0,'0000-00-00 00:00:00'),(100106,'PLANTRONIC 851 855','New','Computer',9,0,'2011-05-11 20:12:07'),(100107,'PLANTRONIC 510','New','Computer',157,0,'2011-05-14 04:15:52'),(100108,'PLANTRONIC 520','New','Computer',23,0,'2011-05-14 04:32:11'),(100109,'Plantronics Discovery 640E 全新盒装','New','Computer',0,0,'0000-00-00 00:00:00'),(100110,'PLANTRONICS VOYAGER PRO','New','Computer',2,0,'0000-00-00 00:00:00'),(100111,'捷波朗 Jabra BT250V  ','New','Computer',1,0,'0000-00-00 00:00:00'),(100112,'捷波朗 Jabra BT250','New','Computer',11,0,'2011-05-10 20:16:56'),(100113,'捷波朗 BT320S','New','Computer',5,0,'2011-04-27 20:14:05'),(100114,'艾美特 Ultimate170VI','New','Computer',5,0,'2011-05-11 20:12:42'),(100115,'艾美特 Ultimate220 ','New','Computer',20,0,'2011-04-18 19:32:20'),(100116,'艾美特 Ultimate220VI 带麦的','New','Computer',4,0,'2011-05-14 04:41:08'),(100117,'艾美特 UE 150','New','Computer',9,0,'2011-05-10 01:47:15'),(100118,'森海塞尔 CX 680','New','Computer',8,0,'2011-04-10 08:12:29'),(100119,'森海塞尔 CX 680i','New','Computer',0,0,'0000-00-00 00:00:00'),(100120,'森海塞尔 MX 680 带配件','New','Computer',17,0,'0000-00-00 00:00:00'),(100121,'森海塞尔 MX 680i','New','Computer',6,0,'2011-04-04 21:47:59'),(100122,'森海塞尔 OMX 680 带配件','New','Computer',4,0,'0000-00-00 00:00:00'),(100123,'森海塞尔 OMX 680I 带麦的','New','Computer',0,0,'0000-00-00 00:00:00'),(100124,'森海塞尔 CX280','New','Computer',0,0,'0000-00-00 00:00:00'),(100125,'森海塞尔 CX281','New','Computer',0,0,'0000-00-00 00:00:00'),(100126,'舒尔shure E2C   黑色','New','Computer',20,0,'2011-05-14 05:05:11'),(100127,'舒尔shure E2C  透明','New','Computer',2,0,'2011-05-14 04:33:49'),(100128,'HP 970012','New','Computer',19,0,'2011-05-08 04:57:06'),(100129,'ZAGG品牌电池 ','New','Computer',1,0,'2011-05-14 04:43:25'),(100130,'zagg 车充','New','Computer',5,0,'2011-05-10 20:11:13'),(100131,'WMN1000C','New','Computer',41,0,'2011-05-09 19:39:39'),(100132,'WMN1000B ','New','Computer',35,0,'2011-05-13 02:37:13'),(100133,'WMN1000A ','New','Computer',13,0,'2011-05-05 20:06:27'),(100134,'创新声卡SB1140','New','Computer',0,0,'0000-00-00 00:00:00'),(100135,'诺基亚 LD-3W ','New','Computer',83,0,'2011-05-14 04:05:04'),(100136,'雷凌（Ralink）RT2870F','New','Computer',19,0,'2011-05-12 19:30:08'),(100137,'雷凌（Ralink）RT2870F +CD 包装','New','Computer',1,0,'2011-05-10 20:26:12'),(100139,'Grohe Shower 高仪花洒','New','Computer',41,0,'2011-05-09 19:32:07'),(100140,'Grohe 高仪1.6米的水管','New','Computer',30,0,'2011-05-14 04:58:31'),(100141,'HP media center+remote+emitter','New','Computer',17,0,'2011-05-08 19:14:14'),(100142,'40-Pin 3.5\" to 44-Pin 2.5\" Laptop IDE Hard Drive Cable','New','Computer',23,0,'2011-05-11 21:16:57'),(100143,'IDE 44 Pin laptop 2.5\" Female Hard Drive Cable(2\"44pin)','New','Computer',39,0,'2011-05-13 01:03:42'),(100144,'40pin to 40pin male to female IDE cable ','New','Computer',15,0,'2011-05-13 02:35:56'),(100145,'VGA 转RJ45','New','Computer',310,0,'2011-05-03 06:34:15'),(100146,'LS-10DT canon太阳能计算器','New','Computer',38,0,'0000-00-00 00:00:00'),(100147,'INOVA(爱诺华) T4 手电 透镜版','New','Computer',0,0,'0000-00-00 00:00:00'),(100148,'INOVA(爱诺华) T4 手电 光杯版','New','Computer',2,0,'2011-05-02 04:09:12'),(100149,'INOVA(爱诺华) T4 手电 光杯版电池','New','Computer',15,0,'2011-05-10 19:56:21'),(100150,'光杯版手电充电器110-220V','New','Computer',22,0,'2011-05-02 04:09:12'),(100151,'JEEP 多功能钳 ','New','Computer',13,0,'2011-05-07 02:52:38'),(100152,'Philip HP8309 salonstraight','New','Computer',4,0,'0000-00-00 00:00:00'),(100153,'原装肯辛通 Kensington K64325 专家型轨迹球CAD制图专用','New','Computer',0,0,'0000-00-00 00:00:00'),(100154,'SONY UWA-BR100','New','Computer',24,0,'2011-05-12 19:29:11'),(100155,'SONY原装VGP-DA10 ','New','Computer',3,0,'2011-05-08 04:29:22'),(100156,'VISENTA V1无线键盘黑色','New','Computer',6,0,'2011-05-12 02:38:49'),(100157,'VISENTA V1无线键盘白色','New','Computer',2,0,'0000-00-00 00:00:00'),(100158,'IPAD 带皮套蓝牙键盘 黑色            ','New','Computer',0,0,'2011-05-04 19:59:40'),(100159,'IPAD 蓝牙键盘 白色                       ','New','Computer',0,0,'2011-04-04 06:49:11'),(100160,'苹果原装蓝牙G6键盘                     ','New','Computer',5,0,'2011-03-31 19:57:19'),(100161,'microsoft 8000 mouse','New','Computer',12,0,'2011-05-06 01:17:15'),(100162,'森松尼 SM-EM19 七绝魔蝎 7D鼠标    ','New','Computer',1,0,'0000-00-00 00:00:00'),(100163,'森松尼 SM-8509  5D 鼠标                ','New','Computer',1,0,'0000-00-00 00:00:00'),(100164,'Ajazz 黑爵 幻彩甲虫A1080 有线游戏鼠标 6D ','New','Computer',1,0,'0000-00-00 00:00:00'),(100165,'Sierra Wireless MC8775 通用版','New','Computer',6,0,'0000-00-00 00:00:00'),(100166,'Sierra Wireless MC8775 IBM版','New','Computer',18,0,'2011-05-13 02:38:55'),(100167,'Sierra Wireless MC8775 HP 版 new','New','Computer',0,0,'0000-00-00 00:00:00'),(100168,'Sierra Wireless MC8780 new GPS','New','Computer',3,0,'2011-05-03 19:50:35'),(100169,'Sierra Wireless MC8781 new  GPS','New','Computer',4,0,'2011-05-14 05:10:31'),(100170,'Sierra Wireless MC8790 new','New','Computer',13,0,'2011-05-10 19:59:04'),(100171,'F3507G 通用版 全新','New','Computer',9,0,'2011-05-10 19:45:24'),(100172,'F3507G IBM版 二手','New','Computer',8,0,'2011-03-30 02:49:45'),(100173,'Option GTM 380 new','New','Computer',0,0,'0000-00-00 00:00:00'),(100174,'Option GTM 382 new GPS','New','Computer',6,0,'2011-05-04 20:18:06'),(100175,'华为 EM660','New','Computer',2,0,'2011-04-17 21:42:55'),(100176,'华为EM770','New','Computer',0,0,'0000-00-00 00:00:00'),(100177,'华为EM770W','New','Computer',0,0,'0000-00-00 00:00:00'),(100178,'F3607GW 通用','New','Computer',7,0,'2011-04-13 20:11:16'),(100179,'半高卡架子 braket','New','Computer',18,0,'2011-05-11 20:02:40'),(100180,'3G wwan 天线','New','Computer',160,0,'2011-05-13 02:38:55'),(100181,'IBM X200 antenna','New','Computer',3,0,'2011-05-12 00:38:04'),(100182,'IBM X200T antenna','New','Computer',10,0,'2011-05-13 03:10:12'),(100183,'DWL-G122','New','Computer',7,0,'2011-05-14 04:57:03'),(100184,'airport I  旧','New','Computer',40,0,'2011-05-10 20:23:50'),(100185,'airport extreme 旧','New','Computer',282,0,'2011-05-04 20:05:58'),(100186,'airport extreme 新的','New','Computer',8,0,'0000-00-00 00:00:00'),(100187,'adapter ','New','Computer',36,0,'2011-05-10 20:23:50'),(100188,'apple 4321','New','Computer',11,0,'2011-05-05 20:10:07'),(100189,'apple 4322  BCM94322MC 旧的','New','Computer',0,0,'0000-00-00 00:00:00'),(100190,'apple 4322 BCM94322MC 新的','New','Computer',0,0,'0000-00-00 00:00:00'),(100191,'apple AR9280 AR5BXB92','New','Computer',31,0,'2011-05-14 05:09:26'),(100192,'apple USB 猫 旧 2针 旧的','New','Computer',12,0,'2011-05-05 19:44:15'),(100193,'apple mighty mouse 新','New','Computer',2,0,'2011-05-14 04:10:51'),(100194,'apple Ipad dock','New','Computer',2,0,'0000-00-00 00:00:00'),(100195,'intel 622AGXHMW','New','Computer',21,0,'2011-05-12 19:55:25'),(100196,'IBM 6250 ANX','New','Computer',3,0,'0000-00-00 00:00:00'),(100197,'dell 4321','New','Computer',2,0,'2011-04-21 19:29:56'),(100198,'DELL 1510','New','Computer',-8,0,'2011-05-10 19:49:27'),(100199,'DW 1520 半高 旧的','New','Computer',0,0,'2011-04-10 07:48:54'),(100200,'HP 4322 二手 BCM94322MC 全高  ','New','Computer',0,0,'0000-00-00 00:00:00'),(100201,'broadcom 半高4322','New','Computer',0,0,'0000-00-00 00:00:00'),(100202,'HP版 BCM4322半高卡 ','New','Computer',46,0,'2011-04-20 19:29:21'),(100203,'atheros 5008 新','New','Computer',38,0,'2011-05-14 04:06:28'),(100204,'atheros 5008 旧','New','Computer',0,0,'2011-04-11 00:15:16'),(100205,'IBM AR5008','New','Computer',3,0,'2011-04-07 19:32:27'),(100206,'HP AR5008','New','Computer',3,0,'0000-00-00 00:00:00'),(100207,'atheros 5424  IBM','New','Computer',2,0,'2011-04-30 07:10:58'),(100208,'atheros 5213A  IBM','New','Computer',5,0,'2011-05-02 19:00:49'),(100209,'AR9287','New','Computer',15,0,'2011-05-02 19:22:01'),(100210,'AR5B93 半高 新','New','Computer',11,0,'2011-04-27 19:46:40'),(100211,'AR5B95 半高 新 AR9285','New','Computer',10,0,'2011-05-12 19:45:05'),(100212,'atheros 9281 新','New','Computer',19,0,'0000-00-00 00:00:00'),(100213,'intel 4965','New','Computer',0,0,'0000-00-00 00:00:00'),(100214,'intel 5150半高 正式 新','New','Computer',8,0,'2011-04-20 20:01:23'),(100215,'intel 5150 通用全高','New','Computer',0,0,'0000-00-00 00:00:00'),(100216,'intel 5150 全高 IBM版','New','Computer',8,0,'0000-00-00 00:00:00'),(100217,'intel 5350 正式版 IBM','New','Computer',0,0,'0000-00-00 00:00:00'),(100218,'intel 5100 半高卡 ','New','Computer',0,0,'0000-00-00 00:00:00'),(100219,'intel 5300半高  正式 新','New','Computer',18,0,'2011-05-08 20:22:55'),(100220,'intel 5300 全高卡 正式 新','New','Computer',35,0,'2011-05-14 04:13:22'),(100221,'intel 5300 全高卡 IBM ','New','Computer',9,0,'0000-00-00 00:00:00'),(100222,'intel 5350 ','New','Computer',8,0,'2011-04-17 19:31:41'),(100223,'Marvell 88W8363 通用版','New','Computer',7,0,'2011-04-07 04:13:56'),(100224,'Powchip POW-N18','New','Computer',5,0,'0000-00-00 00:00:00'),(100225,'2.0单独模块','New','Computer',20,0,'0000-00-00 00:00:00'),(100226,'Dell mini 9','New','Computer',8,0,'2011-04-18 20:21:07'),(100227,'Dell mini10 10v 1010 1011','New','Computer',8,0,'2011-04-27 20:04:27'),(100228,'gateway P-7811 P-7805U P-7801U','New','Computer',6,0,'2011-04-01 19:36:37'),(100229,'S10  OEM','New','Computer',8,0,'2011-04-19 01:58:39'),(100230,'S10-2 8pin 1.0 8cm 五线连接','New','Computer',5,0,'2011-04-26 19:51:15'),(100231,'华硕10pin 0.8 6cm (A8/Z99/F8/N80/U5/U6/EEEPC1101HA/EEEPC1005/W5F)','New','Computer',7,0,'2011-04-30 07:30:24'),(100232,'华硕10pin 0.8 10cm (V1S/E99/F8/N80)','New','Computer',5,0,'0000-00-00 00:00:00'),(100233,'华硕 10pin 1.0 15cm (F5/Z53/F3/M51/G50)','New','Computer',6,0,'2011-05-06 02:33:55'),(100234,'华硕 10 pin 1.0 5cm ( epc901 epc1000)','New','Computer',5,0,'2011-05-12 19:41:53'),(100235,'华硕 8pin 1.0 6cm (G1S/A6/Z92)','New','Computer',10,0,'2011-03-30 03:13:33'),(100236,'acer 4pin 1.25 3cm (Timeline 4810 4810T 5810 3820T)','New','Computer',8,0,'0000-00-00 00:00:00'),(100237,'acer 4pin1.25 4cm (AS 5540 5542, 5560 5562, 5590 5595 )','New','Computer',3,0,'0000-00-00 00:00:00'),(100238,'acer 4pin1.25 5cm (As 4310 4310G 4710 4710G 4920 4920G)','New','Computer',5,0,'0000-00-00 00:00:00'),(100239,'acer 4pin1.25 6cm(T M 4720 4320 Extensa 4620 4620z 4220， Aspire 7738G 5740 8730 7738 7740)','New','Computer',9,0,'2011-05-04 20:14:45'),(100240,'acer 4pin1.25 8cm (AS 5235 5335 5535 5735 5735Z 5738Z 5338)','New','Computer',4,0,'2011-04-21 00:42:14'),(100241,'acer 4pin1.25 15cm (TravelMate 5720 5720G 5320, Extensa 5420 5420G  5220, 5620, 5620Z Aspire 5550 5551 5552)','New','Computer',7,0,'0000-00-00 00:00:00'),(100242,'Acer  4pin 1.25 15cm （aspire D250）薄型黑色头','New','Computer',9,0,'0000-00-00 00:00:00'),(100243,'acer 4pin1.25 18cm  (AS 9410 9411 9420 9423 9424 7110 7000 9300 Travelmate  5110 5610 5620 7510 7512 7513 7514)','New','Computer',4,0,'2011-04-24 02:37:07'),(100244,'acer 4pin1.25 20cm (TM 5520 5530)','New','Computer',13,0,'0000-00-00 00:00:00'),(100245,'acer 5pin 1.25 3cm ( Aspire Timeline 1810 1410 1410T)','New','Computer',10,0,'2011-04-08 04:35:09'),(100246,'acer 5pin1.25 4cm (AS 4230 4530 7730 7730g 7730Z Travelmate 7730 7730A ','New','Computer',4,0,'2011-05-07 03:33:15'),(100247,'acer 5pin1.25 6cm   (AS 6930 6530 6530G 6930G Extensa 5235) ','New','Computer',6,0,'2011-04-17 08:49:20'),(100248,'acer 5pin1.25 15cm (AS 5920 5920G)','New','Computer',2,0,'2011-04-09 07:09:48'),(100249,'acer 5pin1.25 20cm (4720 4720G 4720Z 4320 4220 4220G 4520 4520G AO751h)','New','Computer',13,0,'2011-04-06 19:25:32'),(100250,'acer 6pin1.25 23cm (AS 3680 5580 5570 5570z 5050 ) ','New','Computer',-4,0,'2011-05-11 21:14:24'),(100251,'acer 8pin0.8 16cm   (AS 6920 6920G 6935 6935G)','New','Computer',5,0,'2011-04-04 07:01:19'),(100252,'acer 8pin1.0 3cm (AS 3810 3810T)','New','Computer',5,0,'2011-04-17 19:44:40'),(100253,'acer 8pin 1.0 (4连线）5cm aspire  D150 ','New','Computer',3,0,'0000-00-00 00:00:00'),(100254,'acer 8pin1.00 6cm  (AS 4730 4930 4730G 4930G 4730z 4930z)','New','Computer',12,0,'2011-04-26 20:08:33'),(100255,'acer 8pin1.00 6cm （AS 8920 8920G 8930) 线序不同','New','Computer',2,0,'0000-00-00 00:00:00'),(100256,'acer 8pin1.00 8cm (AS 5100 5110 3100  5680 5630 3690 TravelMate 5210 5510 2400 3210 3220 3230 4280 4230 2490. Extensa 5010 5410)','New','Computer',0,0,'2011-05-14 05:02:58'),(100257,'acer 8pin1.00 15cm (AS 5620 5672 5720 5720G 5220 5220G 5310 5310G 5710 5710G 7720 7720G 7720Z )','New','Computer',3,0,'2011-04-30 21:44:23'),(100258,'acer 8pin1.00 18cm (AS 5520 5520G 5530 )','New','Computer',8,0,'0000-00-00 00:00:00'),(100259,'acer 8pin1.25 10cm (TM 3000 3020 3040 TM3002  TravelMate 4210 4270 4670 AS5760 )','New','Computer',9,0,'2011-05-03 07:00:30'),(100260,'acer 8pin1.25 35cm (Aspire 3500 )','New','Computer',1,0,'0000-00-00 00:00:00'),(100261,'HP 8pin 1.0 3cm  (HP Compaq nw8000 nc8230 nw8240 nw8440 \nHP mini 2133 2140\nHP Compaq NX7300 NX7400)','New','Computer',4,0,'0000-00-00 00:00:00'),(100262,'HP 8pin 1.0 3cm 线序反 (HP Pavilion zd8000, Compaq Presario x6000, HP Compaq nx9600)','New','Computer',2,0,'0000-00-00 00:00:00'),(100263,'\nHP 8pin 1.0 12cm (Pavilion DV2000 DV2100 DV2200 DV2500 DV2600 DV2700 DV2800 DV2900\nPavilion DV8000 DV8100 DV8200 DV8300 DV8400\nPresario V4000 V4100 V4200 V4400\nPresario V3000 V3100 V3400 V3600)','New','Computer',2,0,'2011-04-04 05:56:58'),(100264,'HP 8pin 1.0 18cm 4线连 (HP ProBook 4410S 4411S 4415S 4416S 4510S 4515S 4710S)','New','Computer',6,0,'0000-00-00 00:00:00'),(100265,'HP 8pin 1.0 20cm (HP Compaq nc6220 nc6230 8710w nw9440 nx9420)','New','Computer',2,0,'0000-00-00 00:00:00'),(100266,'HP 8pin 1.0 20cm 线序反的 (HP Compaq NC6320 NC6400)','New','Computer',5,0,'0000-00-00 00:00:00'),(100267,'HP 8pin 1.0 23cm (NC4200 NC4400 TC4200 TC4400 Compaq Presario CQ45, HP Pavilion DV4 Pavilion DV7\nDV5000 V5000','New','Computer',5,0,'2011-04-27 20:12:34'),(100268,'HP 8pin 1.0 25cm 4线连 (HP Compaq 6530S 6531S 6535S)','New','Computer',4,0,'0000-00-00 00:00:00'),(100269,'HP 8pin 1.25 3cm (HP Pavilion ZE2000 ZE2200 ZE2300 ZE2500\nHP Pavilion DV1000 DV1100 DV1300 DV1500 DV1600 DV1700\nCompaq Presario V2000 V2100 V2200 V2300 V2400 V2600 M2000 M2200 M2500)','New','Computer',2,0,'0000-00-00 00:00:00'),(100270,'HP 8pin 1.25 18cm (Pavilion DV6000 DV6000t DV6000z DV6100 DV6200 \nDV6300 DV6400 DV6500 DV6500t DV6500z \nDV6700 DV6700t DV6700z DV6800 DV6900)','New','Computer',2,0,'2011-04-01 19:38:44'),(100271,'HP 8pin 1.25 25cm (Pavilion DV9000 DV9000Z DV9100 DV9200 DV9800 DV9900\nDV9500 DV9500t DV9500z DV9700 DV9700t DV9700z )','New','Computer',1,0,'0000-00-00 00:00:00'),(100272,'HP 8pin 0.8 3cm (Presario TX1000 TX1000z TX1200 TX2000 TX2000z TX2015 TX2500 TX2500z TX2z)','New','Computer',4,0,'0000-00-00 00:00:00'),(100273,'HP 6pin 1.0 12cm (Pavilion DV5 HDX X16)','New','Computer',9,0,'0000-00-00 00:00:00'),(100274,'??','New','Computer',0,0,'0000-00-00 00:00:00'),(100275,'benq s31/s32/t31','New','Computer',1,0,'0000-00-00 00:00:00'),(100276,'benq s41/s42','New','Computer',1,0,'0000-00-00 00:00:00'),(100277,'benq s61','New','Computer',1,0,'0000-00-00 00:00:00'),(100278,'benq r55','New','Computer',1,0,'0000-00-00 00:00:00'),(100279,'samsung r40/r70/r45','New','Computer',1,0,'0000-00-00 00:00:00'),(100280,'samsung r453','New','Computer',1,0,'0000-00-00 00:00:00'),(100281,'samsung r18/r25/r20','New','Computer',0,0,'2011-04-14 20:10:35'),(100282,'samsung nc10/nd10/nc20  4pin 1.25 R620 N110 N120 N140','New','Computer',0,0,'2011-05-10 20:22:40'),(100283,'samsung q1/q1u','New','Computer',2,0,'0000-00-00 00:00:00'),(100284,'samsung x11','New','Computer',1,0,'0000-00-00 00:00:00'),(100285,'samsung x9','New','Computer',1,0,'0000-00-00 00:00:00'),(100286,'2.1单独模块','New','Computer',7,0,'2011-05-05 19:54:13'),(100287,'Dell mini 9 J613H','New','Computer',-1,0,'0000-00-00 00:00:00'),(100288,'Dell mini10 10v 1010 1011','New','Computer',8,0,'2011-04-18 19:48:27'),(100289,'gateway P-7811 P-7805U P-7801U','New','Computer',0,0,'2011-04-04 06:19:13'),(100290,'S10  OEM','New','Computer',24,0,'0000-00-00 00:00:00'),(100291,'S10-2 8pin 1.0 8cm 五线连接','New','Computer',5,0,'2011-04-11 19:38:11'),(100292,'acer 4pin1.25 3cm (Timeline 4810 5810)','New','Computer',5,0,'0000-00-00 00:00:00'),(100293,'acer 4pin1.25 4cm (AS 5540 5542, 5560 5562, 5590 5595 )','New','Computer',11,0,'0000-00-00 00:00:00'),(100294,'acer 4pin1.25 5cm (As 4310 4310G 4710 4710G 4920 4920G)','New','Computer',4,0,'0000-00-00 00:00:00'),(100295,'acer 4pin1.25 6cm (TM 4720 4320 Extensa 4620 4620z 4220 4200，Aspire 7738G 5740 8730 7735 7738 7740)','New','Computer',7,0,'2011-04-27 20:05:08'),(100296,'acer 4pin1.25 8cm (AS 5235 5335 5535 5735 5735Z 5738Z 5338 5536 5236 5536G)','New','Computer',6,0,'0000-00-00 00:00:00'),(100297,'acer 4pin1.25 15cm (TravelMate 5720 5720G 5320, Extensa 5420 5420G  5220, 5620, 5620Z Aspire 5550 5551 5552)','New','Computer',5,0,'2011-05-02 04:11:37'),(100298,'Acer 4pin 1.25 15cm （aspire D250）薄型黑色头','New','Computer',4,0,'0000-00-00 00:00:00'),(100299,'acer 4pin1.25 18cm  (AS 9410 9411 9420 9423 9424 7110 7000 9300 Travelmate  5110 5610 5620 7510 7512 7513 7514)','New','Computer',6,0,'0000-00-00 00:00:00'),(100300,'acer 4pin1.25 20cm (TM 5520 5530)','New','Computer',5,0,'2011-04-27 19:45:40'),(100301,'acer 5pin 1.0 3cm （AS 4745 4820T）','New','Computer',6,0,'0000-00-00 00:00:00'),(100302,'Acer 5pin1.25 3cm ( Aspire Timeline 1810 1410 1410T 1810T 1810TZ) ','New','Computer',4,0,'2011-04-27 20:06:29'),(100303,'acer 5pin1.25 4cm (AS 4230 4530 7730 7730g 7730Z Travelmate 7730 7730A ','New','Computer',11,0,'2011-04-27 04:14:06'),(100304,'acer 5pin1.25 6cm   (AS 6930 6530 6530G 6930G Extensa 5235) ','New','Computer',2,0,'2011-05-03 19:54:26'),(100305,'acer 5pin1.25 15cm (AS 5920 5920G)','New','Computer',10,0,'2011-05-08 19:33:12'),(100306,'acer 5pin1.25 20cm (AS 4720 4720G 4720Z 4320 4220 4220G 4520 4520G AO751h)','New','Computer',11,0,'2011-03-31 02:11:58'),(100307,'acer 6pin1.25 23cm (AS 3680 5580 5570 5570z 5050 ) ','New','Computer',13,0,'2011-04-11 19:37:20'),(100308,'acer 8pin0.8 16cm   (AS 6920 6920G 6935 6935G)','New','Computer',4,0,'0000-00-00 00:00:00'),(100309,'acer 8pin1.0 3cm (AS 3810 3810T, Timeline 3810 3810T)','New','Computer',10,0,'2011-05-14 04:39:54'),(100310,'acer 8pin 1.0 5cm (4连线） aspire D150 ','New','Computer',5,0,'0000-00-00 00:00:00'),(100311,'acer 8pin1.0 6cm  (AS 4730 4930 4730G 4930G 4730z 4930z)','New','Computer',11,0,'0000-00-00 00:00:00'),(100312,'acer 8pin1.00 6cm （AS 8920 8920G 8930 ) 线序不同','New','Computer',13,0,'0000-00-00 00:00:00'),(100313,'acer 8pin1.00 8cm (AS 5100 5110 3100  5680 5630 3690 TravelMate 5210 5510 2400 3210 3220 3230 4280 4230 2490. Extensa 5010 5410)','New','Computer',14,0,'2011-04-28 19:45:30'),(100314,'acer 8pin1.00 10cm （AS4740）','New','Computer',2,0,'2011-04-14 19:34:16'),(100315,'acer 8pin1.00 15cm (AS 5620 5672 5720 5720G 5220 5220G 5310 5310G 5710 5710G 7720 7720G 7720Z  TravelMate 4210 4270 4670)','New','Computer',8,0,'2011-04-25 01:17:39'),(100316,'acer 8pin1.00 18cm (AS 5520 5520G 5530 )','New','Computer',10,0,'0000-00-00 00:00:00'),(100317,'acer 8pin1.25 10cm (TM 3000 3020 3040 TM3002  TravelMate 4210 4270 4670 AS5760 )','New','Computer',3,0,'2011-05-14 04:49:16'),(100318,'acer 8pin1.25 35cm (Aspire 3500 )','New','Computer',2,0,'0000-00-00 00:00:00'),(100319,'HP 8pin 1.0 3cm  (HP Compaq nw8000 nc8230 nw8240 nw8440 \nHP mini 2133 2140\nHP Compaq NX7300 NX7400)','New','Computer',5,0,'2011-04-14 20:03:13'),(100320,'HP 8pin 1.0 3cm 线序反 (HP Pavilion zd8000, Compaq Presario x6000, HP Compaq nx9600)','New','Computer',5,0,'2011-04-17 19:59:00'),(100321,'HP 8pin 1.0 12cm (Pavilion DV2000 DV2100 DV2200 DV2500 DV2600 DV2700 DV2800 DV2900\nPavilion DV8000 DV8100 DV8200 DV8300 DV8400\nPresario V4000 V4100 V4200 V4400\nPresario V3000 V3100 V3400 V3600)','New','Computer',0,0,'2011-05-03 20:12:09'),(100322,'HP 8pin 1.0 18cm 4线连 (HP ProBook 4410S 4411S 4415S 4416S 4510S 4515S 4710S)','New','Computer',3,0,'2011-04-22 00:33:40'),(100323,'HP 8pin 1.0 20cm (HP Compaq nc6220 nc6230 8710w nw9440 nx9420)','New','Computer',3,0,'2011-04-24 03:42:32'),(100324,'HP 8pin 1.0 20cm 线序反的 (HP Compaq NC6320 NC6400)','New','Computer',5,0,'0000-00-00 00:00:00'),(100325,'HP 8pin 1.0 23cm (NC4200 NC4400 TC4200 TC4400 Compaq Presario CQ45, HP Pavilion DV4 Pavilion DV7\nDV5000 V5000','New','Computer',0,0,'2011-05-14 05:04:11'),(100326,'HP 8pin 1.0 25cm 4线连 (HP Compaq 6530S 6531S 6535S)','New','Computer',6,0,'0000-00-00 00:00:00'),(100327,'HP 8pin 1.25 3cm (HP Pavilion ZE2000 ZE2200 ZE2300 ZE2500\nHP Pavilion DV1000 DV1100 DV1300 DV1500 DV1600 DV1700\nCompaq Presario V2000 V2100 V2200 V2300 V2400 V2600 M2000 M2200 M2500)','New','Computer',3,0,'2011-04-14 20:36:42'),(100328,'HP 8pin 1.25 18cm (Pavilion DV6000 DV6000t DV6000z DV6100 DV6200 \nDV6300 DV6400 DV6500 DV6500t DV6500z \nDV6700 DV6700t DV6700z DV6800 DV6900)','New','Computer',-2,0,'2011-04-20 19:54:14'),(100329,'HP 8pin 1.25 25cm (Pavilion DV9000 DV9000Z DV9100 DV9200 DV9800 DV9900\nDV9500 DV9500t DV9500z DV9700 DV9700t DV9700z )','New','Computer',5,0,'2011-05-03 00:28:11'),(100330,'HP 8pin 0.8 3cm (Presario TX1000 TX1000z TX1200 TX2000 TX2000z TX2015 TX2500 TX2500z TX2z)','New','Computer',-8,0,'2011-05-08 04:42:15'),(100331,'HP 6pin 1.0 12cm (Pavilion DV5 HDX X16)','New','Computer',2,0,'2011-05-10 00:40:45'),(100332,'3.0单独模块','New','Computer',-1,0,'2011-05-13 00:01:26'),(100333,'HP 5pin1.0 20cm (CQ42，G42)','New','Computer',4,0,'2011-03-30 19:39:43'),(100334,'HP 6pin1.0 3cm (probook 4321s 4421s 4325s 4326s \n4425s 5220m MINI311) ','New','Computer',4,0,'0000-00-00 00:00:00'),(100335,'Hp 8pin1.0 3cm (mini5101 mini5102)','New','Computer',3,0,'0000-00-00 00:00:00'),(100336,'HP 8pin1.0 8cm ( 5310M) \n','New','Computer',3,0,'0000-00-00 00:00:00'),(100337,'HP 8pin1.0 18cm (probook 4311s )','New','Computer',5,0,'0000-00-00 00:00:00'),(100338,'AKE BC168','New','Computer',1,0,'2011-05-08 04:03:26'),(100339,'AKE BC188 ','New','Computer',3,0,'2011-05-04 03:18:47'),(100340,'AKE BC268 四口','New','Computer',0,0,'2011-04-08 01:18:28'),(100341,'IBM Thinkpad 2nd HDD Caddy for T40 T60 ','New','Computer',9,0,'2011-05-08 19:45:16'),(100342,'DVD slim for T40','New','Computer',13,0,'2011-05-09 21:03:20'),(100343,'苹果硬盘托架 ','New','Computer',28,0,'2011-05-14 04:57:27'),(100344,'AuthenTec 指纹仪 指纹加密识别器','New','Computer',24,0,'0000-00-00 00:00:00'),(100345,'APC Password Fingerprint Manager USB','New','Computer',3,0,'2011-05-14 04:51:33'),(100346,'APC UPB50','New','Computer',1,0,'0000-00-00 00:00:00'),(100347,'PVDM-256K-4','New','Computer',27,0,'0000-00-00 00:00:00'),(100348,'PVDM-256K-8','New','Computer',36,0,'2011-04-19 19:32:51'),(100349,'PVDM-256K-12','New','Computer',11,0,'2011-04-26 00:42:26'),(100350,'PVDM2-8','New','Computer',0,0,'0000-00-00 00:00:00'),(100351,'PVDM2-16','New','Computer',28,0,'2011-04-21 19:52:32'),(100352,'PVDM2-32','New','Computer',2,0,'0000-00-00 00:00:00'),(100353,'HJ-112','New','Computer',126,0,'2011-05-12 19:37:31'),(100354,'黄膜天线*2','New','Computer',65,0,'2011-05-11 20:02:48'),(100355,'黄膜天线*3','New','Computer',73,0,'2011-05-14 04:13:22'),(100357,'APPLE天线','New','Computer',99,0,'2011-04-12 19:51:06'),(100358,'罗技USB线','New','Computer',96,0,'2011-05-11 19:55:16'),(100359,'缤特力车充','New','Computer',91,0,'2011-05-07 23:01:41'),(100360,'缤特力车充','New','Computer',100,0,'0000-00-00 00:00:00'),(100361,'MOTOV3车充','New','Computer',97,0,'2011-05-12 03:18:20'),(100362,'MOTOV8车充','New','Computer',100,0,'0000-00-00 00:00:00'),(100363,'诺记亚细头车充','New','Computer',87,0,'2011-04-30 06:18:46'),(100364,'apple 8GB USB FLASH DRIVE','new','computer',57,100,'2011-05-12 20:07:57'),(100365,'apple 8GB install driver','new','computer',2,100,'2011-04-24 19:45:09'),(100366,'Logitech IO notebook','new','computer',0,15,'2011-05-02 04:25:57'),(100367,'PLANTRONIC Calisto pro','new','computer',29,70,'2011-05-14 05:03:39'),(100368,'3M 9322 respirator','new','computer',9,28,'2011-04-14 20:26:40'),(100369,'FY-II audible radiometer ','new','computer',1,598,NULL),(100370,'nokia BH-700单机 ','new','computer',1,55,'2011-04-20 19:19:54'),(100371,'索爱 HBH-DS200  欧标电源','new','computer',10,150,'2011-04-28 20:09:24'),(100372,'logitech nano receiver','new','computer',38,35,'2011-05-14 04:54:53'),(100373,'VISENTA i0 mouse','new','computer',3,50,'2011-04-17 08:59:29'),(100374,'VISENTA i4 mouse','new','computer',5,57,NULL),(100375,'VISENTA i5 mouse ','new','computer',1,99,NULL),(100376,'VISENTA i6 mouse  ','new','computer',4,60,NULL),(100377,'罗技 890 extender ','used','computer',7,85,'2011-05-14 04:31:25'),(100378,'VGA 转RJ45 white','new','computer',60,3.5,NULL),(100379,'Lenovo 4337 笔记本扩展坞','new','computer',4,250,'2011-05-11 01:32:17'),(100380,'logitech MX518 鼠标new 华硕限量版','new','computer',3,120,'2011-05-08 04:21:24'),(100381,'2.8\'\' 4G MP4  黑/白 ','new','computer',2,145,NULL),(100382,'HP media centre+big receiver+emitter','new','computer',19,50,'2011-04-23 01:09:47'),(100383,'Logitech 890 emitter 单头','new','computer',12,5,'2011-05-14 04:31:25'),(100384,'intel 6250 622ANXHMW 通用','new','computer',4,180,'2011-05-12 04:16:33'),(100385,'HP midia centre+emitter','new','computer',19,32,'2011-05-12 19:41:05'),(100386,'micorsoft 极动鲨 mouse','new','computer',5,40,'2011-05-04 22:24:03'),(100387,'TP-LINK TL-WN821N ','new','computer',4,84,'2011-05-10 19:47:54'),(100388,'NOKIA SU-8W蓝牙键盘','new','computer',1,265,NULL),(100389,'ESI maya44 声卡','new','computer',0,195,'2011-05-11 20:08:55'),(100390,'Jabra JX10 headset','new','computer',8,50,'2011-05-09 19:41:42'),(100391,'plantronics BUA-100 receiver','new','computer',10,23,NULL),(100392,'logitech IO 数码笔','new','computer',5,95,NULL),(100393,'WMN2000B','new','computer',20,250,'2011-05-02 19:32:46'),(100394,'Samsung SSG-2100AB 3D眼镜 ','new','computer',29,200,'2011-05-13 01:19:14'),(100395,'BCM94313 BCM2070  无线蓝牙二合一','new','computer',6,35,'2011-05-08 04:15:32'),(100396,'sony TDG-BR100 3D glasses','new','computer',0,399,'2011-05-02 04:39:11'),(100397,'DENON RC-969遥控','new','computer',0,158,'2011-05-04 23:25:19'),(100398,'罗技M950鼠标外壳  ','new','computer',9,50,'2011-05-11 20:15:48'),(100399,'罗技M705鼠标外壳  ','new','computer',2,30,NULL),(100400,'罗技MX518鼠标外壳   ','new','computer',2,32,NULL),(100401,'罗技M905鼠标外壳 ','new','computer',-1,40,'2011-05-11 00:49:45'),(100402,'罗技G500鼠标外壳','new','computer',2,40,NULL),(100403,'AUI Transceiver 210TS new in box','new','computer',5,40,NULL),(100404,'捷波朗 Jabra BT2080 box','new','computer',1,50,'2011-05-10 20:05:16'),(100405,'samsung SSG-P2100S 3D glasses box','new','computer',22,470,'2011-05-12 20:09:26'),(100406,'samsung SSG-2200KR 3D眼镜 box','new','computer',4,330,'2011-05-14 04:45:04'),(100407,'FireFly keyboard','new','computer',0,95,'2011-05-12 19:50:05'),(100408,'samsung WEP200 box black','new','computer',9,50,'2011-05-13 02:45:36'),(100409,'samsung 3D Blu-ray 3 imax','new','computer',71,10,'2011-05-14 04:59:00'),(100410,'Jabra BT125','new','computer',10,35,NULL),(100411,'Jabra BT135 ','new','computer',10,38,NULL),(100412,'Jabra BT800  ','new','computer',5,80,NULL),(100413,'Jabra 9460 box','new','computer',1,600,NULL),(100414,'PLANTRONIC headset 903','new','computer',5,160,NULL),(100415,'plantronics 音频发射器','new','computer',2,60,NULL),(100416,'Philips SHB6100/02/93 ','new','computer',1,210,NULL),(100417,'ASUS N554 蓝牙鼠标无接收器','new','computer',2,60,NULL),(100418,'linksys  DMP-100 ','new','computer',1,330,NULL),(100419,'samsung  wep250 ','new','computer',5,35,NULL),(100420,'samsung  wep300','new','computer',5,45,NULL),(100421,'Nokia BH-103 盒装','New','computer',1,95,'2011-05-12 19:38:16'),(100422,'motorola H710 new','new','computer',8,80,NULL),(100423,'sony TDG-BR250 3D glasses','new','computer',29,280,NULL),(100424,'samsung SSG-P2100X  3D眼镜 box','new','computer',20,450,NULL),(100425,'Grohe 高仪 花洒座 ','new','computer',5,40,NULL);
/*!40000 ALTER TABLE `hmsh_ebay_eastar_stock` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_eastar_transaction`
--

DROP TABLE IF EXISTS `hmsh_ebay_eastar_transaction`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_eastar_transaction` (
  `id` int(8) NOT NULL AUTO_INCREMENT,
  `transaction_ID` bigint(20) NOT NULL,
  `ebay_itemID` bigint(20) NOT NULL,
  `ebay_itemTitle` varchar(2048) DEFAULT NULL,
  `quantity` tinyint(4) DEFAULT NULL,
  `hmsh_sku` varchar(255) DEFAULT NULL,
  `amountPaid` double DEFAULT NULL,
  `ebay_sellerID` varchar(255) DEFAULT NULL,
  `ebay_buyerID` varchar(255) DEFAULT NULL,
  `ebay_buyerEmail` varchar(255) DEFAULT NULL,
  `shipping_name` varchar(255) DEFAULT NULL,
  `shipping_street` varchar(1024) DEFAULT NULL,
  `shipping_city` varchar(255) DEFAULT NULL,
  `shipping_state` varchar(255) DEFAULT NULL,
  `shipping_country` varchar(255) DEFAULT NULL,
  `shipping_zip` varchar(255) DEFAULT NULL,
  `shipping_phone` varchar(255) DEFAULT NULL,
  `ebaypaymentstatus` varchar(255) DEFAULT NULL,
  `checkoutstatus` varchar(255) DEFAULT NULL,
  `shippingservice` varchar(255) DEFAULT NULL,
  `paid_time` datetime DEFAULT NULL,
  `shippingstatus` tinyint(4) DEFAULT '0',
  `shipping_time` datetime DEFAULT NULL,
  `item_status` tinyint(4) NOT NULL DEFAULT '0',
  `stock_status` tinyint(4) NOT NULL DEFAULT '0',
  `shipping_method` tinyint(4) NOT NULL DEFAULT '0',
  `if_printed` tinyint(2) NOT NULL DEFAULT '0',
  `tracking_id` varchar(256) DEFAULT NULL,
  `notes` varchar(2048) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `ebayDuplicate` (`transaction_ID`,`ebay_itemID`,`ebaypaymentstatus`)
) ENGINE=MyISAM AUTO_INCREMENT=3659 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_eastar_transaction`
--

LOCK TABLES `hmsh_ebay_eastar_transaction` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_eastar_transaction` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (267,561701810013,230397452111,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',13.49,'eastar4','sandmanrus','a_sandman@bk.ru','Andrey Schastnyy','Svobody St. 13A- 308','Kemerovo','','RUSSIAN FEDERATION','650070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 05:58:18',0,NULL,3,0,2,1,NULL,'sandmanrus、'),(266,756605251012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','welectronicss','sales@wholesalelectronics.org','CHris Sanders','780 Amelia Grove Ln','Lawrenceville','GA','UNITED STATES','30045','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 05:37:47',0,NULL,3,0,1,1,NULL,'welectronicss、'),(265,561689912013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',20.95,'eastar4','e**ch','simonezracohen@hotmail.com','EZRA CH. COHEN','Rua Sergipe 475 -Sala 204','Sao Paulo','Sao Paulo','BRAZIL','01243001','55+11+36617983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 04:20:42',0,NULL,3,0,2,1,NULL,'e**ch、'),(264,754978540012,220704730419,'New GENUINE Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',37.5,'eastar4uk','goetmals','benjamindecotte@hotmail.com','Benjamin Decotte','108 avenue du general leclerc','La Fere','Picardie','FRANCE','02800','06-76-83-74-20','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 07:00:41',0,NULL,3,0,3,1,NULL,'goetmals   欧标RA022497905CN、'),(263,516696835004,140516104473,'Logitech Charging Cradle L-LG7 for Harmony 880 890 pro',1,'CRLO002',9.99,'cnfaner','zoraya18','minor-solano@hotmail.com','Zoraya Gautier','2236 Dean Rd','Kernersville','NC','UNITED STATES','27284-8915','(336) 497-4268','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 03:19:27',0,NULL,3,0,1,1,NULL,'zoraya18、'),(262,561678577013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',2,'OTCN001',7.98,'eastar4','wbretas','wbretas@gmail.com','Wagner','Rua Jorge Lossio, 342 / ap 301','Teresópolis','Rio de Janeiro','BRAZIL','25961-265','(+55) 21-8755-1942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 03:15:53',0,NULL,3,0,2,1,NULL,'wbretas、'),(261,681217647011,320443658204,'New Visenta Wireless keyboard Muti-point Touch pad',10,'KBVI001',1000,'eastar4','tralda','adrian@concordia.sa.edu.au','Adrian Wuttke','45 Cheltenham St. Highgate','Adelaide','South Australia','AUSTRALIA','5063','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 01:42:19',0,NULL,3,0,6,1,NULL,'tralda    黑色的\rEE389037529CN\r'),(260,510856084003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','crazystargrl','movetheneedlecreations@yahoo.com','Anna Leehey','819 N Euclid Ave','Oak Park','IL','UNITED STATES','60302-1520','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 01:02:51',0,NULL,3,0,1,1,NULL,'crazystargrl'),(259,514433014004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',2,'HSPL001',23.76,'cnfaner','smcm2894','impapabear43@yahoo.com','STEVEN MCMANN','8915 Buena Pl<br>Apt 4107','Windermere','FL','UNITED STATES','34786-9418','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 22:52:34',0,NULL,3,0,1,1,NULL,'smcm2894'),(258,757035046012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.88,'eastar4uk','lisae.1-2007','lisae123@hotmail.co.uk','lisa eden','30 goffs oak ave<br>goffs oak','hertfordshire','Hertfordshire','UNITED KINGDOM','EN7 5NJ','01707880012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 22:22:08',0,NULL,3,0,3,1,NULL,'lisae.1-2007   英标\rRA022497998CN、'),(257,681150860011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','shpantzeri','ishpantzer@celight.com','Isaac Shpantzer','8312 rising ridge way','Bethesda','MD','UNITED STATES','20817-6944','(301) 365-8976','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 22:02:00',0,NULL,3,0,1,1,NULL,'shpantzeri'),(256,757013066012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','ikarus.vienna','arnold.vorraber@aon.at','Arnold Vorraber','Kanalstrasse 33/A16','Wien','','AUSTRIA','1220','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 21:35:50',0,NULL,3,0,2,1,NULL,'ikarus.vienna、'),(255,757008586012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.69,'eastar4uk','jonny321321','jonny-leech@hotmail.com','Jonathan Leech','Tomfarney<br>Clonroche','Enniscorthy','Wexford','IRELAND','default','0863886880','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 21:28:00',0,NULL,3,0,3,1,NULL,'jonny321321   英标\rRA022497627CN'),(254,757005650012,220713846397,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET',1,'HSNO017',13.29,'eastar4uk','1010diablo','10diablo@mail.ru','Alexander Leonov','post box 4','Moscow','Russia','RUSSIAN FEDERATION','125424','+7 (495) 5002583','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 21:21:40',0,NULL,3,0,2,1,NULL,'1010diablo   欧标、'),(253,516594578004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','scuderia-italiana','ebay@scuderiaitaliana.it','Giancarmine Spadaro','Via Vitrani, 31/33','Barletta','BA','ITALY','70051','3477644808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 20:14:07',0,NULL,3,0,3,1,NULL,'scuderia-italiana\rRA022497715CN\r'),(252,512793107004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','gustavo5694','farahzinho@hotmail.com','Gustavo Farah','Rua: Raimundo Leão de Moura<br>nº 203, Bloco B, Ap 401, Bairro: Nova Betânia.','Mossoró','Rio Grande do Norte','BRAZIL','59611320','(084) 88965705','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 20:14:00',0,NULL,3,0,3,1,NULL,'gustavo5694\rRA022497785CN、'),(251,681089433011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','antti12345','antti.halonen1@gmail.com','Antti Halonen','Tarhurintie 10 C 42','Vantaa','','FINLAND','01350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 20:07:14',0,NULL,3,0,2,1,NULL,'antti12345、'),(250,516589576004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY001*3',23.99,'cnfaner','splashlacey','tomoly@comcast.net','Tom McCain','1722 Timberlake Ct SE','Lacey','WA','UNITED STATES','98503-3049','(360) 866-1277','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 20:01:59',0,NULL,3,0,1,1,NULL,'splashlacey'),(249,516587663004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','sherman720','bigduff79@yahoo.com','Sherman Duffie','23 Redstone Ct','Durham','NC','UNITED STATES','27703-6315','(919) 648-1930','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 19:57:33',0,NULL,3,0,1,1,NULL,'sherman720   旧的'),(248,510739655003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',26.95,'cnfaner','11hacker11','alexbezrodny@gmail.com','Alexandr Yurievich Bezrodny','Petra Vershygory St, 3b, apt. 8','Kiev','Kyiv','UKRAINE','02218','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 19:51:12',0,NULL,3,0,3,1,NULL,'11hacker11   \rRA022497732CN\r'),(247,756911212012,220546768421,'1000000000000000% New Logitech battery 890 880 950mA',1,'BALO001',10.49,'eastar4','driver.shot','roland.menet@hispeed.ch','Roland Menet','Dorfstrasse 21','Algetshausen','','SWITZERLAND','9249','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 19:20:31',0,NULL,3,0,2,1,NULL,'driver.shot、'),(246,756907528012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','paulo*maia','pcsmaia@gmail.com','Paulo Maia','Al Praia de Guarapari, 209<br>casa 87','Salvador','BA','BRAZIL','41600110','+557136046187','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 18:43:35',0,NULL,3,0,2,1,NULL,'paulo*maia、'),(245,681022910011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','lkbleet','lkbleet@aol.com','Lynda  M Kornbleet','1331 Seamist Dr','Houston','TX','UNITED STATES','77008-5017','(713) 868-1021 ext.: 101','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 18:01:15',0,NULL,3,0,1,1,NULL,'lkbleet'),(244,756883522012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','kashpon-rus','kashpon@gmail.com','Belyanikov Alexei','st. Holzunova, h. 36/1, fl. 93','Volgograd','Volgogradskaya oblast','RUSSIAN FEDERATION','400105','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:54:19',0,NULL,3,0,3,1,NULL,'kashpon-rus       \r RA022497817CN、\r'),(243,756875050012,220572910849,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET HS 12W',1,'HSNO025',59.9,'eastar4','todotecno','cococarrey@hotmail.com','Jose Alberto Moreno Raposo','Paseo de la Esperanza 35, 1 Izda','MAdrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:38:46',0,NULL,3,0,3,1,NULL,'todotecno    欧标头\rRA022497635CN'),(242,756859153012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','shashank.chaturvedi85','ricky_chatur2005@yahoo.com','Shashank Chaturvedi','32-D ExpressView Apartment ( Super Mig)<br>Sector-93','Noida','UP','INDIA','201304','9899430045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:10:34',0,NULL,3,0,2,1,NULL,'shashank.chaturvedi85、'),(241,756862133012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','wbrjbr','wbrjbr@bellsouth.net','Walter Rose','58 N Crest Rd','Chattanooga','TN','UNITED STATES','37404-1828','(423) 698-8692','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 17:07:50',0,NULL,3,0,1,1,NULL,'wbrjbr'),(240,756857996012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','armandojpp','armando_pinheiro@hotmail.com','armando pinheiro','rua conde de bonfim 785 apt 101','rio de janeiro','rio de janeiro','BRAZIL','20530000','552134370095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:05:14',0,NULL,3,0,2,1,NULL,'armandojpp、'),(239,510711607003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','dankaert','casmat@gmail.com','Matteo Casalini','Via Copernico 14/A - c/o ASYS SRL','Podenzano - PC','Piacenza','ITALY','29027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 16:43:27',0,NULL,3,0,3,1,NULL,'dankaert        客户的新地址        \r\r Matteo Casalini\rc/o ASYS SRL\rVia Copernico 14/A\r29027 Podenzano (PC)\rITALY\rRA022497729CN\r\r'),(238,510708329003,130490260658,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.99,'cnfaner','yitzhandel','ebay@thehandels.com','Yitzchak Handel','954 Country Club Dr','Teaneck','NJ','UNITED STATES','07666','(201) 837-2844','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 16:30:20',0,NULL,3,0,1,1,NULL,'yitzhandel'),(237,516506241004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','robersonfeitosa','roberson.batista@credicarditau.com.br','Roberson Feitosa Batista','Rua Teixeira de Melo Nº 355 apto 1085<br>Tatuapé','São Paulo','SÃO PAULO','BRAZIL','03067000','(551) 184-3453 ext.: 13','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 15:35:28',0,NULL,3,0,3,1,NULL,'robersonfeitosa\rRA022497865CN'),(236,516499890004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','e_bay_dragon','longmuaban@yahoo.com','Long Bui','300 NW 18th St<br>Apt 25','Gainesville','FL','UNITED STATES','32603-1678','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 14:59:05',0,NULL,3,0,1,1,NULL,'e_bay_dragon'),(235,756787301012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',10.69,'eastar4','probirpaul','probirkrpaul@yahoo.com','Probir Paul','Vill- Baninagar<br>P.O. Pritinagar','Payradanga','West Bengal','INDIA','741247','9831355898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:45:26',0,NULL,3,0,2,1,NULL,'probirpaul、'),(234,680945058011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jsynthesizer','psynthesizer@gmail.com','Jonathan Jia','2110 Lerner Hall<br>2920 Broadway','New York','NY','UNITED STATES','10027-8385','(908) 917-2888','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 14:35:02',0,NULL,3,0,1,1,NULL,'jsynthesizer'),(233,561370477013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',26.1,'eastar4','kawa9green','pean79@telia.dk','Per Worsøe','Bakkevej 9A','Virum','','DENMARK','2830','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:24:44',0,NULL,3,0,2,1,NULL,'kawa9green    一共买了三个CAB-6060、'),(232,678433897011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',119.99,'eastar4','cofman1941','bigfatkitty@carolina.rr.com','Bruce Cofman','5918 Waverly Lynn Ln','Charlotte','NC','UNITED STATES','28269-1455','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 14:15:01',0,NULL,3,0,1,1,NULL,'cofman1941、'),(231,756790342012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','grlgf','graham_langford@btinternet.com','Graham Langford','69 Grove Rd','Harpenden','Hertfordshire','UNITED KINGDOM','AL5 1EN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 13:58:44',0,NULL,3,0,3,1,NULL,'grlgf\rRA022497940CN\r'),(230,510658115003,130458050899,'New GENUINE Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',44.9,'cnfaner','javierk65','ebjk@aptix.net','Javier Kohan','Pellegrini 391<br>Planta Alta','Rosario','Santa Fe','ARGENTINA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 12:35:58',0,NULL,5,0,3,1,NULL,'javierk65'),(229,561426753013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','ziv1281','ziv2312@yahoo.com','Ziv Shchori','10 Amoraeim st. apt. 2','Rehovot','','ISRAEL','76549','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 12:34:19',0,NULL,3,0,2,1,NULL,'ziv1281、'),(228,680898739011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','evggger','evgencyb@gmail.com','Evgeny Tsybin','Vatutina 1','Khimki','Moscow','RUSSIAN FEDERATION','141400','9067266946','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 12:23:27',0,NULL,3,0,2,1,NULL,'evggger、'),(227,680901708011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','alphalove48','alex.scott.spam@gmail.com','Alexander Scott','PO Box 7047','Cloisters Square','Western Australia','AUSTRALIA','6850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 12:07:19',0,NULL,3,0,2,1,NULL,'alphalove48、'),(226,561413319013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','ramy_b','r.bakhos@gmail.com','Ramy Bakhos','7 Janali Ave','Bonnyrigg','New South Wales','AUSTRALIA','2177','0423244445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 11:31:19',0,NULL,3,0,3,1,NULL,'ramy_b\rRA022498004CN'),(225,680892708011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','liverpoollad1','stephen.twist@tesco.net','Stephen Twist','telent<br>Carr Lane','Chorley','Lancashire','UNITED KINGDOM','PR7 3JP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 11:31:41',0,NULL,3,0,2,1,' ','liverpoollad1、'),(224,516178100004,140515718199,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',37.95,'cnfaner','pcsystemsfinland','paypal@pcsystems.fi','PC Systems Finland','PL 54','HELSINKI','FI','FINLAND','00501','+358504020376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 11:15:20',0,NULL,3,0,3,1,NULL,'pcsystemsfinland\rRA022497922CN'),(223,756724794012,220502334252,'2.1 HP ProBook 4510S 4515S 4710S Bluetooth Module cable',1,'BTHP2104',16.59,'eastar4','volocha-bobi','volocha@tut.by','ULADZIMIR MAKHNACH','RAFIEVA,85-242','MINSK','','BELARUS','220051','+375296790085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 10:44:02',0,NULL,3,0,2,1,NULL,'volocha-bobi            HP 8pin 1.0 18cm 4线连、'),(222,756716376012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','kenfong88','hua_88@live.com.my','ken fong','55 jalan permas 15/2<br>bandar baru permas jaya','masai','johor','MALAYSIA','81750','0177303339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 10:41:52',0,NULL,3,0,2,1,NULL,'kenfong88、'),(221,516445717004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','jana677_2009','jana677@hotmail.com','Hanin Bukhari box#JED 7289','147 29 182nd St','Springfield Gardens','NY','UNITED STATES','11413','718 553 8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 10:14:33',0,NULL,3,0,2,1,NULL,'jana677_2009  \r\r客户新地址        \r\rAtif Ali Ajlan\rSaudi Hollandi Bank\rTahlya Street\rbox No :67\rJeddah   21411 \rKingdom of Saudi Ariba\\\r\r'),(219,680851391011,320618273610,'New 3.0 Bluetooth BCM2070 Module+cable HP 5220m MINI311',1,'BTHP3000+BTHP3002',29.99,'eastar4','benzinoid','planetmir@gmx.net','Ove Peter','Werrestrasse 120','Herford','','GERMANY','32049','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 08:40:49',0,NULL,3,0,2,1,NULL,'benzinoid      HP 6pin1.0 3cm 、'),(59,559822473013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','fn800m','schizophrenicx@gmail.com','Tian Zun Aw','22 Sin Ming Road<br>#09-216','default','','SINGAPORE','570022','96541576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 08:06:25',0,NULL,3,0,11,1,NULL,'从此开始    fn800m\r'),(60,678760863011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',2,'CACN001',39.8,'eastar4','vladimir108108','hruby@rackspace.cz','vladimir hruby','trojska 53/782','prague8','','CZECH REPUBLIC','18200','+420720705130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 08:27:37',0,NULL,3,0,3,1,NULL,'RA022490460CN     vladimir108108\r '),(61,678789187011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',5,'WWSI006',295,'eastar4','flozwo','floriank@kempff.net','IPmotion GmbH','Ludwig-Rinn-Straße 14','Heuchelheim','','GERMANY','35452','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 10:33:44',0,NULL,3,0,3,1,NULL,'RA022490694CN       flozwo\r '),(62,754449665012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',11.9,'eastar4uk','duncantanner','duncan_tanner@hotmail.com','Duncan Tanner','191 Rownhams Lane<br>North Baddesley','Southampton','Hampshire','UNITED KINGDOM','SO52 9LR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-11 10:42:50',0,NULL,3,0,2,1,NULL,'从此开始 duncantanner'),(63,754453483012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',14.49,'eastar4','julienp21','blondin21@free.fr','Julien PAGOT','30, rue du recteur Marcel BOUCHARD','Dijon','Bourgogne','FRANCE','21000','0619591562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 10:59:27',0,NULL,3,0,2,1,NULL,'acer 8pin1.00 8cm     julienp21'),(64,678806620011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','iamthepilot','lloydstearns@suddenlink.net','Lloyd Stearns','512 Deer Meadow Cir','Georgetown','TX','UNITED STATES','78633-4692','(512) 686-1344','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-11 11:40:27',0,NULL,3,0,1,1,NULL,'iamthepilot '),(65,509238770003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA003',89.9,'cnfaner','tuisquash','tuisquash@uol.com.br','luiz arthur holland baptista','r: jose ramon urtiza n209 ap241-b','sao paulo','sao paulo','BRAZIL','05717-270','(551) 137-4344 ext.: 60','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 12:29:28',0,NULL,3,0,3,1,NULL,'从此开始 \rRA022490513CN     tuisquash\r'),(66,754477977012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','thanei','thanei@gmail.com','Lukasz Jaskiewicz','Bellerstraße 42','Hürth','','GERMANY','50354','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 12:30:06',0,NULL,3,0,2,1,NULL,'thanei '),(67,559890710013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'eastar4','cdr_80','akine@euskalnet.net','Miguel Angel Aguado','Barrio Alai 15 Bajo B','Zumaia','País Vasco','SPAIN','20750','680164253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 14:06:14',0,NULL,3,0,3,1,NULL,' RA022490439CN      cdr_80'),(68,754530185012,220682003276,'2.1 Acer Timeline 1810T 1810TZ Bluetooth Module cable',1,'BTAC2111',16.59,'eastar4','christianrodler','afirejar@googlemail.com','Christian Rodler','Hammerweg 7','Waldkirchen','','GERMANY','94065','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 15:04:03',0,NULL,3,0,2,1,NULL,'Acer 5pin1.25 3cm      christianrodler'),(69,678889058011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',16.75,'eastar4','grosrien','gliboiron@videotron.ca','Gilles Liboiron','107 de Laval','Bromont','QC','CANADA','J2L1M2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 16:07:37',0,NULL,3,0,2,1,NULL,'grosrien '),(70,515117401004,140516102911,'Genuine Logitech G7 Rechargeable Battery+charger',1,'BALO005+BALO006',19.99,'cnfaner','scissorjammer','scissorjammer@gmail.com','Alexander Rakoczy','600 W Chicago Ave<br>Suite 620 - Groupon','Chicago','IL','UNITED STATES','60654-2801','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-11 16:32:04',0,NULL,3,0,1,1,NULL,'scissorjammer '),(71,754577597012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',49.98,'eastar4','marlonjerry','marlokw1988@gmail.com','Marlo Wilson','7462 E Candice Dr','Camby','IN','UNITED STATES','46113-8656','(317) 361-5580','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-11 17:18:44',0,NULL,3,0,1,1,NULL,'marlonjerry '),(72,754576720012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',24.99,'eastar4','julie55441','julie55441@msn.com','Julie Brown','416 Phillips 308','West Helena','AR','UNITED STATES','72390','(916) 397-3688','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-11 17:58:45',0,NULL,3,0,1,1,NULL,'julie55441 '),(73,678941208011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'eastar4','dorit710','rvnsh@walla.com','reuven shloosh','kikar zabotinski 7/10','tiberias','','ISRAEL','14227','052-4236738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 18:10:23',0,NULL,3,0,11,1,NULL,'dorit710 '),(74,750036649012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',24.99,'eastar4','harley.ray','shoei500@hotmail.com','RAYMOND GIRARD','5433 RUE DU CONCERTO','CHARNY','QC','CANADA','G6X 2W8','(418) 832-6472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 18:13:54',0,NULL,3,0,2,1,NULL,'harley.ray '),(75,559974814013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',2,'HSJA002',43,'eastar4','enygyzer','enygyzer@yahoo.com','Mekia Chatman','1103 Benning Dr','Columbus','GA','UNITED STATES','31903-2107','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-11 19:01:58',0,NULL,3,0,1,1,NULL,'enygyzer '),(76,509360377003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',3,'MOAP001',67.47,'cnfaner','nakdemir','postmail.ebay@gmail.com','Nejdet Akdemir','Kirkkonaklar mh. Semsettin Gunaltay cd<br>363 sok. 3/4','ANKARA','cankaya','TURKEY','06610','903124963904','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 20:12:07',0,NULL,3,0,3,1,NULL,' RA022490473CN     nakdemir'),(77,515187404004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','philipp19701970','philipp@mmserv.ru','Philipp Boreysha','Pestelya Str, 9-164','Moscow','RU','RUSSIAN FEDERATION','127490','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 20:18:07',0,NULL,3,0,3,1,NULL,'RA022490685CN      philipp19701970\r '),(78,509365084003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',22.49,'cnfaner','luvactive','princessofpurses@gmail.com','Katherine Robinson','6710 Leanne Street','mira loma','CA','UNITED STATES','91752','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-11 20:25:09',0,NULL,3,0,1,1,NULL,'luvactive '),(79,515197784004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','amirsofir','sofert@zahav.net.il','amir sofir','kharcom 34','hod hasharon','','ISRAEL','45224','972-97457397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 20:51:10',0,NULL,3,0,3,1,NULL,'RA022490575CN\r amirsofir'),(80,679055116011,320585224260,'Intel 5300 AGN MIMO half size Mini PCI-E Card+tyco ante',1,'WLIN009+ANTY001*3',22.95,'eastar4','basketsbaldo','kdbalding@sbcglobal.net','Kim K Balding','307 N Maple Glade Cir','The Woodlands','TX','UNITED STATES','77382','(281) 367-1818','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-11 22:12:40',0,NULL,3,0,1,1,NULL,'basketsbaldo '),(81,560048274013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',17.4,'eastar4','hsyenhuai','bryan0812@gmail.com','Hsyenhuai Kao','2701 E 24th Avenue','Vancouver','BC','CANADA','V5R1E3','(778) 389-0932','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 22:29:41',0,NULL,3,0,2,1,NULL,'hsyenhuai '),(82,754767782012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',83.99,'eastar4','alessandro.figliolo','alessandrofigliolo@gmail.com','Alessandro Figliolo','Avenida Manoel Ribas, 9110 casa 01','Curitiba','Paraná','BRAZIL','82400000','554136777764','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 23:51:19',0,NULL,3,0,3,1,NULL,' RA022490487CN      alessandro.figliolo'),(83,515242282004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','antigravityworkshop','colin@antigravityworkshop.com','Colin Lamb','1410 STARVIEW DR','CEDAR FALLS','IA','UNITED STATES','50613-4962','(563) 663-0767','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-11 23:54:43',0,NULL,3,0,1,1,NULL,'antigravityworkshop '),(84,679093998011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.7,'eastar4','williamjlyall','nascarbayou@yahoo.com','william lyall','402 Crane St','aurora','IL','UNITED STATES','60505-3258','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-12 00:18:11',0,NULL,3,0,1,1,NULL,'williamjlyall '),(85,509426463003,130458050899,'New GENUINE Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',61.85,'cnfaner','carlito_green','carlo.gardani@sidel.com','Carlo Gardani','Via Broli Antichi 27','Villafranca di Verona','VR','ITALY','37069','3475970310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 00:44:56',0,NULL,3,0,3,1,NULL,'欧标     再发一个NOKIA_BH-202+Carcharger   HSNO006+CCNO001\rRA022490601CN     carlito_green\r'),(86,754785478012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',24.99,'eastar4','langdu_2011','tintran09@yahoo.com','Tin Tran','177 East St','Windsor','CT','UNITED STATES','06095-2408','(860) 882-9016','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-12 00:53:02',0,NULL,3,0,1,1,NULL,'langdu_2011 '),(87,754815274012,220713846482,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','vasileioslos','bacilis_los@hotmail.com','VASILIS LOS','IOUSTINIANI 40','chios','CHIOS','GREECE','82100','00302271029707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-12 02:54:26',0,NULL,8,0,17,0,NULL,NULL),(88,560104000013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.9,'eastar4','bitsorbytes','ajpalm@gmail.com','Andrew Palm','27 Montalbo Rd','Ringwood Nth','Victoria','AUSTRALIA','3134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 02:57:05',0,NULL,3,0,3,1,NULL,' RA022490495CN     bitsorbytes'),(89,754816992012,220713846482,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',2,'HSNO022',20.8,'eastar4uk','vasileioslos','bacilis_los@hotmail.com','VASILIS LOS','IOUSTINIANI 40','chios','CHIOS','GREECE','82100','00302271029707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-12 02:57:11',0,NULL,3,0,3,1,NULL,'一共买了三个    欧标\rRA022490748CN     vasileioslos\r'),(90,515294964004,140427930388,'2.1 Acer Aspire 5536 bluetooth module we offer track#',1,'BTAC2105',16.59,'cnfaner','parcayos','parcayo@hotmail.com','Jose Carlos Barajas','Campeche No. 143 Int.1<br>Colonia Roma sur','Mexico DF.','Mexico DF','MEXICO','06760','5528446773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 06:01:57',0,NULL,3,0,3,1,NULL,'acer 4pin1.25 8cm \rRA022490805CN      parcayos\r'),(91,515092112004,140516807631,'NIB Genuine Altec Lansing M602 iPod Speaker System nano',1,'SPAL001',117,'cnfaner','tamlyly','tam_lee1@yahoo.com','Tam le','14941 dillow st','westminster','CA','UNITED STATES','92683-5910','(714) 684-4185','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 06:26:06',0,NULL,3,0,4,1,NULL,'\rYW864871250CN'),(92,560134412013,230490512845,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','forme2509','tranquoctri@hotmail.com','Tri Tran','10111 Woodico Dr','Houston','TX','UNITED STATES','77038-2435','(832) 677-3666','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-12 06:27:36',0,NULL,3,0,1,1,NULL,'forme2509 '),(93,509484314003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','mathewcb1','mathewcb@hotmail.com','Mathew Bevis','230 Forrest Avenue','Winnipeg','MB','CANADA','R2V 1K1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 07:36:10',0,NULL,3,0,3,1,NULL,'RA022490527CN      mathewcb1\r '),(94,509493671003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','dgrkee9280','dgrkee@hotmail.com','Daniel Kee','3/36 Bream St<br>Coogee','Sydney','New South Wales','AUSTRALIA','2034','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 08:38:58',0,NULL,3,0,3,1,NULL,'RA022490734CN\r dgrkee9280'),(95,754890196012,220752720350,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','steveb3836','highview56@sky.com','steve brazill','56 arundel road','newhaven','East Sussex','UNITED KINGDOM','bn9 0nf','01273517084','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 08:49:58',0,NULL,3,0,2,1,NULL,'steveb3836 '),(96,560162262013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',17.4,'eastar4','gabor.kovacs','gabriel.sintes@gmail.com','Gabriel Sintes','Avda. Canaletas 41 6 2a','Cerdanyola','Cataluña','SPAIN','08290','638024945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 09:30:38',0,NULL,3,0,2,1,NULL,' CAB-6060     gabor.kovacs'),(97,515366802004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',10.79,'cnfaner','mollaguliev','mollaguliyev@gmail.com','Orkhan Mollaguliyev','Yeni Guneshli, A/B 129, 95','Baku','','AZERBAIJAN','1133','+994556575310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 13:19:54',0,NULL,3,0,3,1,NULL,' RA022490646CN      mollaguliev'),(98,509556854003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',12.99,'cnfaner','miamimegahz','jeffrey.heerts@kaplanzeena.com','Jeffrey Heerts','2 S Biscayne Blvd<br>Ste 3050','Miami','FL','UNITED STATES','33131-1808','(305) 530-0800 ext.: 1002','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 14:06:33',0,NULL,3,0,1,1,NULL,'miamimegahz '),(99,515392560004,140442124370,'2.0 dell mini 9 J613H bluetooth module Track#4eachorder',2,'BTDE2001',25.6,'cnfaner','snuggledog12','smithgl4@austin.rr.com','Geoffrey Smith','5910 Cape Coral Dr','Austin','TX','UNITED STATES','78746-7268','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 15:06:22',0,NULL,3,0,1,1,NULL,'snuggledog12\r 、'),(100,509571656003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'cnfaner','joinermike','joinerm@comcast.net','Michael Joiner','4539 Hawk Woods Dr','West Bloomfield','MI','UNITED STATES','48322-4571','(248) 737-5505','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 15:11:10',0,NULL,3,0,1,1,NULL,'joinermike '),(101,509576350003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'cnfaner','gecko6375','marc@mnfamily.org','marc baker','1512 132nd Ln NW','Coon Rapids','MN','UNITED STATES','55448-7102','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 15:19:47',0,NULL,3,0,1,1,NULL,'gecko6375 '),(102,509582953003,130458050482,'NIB Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL004',23.9,'cnfaner','barakm22','barakmor22@walla.co.il','barak mor','alenbi 88','haifa','israel , haifa , kiryat eliezer','ISRAEL','35666','0545271164','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 15:44:22',0,NULL,3,0,3,1,NULL,' RA022490500CN       barakm22'),(103,560252826013,230397452111,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'eastar4','ejviana1981','ejviana@gmail.com','Edgar Viana','Av. Dr. Afonso Vergueiro, 2738<br>Salas 1/2 (Caixa) - Bairro Vila Augusta','Sorocaba','Sao Paulo','BRAZIL','18040-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 15:52:51',0,NULL,3,0,2,1,NULL,' 旧的    ejviana1981'),(104,755068318012,220713846397,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET',1,'HSNO017',13.29,'eastar4uk','paprotka15marta','paprotka15@buziaczek.pl','Marta Kurdziel','84 Macnaghten Road <br>hampshire','Southampton','Hampshire','UNITED KINGDOM','So18 1Gj','07856286335','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 16:55:19',0,NULL,3,0,2,1,NULL,'英标头       paprotka15marta'),(105,509611755003,130458050899,'New GENUINE Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',44.9,'cnfaner','doronmerdinger2008','doron@doronmerdinger.com','Doron Merdinger','9 Ha-erez st','Karmey Yosef','Israel','ISRAEL','99797','+972544820820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:15:47',0,NULL,3,0,3,1,NULL,' RA022490589CN      doronmerdinger2008'),(106,755084193012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','carlos6725','carlos83@ebuyclub.com','Carlos Maia Vieira','408 chemin de la coualo','Vidauban','Provence-Alpes-Côte d\'Azur','FRANCE','83550','0494731580','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:24:41',0,NULL,3,0,2,1,NULL,' 旧的      carlos6725'),(107,515440209004,140433914756,'NEW Red Genuine Lowepro Topload Zoom Mini Camera Bag!',1,'',19.98,'cnfaner','dimitris_biziouras','current94@gmail.com','Dimitrios Biziouras','Ioanninon 39<br>Voula','Athens','Attiki','GREECE','166 73','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:42:23',0,NULL,5,0,18,0,NULL,' '),(108,755118282012,220748081734,'New Motorola HS850 Bluetooth Wireless Headset HS 850',2,'HSMO019',39.98,'eastar4','acaddesign','acaddesign@cox.net','Richard G. Horvath','27151 Neda','Mission Viejo','CA','UNITED STATES','92692','(949) 582-3745','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-12 18:25:12',0,NULL,5,0,1,1,NULL,'acaddesign '),(109,560308512013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',119.99,'eastar4','lustigjm','julian-lustig@hotmail.com','Julian Lustig','16 Creekside Drive<br>PO Box 599','St.David\'s','ON','CANADA','L0S1P0','(289) 296-2785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 18:26:47',0,NULL,3,0,3,1,NULL,'   lustigjm\rRA022497701CN'),(110,515454484004,140516874483,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY001*3',17.99,'cnfaner','ng_mow','ngondaryov@mail.ru','Nikolay Gondaryov','app.55, 11A, Zoi i Alexandra<br>Kosmodemyanskih street','Moscow','Moscow region','RUSSIAN FEDERATION','125130','+79166955040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 18:27:00',0,NULL,3,0,3,1,NULL,'RA022490561CN        ng_mow\r '),(111,755128684012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',22.9,'eastar4','packageradio','paule-panzer@gmx.net','Benedikt Schleusener','Brunnenäcker 18','Heldenfingen','','GERMANY','89547','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 18:42:54',0,NULL,3,0,2,1,NULL,'再发一个 3G WWAN antenna   ANCN001     packageradio'),(112,515260641004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','sparklegirl924','krlombardo@gmail.com','Kristen Lombardo','37 Driggs Ave<br>Apt 2B','Brooklyn','NY','UNITED STATES','11222-4512','(347) 752-2399','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 18:54:02',0,NULL,3,0,1,1,NULL,'sparklegirl924 '),(113,515474753004,140481828186,'New Plantronics Voyager Pro Bluetooth Headset+carcharge',1,'HSPL013+CCPL001',47.9,'cnfaner','richier80','richier@paradise.net.nz','Richard Reynolds','73 Ohariu Road<br>Johnsonville','Wellington','','NEW ZEALAND','6037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 19:19:45',0,NULL,3,0,3,1,NULL,' RA022490615CN      richier80'),(114,509653070003,130466041700,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',48.98,'cnfaner','slider_spb','antonov_mail@mail.ru','Anatoly Antonov','Turistskaja, dom 2, kv. 96','St-Petersburg','St-Petersburg','RUSSIAN FEDERATION','197374','+79052255598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 19:24:11',0,NULL,3,0,3,1,NULL,' RA022490650CN       slider_spb'),(115,515486774004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','kleclerc3','kleclerc3@verizon.net','Kellie Leclerc','22 Adams St','Silver Creek','NY','UNITED STATES','14136','(716) 934-3408','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 19:54:36',0,NULL,3,0,1,1,NULL,'kleclerc3 '),(116,755206917012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',24.99,'eastar4','irene12111','mvb@onetoonerealty.com','Michael Von Bank-','3844 Bexley Sq','Reno','NV','UNITED STATES','89503-1819','(775) 287-4027','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-12 20:54:47',0,NULL,3,0,1,1,NULL,'irene12111 '),(117,515514367004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','algisavia','algis_kr@yahoo.com','Algimantas Krikscikas','1592 Canterbury Rd N','Saint Petersburg','FL','UNITED STATES','33710-5658','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 21:13:20',0,NULL,3,0,1,1,NULL,'algisavia '),(118,755227175012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','webwebes','alejandro_spa@hotmail.com','Alejandro Alvarez Ramos','C/Juan I Portugal 1 Blq.2, 6ºb (Residencial Larios)','Ceuta','Ceuta','SPAIN','51001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-12 21:32:59',0,NULL,3,0,3,1,NULL,' RA022490751CN      webwebes'),(119,509709233003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','ebuyer_uy','vendoxml@gmail.com','Ernesto Mariani','Canelones 1804','Montevideo','','URUGUAY','11200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 22:00:57',0,NULL,3,0,3,1,NULL,' RA022490703CN      ebuyer_uy'),(120,679525679011,320394892477,'Acer Aspire 5235 5335 5535 Bluetooth Module 2.0 +cable',1,'BTAC2005',14.49,'eastar4','joaquinal','donjoaquinal@yahoo.com','joaquin aldeguer quintana','c/ colegial nº 15 5º aptº 51','torremolinos','Malaga','SPAIN','29620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 22:17:03',0,NULL,3,0,2,1,NULL,'acer 4pin1.25 8cm       joaquinal'),(121,515542336004,140428348853,'2.1 Acer Aspire 4730Z bluetooth module we offer track#',1,'BTAC2120',16.59,'cnfaner','skwarkenklux','prof.skwarkenklux@gmail.com','Michael Carver','1577 N Linder rd<br># 108','Kuna','ID','UNITED STATES','83634','(208) 859-9343','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 22:56:21',0,NULL,3,0,1,1,NULL,'acer 8pin1.0 6cm      skwarkenklux'),(122,679549720011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',14.99,'eastar4','websterh','beknweb@gmail.com','Weber Hsu','661 South Pine Road','Everton Park','Queensland','AUSTRALIA','4053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 23:27:40',0,NULL,3,0,2,1,NULL,'websterh '),(123,560425746013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','ungaulois2926','ungaulois@hotmail.com','Mario Ouellette','2926 Carré des argiles','Quebec','QC','CANADA','G2C1K3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 00:28:08',0,NULL,3,0,2,1,NULL,'ungaulois2926 '),(124,560424314013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',2,'HSPL005',27.16,'eastar4','senatordl','sendl1@verizon.net','Richard LaRossa','150 Bull Run Rd','Ewing','NJ','UNITED STATES','08638-1316','(609) 882-1071','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 00:46:12',0,NULL,3,0,1,1,NULL,'senatordl '),(125,515569166004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','marandayoung','marandayounger@yahoo.com','maranda younger','103 Ross Ln','vicksburg','MS','UNITED STATES','39180','(601) 218-9401','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 01:05:44',0,NULL,3,0,1,1,NULL,'marandayoung '),(126,679580192011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',9.99,'eastar4','ltlopes1vk0','ltlopes@gmail.com','Leandro Lopes','Av. Protasio Alves, 1205','Pinheiro Machado','Rio Grande do Sul','BRAZIL','96470-000','55 53 91036993','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 01:13:37',0,NULL,3,0,2,1,NULL,'ltlopes1vk0 '),(127,560325832013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.9,'eastar4','kparise10','ken.parise@wgint.com','Kenneth Parise','11214 Lynbrook Dr','Houston','TX','UNITED STATES','77042','(832) 247-4069','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 01:46:51',0,NULL,3,0,1,1,NULL,'kparise10 '),(128,560447081013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.9,'eastar4','basketball*wildcat','scootswv@insightbb.com','scott vittitow','8107 Florist Rd','louisville','KY','UNITED STATES','40228-2206','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 02:08:16',0,NULL,3,0,1,1,NULL,'basketball*wildcat '),(129,515584046004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',55.99,'cnfaner','bensau2003','bensau@acn.net','Benoit Sauvageau','212, rue de l\'Estran','Lachenaie','QC','CANADA','J6W 6A1','(450) 471-6424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 02:25:59',0,NULL,3,0,3,1,NULL,'RA022490725CN\r bensau2003'),(130,560462270013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',2,'BALO001',20.98,'eastar4','corinthiancobra','paschal304@verizon.net','Sam Paschal','304 Vickery Way','Denton','TX','UNITED STATES','76210-5271','(817) 368-6697','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 03:25:22',0,NULL,3,0,1,1,NULL,'corinthiancobra '),(131,679619704011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',14.99,'eastar4','c_gadgetz','custom.gadgetz@gmail.com','David Mathews','30 Wakelin Circuit','Weston creek','Australian Capital Territory','AUSTRALIA','2611','0432288824','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 03:54:08',0,NULL,3,0,2,1,NULL,'c_gadgetz '),(132,509786909003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',10.79,'cnfaner','svorbei','zvorbei@gmail.com','Shan Qiu','515 Jackson Ave','Vancouver','BC','CANADA','V6A 3W2','(604) 255-5526','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 04:40:57',0,NULL,3,0,3,1,NULL,'RA022490677CN       svorbei\r '),(133,755380365012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',24.99,'eastar4','baandrews10','baandrews@gmail.com','Olivier Simard','1021 Lund Road','Houston','BC','CANADA','V0J1Z1','(250) 845-2447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 06:21:22',0,NULL,3,0,2,1,NULL,'baandrews10 '),(134,755392010012,220748081734,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',19.99,'eastar4','dcheng-117','kaheng117@yahoo.com','david  cheng','407 Silverdale Dr','pomona','CA','UNITED STATES','91767-1427','(626) 484-5350','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 07:12:19',0,NULL,3,0,1,1,NULL,'dcheng-117 、'),(135,560516730013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','xale21','aagogin@gmail.com','Alexey Gogin','Kulikova street, house № 77, flat № 3','Astrakhan','RU','RUSSIAN FEDERATION','414041','7-9170-8512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 09:10:24',0,NULL,3,0,2,1,NULL,'欧标头 银色的    xale21'),(136,515650807004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','mbhand','madddy84@gmail.com','MADHUKAR BHANDARI','#FC, MODERN VIEW APRTMENT<br>4TH MAIN CHANNAPANNAHALLI','BANGALORE','KA','INDIA','560037','919900056463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 09:38:18',0,NULL,3,0,3,1,NULL,'RA022490632CN     mbhand\r '),(137,755442031012,220568348189,'NEW GENUINE NOKIA BH-300 BLUETOOTH HEADSET BH 300',1,'HSNO013',15.6,'eastar4','testbenzin','oelnase@freenet.de','Peter Neu','A-S-R 5a','Itzehoe','','GERMANY','25524','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 09:57:13',0,NULL,3,0,2,1,NULL,'欧标头      testbenzin'),(138,509840557003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',19.9,'cnfaner','marting811','martingruen@aon.at','Martin Grün','Platti 317','Kappl','','AUSTRIA','6555','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 10:06:26',0,NULL,3,0,3,1,NULL,'欧标 \rRA022490629CN    marting811\r'),(139,755085945012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',49.98,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 10:56:21',0,NULL,3,0,3,1,NULL,' RA022490535CN    solopo2009'),(140,679756650011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.99,'eastar4','deluxdealz','deluxfla@gmail.com','Chris Brownell','9210 SW 3rd St<br>Apt 201','Boca Raton','FL','UNITED STATES','33428-4565','(561) 213-7601','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 11:55:40',0,NULL,3,0,1,1,NULL,'deluxdealz '),(141,560569371013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',89.9,'eastar4','krazy-jack','crazyjack@bigpond.com','Gordon Bogdanoski','12 RIBBONWOOD RD','UNANDERRA','New South Wales','AUSTRALIA','2526','0242724888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 12:06:20',0,NULL,3,0,3,1,NULL,' RA022490558CN     krazy-jack'),(142,755503073012,220748081734,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',19.99,'eastar4','501sharon56','lewis7797@sbcglobal.net','Sharon Lewis','6509 Pecan Ln','Little Rock','AR','UNITED STATES','72206','(501) 490-0233','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 12:07:36',0,NULL,3,0,1,1,NULL,'501sharon56 '),(143,560575362013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',10.49,'eastar4','raptor_htk','stefantomaschek@web.de','Stefan Tomaschek','Im Haindell 105','Sulzbach am Taunus','','GERMANY','65843','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 12:26:25',0,NULL,3,0,2,1,NULL,'raptor_htk '),(144,560587552013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.9,'eastar4','ken86c','kennethtse@live.com.au','Kenneth Tse','Level 7 NW<br>105-153 Miller Street','North Sydney','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 13:02:04',0,NULL,3,0,3,1,NULL,' RA022490442CN      ken86c'),(145,560611153013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'eastar4','d_peter','p.duscha@gmx.net','Peter Duscha','Künnestr.1a','Düsseldorf','other','GERMANY','40625','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 14:07:48',0,NULL,3,0,2,1,NULL,'d_peter '),(146,515744669004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','gleb-den','glebden@gmail.com','Gleb Denisov','Baykalskaya, 14/2, 21','Moscow','Moscow','RUSSIAN FEDERATION','107241','+79032096320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 14:46:21',0,NULL,8,0,17,0,NULL,NULL),(147,560627390013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'eastar4','eritonb','sediveneb@gmail.com','Eriton Benevides','rua 21, nr. 500, apto 201, Ed. Indaiá<br>Setor Central','Goiânia','Goiás / Goiânia','BRAZIL','74030070','+556232234688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 14:52:39',0,NULL,3,0,2,1,NULL,'eritonb '),(148,509918135003,130490976227,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',15.99,'cnfaner','gleb-den','glebden@gmail.com','Gleb Denisov','Baykalskaya, 14/2, 21','Moscow','Moscow','RUSSIAN FEDERATION','107241','+79032096320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 14:52:51',0,NULL,3,0,3,1,NULL,'再发一个Atheros AR5008 旧的 WLAT002 \rRA022490717CN     gleb-den\r'),(149,560636042013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',2,'HSNO022',29.96,'eastar4','legionovo','grzegorz.daniluk@wystroje.eu','Grzegorz Daniluk','Warszawska 57','Legionowo','mazowieckie','POLAND','05-120','601 555999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 15:15:35',0,NULL,3,0,2,1,NULL,'\r 银色的和白色的     '),(150,560647626013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.9,'eastar4','okauf','okauf@arcor.de','Ralf Ohmayer','Hauptstraße 17','Isny - Großholzleute','other','GERMANY','88316','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 15:39:47',0,NULL,3,0,3,1,NULL,' RA022490411CN'),(151,677384758011,320666253128,'INOVA T4 LED FLASHLIGHT TORCH + new charger',1,'BAIN002+TOIN002',55.9,'eastar4','robgalvez187','robgalvez1@yahoo.com','Carole Galvez','58227 S. 299th Ave','Gila Bend','AZ','UNITED STATES','85337','(623) 764-6224','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 15:45:02',0,NULL,3,0,1,1,NULL,'RA022490544CN      robgalvez187'),(152,755712775012,220748684536,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','neural69','aj.norcross@yahoo.co.uk','Alastair Norcross','151 Glenfrome Rd<br>Eastville','Bristol','Bristol','UNITED KINGDOM','BS5 6XF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 17:37:57',0,NULL,3,0,2,1,NULL,'neural69 '),(153,510002551003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','underwoj','jamesrobertunderwood@yahoo.com','James R Underwood','140 Berkshire Ln','Waxahachie','TX','UNITED STATES','75165-4811','(469) 337-2779','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 17:48:58',0,NULL,3,0,1,1,NULL,'underwoj '),(154,679975966011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','elyase','yaser.martinez@gmail.com','Ella Gramm','Schubertstrasse 26','Gedern-Wenings, Hessen','','GERMANY','63688','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 17:59:17',0,NULL,3,0,3,1,NULL,'RA022490544CN      elyase'),(155,515472694004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','burnsmark','mtburns1@verizon.net','Mark Burns','9711 Wyman Way','Upper Marlboro','MD','UNITED STATES','20772','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 18:10:40',0,NULL,3,0,1,1,NULL,'burnsmark '),(156,510056258003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','lycan_nl','wingtai_chan@hotmail.com','Wing Tai Chan','Vaillantlaan 322','Den Haag','','NETHERLANDS','2526 HT','0646103503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 18:49:57',0,NULL,3,0,3,1,NULL,'RA022490425CN     lycan_nl'),(157,560789929013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','roik11','ivan4enko-roik@yandex.ru','Elena Ivanchenko-Roik','Bratskaya 1/45 flat.30','Moscow','Moscow','RUSSIAN FEDERATION','111141','+79067269810','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 19:17:20',0,NULL,3,0,2,1,NULL,'欧标头 roik11、'),(158,515898792004,140516104473,'Logitech Charging Cradle L-LG7 for Harmony 880 890 pro',1,'CRLO002',9.99,'cnfaner','whichwayisfriday','keithlaface@gmail.com','Keith LaFace','24 Paulman Cir','West Roxbury','MA','UNITED STATES','02132-1223','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 19:18:11',0,NULL,3,0,1,1,NULL,'whichwayisfriday '),(159,515912108004,140442124370,'2.0 dell mini 9 J613H bluetooth module Track#4eachorder',1,'BTDE2001',12.8,'cnfaner','paz-man','pasi.pinta@gmail.com','Pasi Pinta','4322 Mapleward Road','Thunder Bay','ON','CANADA','P7K 1A3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 19:39:17',0,NULL,3,0,3,1,NULL,'RA022490592CN     paz-man\r'),(160,515929001004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','asafsapira11','asafsapira@walla.com','asaf sapir','hagalil st. 114a','haifa','','ISRAEL','32683','0502795137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 20:17:58',0,NULL,3,0,3,1,NULL,'    asafsapira11\rRA022497556CN'),(161,755931862012,220705174913,'Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO014',19.95,'eastar4uk','karen7c','karenmc_25@hotmail.co.uk','Karen McCrory','31 Harrogate Street','Belfast','Antrim','UNITED KINGDOM','BT12 7AT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 20:52:19',0,NULL,3,0,3,1,NULL,' 英标       karen7c\rRA022497471CN\r'),(162,516002763004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','mancari1','fmancari@aol.com','Frank Mancari','307 Palmer Dr','North Syracuse','NY','UNITED STATES','13212','(315) 458-4024','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 22:47:53',0,NULL,3,0,1,1,NULL,'mancari1 '),(163,560924295013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','lukie4me','bocanegra_4@yahoo.com','Elizabeth Laniohan','3725 NW Poplar Ave','Redmond','OR','UNITED STATES','97756-8158','(541) 480-0398','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 23:47:56',0,NULL,3,0,1,1,NULL,'lukie4me '),(164,516023654004,140515718199,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',37.95,'cnfaner','cjowett','kt@odcia.org','Kristoffer Tjensvoll','Øvrevollveien 54','Bærum','Akershus','NORWAY','1358 Jar','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 00:08:06',0,NULL,3,0,3,1,NULL,'cjowett \rRA022497423CN\r'),(165,680017116011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','mojdeh321','mojdeh321@yahoo.ca','mojdeh mahmoudian','45 pixley private Ottawa ont ','Ottawa','ON','CANADA','k1G 4C3','(613) 421-5009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 00:14:53',0,NULL,3,0,3,1,NULL,' RA022490558CN        mojdeh321'),(166,680264592011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','supercuban89','supercuban89@yahoo.com','Esteban Betancourt','4953 W Eddy St','Chicago','IL','UNITED STATES','60641-3550','(773) 685-8012','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 00:38:26',0,NULL,3,0,1,1,NULL,' RA022490535CN supercuban89'),(167,560942069013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',10.49,'eastar4','layinlowcivic','sdhonda153@hotmail.com','Steve Cockburn','1805 Kenny Ave','Champaign','IL','UNITED STATES','61822-6808','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 00:48:20',0,NULL,3,0,1,1,NULL,'layinlowcivic '),(168,756064919012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',2,'MOLO001',130,'eastar4','skofarrell','skofarrell@yahoo.com','Sean O\'Farrell','1106 E 82nd St','Indianapolis','IN','UNITED STATES','46240','(317) 292-7660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 01:08:13',0,NULL,3,0,1,1,NULL,'skofarrell '),(169,680279336011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',20.98,'eastar4','krissymain','mmain@cmfiber.com','Michael Main','1525 Riviera Dr','Pasadena','Ca','UNITED STATES','91107-1663','(951) 237-2020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 01:20:17',0,NULL,3,0,1,1,NULL,'krissymain '),(170,560952504013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',10.49,'eastar4','outofexcile','curtness@hotmail.com','curt perehudoff','22 davidson cres','saskatoon','SK','CANADA','s7l 4a1','(306) 382-3379','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 01:23:04',0,NULL,3,0,2,1,NULL,'outofexcile '),(171,680282304011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',14.99,'eastar4','dbastin','donbastin@gmail.com','Don Bastin','83 W Garfield Ave','Martinsville','IN','UNITED STATES','46151-2416','(765) 342-3838','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 01:24:55',0,NULL,3,0,1,1,NULL,'dbastin '),(172,560959630013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','cyberuncle2010','rarid2005@yahoo.com','Sanjeev Nayyar','5 Maddybeth Crescent<br>(Basement)','Brampton','ON','CANADA','L6Y5R7','(416) 273-8766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 01:46:17',0,NULL,3,0,2,1,NULL,'银色的 cyberuncle2010、'),(173,510253598003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',10.79,'cnfaner','sbubandit','sbubandit@hotmail.com','Peter Reddish','281 Pompano Ct.','Lapeer','MI','UNITED STATES','48446','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 02:53:59',0,NULL,3,0,1,1,NULL,'sbubandit '),(174,560981577013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'eastar4','cr1sch','crsch@telus.net','Charles Schmidt','#307, 8903 - 106 A Avenue','Edmonton','AB','CANADA','T5H 3Y7','(780) 425-7973','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 02:58:24',0,NULL,3,0,3,1,NULL,' cr1sch\rRA022497445CN\r'),(175,756121599012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',65,'eastar4','kml246','shadow1970@verizon.net','mel matthews','11671 Whitetail Dr','marilla','NY','UNITED STATES','14102-9710','(716) 853-5000 ext.: 18','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 03:33:20',0,NULL,3,0,1,1,NULL,'kml246÷÷ '),(176,510263159003,130493246602,'Logitech harmony Li-ion Rechargeable Battery 930mAh',1,'BALO002',10.5,'cnfaner','vitoa4747','vitoa4747@hotmail.com','Vito Alfino','42 Crestlawn Gate','Woodbridge','ON','CANADA','L4H 0H8','(905) 265-2359','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 03:37:24',0,NULL,3,0,3,1,NULL,'vitoa4747 \rRA022497437CN'),(177,510265765003,130490223099,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',22,'cnfaner','ttschida11','toddtschida@comcast.net','Todd Tschida','740 N Hay Lake Rd','Eagan','MN','UNITED STATES','55123-3024','(651) 457-2881','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 03:51:41',0,NULL,3,0,1,1,NULL,'ttschida11 '),(178,516091688004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY001*3',23.99,'cnfaner','nissi6k','bjjeon@samaneng.com','Jeon beom-jin','706-206,Mugunghwa Kunyoung Apt., Sinchon-dong, Dongan-gu','Anyang-si','Gyeonggi-do','KOREA,REPUBLIC OF','431-791','82-10-6202-2740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 05:28:12',0,NULL,3,0,3,1,NULL,'nissi6k \rRA022497366CN'),(179,559532258013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',16.59,'eastar4','vojak.p','p.rubas@seznam.cz','Pavel Rubáš','Týnec 46','Janovice nad Úhlavou','Janovice nad Úhlavou','CZECH REPUBLIC','34021','724958271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 07:32:31',0,NULL,3,0,2,1,NULL,'acer 4pin1.25 15cm    vojak.p'),(180,510294609003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','stu2565','sfellows@iprimus.com.au','stuart fellows','2565 helena valley rd','helena valley','Western Australia','AUSTRALIA','6056','0892552467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 07:56:45',0,NULL,3,0,3,1,NULL,'stu2565 \rRA022497485CN'),(181,756176391012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','bulzache','florin.cioponea@gmx.com','florin cioponea','Drm. Padurea Pustnicu nr.141B bl. RU37 et.2 ap.6','bucuresti','sector 1','ROMANIA','014042','0040729100276','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 08:04:44',0,NULL,3,0,2,1,NULL,'bulzache '),(182,756182555012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','enfant_des_dieux','goulven.riant@laposte.net','Goulven RIANT','7, Avenue Parmentier<br>SUPINFO','Toulouse','Midi-Pyrénées','FRANCE','31200','0699334951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 08:32:36',0,NULL,3,0,2,1,NULL,'enfant_des_dieux '),(183,516121248004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',32.8,'cnfaner','er_garry','er_garry@hotmail.com','Alejandro Garrido Suárez','Jenaro de la Fuente<br>Nº44,6ºA','Vigo','Pontevedra','SPAIN','36205','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 09:54:58',0,NULL,3,0,3,1,NULL,'er_garry \rRA022497975CN'),(184,756242197012,220477365327,'UNLOCKED Option GTM382 PCI-E Modem WWAN GTM 382+antenna',1,'WWOP003+ANCN001',48.59,'eastar4','girbucks','g_morales_84@yahoo.com','Gilbert S Morales','293 Arandia St., Wildcat Vill., Brgy. Ususan','Taguig','','PHILIPPINES','1634','6323810782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 12:11:19',0,NULL,3,0,3,1,NULL,'girbucks                                     \r\r客户的新地址：\r\rGilbert S Morales\r293 Arandia St., Wildcat Vill., Brgy. Ususan\rTaguig  1634\rPHILIPPINES\r6323810782    \r                                         postal office @ Taguig Postal Office, Metro Manila, PH c/o Gilbert Morales\rRA022497661CN\r'),(185,680448685011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','biddie58','t.eggins@sky.com','Tim Eggins','18 Minehurst Road<br>MYTCHETT','CAMBERLEY','SURREY','UNITED KINGDOM','GU16 6JP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 12:49:53',0,NULL,3,0,2,1,NULL,'biddie58 \rRA022493639CN'),(186,680448812011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',10,'CASS003',87,'eastar4','andre.iacono','lorenalive@hotmail.co.uk','Andre Iacono de Souza','SRTVS, Qd 701 - Bloco K - Sala 303<br>Edificio Embassy Tower','BRasilia','Brasil','BRAZIL','70340908','556186120228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 12:57:59',0,NULL,3,0,3,1,NULL,'andre.iacono \rRA022497542CN\r'),(187,680461622011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',14.49,'eastar4','dj-ghost','djglhlost@yahoo.com','Bryan Enciso','1000 South 2nd Street<br>AF Supply - Quality Warehouse','Harrison','NJ','UNITED STATES','07029','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 13:32:12',0,NULL,3,0,1,1,NULL,'acer 4pin1.25 15cm     dj-ghost'),(188,756277235012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','pedro_vitorino','pedro.vitorino@gmail.com','Pedro Miguel Vitorino','Rua das Palmeiras, 13 - 1º Andar','Alcantarilha','','PORTUGAL','8365-021','+351964685450','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 14:00:41',0,NULL,3,0,3,1,NULL,'pedro_vitorino     \rRA022497750CN'),(189,561097335013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','den6749','denmy501@hotmail.com','chai chang yu','148/38<br>Mount Alexander Road','Travancore','Victoria','AUSTRALIA','3032','0423347433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 14:05:30',0,NULL,3,0,2,1,NULL,'den6749 '),(190,756308829012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','oscarpt1981','oscarpt1981@yahoo.es','OSCAR PEREZ TIRADO','CALLE VILLALMANZO, NUM 5, 3º C','MADRID','Madrid','SPAIN','28032','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 15:21:35',0,NULL,3,0,3,1,NULL,'oscarpt1981 \rRA022497967CN'),(191,510381133003,130490260658,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.99,'cnfaner','davilar74','davilar74@yahoo.com','nigel davilar','14460 40th place north','plymouth','MN','UNITED STATES','55446','(763) 566-2344','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 15:43:53',0,NULL,3,0,1,1,NULL,'davilar74 '),(192,510395015003,130458050899,'New GENUINE Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',44.9,'cnfaner','alexnochmal','alexnochmal@inbox.ru','Alex N','Semenov<br>Tchebysheva 6-628','Ekaterinburg','Sverdolvskaya','RUSSIAN FEDERATION','620062','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 16:35:58',0,NULL,5,0,3,1,NULL,'欧标 alexnochmal'),(193,561143082013,230397452111,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'eastar4','nightwolf-ng','nightwolf_ng@mail.ru','Kirill Burliaev','8-4-31 Gerasima Kurina street','Moscow','Moscow City','RUSSIAN FEDERATION','121108','+79851445596','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 17:02:03',0,NULL,3,0,2,1,NULL,'nightwolf-ng '),(194,756370967012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',29.5,'eastar4','koren.zitser','korenzitser@hotmail.com','koren zitser','hava lutski 9/9','rehovot','merkaz','ISRAEL','76251','972524772300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 17:43:41',0,NULL,3,0,2,1,NULL,'koren.zitser '),(195,756388333012,220477365327,'UNLOCKED Option GTM382 PCI-E Modem WWAN GTM 382+antenna',1,'WWOP003+ANCN001',53.49,'eastar4','jedrzej.marszalkowski','gollum@reddragon.pl','Jędrzej Marszałkowski','Bagienna 2','Sieradz','łódzkie','POLAND','98200','503 113445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 18:16:26',0,NULL,3,0,3,1,NULL,'再发一个3G antenna ANCN001       jedrzej.marszalkowski\rRA022497410CN\r'),(196,561190160013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','pythqn','darvishzadeh@gmail.com','Mostafa Darvishzadeh S.','A-5-3, Arena Green, Bukit Jalil','Kuala Lumpur','WP Kuala Lumpur','MALAYSIA','57000','0173838411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 19:02:05',0,NULL,3,0,2,1,NULL,'pythqn '),(197,756421439012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','p0lpot','namitakirin@gmail.com','John F Schwamlein','906 Villa Venicia Way','Tampa','FL','UNITED STATES','33606-3406','(813) 508-7320','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 19:06:18',0,NULL,3,0,1,1,NULL,'p0lpot '),(198,680652559011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',16.59,'eastar4','javgim78','javgim78@ono.com','Javier Gimeno','Magistrado Monterde 7, 9','Torrente','Comunidad Valenciana','SPAIN','46900','686278183','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 20:35:02',0,NULL,3,0,2,1,NULL,'acer 4pin1.25 6cm    javgim78'),(199,561249674013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',5,'CASS001',43.5,'eastar4','sharmack96','sharmack96@yahoo.co.uk','S.P. Filipek','151 Silbury Blvd','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK91LH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 21:16:28',0,NULL,3,0,3,1,NULL,'sharmack96 \rRA022497468CN\r'),(200,510505963003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','rimautay','rimautay@yahoo.com','Richard Taylor','2613 Cordova rd','Orangeburg','SC','UNITED STATES','29115-9247','(803) 269-7155','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 21:43:57',0,NULL,3,0,1,1,NULL,'rimautay '),(201,680692594011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','2gbwhitman','togbwhitman@hotmail.com','Gregory Whitman','5822 Dusty Heath Ct','Katy','TX','UNITED STATES','77450','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 21:50:37',0,NULL,3,0,1,1,NULL,'2gbwhitman '),(202,680695063011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',12.95,'eastar4','rm_hurst','rm_hurst@yahoo.com','Rob Hurst','1500 S Jupiter Rd<br>Apt 1011','ALLEN','TX','UNITED STATES','75002-4144','(214) 383-3257','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 21:56:52',0,NULL,3,0,1,1,NULL,'rm_hurst '),(203,680697807011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',29.98,'eastar4','moses10777','rolf_030@gmx.net','Peter Pilz','Motzstr. 22<br>abgeben in The JAXX,Motzstr.19,ab 12 Uhr geöffnet','Berlin','','GERMANY','10777','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 22:03:30',0,NULL,3,0,3,1,NULL,'moses10777 \rRA022497675CN'),(204,561268335013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'eastar4','webwebes','alejandro_spa@hotmail.com','Alvaro Castilla','Plaza Europa Nº7 ; 1ºDcha','Torrejon de Ardoz','Madrid','SPAIN','28850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 22:10:56',0,NULL,3,0,3,1,NULL,'webwebes \rRA022497953CN\r'),(205,510516990003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',22.49,'cnfaner','one813','raiseone@aol.com','Fred serrano','2960 drew st apt 1021','clearwater','FL','UNITED STATES','33759','(727) 831-7183','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 22:22:20',0,NULL,3,0,1,1,NULL,'one813 '),(206,756556155012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',10.49,'eastar4','alexandre_cgr','alexandrepalhares@gmail.com','Alexandre Garcia Palhares','maria madalena','campo grande,','mato grosso do sul','BRAZIL','79004360','+55 67 33821690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 23:20:52',0,NULL,3,0,3,1,NULL,'alexandre_cgr \rRA022497746CN'),(207,753426721012,220750775183,'NEW seal SAMSUNG WIS09ABGNX/XTT WIS09ABGN Wi-Fi Adapter',1,'',69.99,'eastar4','skramdan','dantheskram@yahoo.com.au','daniel marks','19 delphi court<br>rossmoyne','perth','Western Australia','AUSTRALIA','6148','0894577924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 23:13:23',0,NULL,3,0,3,1,NULL,'skramdan \rRA022497984CN'),(208,756577704012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','lwonpurpose','lwhite@pcsii.com','Larry White','14 Highland Park Dr','Highland','AR','UNITED STATES','72542-9324','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 00:05:47',0,NULL,3,0,1,1,NULL,'lwonpurpose '),(209,516358719004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','prodinet.computacion','snc1972@hotmail.com','Sergio Czop','Carlos Pellegrini 650','Quilmes','Buenos Aires','ARGENTINA','1878','011 42545000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 00:25:33',0,NULL,3,0,3,1,NULL,'prodinet.computacion \rRA022497882CN'),(210,756584483012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','kaydonwelder334','kaydonwelder@yahoo.com','Scotty Daniel','1080 County Road 26','Roanoke','AL','UNITED STATES','36274','(334) 863-6955','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 00:28:33',0,NULL,3,0,1,1,NULL,'kaydonwelder334 '),(211,510555533003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','auctionwidower','ken.ebay@minker.dyndns.org','Ken Mink','12901 Edsel Dr','Raleigh','NC','UNITED STATES','27613','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'echeck   auctionwidower'),(212,680761679011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','dannir0','dan_nir@hotmail.com','Dan Nir','397 Front St. W.<br>Apt. 3310','Toronto','ON','CANADA','M5V 3S1','(647) 216-5988','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 01:16:32',0,NULL,3,0,2,1,NULL,'dannir0 、'),(213,680805575011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','1234garyl','garry.leech@internode.on.net','David Veldkamp','1 Collin Court<br>Kingston','Brisbane','Queensland','AUSTRALIA','4114','0424784131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 04:05:36',0,NULL,3,0,2,1,NULL,'1234garyl \\'),(214,756658728012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','pvt333','phuongtran333@yahoo.com','Phuong V. Tran','18219 Wall St','Carson','CA','UNITED STATES','90746','(714) 670-9038','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 04:49:58',0,NULL,3,0,1,1,NULL,'pvt333  \r发重了   周一再发一个 \\'),(220,756719918012,220716842449,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','tinguely_de','cesar.perera@bluewin.ch','Cesar Perera','Rebmattweg 30','Merlischachen','','SWITZERLAND','6402','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 09:59:22',0,NULL,3,0,2,1,NULL,'tinguely_de、'),(215,561375626013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.99,'eastar4','ca4ho','sanchowork@yandex.ru','Alexander Gutarov','27-Parts\'ezda Str. 4, app.36','Kinel','Samara region','RUSSIAN FEDERATION','446430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 07:25:16',0,NULL,3,0,2,1,NULL,'ca4ho、'),(216,510615537003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','cokivg','k_cuncic@yahoo.com','Krešimir Čunčić','Matice Hrvatske 7','Velika Gorica','CROATIA','CROATIA','10410','095/808-4398','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-15 08:06:59',0,NULL,3,0,3,1,NULL,'cokivg\rRA022497936CN'),(217,516428503004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','marianob9960','mariano.beguer@eu.omron.com','MARIANO BEGUER HORNA','CALLE RIO PEÑÓN 11','GUADALAJARA','Castilla-La Mancha','SPAIN','19005','949881030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 08:14:31',0,NULL,3,0,3,1,NULL,'marianob9960\rRA022497896CN、'),(218,516430093004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','chrischixxx','maackralf@wtnet.de','Ralf Maack','Rechnung<br>Poppenbütteler Str. 266a','Norderstedt','','GERMANY','22851','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 08:26:12',0,NULL,3,0,3,1,NULL,'chrischixxx\r'),(268,681286643011,320473794410,'New Logitech  battery 1250mAh Harmony remote 1000 1100',1,'BALO003',11.99,'eastar4','mbafalos','alexiosk@cytanet.com.cy','Alexios Koniotis','Tandalidi 3A','Larnaca','Larnaca','CYPRUS','6056','0035799533137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 07:05:21',0,NULL,3,0,2,1,NULL,'mbafalos、'),(269,516725931004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',44.98,'cnfaner','brilthor2','john@wice.ca','Jon Wice','Basement<br>144 Emerson St','Hamilton','ON','CANADA','L8S2X9','(253) 753-2095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 07:29:14',0,NULL,3,0,3,1,NULL,'brilthor2、RA022497834CN'),(270,516561576004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','paoloborghesi','spaceman1973@gmail.com','Paolo Borghesi','16 Rue Mathias Tresch','Luxembourg','','LUXEMBOURG','L-2626','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 08:15:43',0,NULL,3,0,2,1,NULL,'paoloborghesi   欧标、'),(271,510920638003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','igorfarkas','igor.farkas@email.t-com.hr','igor farkas','zvonimirova 16','velika gorica','','CROATIA','10410','+38598392156','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-16 08:17:07',0,NULL,3,0,3,1,NULL,'igorfarkas\rRA022495453CN'),(272,681312863011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','nicolle1031','ndube31@gmail.com','Nicolle Levesque','69 Sigourney St','Bristol','CT','UNITED STATES','06010','(860) 261-4624','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 09:14:42',0,NULL,3,0,1,1,NULL,'nicolle1031、'),(273,561732670013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','bergler11','adrian_heel@hotmail.com','Heel Adrian','Oberbach 43','Bach im Lechtal','','AUSTRIA','6653','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 09:49:52',0,NULL,3,0,3,1,NULL,'bergler11\rRA022496140CN'),(274,516766620004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY001*3',23.99,'cnfaner','zerg_32','serg.karpushev@gmail.com','Serg Karpushev','Chkalovsky 9 28','Saint-Petersburg','','RUSSIAN FEDERATION','197110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 11:25:14',0,NULL,3,0,3,1,NULL,'zerg_32\rRA022496065CN'),(275,681350150011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','chubuts','alex@chubays.com','Alexander Emshanov','Yauzskaya str. 6/8-41','Moscow','RU','RUSSIAN FEDERATION','109240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 11:44:52',0,NULL,3,0,2,1,NULL,'chubuts、'),(276,561758690013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','makroae1','christoph.jeker@intergga.ch','Christoph Jeker','Talackerstr. 9','Reinach/BL','','SWITZERLAND','4153','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 12:07:24',0,NULL,3,0,3,1,NULL,'makroae1\rRA022496153CN'),(277,561760827013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','monavita75','shelegs@gmail.com','Sergej Seleg','L. Asanaviciutes 48 - 54','Vilnius','Vilniaus','LITHUANIA','04319','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 12:18:40',0,NULL,3,0,2,1,NULL,'monavita75           欧标、'),(278,0,230597232803,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','beanman63','tvwcpa@comcast.net','Ted VanderWall','17413 Deer Point Dr','Orland Park','IL','UNITED STATES','60467','(708) 403-9654','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-16 13:16:54',0,NULL,3,0,1,1,NULL,'beanman63、'),(279,561787893013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','art22','artsworkshop1@comcast.net','Arthur J. Sulik','310 E Ridgewood Ave','Galloway','NJ','UNITED STATES','08205-9767','(609) 457-2190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 14:22:24',0,NULL,3,0,1,1,NULL,'art22\\'),(280,681417467011,320586526867,'HP Broadcom BCM94322 4322  mini PCI-E card wifi AGN',1,'WLHP001',18.99,'eastar4','heey09','c.asche@gmail.com','Christoph Asche','Woermannstr 20','Hannover','','GERMANY','30455','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 15:14:49',0,NULL,3,0,2,1,NULL,'heey09、'),(281,0,320671446937,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'',12.5,'eastar4','n00bhauser','hanky.mei@gmail.com','Georgia Tech Post Office','350 Ferst Drive<br>Attn: Heqing Mei Box #: 325679','Atlanta','GA','UNITED STATES','30332-0001','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 15:20:27',0,NULL,3,0,1,1,NULL,'n00bhauser   RELO002、'),(282,511005414003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','kazu4898','kazuo@e.email.ne.jp','Kazuo MORIOKA','Imajuku 2-12-10-16','Moriyama','Shiga','JAPAN','5240046','817775760421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 15:39:37',0,NULL,3,0,3,1,NULL,'kazu4898\rRA022496238CN'),(283,516715102004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','caretruck','datauto@hotmail.com','Juan Clemente Sanchez Rodriguez','Ildefonso Vasquez#1310 col. Francisco<br>I. Madero','Monterrey','Nuevo Leon','MEXICO','064560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 15:59:12',0,NULL,3,0,3,1,NULL,'caretruck\rRA022496136CN'),(284,757334159012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',5,'ANTY001*3',17.9,'eastar4','germanskynet','german-skynet@bk.ru','German Shramov','9/22, Gogol str.','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49044','+380674097000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 16:04:49',0,NULL,3,0,2,1,NULL,'germanskynet    、'),(285,757238099012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','gena_sh','gena08@gmail.com','shalva pichkhadze','hatsivoni 7-3','nesher','Israel','ISRAEL','38681','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 16:11:02',0,NULL,3,0,3,1,NULL,'gena_sh\rRA022496309CN'),(286,0,230597229448,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.76,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 16:32:07',0,NULL,3,1,1,1,NULL,'4278dennis     再发一个8V -AC adapter、'),(287,511026606003,130490260658,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.99,'cnfaner','hydoc73','hdwosh@rogers.com','Hy Dwosh','347 Cortleigh Blvd','Toronto','ON','CANADA','M5N1R4','(416) 418-7080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 16:59:14',0,NULL,3,0,3,1,NULL,'hydoc73RA022496224CN'),(288,681455958011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','cdtan99','charlesdonaldtan@gmail.com','Charles Donald Tan','M/F, ATL Logistics Centre B- Safety<br>Berth 3, Kwai Chung','New Territtory','','HONG KONG','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 17:05:59',0,NULL,3,0,2,1,NULL,'cdtan99、'),(289,516846696004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','thikalicious68','dionnika1968@yahoo.com','Miranda Vaughn','2622 Lee Road 239','Smiths Station','AL','UNITED STATES','36877-4730','(334) 214-5574','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 17:12:06',0,NULL,3,0,1,1,NULL,'thikalicious68、'),(290,757391809012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','rivell56143','zigen@rkmail.ru','Vacheslav Abramovsky','Bumashnikov 8-8','Kondopoga','Karelia','RUSSIAN FEDERATION','186220','89214650777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 18:07:04',0,NULL,3,0,2,1,NULL,'rivell56143、'),(291,757396916012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','dread_hunter777','dread86@bk.ru','Sergey Yakushev','Dror56/9','Rishon-Le-Zion','','ISRAEL','75296','+972 547899650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 18:16:35',0,NULL,3,0,2,1,NULL,'dread_hunter777、'),(292,516703754004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','pcsncards','itznanna@aol.com','curtis Lavin','13841 N 57th St','Scottsdale','AZ','UNITED STATES','85254-3013','(914) 441-8763','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 19:29:23',0,NULL,3,0,1,1,NULL,'pcsncards、'),(293,511095329003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','boscarorudy','rudyboscaro@hotmail.it','enrico boscaro','via chiesa 114<br>gambarare','mira','VE','ITALY','30034','3332675755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 20:16:32',0,NULL,3,0,3,1,NULL,'boscarorudy  欧标\rRA022496215CN'),(294,681570234011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','alfre1975','alfredo.nunez@terra.es','Esther Saldaña Bernal','CPerdiguero de Burgos 14 5ºC','Burgos','Castilla y León','SPAIN','09003','645774108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 20:36:03',0,NULL,3,0,2,1,NULL,'alfre1975、'),(295,681569959011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','dimjan12','dimjan-12@inbox.lv','Dmitrijs Vaitjulevics','Pavasara gatve 6-54','Riga','','LATVIA','LV1082','(371)29503493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 20:40:08',0,NULL,3,0,2,1,NULL,'dimjan12、'),(296,757464861012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','dimaluk','dima-lukashenko@yandex.ru','Дмитрий Лукашенко','ул.Орловская д.27 кв.10','Брянск','','RUSSIAN FEDERATION','241012','+7(920)6002838','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-16 20:57:47',0,NULL,3,0,3,1,NULL,'dimaluk\rRA022496079CN'),(297,681590633011,320473794410,'New Logitech  battery 1250mAh Harmony remote 1000 1100',1,'BALO003',11.99,'eastar4','mhandmh','mhx2@bellsouth.net','Michael J. Holmbeck','13526 Emeraldview Dr','Orlando','FL','UNITED STATES','32828','(407) 616-8088','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-16 21:19:40',0,NULL,3,0,1,1,NULL,'mhandmh、'),(298,561927785013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','yaboy1956','buenterprises@yahoo.com','Alvin Wright','8448 Crossland Loop<br>Ste 142','Montgomery','AL','UNITED STATES','36117-0951','(334) 649-3045','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 21:25:41',0,NULL,3,0,1,1,NULL,'yaboy1956   银色的\\'),(299,561944232013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','kesh342','patr1ck342@mail.ru','Dmitry Popov','Moskovskaya street 342/9-56','Brest','Belarus','RUSSIAN FEDERATION','224023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 22:07:39',0,NULL,3,0,2,1,NULL,'kesh342、'),(300,511149088003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',2,'HSMO018',25.98,'cnfaner','herr_mimiker','cesar.parra.r@gmail.com','César Parra','Los Vilos 7855','Santiago','Región Metropolitana','CHILE','8780669','+56982238282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 23:13:36',0,NULL,3,0,3,1,NULL,'herr_mimiker\rRA022496241CN'),(301,561008106013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.99,'eastar4','richlock10','r.lock1@verizon.net','richard lockett','23502 Coyote Springs Dr','diamond bar','CA','UNITED STATES','91765-2621','(909) 612-0735','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 23:34:16',0,NULL,3,0,1,1,NULL,'richlock10、'),(302,757568425012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',2,'HSPL011',44,'eastar4','davegees','skillz04@yahoo.com','dave brown','625 caroline dr','norristown','PA','UNITED STATES','19401-3517','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 23:54:59',0,NULL,3,0,1,1,NULL,'davegees、'),(303,516976193004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',32.9,'cnfaner','onlydarling','ravi.saraswat@gmail.com','Ravi Saraswat','53,Tineta Crescent,<br>Scarborough','TORONTO','ON','CANADA','M1S 2Y5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 00:07:53',0,NULL,3,0,3,1,NULL,'onlydarling\rRA022496272CN  \r'),(304,561977098013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','lien197171','bos157@ziggo.nl','E van den Bos','Egellaan 28','VEENENDAAL','','NETHERLANDS','3903CP','0318553702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 00:19:14',0,NULL,3,0,2,1,NULL,'lien197171    欧标 \\'),(305,681666945011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',2,'RCLO006',99.98,'eastar4','mpronovost1','martin@yaknet.ca','martin pronovost','106 santa','st-jerome','QC','CANADA','j7y4l6','(450) 436-9923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 00:50:50',0,NULL,3,0,3,1,NULL,'mpronovost1RA022496365CN   '),(306,681668686011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','tdhalbert','thalbert@yahoo.com','Tom Halbert','Box 563 - 1023 Creekside Village<br>500 Adelaide St.','Pincher Creek','AB','CANADA','T0K1W0','(403) 627-2411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 00:57:51',0,NULL,3,0,2,1,NULL,'tdhalbert\\'),(307,561982545013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','wit-sh','wit_sh@gmx.net','Pisec GmbH, vitali chichkine','Goettweihergasse 1/8','wien','','AUSTRIA','1010','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 01:06:34',0,NULL,3,0,2,1,NULL,'wit-sh   欧标、'),(308,0,230597232246,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.25,'eastar4','dsharp101','jdavis6825@aol.com','joseph davis','Po box 321','east orange','NJ','UNITED STATES','07019-0321','(973) 449-3355','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 02:49:24',0,NULL,3,0,1,1,NULL,'dsharp101、'),(309,757622397012,220741015891,'New Motorola H350 Bluetooth Wireless Headset H 350',2,'HSMO005',25.98,'eastar4','adambergen1204','adam_stargate@yahoo.ca','adam bergen','box 486','winkler','MB','CANADA','r6w4a7','(120) 436-2634 ext.: 6','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 03:08:56',0,NULL,3,0,2,1,NULL,'adambergen1204  黑色的\\'),(310,753048822012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','superkoala','trimakasi@freenet.de','Ralf Richter','Meyerstraße 56','Bremen','','GERMANY','28201','Invalid Request','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'superkoala'),(311,757691859012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',2,'BALO001',20.98,'eastar4','unifix2004','arcelina@t-online.de','Frank Raschke','Lökesfeld 26','Ratingen','','GERMANY','40885','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 08:54:47',0,NULL,3,0,2,1,NULL,'unifix2004\\'),(312,562068306013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','mat0373','mathewv@pb.ozemail.com.au','Mathew Phillip Vanderleer','24 Bayside Boulevard<br>Port Kennedy','Perth','Western Australia','AUSTRALIA','6172','0895246239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 09:48:04',0,NULL,3,0,3,1,NULL,'mat0373\rRA022496493CN\\'),(313,757725881012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',15.99,'eastar4uk','yoshiyasukouichi','yoshiyasu@toughenough.jp','Koichi Yoshiyasu','Higashi 4-4-12<br>#106','Shibuya ku','Tokyo','JAPAN','150-0011','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-17 11:07:22',0,NULL,3,0,2,1,NULL,'yoshiyasukouichi\\'),(314,757732634012,220455477514,'HP 8710w nw9440 nx9420 Bluetooth Module EDR 2.0 +cable',2,'BTHP2005',28.98,'eastar4','69monkee','lmwyss1@gmail.com','Larry Wyss','2909 Hameln Dr','Saint Charles','MO','UNITED STATES','63301','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 11:32:37',0,NULL,3,0,1,1,NULL,'69monkee    HP 8pin 1.0 20cm、'),(315,757741105012,220743499505,'NEW Genuine Motorola S9 Bluetooth Stereo Headset',1,'HSMO002',31,'eastar4uk','ben-hearne','bernard.hearne@gmail.com','Ben Hearne','Milestown<br>Cloneen','Clonmel','Tipperary','IRELAND','','0868562275','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-17 12:01:24',0,NULL,3,0,3,1,NULL,'ben-hearne   英标\rRA022496768CN\\'),(316,681816571011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','plazomat','plaz@rogers.com','Tony Perfetto','123 Belair Way','Woodbridge','ON','CANADA','L4L 7S9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 12:24:00',0,NULL,3,0,2,1,NULL,'plazomat\\'),(317,681821318011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',16.59,'eastar4','seluxxl','seluxl@hotmail.com','selu valladolid','santa isabel 16','almonte (huelva)','Andalucía Ceuta y Melilla','SPAIN','21730','959451454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 12:40:34',0,NULL,3,0,2,1,NULL,'seluxxl    acer 8pin1.00 15cm\\'),(318,681847306011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','gsollfrank','georg.sollfrank@web.de','Georg Sollfrank','Wilhelm Leibl Str. 23','Holzkirchen','','GERMANY','83607','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:11:30',0,NULL,3,0,2,1,NULL,'gsollfrank\\'),(319,511292749003,130490976227,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',15.99,'cnfaner','htunlogic','tibor.hudik@gmail.com','Tibor Hudik','Kapelska 6','Osijek','CA','CROATIA','31000','091 210 8865','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:43:33',0,NULL,3,0,3,1,NULL,'htunlogic\rRA022496808CN\\'),(320,510348526003,130489932541,'%%% NEW Lowepro Rover AW II Photo Camera Bag Backpack ',1,'',79.99,'cnfaner','drishteemungur','drishtee21@gmail.com','Drishtee Mungur','49, Lapeyrousse Street<br>Eau-Coulee','Curepipe','Curepipe','MAURITIUS','230','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-17 12:58:55',0,NULL,5,0,18,0,NULL,'drishteemungur'),(321,0,320671982482,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'',8.99,'eastar4','chinabeach65','giongabor@yahoo.com','Gabor GION','5, Odos Athinon','Lefkosia','AGIOS DOMETHIOS','CYPRUS','2363','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 15:11:11',0,NULL,3,0,2,1,NULL,'chinabeach65    HSPL001\\'),(322,0,320671983552,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12,'eastar4','gregoryc631','funaki4u@gmail.com','gregory carter','203 hawthorne ave apt 30','central islip','NY','UNITED STATES','11722','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 15:17:55',0,NULL,3,0,1,1,NULL,'gregoryc631、'),(323,681873340011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','dabue','dabue1983@yahoo.com','david bue','5175 jumper st','cocoa','FL','UNITED STATES','32927','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 15:24:02',0,NULL,3,0,1,1,NULL,'dabue、'),(324,0,320671980941,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',12.24,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 15:44:37',0,NULL,3,0,1,1,NULL,'4278dennis    一共买了两个、'),(325,757817712012,220711639863,'New Logitech Rechargeable battery 890 880 950mA+charger',1,'BALO001+BAIN002',15.99,'eastar4','limooihwa','ohlim@yahoo.com','Lim Ooi Hwa','Wisma Algotech, 43-1 & 43-M, Medan Setia 1, Plaza Damansara, Damansara Heights','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','50490','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 15:55:54',0,NULL,3,0,2,1,NULL,'limooihwa\\'),(326,562155311013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','10tdm850','sergei0508@mail.ru','Сергей Горячев','Карла маркса, 19, 19','Верхняя Салда','Свердловская область','RUSSIAN FEDERATION','624760','89222175772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:27:52',0,NULL,3,0,2,1,NULL,'10tdm850   欧标\\'),(327,757831741012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','korolevich1968','kristinakor@balticum-tv.lt','Sergej Koroliov','Laukininku<br>35-09','Klaipeda','Klaipeda','LITHUANIA','95173','0037063122648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:24:06',0,NULL,3,0,2,1,NULL,'korolevich1968\\'),(328,561632925013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',2,'MOSA002',149.6,'eastar4','lcs200977','lcs77@gmx.de','Patrick Sauer','Am Köpping 5','Eisenach','','GERMANY','99817','Invalid Request','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-17 16:23:27',0,NULL,3,0,3,1,NULL,'lcs200977\rRA022496710CN\\\r'),(329,517139462004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','gorodok0','grabsky@sbcglobal.net','val grabsky','1207 Moncoeur Dr','Saint Louis','MO','UNITED STATES','63146-5342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 16:27:37',0,NULL,3,0,1,1,NULL,'gorodok0、'),(330,0,320671984923,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'',13.99,'eastar4','skiptomymoo','jeffreyluu@gmail.com','Jeffrey Luu','24540 Skyridge Dr','Newhall','CA','UNITED STATES','91321-3552','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 16:40:51',0,NULL,3,0,1,1,NULL,'skiptomymoo    WLDE002、'),(331,562158742013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',10.99,'eastar4','imazshna','n_peermohamed@yahoo.com','Imran Peermohamed','41 Windy Golfway','Toronto','ON','CANADA','M3C3A6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:39:31',0,NULL,3,0,2,1,NULL,'imazshna\\'),(332,0,320671983892,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12,'eastar4','shenshaw1976','henshaw76@hotmail.com','stuart henshaw','27 pacific way<br>beldon','perth','Western Australia','AUSTRALIA','6027','0422927547','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'shenshaw1976'),(333,511331895003,130458644453,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET track#',1,'HSNO015',35.99,'cnfaner','igarok82','igal821@bezeqint.net','Igal Berger','Yoav Ben Zroya 10/40','Ashdod','Israel','ISRAEL','77525','+256006363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 17:05:52',0,NULL,3,0,3,1,NULL,'igarok82\rRA022496480CN\r'),(334,562171127013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','gugadalmolin','guga_dalmolin@hotmail.com','Gustavo Dal Molin','Rua Silveiro, 1007, Casa 5','Porto Alegre','Rio Grande do Sul','BRAZIL','90850-000','5132321199','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 17:22:08',0,NULL,3,0,3,1,NULL,'gugadalmolin\rRA022496414CN\\'),(335,681831103011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','phlash2k','msp084@hotmail.com','Mike Potter','5311 Cider Mill Rd','Erie','PA','UNITED STATES','16509-3947','(412) 417-6847','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 13:14:20',0,NULL,3,0,1,1,NULL,'phlash2k、'),(336,757877292012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',3,'OTGR001',59.7,'eastar4','vladimirmi','finwise@gmail.com','VOLODIMIR MIHAYLOV','per.2 Odesskij dom 9 kv.2','Cherkassy','Cherkasy region','UKRAINE','18000','+380505025230','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 18:04:37',0,NULL,3,0,3,1,NULL,'vladimirmi\rRA022496476CN\\'),(337,681947019011,320665720437,'New Genuine Sony Ericsson HBH-608 Bluetooth  Headset',1,'HSSE007',19.9,'eastar4','modulist','belkons69@gmail.com','Konstantin Belov','prospekt  Gagarina, d 13, kv 1','Yoshkar-Ola,','Mari El','RUSSIAN FEDERATION','424006','+79276806910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 18:36:47',0,NULL,3,0,2,1,NULL,'modulist     欧标\\'),(338,0,220755495501,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'',9.99,'eastar4','country*1','howard.gerdes@mchsi.com','Howard Gerdes','PO Box 113<br>104 E. Gilman','Secor','IL','UNITED STATES','61771','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-17 19:49:22',0,NULL,3,0,1,1,NULL,'country*1   OMHJ001、'),(339,682021230011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','gary811000','gary811000@yahoo.com','GARY GREENWALD','811 Hidden Valley Ln','RICHMOND','IN','UNITED STATES','47374-5161','(765) 962-7486','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 20:54:06',0,NULL,3,0,1,1,NULL,'gary811000、'),(340,562250559013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',16.59,'eastar4','tkuepper','microship@gmx.net','Thomas Küpper','Lothringer Str. 13','Mönchengladbach','','GERMANY','41061','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 20:58:48',0,NULL,3,0,2,1,NULL,'tkuepper      HP 8pin 1.0 23cm \\'),(341,511394343003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','shannie250','reggie250@hotmail.com','reinaldo','urb loma alta calle 4 blq.C #41<br>urb loma alta calle 4 blq.C #41','Carolina','PR','UNITED STATES','00987','(787) 698-0090','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 20:27:58',0,NULL,3,0,1,1,NULL,'shannie250、'),(342,681872512011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ccharlesh','charleshan-@hotmail.com','Charles Han','20792 123 Ave.','Maple Ridge','BC','CANADA','V2X4A9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 15:21:13',0,NULL,3,0,2,1,NULL,'ccharlesh\\'),(343,757964801012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','8727stevenj','stevenjohnson4@hotmail.com','steven johnson','9907 crystal falls drive','hagerstown','MD','UNITED STATES','21740','(240) 723-6806','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 20:40:26',0,NULL,3,0,1,1,NULL,'8727stevenj、'),(344,682035905011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',118.99,'eastar4','mceachern_jr','mceachern_jr@yahoo.com','Bob McEachern Jr.','720 N 64th St','Waco','TX','UNITED STATES','76710-4387','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 21:21:56',0,NULL,3,0,1,1,NULL,'mceachern_jr\\'),(345,757986114012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','spark33150','spark3315@hotmail.com','Hatice Karaca','Dedekorkut mh.eserler sk<br>Raykent Sit.Nu.:19-4','konya,meram','TN','TURKEY','42080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 21:23:47',0,NULL,3,0,2,1,NULL,'spark33150\\'),(346,681905420011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','dino_ferrari','myles_melillo@snet.net','myles melillo','30 Melillo Cir','north haven','CT','UNITED STATES','06473-2126','(203) 248-1148','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 16:58:23',0,NULL,3,0,1,1,NULL,'dino_ferrari、'),(347,562268415013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','teixeiramarcelo2010','teixeiramarcelo1@hotmail.com','Mauricio Alves Teixeira','Euler de Azevedo nº 417','Campo Grande','Mato Grosso do Sul','BRAZIL','79116-610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 21:52:22',0,NULL,3,0,2,1,NULL,'teixeiramarcelo2010   CAB-6060    三个\\'),(348,517216069004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','kyssis13','jan.kyselka@tiscali.cz','jan kyselka','nawkova 345','ceska lipa','liberecky kraj','CZECH REPUBLIC','47001','420737137070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 20:26:01',0,NULL,3,0,3,1,NULL,'kyssis13   欧标\rRA022496723CN\\   '),(349,682017156011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','mariano.bispo','mariano_bispo@hotmail.com','Mariano Bispo Silva Neto','Rua:quinta do Regalo,71<br>Americanopolis','São Paulo','SP','BRAZIL','04335-120','11-5562-0035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 20:45:42',0,NULL,3,0,2,1,NULL,'mariano.bispo\\'),(350,682081296011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',2,'RCLO006',99.98,'eastar4','diegosanabrazil','diego.flogao@uol.com.br','Diego  de Morais Sana','Rua Diogenes Nascimento das Neves 165/102B','Vitoria','Espirito Santo-ES','BRAZIL','29055915','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 23:24:50',0,NULL,3,0,3,1,NULL,'diegosanabrazil\rRA022496842CN\\'),(351,758050828012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',2,'HSNO005',21.76,'eastar4uk','02finchley','ash1ferrari@hotmail.com','Ashraf Borghol','283 Finchley Road','London','London','UNITED KINGDOM','NW36ND','02076927199','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-18 00:06:44',0,NULL,3,0,3,1,NULL,'02finchley   英标\rRA022496856CN\\   '),(352,754361018012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',20,'TRMX003',309,'eastar4','snappy-seller','nabeel.malik@hotmail.com','Nabeel Malik','339 Knollwood Trl','Richmond Heights','OH','UNITED STATES','44143','(216) 272-8251','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 00:09:44',0,NULL,3,0,4,1,NULL,'snappy-seller   一共买了20个210TS       20个MX20T\rYW864871143CN\r'),(353,0,230597696391,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'',12.99,'eastar4','vealbird','jrob2524@yahoo.com','James Robinson','2526 Meredith St','Philadelphia','PA','UNITED STATES','19130-2422','(215) 765-1840','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'vealbird'),(354,562309858013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','saucy_28','cmoney85222@hotmail.com','Cruz  bradford','637 E Manor Dr','Casa Grande','AZ','UNITED STATES','85222','(520) 208-5369','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 00:38:37',0,NULL,3,0,1,1,NULL,'saucy_28、'),(355,562312877013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','fdamata','fabianodamata@yahoo.com.br','Fabiano da Mata Almeida','Rua Domingos Belem, 47/204<br>Fonte Grande','Contagem','MG','BRAZIL','32013-130','+55 31 86343417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 00:56:54',0,NULL,3,0,3,1,NULL,'fdamata\rRA022496502CN\\'),(356,0,230597704797,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',30.49,'eastar4','heberthunt','heberthunt@hotmail.com','David Hebert','144 Grand Ave','Lafayette','LA','UNITED STATES','70503','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 02:16:43',0,NULL,3,0,1,1,NULL,'heberthunt、'),(357,758095559012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',15.9,'eastar4uk','mokirra','kirra9@hotmail.com','michael keily','48 roden st','melb','Victoria','AUSTRALIA','3003','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-18 02:42:09',0,NULL,3,0,2,1,NULL,'mokirra   澳标\\'),(358,758096593012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',29.5,'eastar4','rcoberly75','allen.coberly@yahoo.com','richard  coberly','102 tarleton bivouac','williamsburg','VA','UNITED STATES','23185-6227','(757) 218-3089','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 02:47:45',0,NULL,3,0,1,1,NULL,'rcoberly75、'),(359,562339371013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',1,'BAZA001',83.6,'eastar4','kweechuan73','kcang73@hotmail.com','Kwee Chuan Ang','Blk 231 Ang Mo Kio Ave 3<br>#09-1228','default','','SINGAPORE','560231','96536223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 03:11:14',0,NULL,3,0,3,1,NULL,'kweechuan73    BAZA001 \rRA022496555CN\\'),(360,682145510011,320462974714,'2.0 New ASUS Bluetooth Module +cable epc901 epc1000',1,'BTHU2004',12.88,'eastar4','bigsoftkitty7','hairybbw@ymail.com','Nina Kirsanova','MD2044 Moldova, repulic of, Chisinau, A.Russo str. 63/4 ap.43','Chisinau','mun Chisinau','MOLDOVA, REPUBLIC OF','MD2044','+37369428894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 03:22:50',0,NULL,3,0,2,1,NULL,'bigsoftkitty7    \r10 pin 1.0 5cm \r\\'),(361,0,220755501016,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'',10.29,'eastar4','shawabkeh86','i_d_shawabkeh@yahoo.com','shawabkeh86 alshawabkeh','37 royal crest dr<br>apt 6','nashua','NH','UNITED STATES','03060-6623','(508) 440-9646','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 03:29:52',0,NULL,3,0,1,1,NULL,'shawabkeh86    HSPL005、'),(362,682074566011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tlb_global','ebay@thefubar.co.uk','Tony Butcher','10 Thorkhill Road','Thames Ditton','Surrey','UNITED KINGDOM','KT7 0UE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 23:02:04',0,NULL,3,0,2,1,NULL,'tlb_global\\'),(363,758122136012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jasonglasser','jasondglasser@gmail.com','Jason Glasser','980 Montecito Dr<br>Ste 202','Corona','CA','UNITED STATES','92879-1795','(951) 858-8975','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 04:41:24',0,NULL,3,0,1,1,NULL,'jasonglasser、'),(364,511499186003,130490207271,'New Logitech harmony Li-ion Rechargeable Battery1250mAh',1,'BALO003',11.99,'cnfaner','waltdarmanin','waltd2@bigpond.com','walt darmanin','12  sea cliff place','caves beach','New South Wales','AUSTRALIA','2281','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 04:46:03',0,NULL,5,0,18,0,NULL,'waltdarmanin'),(365,758123779012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',15,'eastar4uk','bazzelsm218','mbazzel@hotmail.com','Susan Bazzel','27 White Oak Rd','Landenberg','PA','UNITED STATES','19350-1027','(610) 255-0354','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-18 04:51:04',0,NULL,3,0,1,1,NULL,'bazzelsm218、'),(366,562359248013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','phlwbg131517','philippe.lowemberg@wanadoo.fr','Philippe LOWEMBERG','11 quai Francois Mauriac<br>CODE GRILLE 15461','PARIS','Île-de-France','FRANCE','75013','01.44.24.16.50','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 05:15:11',0,NULL,3,0,3,1,NULL,'phlwbg131517     MOSA003\rRA022496462CN\\'),(367,511504544003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','haygij85','haygij@gmail.com','Karen Ashotyan','Ha\'atsmaut 40/20','Herzeliya','Hasharon','ISRAEL','46789','0545299908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 05:43:19',0,NULL,3,0,2,1,NULL,'haygij85   \\'),(368,682179797011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','sonnyblack273','thomas.hippold@online.de','Thomas Hippold','Rheinstr. 37h','Osthofen','','GERMANY','67574','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 06:59:21',0,NULL,3,0,2,1,NULL,'sonnyblack273'),(369,562374926013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','robbotheyobbo08','robby0809@yahoo.com.au','Robby Bruce','9/36 Epsilon Drive<br>Rockingham','Perth','Western Australia','AUSTRALIA','6168','0061450221468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:41:10',0,NULL,3,0,3,1,NULL,'robbotheyobbo08       MOSA002\r RA022496860CN\\'),(370,758154020012,220546791970,'Yagi 16dBi 2.4 GHz 802.11b/g Wifi Antenna RP-SMA',1,'ANYA001',14.45,'eastar4','ksy_com','ksycom@gmail.com','KSY.Computer','43 Sangchuto Rd.<br>T.Tamakam','Moung','Kanchanaburi','THAILAND','71000','6634624422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:53:50',0,NULL,3,0,11,1,NULL,'ksy_com   ANYA001'),(371,682178098011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','astro_ca','gpuntchev@gmail.com','Gueorgui I Pountchev','231-7280 Darcel Ave.','Mississauga','ON','CANADA','L4T 3T7','(416) 428-3401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 06:47:40',0,NULL,3,0,2,1,NULL,'astro_ca'),(372,758159216012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.98,'eastar4','ssargavinski','percival@tele2.hr','Srđan Šargavinski','E. Kvaternika 14','Čepin','','CROATIA','31431','+385955055144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:18:04',0,NULL,3,0,2,1,NULL,'ssargavinski'),(373,562383618013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.85,'eastar4','nittenyadhav3','nittenyadhavebay@gmail.com','Nitten Yadhav','SkillSoft Ireland<br>Block 7, Belfield Office Park, Clonskeagh','Dublin','Dublin','IRELAND','4','0877479291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:41:27',0,NULL,5,0,2,1,NULL,'nittenyadhav3'),(374,562385693013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',64.45,'eastar4','kokdima','volde@mail.ru','Dmitriy Volodenkov','Mayakovskogo str. 18-197','Krasnoyarsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','660003','8(391)275-79-50','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:55:23',0,NULL,8,0,17,0,NULL,'kokdima'),(375,682202326011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','kokdima','volde@mail.ru','Dmitriy Volodenkov','Mayakovskogo str. 18-197','Krasnoyarsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','660003','8(391)275-79-50','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:56:37',0,NULL,3,0,3,1,NULL,'kokdima  再发一个IBM Intel Advanced-N WiMAX 6250 622ANXHMW       RA022496989CN  \\'),(376,562389857013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','teeem','tim.mironov@gmail.com','Veronika Mironova','Amirkhana str, 10a/2, apt. 74','Kazan','Tatarstan','RUSSIAN FEDERATION','420126','+7-917-897-96-88','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 09:27:46',0,NULL,3,0,3,1,NULL,'teeem\rRA022496670CN\r'),(377,511536068003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.99,'cnfaner','mfotinakis68','michael.fotinakis@gmail.com','Michael Fotinakis','Karaoli 40-42','Athens','Aharnai','GREECE','13671','6942433343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 09:58:00',0,NULL,3,0,3,1,NULL,'mfotinakis68   欧标\rRA022495201CN\r'),(378,562398119013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','vitalybu','vitalybu@gmail.com','Vitaly Bukhovsky','14 Vered St.','Bney-Aish','','ISRAEL','60860','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 10:15:39',0,NULL,3,0,3,1,NULL,'vitalybu\rRA022496771CN\r'),(379,562404324013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','elise2k1','chun168@yahoo.com','Man Wong','Optus OCSE3, 1 Lyonpark Road<br>Macquarie Park','Sydney','New South Wales','AUSTRALIA','2113','0423609953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 10:49:07',0,NULL,3,0,3,1,NULL,'elise2k1\rRA022495246CN\r'),(380,561778495013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',8,'WLAP008',151.92,'eastar4','don-bx11','hae_tho_don@gmx.de','Thomas Häckl','Geschwister-Scholl-str.38','Donauwörth','','GERMANY','86609','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 11:52:08',0,NULL,3,0,3,1,NULL,'don-bx11 \rRA022496604CN\r'),(381,561779309013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',5,'WLAT001',74.95,'eastar4','www_nontoxic-store24_de','info@nontoxic-store24.de','Thomas Häckl','Geschwister-Scholl-Str.38','Donauwörth','','GERMANY','86609','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 11:57:16',0,NULL,3,0,3,1,NULL,'www_nontoxic-store24_de\rRA022495881CN\r'),(382,517388581004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','asus78m','asus78@yahoo.it','rosa santangelo','viale regione siciliana sud est<br>2219','palermo','PA','ITALY','90126','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 12:52:52',0,NULL,3,0,3,1,NULL,'asus78m   欧标\rRA022495904CN\r'),(383,758247769012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',81.95,'eastar4','stevebv','stefanvock@gmx.at','Vock Stefan','Marchetstrasse 14','Baden','','AUSTRIA','2500','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 13:37:55',0,NULL,3,0,3,1,NULL,'stevebv\rRA022495935CN\r'),(384,758275590012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',10.69,'eastar4','silviademelao','silviademelao@hotmail.com','RICARDO  MACHADO','Rua Otto Lacerda França 27<br>Bandeirantes','Leopoldina','Minas Gerais','BRAZIL','36700-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 14:54:42',0,NULL,3,0,2,1,NULL,'silviademelao\\'),(385,511596564003,130490963246,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',15.5,'cnfaner','csjsolar','csj@atvci.net','Charlie R Solar JR','7212 Highway 182 E','Morgan City','LA','UNITED STATES','70380-2167','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 15:11:32',0,NULL,3,0,1,1,NULL,'csjsolar\\'),(386,510555533003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','auctionwidower','ken.ebay@minker.dyndns.org','Ken Mink','12901 Edsel Dr','Raleigh','NC','UNITED STATES','27613','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 15:46:31',0,NULL,3,0,1,1,NULL,'auctionwidower\\'),(387,0,220754847095,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',8.99,'eastar4','peterr0123','peterr0123@yahoo.gr','Peter Triantafyllopoylos','DOCK 10  (APOTHIKI DUTY FREE) tel +30 6977218078<br>PATRAS PORT','PATRA','ACHAIA','GREECE','26223','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 15:47:32',0,NULL,3,0,3,1,NULL,'peterr0123\rRA022495952CN\r'),(388,758273886012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',2,'OTAP001',21.38,'eastar4','xmen4ugt','xmen4u@gmail.com','Gil Tamari','10 Nemirover St.','Tel aviv','','ISRAEL','69713','97236447976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 16:24:57',0,NULL,3,0,2,1,NULL,'xmen4ugt\\'),(389,758313345012,220459525292,'Acer Aspire 5550 5551 5552 Bluetooth Module 2.0 +cable',1,'BTAC2006',14.49,'eastar4','malacat_ent','steve@malacat.ca','Steve Bradshaw','1033 Braithwaite Drive','Cobble Hill','BC','CANADA','V0R1L4','(250) 743-3137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 16:29:01',0,NULL,3,0,2,1,NULL,'malacat_ent     acer 4pin1.25 15cm \\'),(390,517439898004,140516092415,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'cnfaner','lj_kokomo','lj_kokomo@yahoo.com','Joseph Petrich','14814 Burbank Blvd<br>Apt 12','Sherman Oaks','CA','UNITED STATES','91411','(323) 857-3512','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 16:35:02',0,NULL,3,0,1,1,NULL,'lj_kokomo\\'),(391,0,230597229456,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'',22.02,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 16:41:12',0,NULL,8,0,17,0,NULL,'4278dennis     SCLO001     \r 再发一个AC adapter     POLO001  '),(392,562497156013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','sasiri_w','sasiriw@gmail.com','Dr Sashika Weerathunga.','905 / 1,<br>Aluwihare,','Mathale.','','SRI LANKA','0000','+94772314617','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 17:16:30',0,NULL,3,0,2,1,NULL,'sasiri_w\\'),(393,758347922012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','sonocite','sonocite@yahoo.fr','SONO CITE Service Technique','avenue de la libération 16','ghlin','','BELGIUM','7011','0494-276983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 17:47:19',0,NULL,3,0,2,1,NULL,'sonocite\\'),(394,682302118011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','physics_tech_man','rbeery@i2k.com','Ronald Beery','760 S Waverly Rd<br>C/O A.S.M.','Holland','MI','UNITED STATES','49423-9121','(616) 209-5266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 18:02:38',0,NULL,3,0,1,1,NULL,'physics_tech_man\\'),(395,517473358004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','slava1661','s_l_a_w_a@inbox.lv','Vjaceslavs Kursits','Smiltenes iela 4-6','Daugavpils','Latgale','LATVIA','LV-5401','+37129959984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 18:30:10',0,NULL,3,0,3,1,NULL,'slava1661    欧标\rRA022496697CN\r\r'),(396,511647433003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',22.49,'cnfaner','shorah_ann','shorah.ann@gmail.com','Anna Doroshina','Minskaya 21-70','Smolensk','Smolensk','RUSSIAN FEDERATION','214034','+79517055202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 19:10:51',0,NULL,3,0,3,1,NULL,'shorah_ann\rRA022495192CN\r'),(397,562533161013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','themooschina','d.velin@mail.ru','Dmitry Velin','pr. Lenina, 30a, 45','Chelyabinsk','','RUSSIAN FEDERATION','454091','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 19:03:21',0,NULL,3,0,2,1,NULL,'themooschina   欧标\\'),(398,562543934013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','shelby220077','redteam_77@hotmail.com','Ste-marie Jean','810 coté','Thetford mines','QC','CANADA','G6G7B6','(418) 338-4979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 19:31:38',0,NULL,3,0,2,1,NULL,'shelby220077\\'),(399,562562272013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','dieterhm','dieter.h.mayer@t-online.de','Dieter Mayer','Falkenweg 4 1/2','Königsbrunn','','GERMANY','86343','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 20:22:51',0,NULL,3,0,2,1,NULL,'dieterhm   欧标\\'),(400,516628254004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',32.8,'cnfaner','just371','wlkjr7@aol.com','Jerome Walker','230 W Runyon St','Newark','NJ','UNITED STATES','07108-1722','(732) 921-2387','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 20:29:19',0,NULL,3,0,1,1,NULL,'just371、'),(401,682458900011,320586526867,'HP Broadcom BCM94322 4322  mini PCI-E card wifi AGN',1,'WLHP001',18.99,'eastar4','coinburgh','timkrofchik@gmail.com','Tim Krofchik','435 Violet Dr','Lower Burrell','PA','UNITED STATES','15068-3339','(412) 951-8455','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 21:07:39',0,NULL,3,0,1,1,NULL,'coinburgh\\'),(402,682463210011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','drulf42','2ulf@gmx.de','Ulf Garbotz','Baumschulenweg 74','Remagen','','GERMANY','53424','Invalid Request','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'drulf42'),(403,758445899012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','hudson7910','hudson7910@comcast.net','matt hudson','12307 nw 36th ave','vancouver','WA','UNITED STATES','98685-2222','(503) 895-0609','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 21:00:07',0,NULL,3,0,1,1,NULL,'hudson7910\\'),(404,682462322011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','chris4p8o','chris@yewchuk.com','A. Junaki','50 Dent Street','Glen IRIS','Victoria','AUSTRALIA','3146','(862) 812-3176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 21:02:27',0,NULL,3,0,2,1,NULL,'chris4p8o\\'),(405,682463210011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','drulf42','2ulf@gmx.de','Ulf Garbotz','Baumschulenweg 74','Remagen','','GERMANY','53424','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 21:36:52',0,NULL,3,0,2,1,NULL,'drulf42\\'),(406,511715020003,130490976186,'New Atheros AR5B95 AR9285 Half Mini PCI-E card+antenna',1,'WLAT009+ANTY001',17.5,'cnfaner','henriquet.carvalho','cht.info@bol.com.br','Carlos Henrique Teixeira de Carvalho','av Getúlio Vargas, nº 632','candelaria','Rio Grande do Sul','BRAZIL','96930000','(+55 51) 8475 4911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 21:57:34',0,NULL,3,0,3,1,NULL,'henriquet.carvalho\rRA022496745CN\r'),(407,511732561003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','wnaimu','wneumu@gmail.com','Waldemar Neumüller','Steinbeisstrasse 31','Aalen','','GERMANY','73430','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 23:12:28',0,NULL,3,0,3,1,NULL,'wnaimu\rRA022496754CN\r'),(408,562614443013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',2,'WWSI004+ANCN001',74.4,'eastar4','neolore_ca','purchasing@neolore.com','NeoLore Networks Inc.','2781 Lancaster Raod<br>Suite 302','Ottawa','ON','CANADA','K1B1A7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 23:23:09',0,NULL,3,0,3,1,NULL,'neolore_ca  \rRA022495436CN\r'),(409,682517984011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','leinadnitnac','cantin.daniel@gmail.com','Daniel Cantin','7353 Coffee','Montreal','QC','CANADA','H4B 1J9','(514) 515-3801','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 23:37:41',0,NULL,3,0,2,1,NULL,'leinadnitnac\\'),(410,511738813003,130498781630,'100% Lowepro Mini Trekker AW Photo Camera Bag Backpacks',1,'',64,'cnfaner','mshalo54','ebaymine@att.net','Angela Puklavetz','4506 Avenida de las Flores','Yorba Linda','CA','UNITED STATES','92886','(714) 875-2666','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-03-18 23:49:08',0,NULL,3,0,3,1,NULL,'mshalo54\rRA022496578CN\r'),(411,511739947003,130490194854,'Genuine Logitech Harmony 880 Universal Remote Control',1,'RCLO002',75.99,'cnfaner','crle666teo','teodor.prizmic@ri.t-com.hr','Teodor Prizmić','Mate Lovraka 16','Rijeka','','CROATIA','51000','++385 51 625 422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 23:50:48',0,NULL,3,0,3,1,NULL,'crle666teo\rRA022496595CN\r'),(412,758514353012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',3,'OTCN003',14.97,'eastar4','lvkilo','kiloinvegas@gmail.com','Harold Kinchelow Jr','7736 Crenshaw Way','Las Vegas','NV','UNITED STATES','89129-5498','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 23:57:37',0,NULL,3,0,1,1,NULL,'lvkilo\\'),(413,517568862004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','tiagotrentini','denistrentini@gmail.com','Erika Iris Trentini','Getulio Vargas, 2580','Sao Jose','Santa Catarina','BRAZIL','88103-400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 00:33:24',0,NULL,3,0,3,1,NULL,'tiagotrentini\rRA022496635CN\r'),(414,682533770011,320451492463,'Atheros AR5008 802.11N 300M Wireless PCI-E+ 3 antenna',3,'WLAT002+ANTY001*3',46.47,'eastar4','jakub_16hc','jakub_k@o2.pl','jakub kochan','62 the paddocks','newcastle west','Limerick','IRELAND','default','06977604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 00:35:15',0,NULL,3,0,3,1,NULL,'jakub_16hc   用新的发\r\rRA022495440CN\r'),(415,682433888011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','lafond2010paul','lafond3@hotmail.com','Paul Pelletier','39 Chaplin St.','Pawtucket','RI','UNITED STATES','02861','(401) 585-2745','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 20:00:07',0,NULL,3,0,1,1,NULL,'lafond2010paul\\'),(416,758545571012,220741015891,'New Motorola H350 Bluetooth Wireless Headset H 350',1,'HSMO005',12.99,'eastar4','qda22','qda22@yahoo.com','glen simpson','72 mckall','winnipeg','MB','CANADA','r3x1t8','(204) 255-7338','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 01:54:22',0,NULL,3,0,2,1,NULL,'qda22\\'),(417,758548747012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',29.5,'eastar4','northwest_treasurechest','jarfanci@comcast.net','Elizabeth Cordero','1219 Mountain Aire Way SE','Lacey','WA','UNITED STATES','98503-1920','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 02:07:00',0,NULL,3,0,1,1,NULL,'northwest_treasurechest\\'),(418,682425535011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','propshaft4','j.p.gerrits@ziggo.nl','j.p. gerrits','De Niagara 4','DRUNEN','','NETHERLANDS','5152VB','0416753575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 19:45:16',0,NULL,3,0,2,1,NULL,'propshaft4\\'),(419,0,220754847098,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'',8.99,'eastar4','nikkay77','nikkay77@yahoo.com','Nikki Kimsey','16524 Spaulding Ave','Markham','IL','UNITED STATES','60428-5525','(708) 566-4822','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 03:28:17',0,NULL,3,0,1,1,NULL,'nikkay77   HSPL001\\'),(420,511788354003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','earthbodysoul','mbytheway@optusnet.com.au','Marc Bytheway','172 Humphries Road','Mt Eliza','Victoria','AUSTRALIA','3930','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 05:31:10',0,NULL,3,0,3,1,NULL,'earthbodysoul\rHSUE004\rRA022496621CN\r'),(421,758606996012,220705174844,'New  Motorola H500 Bluetooth Wireless Headset pink',1,'HSMO006',9.26,'eastar4uk','bizeloui','d.othonos@cytanet.com.cy','Despo Othonos','Anexartisias 7A, Aglantzia','Nicosia','','CYPRUS','2108','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 07:09:06',0,NULL,3,0,2,1,NULL,'bizeloui   英标\\'),(422,758615251012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','larkeylou','joycielou11@gmail.com','Joyce Stroud','1979 Crescent Dr','Las Cruces','NM','UNITED STATES','88005-3322','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 07:51:27',0,NULL,3,0,1,1,NULL,'larkeylou   \\'),(423,757732319012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','patakurko','tuomaslaukkanen@hotmail.com','Tuomas Laukkanen','kalevankatu 18b b15','Joensuu','','FINLAND','80110','0504120998','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 07:52:10',0,NULL,3,0,3,1,NULL,'patakurko   OTRA002\r\r客户新地址\r\rTuomas Laukkanen\rHofinkatu 6A\rJoensuu  80140\rFinland\rRA022496581CN\r\r\r'),(424,758620521012,220748684536,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',5.98,'eastar4uk','atomic_shrimp','ebaycontact@gurman.co.uk','Mike Gurman','9 Rectory Court<br>Botley','Southampton','Hampshire','UNITED KINGDOM','SO30 2SJ','','NoPaymentFailure','CheckoutIncomplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,0,3,1,NULL,'atomic_shrimp\rRA022495294CN\r'),(425,758623994012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','mihhaila_123','mihhaila@hotmail.com','Mihhail Aulov','Peterburi tee 24-56','Tallinn','Harjumaa','ESTONIA','11411','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 08:30:39',0,NULL,3,0,2,1,NULL,'mihhaila_123  欧标\\'),(426,562701944013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','mich2780','computercleanau@yahoo.com.au','Michelle Riccio','3 Jellicoe Street, Caringbah','Sydney','New South Wales','AUSTRALIA','2229','0410531047','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 08:57:35',0,NULL,3,0,2,1,NULL,'mich2780\\'),(427,511814105003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','ekimovsi1982','ekimovsi@gmail.com','Siarhei Yakimau','Nezavisimosti pr. , 151-87','Minsk','','BELARUS','220114','375296542585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 09:10:13',0,NULL,3,0,3,1,NULL,'ekimovsi1982\rHSNO008   欧标\rRA022495475CN\r'),(428,758643098012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','inbio','sergeyproskuryakov@gmail.com','Sergey Proskuryakov Сергей Проскуряков','ul. Voronezhskaya, d. 88, ул. Воронежская, д. 88','Tambov, Тамбов','Tambovskaya oblast\', Тамбовская область','RUSSIAN FEDERATION','392022','(905) 547-60-25','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 09:42:50',0,NULL,3,0,2,1,NULL,'inbio  MX20T\\'),(429,562712186013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','jnboutique','jess@creativedigitalmedia.com.au','Jessica McLennan','38 Arena Parade','Officer','Victoria','AUSTRALIA','3809','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 09:54:14',0,NULL,3,0,3,1,NULL,'jnboutique   MOSA001\rRA022496825CN\r'),(430,562716046013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','ekimovsi1982','ekimovsi@gmail.com','Siarhei Yakimau','Nezavisimosti pr. , 151-87','Minsk','','BELARUS','220114','375296542585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 10:44:51',0,NULL,8,0,17,0,NULL,'ekimovsi1982'),(431,758671083012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','antiqboy31221','telez444@rambler.ru','Vladimir Grigoriev','kesk 6-61','Kohtla-Jarve','Esti  ee','ESTONIA','31221','+3725227829','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 11:16:49',0,NULL,3,0,2,1,NULL,'antiqboy31221   欧标\\'),(432,562731315013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','i_naama','shai178@walla.com','Shai Nachmani','Emek Ha\'ela 98','Modiin','Israel','ISRAEL','71723','(972)52-552-9002','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 11:31:50',0,NULL,3,0,2,1,NULL,'i_naama\\'),(433,758684896012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',29.9,'eastar4uk','ingridmrsi','gandi@zippy-uk.com','mrs I Morrish','9 Lexington Way','Barnet','Hertfordshire','UNITED KINGDOM','En5 2SN','02084470180','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-19 12:02:41',0,NULL,3,0,3,1,NULL,'ingridmrsi\rOTGR001+OTGR002\rRA022495515CN\r'),(434,682679457011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.8,'eastar4','dan.2007407','danherghelegiu@yahoo.com','Dan Herghelegiu','Bd. GRIVITEI 49 / Bl. 34 / Sc. A / Ap. 28','Brasov','Brasov','ROMANIA','500177','+40 723 559491','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 12:08:01',0,NULL,3,0,3,1,NULL,'dan.2007407\rMOSA001\rRA022496839CN\r'),(435,562741643013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','vaiana22','isadadoulove@hotmail.fr','DUPONT-DUMOULIN DAMIEN OU ISABELLE','17 RUE DES MALPIQUES','GENNES','Pays de la Loire','FRANCE','49350','0610703530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 12:22:31',0,NULL,3,0,2,1,NULL,'vaiana22   欧标\\'),(436,758707262012,220743499522,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',9.2,'eastar4uk','guladem','agul@ofisiletisim.com','ADEM GUL','IZZETPASA MAH. YENIYOL CAD. AYAZMAYOLU SOK. IKIZDERE HAN. NO:1/2<br>SISLI','ISTANBUL','SISLI','TURKEY','34387','902122198877','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 13:08:59',0,NULL,3,0,2,1,NULL,'guladem\\'),(437,758714979012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.69,'eastar4uk','brianarsenal71','btipper69@virginmedia.com','b tipper','7 chapel end','hoddesdon','Hertfordshire','UNITED KINGDOM','en11 8dn','01992465684','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-19 13:35:45',0,NULL,3,0,3,1,NULL,'brianarsenal71   英标\rHSPL010\rRA022495189CN\r'),(438,517698443004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',32.9,'cnfaner','brunovegar','brunoveg@yahoo.com','Bruno Veguillas','Santa Fe 1173','Rosario','Santa Fe','ARGENTINA','S2000ATO','+54 (0341) 156953591','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 14:13:55',0,NULL,3,0,3,1,NULL,'brunovegar\rHSNO003\rRA022496618CN\r'),(439,758741810012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','818vinscuzzy','vinscuzzy@hotmail.com','jason  rabinowitz','7842 fairchild ave','canoga park','CA','UNITED STATES','91306-2008','(818) 621-4043','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 14:47:31',0,NULL,3,0,1,1,NULL,'818vinscuzzy'),(440,0,230597693894,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',9.99,'eastar4','dollysboutique7','dollysboutique@hotmail.com','CARMEN BURGOS','URB. VILLA MADRID<br>O-11','COAMO','PR','UNITED STATES','00769','(787) 344-3619','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 15:10:59',0,NULL,3,0,1,1,NULL,'dollysboutique7\\'),(441,0,220755498710,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',13.25,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 15:12:26',0,NULL,8,0,17,0,NULL,'4278dennis\r一共买了两个'),(442,0,230597695271,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',9.99,'eastar4','rautzu','rautzu@yahoo.com','PAUL POPA','5488, Rue Avonmore, #204','Montreal','QC','CANADA','H3X1Z3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 15:16:55',0,NULL,3,0,2,1,NULL,'rautzu\\'),(443,562786002013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','asphix1028','asphix20@gmail.com','Bernardo Garibay','409 Broad St','Windsor','CT','UNITED STATES','06095-3006','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 15:21:24',0,NULL,3,0,1,1,NULL,'asphix1028\\'),(444,0,220755505373,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',14.51,'eastar4','dbluband','dbluband@gmail.com','David Bluband','1636 Scott St','Saint Helena','CA','UNITED STATES','94574-1728','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 15:34:22',0,NULL,3,0,1,1,NULL,'dbluband\\'),(445,0,320671979928,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','jgeer100','johngeer1@gmail.com','John Geer','643 Bair Island Rd<br>Consolidated Investments Ste 100','Redwood City','CA','UNITED STATES','94063-2755','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-19 15:46:37',0,NULL,3,0,1,1,NULL,'jgeer100\\'),(446,682756338011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','lemmingleader','lennartz@lennartz.org','Thomas Lennartz','Am Kärling 80','Castrop-Rauxel','','GERMANY','44581','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 15:48:55',0,NULL,3,0,2,1,NULL,'lemmingleader\\'),(447,517726719004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','askoldvadim','rozanow@mail.ru','Vadim Rozanov','Kolomyazhsky Prospect, home 28,<br>housing 1, flat 82','St. Petersburg','','RUSSIAN FEDERATION','197341','011-7-812-336-04-82','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 16:00:50',0,NULL,3,0,3,1,NULL,'askoldvadim\rOMHJ001\rRA022495966CN\r'),(448,682801723011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','cmanuelsantos','carlos.thalesgroup@gmail.com','Carlos De Los Santos','8532 NW 66th St<br>Apt 013419','Miami','FL','UNITED STATES','33166','(829) 640-3391','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 17:32:46',0,NULL,3,0,1,1,NULL,'cmanuelsantos\\'),(449,758556844012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',33.97,'eastar4','jck-p','jck_p@hotmail.com','Jack R. Poudrier','1732 Lakeview Ave','Klamath Falls','OR','UNITED STATES','97601','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 02:47:55',0,NULL,3,0,1,1,NULL,'jck-p\r再发一个HP Broadcom BCM4322     WLHP001 \r'),(450,562855552013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','buffet66','dspeich66@netscape.net','Douglas Speich','15 Biddlecum Rd','Pennellville','NY','UNITED STATES','13132','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 18:52:32',0,NULL,3,0,1,1,NULL,'buffet66\\'),(451,511984394003,130490260658,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.99,'cnfaner','j89j','jj89jj@msn.com','Jerrold Jackson','606 SW Langston Rd','Renton','WA','UNITED STATES','98057-2208','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 20:19:03',0,NULL,3,0,1,1,NULL,'j89j\\\r'),(452,562890144013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','leovirgo28','george@tapped-out.com','George Constantinou','8A Demonicou Street','Larnaca','Larnaca','CYPRUS','6016','0035796799507','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 20:15:45',0,NULL,3,0,2,1,NULL,'leovirgo28\\'),(453,517813407004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY001*3',23.99,'cnfaner','anichkin_a.g','klasika@bk.ru','Anichkin Alexander','Volhovskiy pereulok 2, apt.180','Moscow','Moskva','RUSSIAN FEDERATION','105005','8(916)982-2332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 20:19:20',0,NULL,3,0,3,1,NULL,'anichkin_a.g\rWLIN010 +ANTY001*3\rRA022496799CN\r'),(454,517828040004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','olegja','olegja@navigator.lv','Oleg Jarmakov','Gobas 35-4','Riga','','LATVIA','LV-1016','371-7433431','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 21:09:18',0,NULL,3,0,3,1,NULL,'olegja\rWWSI005\rRA022496666CN\r'),(455,517841639004,140516092374,'Logitech harmony Li-ion Rechargeable Battery 950mAh',1,'BALO008',6.6,'cnfaner','michaelthorn','mthorn@aol.com','Michael Thorn','19 Argyle Dr','Shirley','NY','UNITED STATES','11967-4201','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 21:57:54',0,NULL,3,0,1,1,NULL,'michaelthorn  旧的\\'),(456,562924080013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','sowji_kambam','kambam.sowjanya@gmail.com','sowjanya kambam','38319 GolfView Dr','Farmington Hills','MI','UNITED STATES','48331-2957','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 21:56:45',0,NULL,3,0,1,1,NULL,'sowji_kambam\\'),(457,758978852012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',8,'CASS003',69.6,'eastar4','felix.rm','radmilo.felix@gmail.com','Radmilo Felix','9, Hotin street','Bucharest','Bucharest','ROMANIA','012971','+40724588505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 22:35:26',0,NULL,3,0,3,1,NULL,'felix.rm    CAB-6060   CASS003\rRA022495970CN\r'),(458,758941210012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','gpakraemer','wkraemer@nwi.net','William Kraemer','PO Box 2222<br>225 W Highland #2','Chelan','WA','UNITED STATES','98816-2222','(509) 682-4701','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 21:12:50',0,NULL,3,0,1,1,NULL,'gpakraemer\\'),(459,514814822004,140516157546,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'TOIN002+BAIN002+BAIN001',41.9,'cnfaner','luizserafim','serafimc@terra.com.br','luiz carlos serafim','prof. abelardo rupp, 255, j.itaguaçu','florianopolis','santa catarina','BRAZIL','88085595','55-48-78110508','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 23:00:05',0,NULL,3,0,3,1,NULL,'luizserafim\rTOIN002+BAIN002+BAIN001\rRA022495232CN\r'),(460,758990202012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',12.8,'eastar4','jstmco','holaccounts@cableone.net','Marv Fulcher','1222 W Brown Trout Dr','Meridian','ID','UNITED STATES','83642-7730','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 23:03:05',0,NULL,3,0,1,1,NULL,'jstmco\\'),(461,0,220755518895,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32.5,'eastar4','pkm.sal','ptka@live.fi','Petri Salenius','Pännitie 4','Nummela','','FINLAND','03100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 21:45:00',0,NULL,3,0,3,1,NULL,'pkm.sal\rOTRA002\rRA022496706CN\r'),(462,512033750003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','artemisa777','emerleon@gmail.com','CARLOS LUENGO','MOISÉS DE LEÓN 34;6-A','LEÓN','Castilla y León','SPAIN','24006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 23:09:49',0,NULL,3,0,3,1,NULL,'artemisa777  欧标\rHSMO016\rRA022496683CN\r'),(463,0,220756937052,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',16,'eastar4','thickstudny','thickstudny@aol.com','George Beletsis','4489 Broadway<br>Apt 4F','New York','NY','UNITED STATES','10040-2495','(646) 533-0763','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 23:16:56',0,NULL,3,0,1,1,NULL,'thickstudny\\'),(464,681255022011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','caroubay','enor.caroupin@wanadoo.fr','ENOR CAROUPIN','PINTADE','BASSE-TERRE','GUADELOUPE','GUADELOUPE','97100','0690901166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 23:19:47',0,NULL,3,0,2,1,NULL,'caroubay\\'),(465,562948797013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','mossete','minamibia@gmail.com','JOSE MANUEL CABEZUDO ARTERO','C/ Pantano Puerto Peña 63. Vivienda nº 6','Badajoz','Extremadura','SPAIN','06010','639752633','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 23:25:26',0,NULL,3,0,3,1,NULL,'mossete\rMOSA001\rRA022496900CN\r'),(466,512024290003,130460438605,'New Plantronics Explorer 340 BLUETOOTH HEADSET track#',1,'HSPL007',19.9,'cnfaner','phinzhater','boomer_67@comcast.net','Keith A. Landers Jr.','6508 Kenwood Ave','Rosedale','MD','UNITED STATES','21237-1814','(443) 798-1957','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 22:30:23',0,NULL,3,0,1,1,NULL,'phinzhater、'),(467,562949723013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','mwgolson','mgolson1123@gmail.com','Melanie   Golson','1541 Pine Ridge Rd','Montgomery','AL','UNITED STATES','36109-1355','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 23:30:45',0,NULL,3,0,1,1,NULL,'mwgolson\\'),(468,759014329012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','dracomoye','dracomoye@hotmail.com','Fontaine Sylvain','1060 principale ouest','Lawrenceville','QC','CANADA','J0E 1W0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 00:14:02',0,NULL,3,0,2,1,NULL,'dracomoye\\'),(469,682991381011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','rmccain316','robert@infodesignsolutions.com','Robert M. McCain','8860 E Chaparral Rd<br>Ste 100','Scottsdale','AZ','UNITED STATES','85250-2610','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 00:53:41',0,NULL,3,0,1,1,NULL,'rmccain316\\'),(470,517889768004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'cnfaner','sagueb30','sagueb.sbeb@gmail.com','sebastien sues','6 chemin du figuier<br>hameau de sinsans','calvisson','Languedoc-Roussillon','FRANCE','30420','0646253923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 01:27:09',0,NULL,3,0,3,1,NULL,'sagueb30\rWLDE002\rRA022496785CN\\'),(471,562977512013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','t3knique','t3k@2x.ca','Will Law','2107 - 7088 Salisbury Ave','Burnaby','BC','CANADA','V5E0A4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 01:37:07',0,NULL,3,0,2,1,NULL,'t3knique\\'),(472,759040647012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','bopperd','bopperda@yahoo.com','Dave Schinbeckler','Rural Route 1','Mindemoya','ON','CANADA','p0p1s0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 01:39:51',0,NULL,3,0,3,1,NULL,'bopperd\rOTGR001+OTGR002\rRA022495921CN\r'),(473,562982453013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','eldume83','joan.dume@yahoo.com','Juan Dume','97 Camden St<br>Roxbury Apt 320','boston','MA','UNITED STATES','02118','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 02:00:02',0,NULL,3,0,1,1,NULL,'eldume83\\'),(474,562992722013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',2,'WLDL001',16.7,'eastar4','jack*of*hearts','cjohns13@hotmail.com','Dan Johnson','937 Grandmere Rd','Lawrenceburg','TN','UNITED STATES','38464-7027','(931) 766-0407','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 02:55:42',0,NULL,3,0,1,1,NULL,'jack*of*hearts\\'),(475,0,220755500341,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',16.5,'eastar4','ekimovsi1982','ekimovsi@gmail.com','Siarhei Yakimau','Nezavisimosti pr. , 151-87','Minsk','','BELARUS','220117','+375296542585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 03:00:53',0,NULL,3,0,3,1,NULL,'ekimovsi1982\r一共买了三个\rRA022495878CN\r'),(476,562998171013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','rodolfofonseca94','fonseca.elder@superig.com.br','Elder Fonseca','Rua carlos morgado number 03<br>House 1','São Paulo','São Paulo','BRAZIL','02219-060','5511-22010419','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 03:34:46',0,NULL,3,0,3,1,NULL,'rodolfofonseca94\rMOSA002\rRA022496811CN'),(477,562313206013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','thor1364','eric_s_davis@hotmail.com','Eric Davis','5124 Panorama Drive','Cheyenne','WY','UNITED STATES','82009','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 04:28:47',0,NULL,3,0,1,1,NULL,'thor1364\\'),(478,0,230597230040,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12,'eastar4','hormel-ugcs','pablo@alumni.caltech.edu','Paul Thienprasit','358 Alvarez Common','Milpitas','CA','UNITED STATES','95035','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 08:12:13',0,NULL,3,0,1,1,NULL,'hormel-ugcs\\'),(479,563041879013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','sal_paradise00','andrewcunningham@mac.com','Andrew Cunningham','1 Hone Street','Parkside','South Australia','AUSTRALIA','5063','61439865012','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 08:30:00',0,NULL,3,0,3,1,NULL,'sal_paradise00\rMOSA003\rRA022496895CN\r'),(480,683114993011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','ksstyle831','zhenwenxuan@hotmail.com','ZHIHUA HE','46 MINTARO AVE<br>STRATHFIELD','SYDNEY','New South Wales','AUSTRALIA','2135','61405093438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 09:53:49',0,NULL,3,0,2,1,NULL,'ksstyle831\\'),(481,563058923013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','mavieillepeugeot504','mavieillepeugeot@live.fr','rachid dali','33 boulevard du bosphore résidence val pins<br>batiment c3','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13015','0659298238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 09:44:11',0,NULL,3,0,2,1,NULL,'mavieillepeugeot504\\'),(482,512142046003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','massimo.sabia','massimosabia@hotmail.com','Massimo Sabia','Via Feltre<br>n21','Belluno','BL','ITALY','32100','0437 941662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 10:12:55',0,NULL,3,0,3,1,NULL,'massimo.sabia\rRELO002\rRA022495285CN\r'),(483,759168476012,220748684536,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','ketron040','jukka.t@japo.fi','Jukka Turja','Suvitie 278','62830 Luoma-aho','länsisuomi','FINLAND','62830','040 7404230','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-20 10:40:29',0,NULL,3,0,2,1,NULL,'ketron040\\'),(484,561891316013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','mikalaiblr','nickblack@tut.by','Mikalai Krautsou','Julpva str. 36/2 - 40','Gomel','','BELARUS','246029','+375257408137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 11:08:58',0,NULL,3,0,2,1,NULL,'mikalaiblr\\'),(485,683176049011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','mad_max_8','jeroenklaassen@home.nl','Jeroen Klaassen','Willem-Alexanderlaan 17','HAPS','','NETHERLANDS','5443BX','0617136656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 12:18:24',0,NULL,3,0,2,1,NULL,'mad_max_8\\'),(486,0,230597232820,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',11.25,'eastar4','karooumba','karooumba@hotmail.com','Karine Latraverse','119 Place Fontainebleau','Saint-Lambert','QC','CANADA','J4S 1X6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 12:34:19',0,NULL,3,0,2,1,NULL,'karooumba\\'),(487,563112833013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','cheyque','blundface@gmail.com','Jesse G Herrera','1101 Sapphire St','Laredo','TX','UNITED STATES','78045-8053','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 12:44:33',0,NULL,3,0,1,1,NULL,'cheyque\\'),(488,563113569013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','georgebouk','schorsch@freemail.gr','Bouklas Georgios','Omirou str.10','Grevena','','GREECE','51100','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 12:52:20',0,NULL,3,0,2,1,NULL,'georgebouk    欧标\\'),(489,759255413012,220747230973,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',21.99,'eastar4uk','janiugrinb','jani.ugrin@me.com','Jani Ugrin','Klariceva ulica 11','Koper','','SLOVENIA','6000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-20 13:16:21',0,NULL,3,0,3,1,NULL,'janiugrinb\rHSUE002\rRA022495949CN\r'),(490,563123302013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','kipishev','tiki@list.ru','Andrey Tikishev','ul. Pozharskogo d.18 kv.12','Himki','Moskovskaya obl','RUSSIAN FEDERATION','141411','(926)593-1128','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 13:17:29',0,NULL,3,0,3,1,NULL,'kipishev\rMOSA002\rRA022496649CN\r'),(491,0,220754849414,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'',9.99,'eastar4','joejv4321','joevaladez10@yahoo.com','joe valadez','140 Norma St','san angelo','TX','UNITED STATES','76903','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-20 13:23:58',0,NULL,3,0,1,1,NULL,'joejv4321\rOMHJ001\\'),(492,518032683004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','versat9110','pandosantos@gmail.com','verissimo alfredo pando santos','urbanização quinta da palmeira<br>lote 52 2º. ESQ.','FARO','FARO','PORTUGAL','8005-546','911020759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 13:45:33',0,NULL,3,0,3,1,NULL,'versat9110   欧标\rHSNO005\rRA022495895CN\r'),(493,759273310012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','dariusp85','darius@onrails.lt','Darius Pėža','Nykos 5, Gerdžiūnų km. Šakių raj. Lithuania','Šakiai','','LITHUANIA','4744','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 13:52:12',0,NULL,3,0,2,1,NULL,'dariusp85\rHSNO006\r欧标\\'),(494,0,230598822052,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','7529jeffrey','delete3970@aol.com','Jeffrey Muto','218 McChain Rd','Finleyville','PA','UNITED STATES','15332-4111','(724) 348-5716','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 14:26:15',0,NULL,3,0,1,1,NULL,'7529jeffrey\\'),(495,0,320673333383,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.99,'eastar4','dajkam','dajmik@freemail.hu','Miklós Dajka','Csokonai út 53. 1/2.','Szolnok','','HUNGARY','5000','+36203424949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 14:30:02',0,NULL,3,0,2,1,NULL,'dajkam\r欧标\\'),(496,759308003012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','jaltin','jaltin@gmx.de','jörg altintzoglou','gerhart hauptmann str 40','erkrath','','GERMANY','40699','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 14:57:39',0,NULL,3,0,2,1,NULL,'jaltin\\'),(497,759307667012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','electric-assembler','kalleniskanen@gmail.com','Kalle-Hermanni Niskanen','Soliskyläntie 10','Viitasaari','','FINLAND','44500','+358408667011','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 14:58:54',0,NULL,3,0,2,1,NULL,'electric-assembler\\'),(498,512236394003,130490202395,'Genuine Logitech Harmony 525 Universal Remote Control',1,'RCLO005',74.99,'cnfaner','ravst8o','phepso@broadpark.no','Petter Hepso','Markaplassen 9<br>7054 Ranheim','Trondheim','','NORWAY','nozip','+4790750217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 15:25:40',0,NULL,3,0,3,1,NULL,'ravst8o\rRCLO005\rRA022495498CN\r'),(499,563171241013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','belevichd','denis@belevich.net','Denis Belevich','ul. Lenina 112 - 6','Krasnoyarsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','660017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 15:34:46',0,NULL,3,0,2,1,NULL,'belevichd\\'),(500,759373243012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',29.5,'eastar4','kasparavicius123','maria_mrrqn@yahoo.com','MARIA KASPARAVICIUS','409 Addison St<br>Apt 1','ELGIN','IL','UNITED STATES','60120-4434','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 16:44:23',0,NULL,3,0,1,1,NULL,'kasparavicius123\\'),(501,512278035003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','ingpoint17','mbas@email.it','PAMELA LOSURIELLO','VIA VITTORIO VENETO 97','ADELFIA','BARI','ITALY','70010','328-5518721','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 17:05:03',0,NULL,3,0,3,1,NULL,'ingpoint17  欧标\rHSNO008\rRA022495864CN\r'),(502,512269086003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','dido22_974','david.hivanhoe@sfr.fr','David Hivanhoé','App 63, Central FAC 6<br>1 Rue de Grêce','Le Tampon','Réunion','REUNION','97430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 16:46:25',0,NULL,3,0,3,1,NULL,'dido22_974\rRELO002\rRA022495161CN\r'),(503,512271310003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','fulviocam','fulvio.campagnoli@virgilio.it','GIUSEPPE CAMPAGNOLI','VIA U.FOSCOLO N°13','ARCISATE','VA','ITALY','21051','0332470685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 16:50:23',0,NULL,3,0,3,1,NULL,'fulviocam  欧标\rHSNO008\rRA022496564CN\r'),(504,518112552004,140516874483,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',2,'WLAT001+ANTY001*3',35.98,'cnfaner','akhu','jprohart@free.fr','Jean Philippe Rohart','31 rue Louis Braille','Bordeaux','Aquitaine','FRANCE','33000','06 58 16 14 08','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 17:10:38',0,NULL,3,0,3,1,NULL,'akhu     WLAT001+ANTY001*3\rRA022495250CN\r'),(505,683359707011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','6969traba','markerbeacon@att.net','Michael Abart','8534 Red Baron Blvd','Reno','NV','UNITED STATES','89506','(775) 677-0923','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 17:38:32',0,NULL,3,0,1,1,NULL,'6969traba、'),(506,0,230597230034,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',15.5,'eastar4','dgrunsten','dgrunsten@yahoo.com','Dehn Grunsten','928 Prairie Ridge Ct','Burr Ridge','IL','UNITED STATES','60527','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 17:50:24',0,NULL,3,0,1,1,NULL,'dgrunsten\\'),(507,759470015012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','mariusz7879','mariusz7879@hotmail.com','Anna  Goralik','2828 Pearl St','Franklin Park','IL','UNITED STATES','60131','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 18:28:10',0,NULL,3,0,1,1,NULL,'mariusz7879\\'),(508,0,220754847104,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',8.99,'eastar4','lilfelacamacho440','davidcamachojr61@gmail.com','david camacho','7810 ackley rd','cleveland','OH','UNITED STATES','44129-4910','(216) 324-7218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 18:36:37',0,NULL,3,0,1,1,NULL,'lilfelacamacho440\r一共买了2个 PLANTRONICS 220\r2个PLANTRONICS 330\\\r'),(509,683356191011,320443637303,'Acer Timeline 4810 5810 Bluetooth Module 2.0 EDR+ cable',1,'BTAC2001',14.49,'eastar4','seborss','borshchenko@gmail.com','Sergii Borshchenko','Kovpaka 4, 95','Kyiv','Kyiv','UKRAINE','03150','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-20 18:23:28',0,NULL,3,0,2,1,NULL,'seborss\racer 4pin 1.25 3cm\\'),(510,0,230598822363,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',29.99,'eastar4','artleks','art2003@inbox.ru','Artem Kulev','Arhipova st. 4-7','Petrozavodsk','','RUSSIAN FEDERATION','185000','+79114110120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 17:07:06',0,NULL,3,0,2,1,NULL,'artleks\\'),(511,512399843003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','shirikaro','itay50@gmail.com','shiri karo','mohaliver 130','yehud','israel','ISRAEL','56209','0508355836','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 20:09:54',0,NULL,3,0,3,1,NULL,'shirikaro\rHSNO008\rRA022496652CN\r'),(512,0,220756896741,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',9.99,'eastar4','trmnshwrx','dovereb@yahoo.com','Don Bishop','PO Box 772','Sublette','KS','UNITED STATES','67877','(801) 753-8257','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 20:03:53',0,NULL,3,0,1,1,NULL,'trmnshwrx\\'),(513,0,220754846386,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',21.49,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 20:09:57',0,NULL,3,0,1,1,NULL,'4278dennis\r再发一个保护屏\\\r4  电源    \r2  屏幕    、'),(514,563365659013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',2,'MOSA002',149.6,'eastar4','tomek*111','tomasz.wysocki@aster.pl','Tomasz Wysocki','J.Nowaka-Jeziorańskiego<br>9/330','Warsaw','mazowieckie','POLAND','03-984','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 20:37:35',0,NULL,3,0,3,1,NULL,'tomek*111\rMOSA002\rRA022495626CN\r'),(515,683514293011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','afzaal2010afzaal','afzaal81@yahoo.com','AFZAAL RANA','200 Woodydell ave','winnipeg','MB','CANADA','R2M2V1','(120) 496-0826 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 21:20:26',0,NULL,3,0,2,1,NULL,'afzaal2010afzaal\\'),(516,563400613013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','vanessa_wiest','van.m.vincent@gmail.com','Vanessa Vincent','352 Meredith Sq','Columbia','SC','UNITED STATES','29223-2268','(801) 494-4444','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-20 21:37:56',0,NULL,3,0,1,1,NULL,'vanessa_wiest\\'),(517,759641343012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','hubbify77x','hubbify77x@hotmail.com','Derek Husband','6210 Santa Ana Way','Stockton','CA','UNITED STATES','95215-9657','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 21:10:17',0,NULL,5,0,18,0,NULL,'hubbify77x'),(518,759668266012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',96.8,'eastar4','proszper','proszper@freemail.hu','László Kiss','Középszer u. 62. 8/2','Miskolc','','HUNGARY','3529','+36209154854','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 21:51:11',0,NULL,3,0,3,1,NULL,'proszper    欧标\r再发一个1000B\r\rRA022494047CN\r'),(519,759683948012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','miguel_viana','viana_miguel@yahoo.com','Miguel Viana','R. Alvaro Guerra Lt.5 3º Dt.º','Póvoa de Santa Iria','','PORTUGAL','2625-268','+351963803798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 22:17:52',0,NULL,3,0,2,1,NULL,'miguel_viana\\'),(520,518305668004,140515701798,'New GENUINE NOKIA BH-205 BLUETOOTH HEADSET track#',1,'HSNO009',15.5,'cnfaner','meemee64','meemee64@hotmail.com','La\'Meesha Richardson','228 S 60th St<br>Fl 3','Philadelphia','PA','UNITED STATES','19139','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-20 23:08:22',0,NULL,3,0,1,1,NULL,'meemee64、'),(521,512459326003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'cnfaner','sammaramma','sammeehoo@yahoo.ca','Sam Niemi','PO Box 10496','Thunder Bay','ON','CANADA','P7B 6T9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 22:50:33',0,NULL,3,0,3,1,NULL,'sammaramma\rRA022495263CN\r'),(522,759725630012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','clckleezer','cleezer@wowway.com','Christina Leezer','5691 Buenos Aires Blvd','Westerville','OH','UNITED STATES','43081-4245','(614) 895-3524','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 23:50:36',0,NULL,3,0,1,1,NULL,'clckleezer\rLK032969309CN\r\\'),(523,0,320671449348,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',9.99,'eastar4','lilfelacamacho440','davidcamachojr61@gmail.com','david camacho','7810 ackley rd','cleveland','OH','UNITED STATES','44129-4910','(216) 324-7218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 00:09:16',0,NULL,8,0,17,0,NULL,'lilfelacamacho440'),(524,759715474012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.88,'eastar4uk','sean5167','seanbehan4@hotmail.com','sean behan','2 craigmuir gardens','blantyre','South Lanarkshire','UNITED KINGDOM','g72 9ry','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-20 23:27:58',0,NULL,3,0,3,1,NULL,'sean5167\rRA022495229CN\r'),(525,518326890004,140490658302,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'cnfaner','youpla.b','youpla.b@gmail.com','Damien Leblanc','11 rue de Seine','Sartrouville','Île-de-France','FRANCE','78500','+33668434788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 00:19:36',0,NULL,3,0,3,1,NULL,'youpla.b    加一个IBM  X200  antenna \rRA022495277CN\r\r'),(526,683633153011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',8,'CASS002',130.5,'eastar4','leander.janssen','leander@slaco.net','Leander Janssen','Van der Stoklaan 9','Den Haag','Zuid Holland','NETHERLANDS','2493BX','+31654947981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 23:41:37',0,NULL,3,0,5,1,NULL,'leander.janssen\r一共买了8个CAB-2660\r3个CAB－6060\r4个CAB－2626  \rCP226379436CN\r\r\r'),(527,759743234012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','youpla.b','youpla.b@gmail.com','Damien Leblanc','11 rue de Seine','Sartrouville','Île-de-France','FRANCE','78500','+33668434788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 00:34:45',0,NULL,8,0,17,0,NULL,'youpla.b'),(528,683674616011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','maro_jp','mstudio.jp@gmail.com','Masahiro Matsushita','2-1, E-103 Minami-Numagami<br>Aoi-Ku','Shizuoka','Shizuoka','JAPAN','4200905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 01:29:50',0,NULL,3,0,2,1,NULL,'maro_jp\\'),(529,563495226013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','emangel415','eakreppel@gmail.com','Emilie  Kreppel','16 Hoover Ave','Kenmore','NY','UNITED STATES','14217','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 02:41:32',0,NULL,3,0,1,1,NULL,'emangel415\rLK032967577CN\\'),(530,563495181013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','danfromengland','dan.mcgrath@tng.ca','Daniel McGrath','17 Campkin Street','Brampton','ON','CANADA','L6Y 3G9','(647) 801-8856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 02:44:26',0,NULL,3,0,2,1,NULL,'danfromengland\\'),(531,563339937013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','valearlf','vfrederick@gmail.com','Val Frederick','12143 Valleyheart Dr<br>Apt 3','North Hollywood','CA','UNITED STATES','91604-2089','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 19:51:58',0,NULL,3,0,1,1,NULL,'valearlf、'),(532,563164719013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','jacki312','epifini@gmail.com','Jacki Kinzy','6759 Tribal Ct','Long Grove','IL','UNITED STATES','60047-5119','(847) 566-3135','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 04:01:17',0,NULL,3,0,1,1,NULL,'jacki312\\'),(533,563512171013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'eastar4','thealy_ir','thealy@rocoil.com.au','Tim Healy','Rocoil, Level 18<br>321 Kent Street','Sydney','New South Wales','AUSTRALIA','2000','0405623971','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 04:08:37',0,NULL,3,0,2,1,NULL,'thealy_ir\\'),(534,563506169013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','tribocharge','jjcollett@triad.rr.com','John Collett','1321 Cedar Dr','Thomasville','NC','UNITED STATES','27360','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 03:33:14',0,NULL,3,0,1,1,NULL,'tribocharge\rLK032939845CN \\'),(535,759829267012,220546791970,'Yagi 16dBi 2.4 GHz 802.11b/g Wifi Antenna RP-SMA',1,'ANYA001',14.45,'eastar4','junior2426','adalbertojun28@gmail.com','junior gonzalez','HC 2 Box 7386<br>Bo Montones 4','Las Piedras','PR','UNITED STATES','00771','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 05:10:13',0,NULL,3,0,11,1,NULL,'junior2426\\'),(536,0,220756896424,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',9.99,'eastar4','lilfelacamacho440','davidcamachojr61@gmail.com','david camacho','7810 ackley rd','cleveland','OH','UNITED STATES','44129-4910','(216) 324-7218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 00:10:24',0,NULL,8,0,17,0,NULL,'lilfelacamacho440'),(537,0,320673334007,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',8.99,'eastar4','lilfelacamacho440','davidcamachojr61@gmail.com','david camacho','7810 ackley rd','cleveland','OH','UNITED STATES','44129-4910','(216) 324-7218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 00:10:57',0,NULL,8,0,17,0,NULL,'lilfelacamacho440'),(538,563451968013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','koorni71','kai.oorni@gmail.com','Kai Öörni','Kuuraparrantie 19 E 2','Oulu','','FINLAND','90630','358405484661','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 00:17:58',0,NULL,3,0,3,1,NULL,'koorni71  \rRA022495348CN\r'),(539,683713403011,320575306082,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',14.95,'eastar4','nanu4k7','nan4k7@gmail.com','Hernán Nesprías','Hipólito Yrigoyen 480','Buenos Aires','Ciudadela','ARGENTINA','1702','11-63517176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 03:37:55',0,NULL,3,0,2,1,NULL,'nanu4k7\\'),(540,563535874013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','cmancini','cmancini1@yahoo.com','Cesare Mancini','84-78 Austin st.','Kew Gardens','NY','UNITED STATES','11415-2205','(917) 282-4745','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 07:22:54',0,NULL,3,0,1,1,NULL,'cmancini\\'),(541,759873793012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',2,'HSNO019',55.98,'eastar4uk','mmil5305','kirsty.brisco@alterfencing.com','Mary Miller','Weels Farm<br>Lochwinnoch','Glasgow','Renfrewshire','UNITED KINGDOM','PA12 4LD','01505842201','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-21 08:56:24',0,NULL,3,0,3,1,NULL,'mmil5305\r英标   HSNO019\rRA022495365CN\r'),(542,683773861011,320613191693,'NEW Motorola H700 Gold DG Bluetooth Headset+car charger',1,'HSMO012+CCMO001',19.9,'eastar4','guyarkoni','guyark@hotmail.com','guy yarkoni','halamed hey','kfar-saba','','ISRAEL','44395','972-546655527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 09:10:47',0,NULL,3,0,2,1,NULL,'guyarkoni\\'),(543,512593944003,130466041485,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.99,'cnfaner','mecenat76','khlupov@km.ru','Alexandr Khlupov','Altaiskaya  21-160','Moscow','','RUSSIAN FEDERATION','107589','+79161422461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 10:27:33',0,NULL,3,0,3,1,NULL,'mecenat76\rWWSI005 +ANCN001\rRA022495379CN\r'),(544,683621163011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jimbowey','jim.bowey@comcast.net','Jim Bowey','4002 NW Poppy Dr','Corvallis','OR','UNITED STATES','97330-3477','(541) 752-1620','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 23:07:19',0,NULL,3,0,1,1,NULL,'jimbowey\\'),(545,683808589011,320575299743,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',1,'WLAT003',31.9,'eastar4','steff.killer','steff_killer@hotmail.com','stephane INION','6 rue falque','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13006','06.23.17.85.95','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 11:25:44',0,NULL,3,0,3,1,NULL,'steff.killer\rWLAT003  \rRA022495776CN\r'),(546,683578327011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','berlin6776','rafael.burghardt@gmx.de','Rafael Burghardt','Pariser Strasse 55','Berlin','','GERMANY','10719','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 21:36:38',0,NULL,3,0,2,1,NULL,'berlin6776、'),(547,563597045013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','ophtha72','ophtha@empal.com','Jonghyun Lee','Hyundae-Hometown 3rd. Apartment 302-402, Bang-Bae-Dong 2233<br>Seo-Cho-Gu','Seoul','','KOREA,REPUBLIC OF','137-060','(822) 592-4329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:12:22',0,NULL,3,0,2,1,NULL,'ophtha72、'),(548,0,320673821326,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32,'eastar4','oldmanuals','harley.abud@gmail.com','Harley Zanarotti Abud','Rua David Maria M. Gomes, 40 / 34<br>Centro - CEP 12020-300','Taubate','São Paulo','BRAZIL','12020-300','(128) 827-5375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:12:26',0,NULL,3,0,3,1,NULL,'oldmanuals\rOTRA002\rRA022495396CN\r'),(549,683841445011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','hojuguy','rosspacker@gmail.com','Ross Packer','2 Botany Court','Wantirna','Victoria','AUSTRALIA','3152','0398840513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:18:28',0,NULL,3,0,2,1,NULL,'hojuguy\r澳标\\'),(550,512626760003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','masteroll2010','abirman@mts.com.ua','Alexandr Birman','K.Libkneht, 1/3/29','Dnepropetrovsk','','UKRAINE','49030','+380503200088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:21:29',0,NULL,3,0,3,1,NULL,'masteroll2010\rRELO002\rRA022495484CN\r\\'),(551,563601945013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','sjmont5','bsm5000@yahoo.com','steve monterio','36 spartan arrow rd','littleton','MA','UNITED STATES','01460-1257','(508) 864-6212','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 13:27:39',0,NULL,3,0,1,1,NULL,'sjmont5\\'),(552,518467290004,140516092374,'Logitech harmony Li-ion Rechargeable Battery 950mAh',1,'BALO008',6.6,'cnfaner','dramisys','yvan@simard.com','Yvan  Simard','332 Joseph-Leduc','St-Eustache','QC','CANADA','J7R7K1','(514) 231-0535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:50:50',0,NULL,3,0,3,1,NULL,'dramisys\rRA022495334CN\r'),(553,563615951013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','divemasterlv','divemaster.lv@gmail.com','Toms Uzans','Ezera 9-17','Riga','Latvia','LATVIA','LV-1005','22339758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 14:20:45',0,NULL,3,0,2,1,NULL,'divemasterlv\\'),(554,683870978011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','quest_fore_eagle','fernand_couture@sympatico.ca','Fernand Couture','C/O Richelieu Hosiery Int\'l Inc.<br>600 Campbell','Cornwall','ON','CANADA','K6H 6C9','(613) 938-6461 ext.: 236','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 14:46:18',0,NULL,3,0,2,1,NULL,'quest_fore_eagle、'),(555,0,320671984289,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',11.25,'eastar4','wanderingwizard','chaitu45@gmail.com','Chaitanya Reddy Teegela','3307 Jefferson Ave<br>Apt 5','Cincinnati','OH','UNITED STATES','45220-2120','(513) 545-8384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 15:17:23',0,NULL,3,0,1,1,NULL,'wanderingwizard\\'),(556,0,320671980191,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','xpo040','youllbsmiling@gmail.com','Pheing Ngo','696 Seyton Dr.','Ottawa','ON','CANADA','K2H1A4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 15:21:31',0,NULL,3,0,2,1,NULL,'xpo040\\'),(557,0,320672002304,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',35,'eastar4','ivan_piter','arhipov_2000@mail.ru','Иван Михайлович Архипов','ул. Воронежская, д.15, кв.33<br>St-Peterburg, st. Voronejskay d,15, kv.33','Санкт-Петербург','','RUSSIAN FEDERATION','191119','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 15:50:44',0,NULL,3,0,3,1,NULL,'ivan_piter\rOTRA002\rRA022495538CN\r'),(558,760003942012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','zman.2009','anonexaykittirath@yahoo.com','anonexay kittirath','General Delivery','Ringgold','LA','UNITED STATES','71068-9999','(337) 366-7331','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 15:51:10',0,NULL,3,0,1,1,NULL,'zman.2009\\'),(559,760008560012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','xpmaster_antofagasta','acortes@nortraining.com','Alvaro Cortes','Cerro Colorado 3746 Edificio Radiatta Dept. 503<br>Condominio Jardines del Sur','Iquique','Tarapacá','CHILE','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 15:59:29',0,NULL,3,0,2,1,NULL,'xpmaster_antofagasta、'),(560,563418523013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',125.99,'eastar4','wulfy19','dave.dewulf@gmail.com','Dave Dewulf','409 Gilpin Dr','Newmarket','ON','CANADA','L3X3H3','(289) 221-5333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 16:20:04',0,NULL,3,0,3,1,NULL,'wulfy19\rRCLO003\rRA022494055CN\r'),(561,518502347004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','jrgnmrn','jhw58@arcor.de','Jürgen Wilke','An den Birken 5','Hohen Neuendorf','','GERMANY','16562','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 16:20:52',0,NULL,3,0,3,1,NULL,'jrgnmrn\rBALO007\rRA022495351CN\r'),(562,516070829004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','arquivision','joaquin2112@gmail.com','Joaquin Rosales','18 Av. 37-00 Zons 12 Cond. Villa Sol Apto. 824','Guatemala','Guatemala','GUATEMALA','01012','502-24766680','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 17:11:27',0,NULL,3,0,3,1,NULL,'arquivision\rOTCR001\rRA022495422CN\r'),(563,518524486004,140516102898,'Genuine Logitech G7 Rechargeable Battery good condition',1,'BALO005',7.1,'cnfaner','punkrockallstar','punkrockallstar1@gmail.com','Sooksan Pashayanukun','118 Mb. Pontep , soi Patanakarn 54<br>Patanakarn Rd. , Suanluang','Bangkok','','THAILAND','10250','66819077677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 17:41:23',0,NULL,3,0,3,1,NULL,'punkrockallstar\rBALO005\rRA022495325CN\r'),(564,518521393004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','7040014','ilan.neeman@gmail.com','Ilan Neeman','36 Visbourg St.','Tel-Aviv','','ISRAEL','69358','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 17:42:17',0,NULL,3,0,3,1,NULL,'7040014\rHSPL010\rRA022495215CN\r\\'),(565,0,220755498992,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',14.24,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 17:53:08',0,NULL,3,0,1,1,NULL,'4278dennis\r一共买了两个New US Logitech Harmony AC Power Adapter 720 880 890\\'),(566,518536093004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',1,'HSJA002',21.5,'cnfaner','artur.rodrigo','arturrodrigo@terra.com.br','Artur Rodrigo Oliveira Dias','Rua São Florêncio, 1300 casa 55<br>Cangaíba','São Paulo','SP','BRAZIL','03733-020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 18:17:04',0,NULL,3,0,3,1,NULL,'artur.rodrigo\rHSJA002\rRA022495405CN\r'),(567,683980346011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','volfenhag666','volfenhag666@hotmail.com','Thomas MOREL','23 Rue St Michel','CORBIERES','Provence-Alpes-Côte d\'Azur','FRANCE','04220','0678912904','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 18:58:36',0,NULL,3,0,2,1,NULL,'volfenhag666\\'),(568,760103446012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',16.59,'eastar4','digitalwimp','st.rieder@web.de','Stefan Rieder','Dammerkamp 7','Mühlenbarbek','','GERMANY','25548','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 19:07:12',0,NULL,3,0,2,1,NULL,'digitalwimp  Acer 5pin1.25 3cm\r新地址\rStefan Rieder\rSARmedia\rDammerkamp 7\rMühlenbarbek  25548\rGERMANY\\'),(569,683669802011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','minwye','minwye@gmail.com','Min Wye Chan','Visual Eyes 444 Brunswick Street','Fortitude Valley','Queensland','AUSTRALIA','4006','610404327468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 01:18:56',0,NULL,3,0,2,1,NULL,'minwye\\'),(570,760110365012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','asti4268','davoserem@cox.net','Albert Stiehle','627 Windsor Circle','Chula Vista','CA','UNITED STATES','91910','(619) 425-5217','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 19:14:20',0,NULL,3,0,1,1,NULL,'asti4268\rLK032811190CN\r'),(571,563724898013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','floridabeaches','doug@digital-ocean.net','Douglas Darlington','4431 Windsmere Blvd','Orlando','FL','UNITED STATES','32835','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 19:48:02',0,NULL,3,0,1,1,NULL,'floridabeaches\\'),(572,563717893013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','ebuymyshop','akkara111@yahoo.com','Akkara Lekkla','2641 Moo 3 Soi Baring 19<br>Somrongnai','Maung','Samutprakarn','THAILAND','10270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 19:33:54',0,NULL,3,0,2,1,NULL,'ebuymyshop\\'),(573,512734158003,130489883385,'New Sony Ericsson HBH-PV702 BLUETOOTH HEADSET track#',1,'HSSE003',21.9,'cnfaner','duskabond','bondarenkoandrej@mail.ru','ANDREI BANDARENKA','N.DVORNIKOVA 14/36','GOMEL','','BELARUS','246004','375293551382','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 19:47:54',0,NULL,3,0,3,1,NULL,'duskabond\rHSSE003   欧标\rRA022495303CN\r'),(574,684033694011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','guillaume_fp','guillaume.coeffe@ecl2006.ec-lyon.fr','guillaume Coeffe','48, Rue Saint Ferdinand','PARIS','Île-de-France','FRANCE','75017','0632418579','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:23:35',0,NULL,3,0,2,1,NULL,'guillaume_fp、'),(575,563736687013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','romanenko2010','romanenkooleksandr@gmail.com','Oleksandr Romanenko','proulok.Karla Marksa street. 18 app 73','vinnitsa','vinnitsa region','UKRAINE','21034','0672185338','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:13:05',0,NULL,3,0,2,1,NULL,'romanenko2010\\'),(576,760171460012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',34.8,'eastar4','katmandunor','katmandu@live.com','Odd Viggo Roeggen','Bokfinkveien 28a','Kristiansand','','NORWAY','4626','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:49:40',0,NULL,3,0,3,1,NULL,'katmandunor\rWLDE002\rRA022495541CN\r'),(577,0,320671985860,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','mafiaface','tntmafiaface@aol.com','Terry Nham','2752 California St','Berkeley','CA','UNITED STATES','94703-1847','(510) 610-7109','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 21:11:31',0,NULL,3,0,1,1,NULL,'mafiaface\\'),(578,760186372012,220749207909,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.99,'eastar4uk','pauk_88','stufler@rambler.ru','Иван Дриль','Россия<br>пер. Попова д.9','Брянск','RI','RUSSIAN FEDERATION','241028','8-953-270-72-70','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-21 21:26:45',0,NULL,3,0,2,1,NULL,'pauk_88、'),(579,0,320671984492,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',11.25,'eastar4','james_speck','speck@tut.by','Dzmitry Hiz','Miroshnichenko st.<br>15-98','Minsk','','BELARUS','220131','+375296462580','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 22:02:02',0,NULL,3,0,2,1,NULL,'james_speck\\'),(580,512822855003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',16.75,'cnfaner','jams1970160','jorgesousa@netcabo.pt','Jorge Amadeu Moreira Sousa','Rua Delfim de Lima, 1883','Canelas','','PORTUGAL','4410-227','00351938307186','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 00:19:20',0,NULL,3,0,3,1,NULL,'jams1970160\rHSNO005+CCNO001\rRA022495555CN\r'),(581,760265760012,220752720350,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',5.98,'eastar4uk','jhow1779','jeff.caroline@btinternet.com','Jeffrey Howard','113 Potter Street','Harlow','Essex','UNITED KINGDOM','CM17 9AN','01279445269','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-22 00:23:29',0,NULL,3,0,3,1,NULL,'jhow1779\rOTCN003\rRA022495382CN\r'),(582,563823193013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','bordij','jbev@bordyfamily.com','John Bordy','3215 Hampshire Ln','Oklahoma City','OK','UNITED STATES','73179-1205','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 00:46:11',0,NULL,3,0,1,1,NULL,'bordij\rLK032827760CN\r'),(583,512828622003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','989dave3301','dmging1@verizon.net','Dave Gingerich','7933 Wildcat Rd','Ovid','MI','UNITED STATES','48866-9656','(989) 277-8827','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:46:21',0,NULL,3,0,1,1,NULL,'989dave3301\\'),(584,684084480011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',2,'WLAP001',29.62,'eastar4','whitenoise.dac','whitenoise.alejandro@gmail.com','Alejandro Blanco','Ramon Falcon 6411 Dpto C','Capital Federal','Buenos Aires','ARGENTINA','1408','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 01:02:57',0,NULL,3,0,2,1,NULL,'whitenoise.dac\\'),(585,760286800012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','quesnyv','yves.quesnel@videotron.ca','yves quesnel','105 rue du foin','saint-augustin de desmaures','QC','CANADA','g3a 2s1','(418) 878-8664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 01:28:16',0,NULL,3,0,2,1,NULL,'quesnyv\\'),(586,0,230597232252,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'',10.8,'eastar4','vickie13100','chewbacca42499@yahoo.com','Vickie Smith','470 N Front St','Steelton','PA','UNITED STATES','17113','(717) 635-0464','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 02:28:54',0,NULL,3,0,1,1,NULL,'vickie13100\rHSPL005\\'),(587,518681841004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','soulgravy','likwidsoul007@yahoo.com','George Hermantin','1747 Sophias Dr<br>Apt 106','Melbourne','FL','UNITED STATES','32940-6209','(321) 505-2292','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 02:32:09',0,NULL,3,0,1,1,NULL,'soulgravy\\'),(588,0,320671980077,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',10.25,'eastar4','doglipz','19val70@sbcglobal.net','Valdemar Perez','5101 Prairie Dunes Dr','Austin','TX','UNITED STATES','78747','(512) 280-6020','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-22 02:34:32',0,NULL,3,0,1,1,NULL,'doglipz\\'),(589,760309869012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','trickybiddy','trickybid@gmail.com','G Nakamoto','568 McGraw St','Seattle','WA','UNITED STATES','98109-2250','(206) 852-4291','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 02:44:57',0,NULL,3,0,1,1,NULL,'trickybiddy\\'),(590,684176622011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','jfbimkiii','jfbimkiii@hotmail.com','JF Bienvenu','2190 Gertrude','Carignan','QC','CANADA','j3l4h1','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'jfbimkiii'),(591,684178125011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','dimitri6957','dimivanhemelrijck@hotmail.com','Dimitri Vanhemelrijck','landbeekstraat 10','Meise','','BELGIUM','1860','32486565322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 02:54:24',0,NULL,3,0,2,1,NULL,'dimitri6957\\'),(592,563855874013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','littlejohn1134','johnmeindersee@yahoo.com','John Meindersee II','513 Richardson ST','Martinez','CA','UNITED STATES','94553-1522','(925) 588-4279','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 03:15:12',0,NULL,3,0,1,1,NULL,'littlejohn1134\\'),(593,563857271013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','yogrark','retlaw@rogers.com','Walter Smith','69 Bushey Ave','Toronto','ON','CANADA','M6N2R4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 03:20:53',0,NULL,3,0,2,1,NULL,'yogrark\\'),(594,760335019012,220448700087,'Acer Aspire 5520 5520G 5530 Bluetooth Module 2.0+cable',1,'BTAC2023',14.49,'eastar4','mnorton1967','markdjnorton@internode.on.net','Mark Norton','59 Dalkeith Drive','Mount Gambier','South Australia','AUSTRALIA','5290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 04:31:26',0,NULL,3,0,2,1,NULL,'mnorton1967\racer 8pin1.00 18cm\\'),(595,684201507011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','0valka0','vvionov2007@gmail.com','Хабаровский край Ионов','Запарина<br>160','Хабаровск','Хабаровский край','RUSSIAN FEDERATION','680011','+79147704950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 04:57:31',0,NULL,3,0,2,1,NULL,'0valka0\\'),(596,563874998013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','fifita-2008','simphonie08@yahoo.com','legette cruz','6 Abington Ave<br>Apt 4','newark','NJ','UNITED STATES','07104-1463','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 05:35:54',0,NULL,3,0,1,1,NULL,'fifita-2008\rLK032934503CN\\'),(597,760349327012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','kasiuskarm','serega70@gmail.com','Sergey Vandalovsky','Khativat Karmeli 21 / 3','Karmi\'el','Zafon','ISRAEL','21991','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 06:02:55',0,NULL,3,0,2,1,NULL,'kasiuskarm\\'),(598,684218604011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',16.59,'eastar4','exileo','esanhusky@comcast.net','Michael Marr','17 Euclid Ave','Washington','PA','UNITED STATES','15301-5461','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 06:50:05',0,NULL,3,0,1,1,NULL,'exileo\rHP 8pin 1.25 18cm\\'),(599,512889657003,130466041713,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',69.9,'cnfaner','y.krasnov','y.krasnov.ebay@gmail.com','Jyri Krasnov','21 King Street<br>New Market','Maidenhead','Berkshire','UNITED KINGDOM','SL6 1DR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 08:02:33',0,NULL,3,0,3,1,NULL,'y.krasnov    WWOT002\r新地址\r\rJyri Krasnov\rBarrikadnyi 36\rBishkek Kyrgyzstan 720007\rKyrgyzstan\rRA022494841CN\r'),(600,563895285013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','szubrilov','zubrilov@freenet.com.ua','Sergey Zubrilov','7 Myshugy Street<br>Apt. 37','Kyiv','','UKRAINE','02140','380445728041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 08:30:58',0,NULL,3,0,3,1,NULL,'szubrilov\rRA022494824CN\r'),(601,563897208013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','d.thomas2011','d.thomas@stryker.com','DAVID Thomas','38 Mulyan Street','Como','New South Wales','AUSTRALIA','2226','0402164454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 08:41:05',0,NULL,3,0,3,1,NULL,'d.thomas2011\rRA022494767CN\r'),(602,684243814011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','sergiabo','sergionietodelamo@gmail.com','Francisco Dominguez','C Marques de Santillana, Nº 1  3ºD','Valladolid','Castilla y León','SPAIN','47010','609203599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 09:02:32',0,NULL,3,0,2,1,NULL,'sergiabo\\'),(603,683859377011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jmok222','jmok@hotmail.com','James Mok','149 Lakeshore Rd. E.','Mississauga','ON','CANADA','L5G 4T9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 14:14:26',0,NULL,3,0,2,1,NULL,'jmok222\\'),(604,684254556011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',2,'MOCN001',9.32,'eastar4','n.dmitry','ndmitry@gmail.com','Dmytro Nyeizvyestnyy','10, Kruhlo-Universytetska str.','Kyiv','','UKRAINE','01024','+380674400044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 09:47:47',0,NULL,3,0,2,1,NULL,'n.dmitry\\'),(605,518738945004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','adwraj','me@adwraj.com','Andrew Raj','No 21, SS3/23,<br>Taman Universiti,','Petaling Jaya','Selangor','MALAYSIA','47300','0175809780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 10:02:10',0,NULL,3,0,3,1,NULL,'adwraj\rRA022494943CN\r'),(606,746208073012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',50,'eastar4','denand71','denand@live.ru','Andrey Denisov','8 peschaniy st.6','Tula','Tulskaya obl','RUSSIAN FEDERATION','300031','+7 903 6588888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-02-24 05:15:15',0,NULL,5,0,18,0,NULL,'denand71'),(607,760410444012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','rothschildinvestment','gtanasic@gmail.com','Gavrilo Tanasic','Zuercherstrasse 13','Basel','','SWITZERLAND','4052','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 10:42:17',0,NULL,3,0,2,1,NULL,'rothschildinvestment\\'),(608,518751667004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','os1samba','user@os9samba.com','Ilja Levinson','Pervomayskaya st., 67-4','Yekaterinburg','','RUSSIAN FEDERATION','620062','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 11:21:46',0,NULL,3,0,3,1,NULL,'os1samba\rRA022494651CN\r'),(609,518297376004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','annak541','annakrug@hotmail.com','Anna Krug','905 Darneille Ln','Grants Pass','OR','UNITED STATES','97527-6181','(541) 582-1118 ext.: 42','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 11:22:27',0,NULL,3,0,1,1,NULL,'annak541\r\\'),(610,563927521013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','rensu83','juha-matti.rensujeff@dlc.fi','Juha-Matti Rensujeff','Kuukkelitie 3A6','Rovaniemi','','FINLAND','96910','+358445556564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 11:33:57',0,NULL,3,0,3,1,NULL,'rensu83\rRA022494784CN\r'),(611,518754741004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'cnfaner','assaframan','asaf_at_china@yahoo.com','Assaf Raman','4/8 Jericho street','Tel Aviv','','ISRAEL','62035','+972528391448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 11:37:52',0,NULL,3,0,3,1,NULL,'assaframan\rRA022494722CN\r'),(612,512926931003,130498781630,'100% Lowepro Mini Trekker AW Photo Camera Bag Backpacks',1,'',64,'cnfaner','anubhav4you','anubhav4you@hotmail.com','Anubhav Visen','112 W 51st St<br>Apt 102','Kansas City','MO','UNITED STATES','64112-2442','(816) 651-6962','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-03-22 11:59:13',0,NULL,3,0,3,1,NULL,'anubhav4you\rRA022494515CN\r'),(613,760435457012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','siciliano1954','siciliano2002@gmail.com','carlos alberto siciliano','rua prof. pedreira de freitas, 69<br>apto 91 - tatuape','São Paulo','SP','BRAZIL','03312052','055 21 82311262','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:10:14',0,NULL,3,0,2,1,NULL,'siciliano1954\\'),(614,0,230597696898,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','superjett55','superjett55@hotmail.com','Joshua Gardner','61 Beaucourt Road','Hamilton','ON','CANADA','L8S 2R2','(416) 818-1231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:12:14',0,NULL,3,0,2,1,NULL,'superjett55\r一共买了两个\r\\'),(615,518760570004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','pjy85n','85park@hanmail.net','JUNYOUNG PARK','303ho, 33-7<br>Sosa-dong, Wonmi-gu','Bucheon-si','Gyeonggi-do','KOREA,REPUBLIC OF','420-818','011)93811353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:19:02',0,NULL,3,0,3,1,NULL,'pjy85n\rRA022494563CN\r'),(616,518762987004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','mrbud321','mrbud321@yahoo.com','Scott Wages','1440 Lakes Pkwy<br>Ste 600','Lawrenceville','GA','UNITED STATES','30043-5896','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 12:53:44',0,NULL,5,0,18,0,NULL,'mrbud321'),(617,684302804011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','riantini','riantini999@yahoo.co.id','Riantini Pujianto','Jl. Wijaya Kusumah IV Blok XI No 87<br>Rt 07/Rw 19 Cijerah','Cimahi Selatan','Jawa Barat','INDONESIA','40534','+6285759939999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:54:14',0,NULL,3,0,2,1,NULL,'riantini\\'),(618,563953215013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',7.98,'eastar4','jaccogeul','j.geul@haphana.org','Jacco Geul','Strevelsweg 966','Rotterdam','','NETHERLANDS','3083LW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 13:40:28',0,NULL,3,0,2,1,NULL,'jaccogeul  再发一个44pin的\rOTCN002\\'),(619,0,320674541191,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','djohnsencep','djohnsen@chicagoequity.com','David Johnsen','180 N La Salle St<br>Suite 3800','Chicago','IL','UNITED STATES','60601','(312) 629-5771','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-22 14:29:02',0,NULL,3,0,1,1,NULL,'djohnsencep\\'),(620,0,220758135568,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','ag14141414','ag1414@hotmail.com','Angela Gaffke','606 165th St S','Spanaway','WA','UNITED STATES','98387','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 14:29:33',0,NULL,3,0,1,1,NULL,'ag14141414\r\\'),(621,760486972012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','macei1','macei1@hotmail.com','luis gustavo macei','rua piratininga 805','ribeirao preto','sao paulo','BRAZIL','14050150','+55 16 3019-2690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 14:44:29',0,NULL,3,0,2,1,NULL,'macei1\\'),(622,760203909012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','sillyppl','sillyppl76@hotmail.com','Austin Sharp','PO Box 502<br>103 West South St.','Anna','OH','UNITED STATES','45302-0502','(937) 394-8217','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 21:46:23',0,NULL,3,0,1,1,NULL,'sillyppl'),(623,563972810013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','webwebes','alejandro_spa@hotmail.com','Alberto Albear','Alfabeguer, 2, pta 8','Manises','Comunidad Valenciana','SPAIN','46940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 15:05:48',0,NULL,3,0,3,1,NULL,'webwebes\rOTRA002\rRA022494594CN\r'),(624,563977085013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','natali.gomel','natali_gomel@yahoo.com','Aliaksandr Hvozdz','MZK \'Solnechnyi\', korpus 5, kv. 71<br>мжк\"Солнечный\" корп.5 кв71','Gomel','','BELARUS','246012','353867711758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 15:25:15',0,NULL,3,0,2,1,NULL,'natali.gomel\\'),(625,563981519013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','strikerspb','kirill@striker.ru','Kirill Blaushild','Ordjonikidze str., d.43, kv.85','Saint-Petersburg','','RUSSIAN FEDERATION','196158','(911)215-8793','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 15:48:47',0,NULL,3,0,3,1,NULL,'strikerspb\rRA022494603CN\r'),(626,760516900012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','clive486','clive.laycock@ntlworld.com','Clive Laycock','195 Harrowby Lane','Grantham','Lincolnshire','UNITED KINGDOM','NG31 9HQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 16:08:10',0,NULL,3,0,3,1,NULL,'clive486\r英标\rRA022494775CN\r'),(627,0,230597696391,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'',12.99,'eastar4','vealbird','jrob2524@yahoo.com','James Robinson','2526 Meredith St','Philadelphia','PA','UNITED STATES','19130-2422','(215) 765-1840','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 16:15:14',0,NULL,3,0,1,1,NULL,'vealbird\rSCLO001\\'),(628,518814817004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','kristenwin','kwinter22@gmail.com','Kristen Winter','3522 Summit Pointe Ct','Forest Grove','OR','UNITED STATES','97116-2958','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 16:27:31',0,NULL,3,0,1,1,NULL,'kristenwin\\'),(629,684375070011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','siminfo','sim.sales@skynet.be','M. Abou','boulevard du jubilé 40','bruxelles','','BELGIUM','1080','024201765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 16:34:49',0,NULL,3,0,2,1,NULL,'siminfo\\'),(630,760553174012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','teddy9497-2008','terjuan535@clear.net','TERJUAN ROGERS','535 N Luzerne Ave','BALTIMORE','MD','UNITED STATES','21205','(443) 758-2080','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 17:32:34',0,NULL,3,0,1,1,NULL,'teddy9497-2008\\'),(631,564015455013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','vpal8821','vpaluri@yahoo.com','Vasantha Paluri','16, St James Street','Monroe','NJ','UNITED STATES','08831','(732) 656-1913','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 17:39:04',0,NULL,3,0,1,1,NULL,'vpal8821\\'),(632,0,230599766158,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 17:39:31',0,NULL,3,0,1,1,NULL,'michael2289xd\\'),(633,760561309012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','frankster1962','fdfrankster8@gmail.com','frank depaz','2841 s marigold ave','ontario','CA','UNITED STATES','91761','(909) 815-5894','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 17:48:59',0,NULL,3,0,1,1,NULL,'frankster1962\\'),(634,564019596013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','abdulrahim79','lucky_3abdu@hotmail.com','Abdulrahim alharthi','oman<br>P.O BOX NO:74 , P.CODE:122  MABELLAH,SEEB','seeb','MUSCAT','OMAN','968','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 17:53:49',0,NULL,3,0,2,1,NULL,'abdulrahim79\\'),(635,518841464004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',2,'HSPL010',49.98,'cnfaner','dam005','derekm@southslope.net','Derek Miller','1875 State St','Ely','IA','UNITED STATES','52227','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 18:05:26',0,NULL,3,0,1,1,NULL,'dam005\\'),(636,760615560012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','w11337','houbeau_christophe@hotmail.com','Christophe Houbeau','Langesthal, 163','Eupen','','BELGIUM','4700','0476936458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 19:28:25',0,NULL,3,0,2,1,NULL,'w11337\\'),(637,684037937011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','rostien0','dpav28@msn.com','dave','1130 37A AVE NW','edmonton','AB','CANADA','T6T0E7','(780) 756-3192','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:30:50',0,NULL,3,0,2,1,NULL,'rostien0'),(638,564071082013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','epvenom13','epvenom13@hotmail.com','Edgar Nava','12528 Crystal Ridge St','El Paso','TX','UNITED STATES','79938','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 20:07:11',0,NULL,3,0,1,1,NULL,'epvenom13\r\\'),(639,760631191012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jimry','jimry@ccaonline.com','Jim R. Youngquist','601 Keokuk St','Lincoln','IL','UNITED STATES','62656-1730','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 20:28:59',0,NULL,3,0,1,1,NULL,'jimry\\'),(640,0,320674545985,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',30.49,'eastar4','edznewone','edznew1@gmail.com','John Wright','720 Newport Dr','Villa Rica','GA','UNITED STATES','30180-7456','(678) 427-2266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 20:45:13',0,NULL,3,0,1,1,NULL,'edznewone\\'),(641,564086810013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','javi_cordoba','haynsur@hotmail.com','Javier Gutierrez','cazkuene 35, 7ºC','San Sebastian','País Vasco','SPAIN','20017','665286795','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 20:47:19',0,NULL,3,0,3,1,NULL,'javi_cordoba\rRA022494838CN\r'),(642,564099490013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','bootybates','denariusbates@yahoo.com','Denarius Bates','4488 Spears Rd','Liberty','MS','UNITED STATES','39645-6107','(601) 657-8559','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 21:18:20',0,NULL,3,0,1,1,NULL,'bootybates\\'),(643,684174796011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','triplethinker','evelyn_design@hotmail.com','Yi Xiao','523 W 112th St<br>Apt 44B','New York','NY','UNITED STATES','10025-1619','(347) 429-3887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 02:43:45',0,NULL,3,0,1,1,NULL,'triplethinker'),(644,518919585004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','barsaxd','s.bertas@gmail.com','Robertas Sabunas','Respublikos 10-14','Kedainiai','','LITHUANIA','57399','0037061697232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 21:41:48',0,NULL,3,0,3,1,NULL,'barsaxd\rRA022494577CN\r'),(645,564098353013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','pdfuzzbug','jesseboulard@gmail.com','Jesse Boulard','7416 Apple Mill Dr','Louisville','KY','UNITED STATES','40228','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-22 21:42:41',0,NULL,3,0,1,1,NULL,'pdfuzzbug\\'),(646,513085357003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','alkagirish','alka_talati@hotmail.com','Alka Talati','1811 Nours Landing Way','Duluth','GA','UNITED STATES','30097-3420','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 21:51:20',0,NULL,3,0,1,1,NULL,'alkagirish\\'),(647,563706661013,230576095186,'Logitech MX518 MX 518 Gaming Optical USB Mouse 90% new',1,'MOLO003',32.9,'eastar4','natasha1808','natasa.marcinkovic@gmail.com','NATAŠA MARČINKOVIĆ','BANA JOSIPA JELAČIĆA 48<br>EMINOVCI','JAKŠIĆ','POŽEGA','CROATIA','34308','0038534247041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 22:06:21',0,NULL,3,0,3,1,NULL,'natasha1808\rRA022494585CN\r'),(648,513091140003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','krissylynnw','krissylynng@yahoo.com','Peggy Key','1000 SE Prairie Ln<br>Apt 22','Oak Grove','MO','UNITED STATES','64075-9393','(816) 778-4382','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 22:07:08',0,NULL,3,0,1,1,NULL,'krissylynnw\\'),(649,0,320674541016,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',12.99,'eastar4','imamacuserartist','tadlakelady@gmail.com','Dianne Clowes','5391 Helena Lake Road','One Hundred Mile House','BC','CANADA','V0K 2E1','(250) 791-7222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 22:18:36',0,NULL,3,0,2,1,NULL,'imamacuserartist\\'),(650,684553228011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','jasonmiles','miles267@gmail.com','Jason Miles','6511 Hearth Falls Dr','Rogers','AR','UNITED STATES','72758-4182','(904) 610-8795','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 22:42:05',0,NULL,3,0,1,1,NULL,'jasonmiles\r\\'),(651,760332130012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','shirishagra','shirishsinha@sancharnet.in','Shirish Sinha','C 3 third floor<br>Surajdham Apartment Shamshabad Road','Agra','UP','INDIA','282001','9897048405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 04:17:55',0,NULL,3,0,2,1,NULL,'shirishagra'),(652,684200075011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','winnie_yang21','yangmei711@hotmail.com','Hsiao-Yu Yang','645 Chestnut Ave<br>Apt 303','Long Beach','CA','UNITED STATES','90802-1275','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 04:45:13',0,NULL,3,0,1,1,NULL,'winnie_yang21\rLK032927017CN'),(653,0,320674546151,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','bright_spark_it','tskinner82@hotmail.com','Timothy Skinner','75A Pearce Dr','Coffs Harbour','New South Wales','AUSTRALIA','2450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 23:29:50',0,NULL,3,0,3,1,NULL,'bright_spark_it\rRA022494798CN\r\r'),(654,0,320671983892,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12,'eastar4','shenshaw1976','henshaw76@hotmail.com','stuart henshaw','27 pacific way<br>beldon','perth','Western Australia','AUSTRALIA','6027','0422927547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 23:41:51',0,NULL,3,0,2,1,NULL,'shenshaw1976\\'),(655,684149503011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ncdebpas','ncdebpas@hotmail.com','Deborah Pasquantonio','3512 Edsel Pl','Charlotte','NC','UNITED STATES','28205','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 01:13:55',0,NULL,3,0,1,1,NULL,'ncdebpas'),(656,760758666012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','raytatover','jason.oatway@gmail.com','Jason Oatway','22A Locks Rd','Dartmouth','NS','CANADA','b2x2j5','(902) 405-2395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 00:32:26',0,NULL,3,0,2,1,NULL,'raytatover\\'),(657,684599630011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.9,'eastar4','tongael14','fedeel14@gmail.com','Gaston Lopez Duarte','Lima 1445 11b','Capital Federal','Capital Federal','ARGENTINA','1138','43053745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 01:15:53',0,NULL,3,0,2,1,NULL,'tongael14\\'),(658,513138125003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',2,'BAZA001',151.2,'cnfaner','will_andrew','sublimeatucf@gmail.com','William Campbell','PO Box 8079','Coral Springs','FL','UNITED STATES','33075','(407) 625-4590','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 01:36:33',0,NULL,3,0,1,1,NULL,'will_andrew\\'),(659,564168295013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','bdgold','asubhan175@yahoo.com','Abdus Subhan','C/ Carretes 34, 01º 01ª','Barcelona','Cataluña','SPAIN','08001','634273405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 01:47:18',0,NULL,3,0,2,1,NULL,'bdgold\\'),(660,518976101004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','rugrats_10','car105_ac@hotmail.com','jorge  marquez','4402 little moser ln','charlotte','NC','UNITED STATES','28227-8673','(704) 545-8838','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 02:02:23',0,NULL,3,0,1,1,NULL,'rugrats_10\r\\'),(661,0,320674798915,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',8.99,'eastar4','rook1961','lunnakitty3@aol.com','Tori Johnson','2008 Dement Hollow Rd','Readyville','TN','UNITED STATES','37149-5176','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 02:02:25',0,NULL,3,0,1,1,NULL,'rook1961\\'),(662,518977313004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','vinnyozzy','viniscsp@gmail.com','Vinícius da Silva Costa','Rua Inacio Manuel alvares, #95','São Paulo','São Paulo','BRAZIL','05372-110','55 11 94996391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 02:03:02',0,NULL,3,0,3,1,NULL,'vinnyozzy\rRA022494855CN\r'),(663,518971071004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','babimisti1','babimisti1@aol.com','AMBER MARES','1803 Childers Dr NE','albuquerque','NM','UNITED STATES','87112','(505) 362-3329','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 02:12:04',0,NULL,3,0,1,1,NULL,'babimisti1\r\\'),(664,684616877011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',16.59,'eastar4','t40puter','t40cal@comcast.net','Timothy  Overton','630 Lolita Dr','Murfreesboro','TN','UNITED STATES','37130-3217','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 02:12:35',0,NULL,3,0,1,1,NULL,'t40puter\rHP 8pin 1.25 25cm \r\\'),(665,0,220758409604,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',11.98,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 03:50:43',0,NULL,3,0,1,1,NULL,'michael2289xd\r一共买了两个\\'),(666,684640764011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','fcollingwood','frank@collingwood.me.uk','Frank Collingwood','125 Hanham Road<br>RD1','Kumeu','Rodney','NEW ZEALAND','0891','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 03:52:32',0,NULL,3,0,2,1,NULL,'fcollingwood\\'),(667,0,230600020579,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',9.99,'eastar4','solidgolds','nitnem@hotmail.com','Jaswinder Singh','159 wexford road','Brampton','ON','CANADA','L6Z 2P8','(647) 449-4744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 04:09:09',0,NULL,3,0,2,1,NULL,'solidgolds\\'),(668,564198318013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','rpas9523','fhptrooper1@bellsouth.net','RAYMOND PASTRANA','4081 Heirloom Rose Pl','OVIEDO','FL','UNITED STATES','32766-6681','(407) 256-6132','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 04:35:48',0,NULL,3,0,1,1,NULL,'rpas9523\\'),(669,513168045003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',58.74,'cnfaner','nevelin78','nino2003ca@yahoo.ca','Nevelin Nonchev','1818-55 wynford heights cres','Toronto','ON','CANADA','m3c1l4','(647) 885-0909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 04:40:57',0,NULL,3,0,3,1,NULL,'nevelin78\r再发一个 NOKIA  BH 900\rRA022494648CN\r'),(670,519006126004,140481827765,'NIB Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL003',17.5,'cnfaner','*jaby*','taurus39208@yahoo.com','erika bowden','105 cedar ridge blvd','pearl','MS','UNITED STATES','39208-8088','(601) 209-1342','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 05:08:33',0,NULL,3,0,1,1,NULL,'*jaby*\\'),(671,519010335004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',2,'HSNO005',29.5,'cnfaner','majidafzal404mario','majidafzal404@yahoo.com','mario afzal','10431 Pilot Rock Rd','collierville','TN','UNITED STATES','38017-1962','(901) 463-8223','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 05:50:07',0,NULL,3,0,1,1,NULL,'majidafzal404mario\\'),(672,513176266003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','kavinduinfo','kavindu@live.com','Kavindu Kanishka','No 226,<br>Kandawatta, Dediyawala,','Waskaduwa','Western','SRI LANKA','12580','94342238006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 06:02:23',0,NULL,3,0,3,1,NULL,'kavinduinfo\rRA022494665CN\r\r\r'),(673,684289771011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','hyunkel8424','hyunkellll@hotmail.com','maxime roy','10300 gouin st','montreal','QC','CANADA','h1c1b1','(514) 881-2671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:05:37',0,NULL,3,0,2,1,NULL,'hyunkel8424\\'),(674,0,320674798930,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','purchase4u','tjmbartlett@gmail.com','Timothy Bartlett','Kappinghat 289 Property<br>198-204 Wandobah Rd.','Gunnedah','New South Wales','AUSTRALIA','2380','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 06:52:57',0,NULL,3,0,3,1,NULL,'purchase4u\rRA022494149CN\r\\'),(675,519020449004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','ahhuss','m.annab@yahoo.com','Annabella Markus','Toldi Miklós u. 28/A','Gyal','Pest','HUNGARY','2360','+36 30 257 67 25','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 07:29:50',0,NULL,3,0,3,1,NULL,'ahhuss\r欧标\rRA022494152CN\r\\'),(676,564221549013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','botaksetan','support.ibu4aceh@gmail.com','Adi Sunardy','Gedung Danamon Lantai 8<br>Jl. Diponegoro No. 35','Medan','Sumatera Utara','INDONESIA','20152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 07:51:17',0,NULL,3,0,3,1,NULL,'botaksetan\rRA022494740CN\r\\'),(677,760734111012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','kontesa7','zrinac@gmail.com','Zrinka Nazor','Dobroniceva 15','Zagreb','Croatia','CROATIA','10110','+385958589520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 08:23:50',0,NULL,3,0,2,1,NULL,'kontesa7   欧标\r\\'),(678,760876977012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','driven888','dchiu@telus.net','Daniel Chiu','46 West 22nd Avenue','Vancouver','BC','CANADA','V5Y 2E8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 09:10:22',0,NULL,3,0,2,1,NULL,'driven888\r\\'),(679,519038556004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','chanuka11','chanuka1992@gmail.com','chanuka','195/5,rajaphilla mw ,kandy','kandy','','SRI LANKA','20000','+940777227728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 09:41:19',0,NULL,3,0,3,1,NULL,'chanuka11\rRA022494104CN\r\\'),(680,0,220758409526,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',15.99,'eastar4','stuff_e_nuff','stef@statice.eu','Stef den Mulder','De Oude Kooien 15','Beringe','Limburg','NETHERLANDS','5986 PJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 10:29:59',0,NULL,3,0,2,1,NULL,'stuff_e_nuff\r\\'),(681,684717648011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','shantavatapipi','shantava1@abv.bg','Vasil Lefterov','GETECH Kitson House<br>Elmete lane','Leeds','West Yorkshire','UNITED KINGDOM','LS8 2LJ','07807753598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 10:40:51',0,NULL,3,0,2,1,NULL,'shantavatapipi\r\\'),(682,684398455011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mahmoud_yassine','mahmoudyassine@gmail.com','Ehab Neama Wahba','147-29 182nd Street, KWI 15536<br>KWI 15536','Springfield Gardens','NY','UNITED STATES','11413','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 17:35:56',0,NULL,3,0,1,1,NULL,'mahmoud_yassine'),(683,564251699013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',37.2,'eastar4','s.kamenskih','skamenskih@gmail.com','Sergey Kamenskikh','Leninskij pr., d. 79, k.2, kv. 318','Saint-Petersburg','RU','RUSSIAN FEDERATION','198332','(921) 9464710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 11:08:09',0,NULL,3,0,3,1,NULL,'s.kamenskih\rRA022494753CN\r\\'),(684,564255897013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.85,'eastar4','arnoldso','arnoldso@yahoo.com','Arnoldo Suarez Ortega','Maria Uribe #449','Guadalajara','Jalisco','MEXICO','44820','+523336052763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 11:24:37',0,NULL,3,0,2,1,NULL,'arnoldso\r\\'),(685,564256752013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','tomykas0','tomykui@gmail.com','Tomas Kuciukas','Baltu pr. 25 - 3','Kaunas','LT','LITHUANIA','48237','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 11:28:45',0,NULL,3,0,2,1,NULL,'tomykas0\r\\'),(686,563840460013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','china73','ciuped@yahoo.com','Ioan Ciupe','4825 W Warner Ave','Chicago','IL','UNITED STATES','60641-1815','(773) 297-0399','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 11:41:14',0,NULL,3,0,1,1,NULL,'china73'),(687,519065509004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','nuriel79','nuriel1985@walla.com','nuriel maynayev','tzahal 2','Petah Tiqva','ramat verber','ISRAEL','49521','039234632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 12:18:34',0,NULL,3,0,3,1,NULL,'nuriel79\rRA022494679CN\r\\'),(688,518920020004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','marazza_58','marazza_58@yahoo.it','Siegfried MUELLER','Strada da l\'ort 8','Lugano','','SWITZERLAND','6915','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 12:44:55',0,NULL,3,0,3,1,NULL,'marazza_58\rRA022494081CN\r\\\r'),(689,760936045012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','nibelungen-kiez','w.ahlgrimm@gmx.de','Ahlgrimm Werner','Guntherstr. 37A','Berlin','','GERMANY','10365','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 12:51:37',0,NULL,3,0,2,1,NULL,'nibelungen-kiez\r欧标\r\\'),(690,760945469012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','gvpieper','gary.piper@snet.net','Gary V. Pieper','47 Bayberry Dr','Wallingford','CT','UNITED STATES','06492-4713','(203) 265-6105','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 13:14:31',0,NULL,3,0,1,1,NULL,'gvpieper\r、'),(691,760953788012,220752720350,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','rob00120','rob0013@blueyonder.co.uk','robert pearson','50 whitbeck court<br>slatyford','newcastle upon tyne','Tyne and Wear','UNITED KINGDOM','NE52XF','07769717000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-23 13:43:35',0,NULL,3,0,3,1,NULL,'rob00120\rRA022494078CN\r\\'),(692,519085817004,140516805344,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'cnfaner','hitmanoh','tom.mason@promevo.com','Tom Mason c/o Promevo','808 Lyndon Ln<br>Suite 205','Louisville','KY','UNITED STATES','40222-7899','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:01:48',0,NULL,3,0,1,1,NULL,'hitmanoh\r、'),(693,0,320674976735,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','williamshernandez','willyraque@hotmail.com','William Hernández','Calle Nicaragua, Número 7, 3 Izquierda.','Telde, Gran Canarias.','Canarias','SPAIN','35210','675942125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 14:13:26',0,NULL,3,0,3,1,NULL,'williamshernandez\rRA022494682CN\r\\'),(694,513256612003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',12.99,'cnfaner','muskie99d','derek.longman@bell.net','Derek Longman','33387 Coursey Line<br>RR 1','Lucan','ON','CANADA','N0M 2J0','(519) 227-1732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 14:28:33',0,NULL,3,0,3,1,NULL,'muskie99d\rRA022494118CN\r\\'),(695,760973102012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','korobkinoleg','korobkin.o@gmail.com','Oleg Korobkin','Goloseevskaya 16. App. 137','Kiev','UA','UKRAINE','03039','380636180149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 14:35:26',0,NULL,3,0,2,1,NULL,'korobkinoleg\r\\'),(696,760971949012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','korobkinoleg','korobkin.o@gmail.com','Azarov Anton','Lesya Kurbasa 4 st. app. 67','Kiev','','UKRAINE','03148','+380936844412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 14:38:39',0,NULL,3,0,2,1,NULL,'korobkinoleg\r\\'),(697,564315599013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','warhol1959','nc-meumerju@netcologne.de','Juergen Meumerzheim','Pützfelder weg 15','Bonn','','GERMANY','53177','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 15:52:19',0,NULL,3,0,3,1,NULL,'warhol1959\rRA022494135CN\r\\'),(698,513275143003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','jlofish','jlpuente@telefonica.net','JOSE LUIS LOPEZ PUENTE','Cl. Canalillo, 8 - 6º A','Madrid','Madrid','SPAIN','28028','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 15:53:35',0,NULL,3,0,3,1,NULL,'jlofish\rRA022494064CN\r\\'),(699,684631075011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',118.99,'eastar4','mkpwl3','mickpwl@yahoo.com','Michael Powell','592 N 100 E','Springville','UT','UNITED STATES','84663-1179','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 16:14:33',0,NULL,3,0,1,1,NULL,'mkpwl3\r、'),(700,519118204004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',2,'OTGR001+OTGR002',79.8,'cnfaner','christopher.714','thichdathe@yahoo.com','christopher hoang','8162 Lambert Dr','huntington beach','CA','UNITED STATES','92647-4816','(714) 596-6194','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 16:24:11',0,NULL,3,0,1,1,NULL,'christopher.714\r再发一个水管'),(701,518898499004,140429833142,'2.1 Acer Aspire One 751 AO751h bluetooth module track#',1,'BTAC2115',16.59,'cnfaner','p13w13','maartenklein@home.nl','Maarten Klein','Lambertinck 31','Den Ham','','NETHERLANDS','7683WR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 20:40:44',0,NULL,3,0,3,1,NULL,'p13w13\racer 5pin1.25 20cm\rRA022494532CN\r\\'),(702,761034759012,220723618818,'Nokia HF-31W Bluetooth Plug-in Car Kit Speakphone',1,'HSNO027',15.5,'eastar4','dimasas','pankdima@takas.lt','Dmitrij Pankejev','Mickeviciaus 19-89','Siauliai','','LITHUANIA','LT-77165','+37060475330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 17:12:49',0,NULL,3,0,2,1,NULL,'dimasas\r\\'),(703,0,230597705940,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',30.5,'eastar4','quegc22','gastonchaine@sympatico.ca','Gaston Chaine','7750 Ch. Sainte-Marguerite','Trois-Rivieres Secteur Ouest','QC','CANADA','G9A 5C9','(819) 377-5403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 17:15:38',0,NULL,3,0,3,1,NULL,'quegc22\rRA022494095CN\r\\'),(704,519133984004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','christopher.714','thichdathe@yahoo.com','christopher hoang','8162 Lambert Dr','huntington beach','CA','UNITED STATES','92647-4816','(714) 596-6194','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 17:23:22',0,NULL,8,0,17,0,NULL,'christopher.714'),(705,761043733012,220752720350,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','amlbr','amlbrfr@gmail.com','Marcelo ARAUJO DE ALMEIDA','76, rue des fleurs','carrières sous poissy','Île-de-France','FRANCE','78955','0130743767','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-23 17:36:47',0,NULL,3,0,2,1,NULL,'amlbr\r\\'),(706,564344512013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','ninie5781','vin.vir@orange.fr','Virginie KREMER','26, route d\'Elzange','INGLANGE','Lorraine','FRANCE','57970','03.82.56.06.29','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 17:39:59',0,NULL,3,0,3,1,NULL,'ninie5781\rRA022494546CN\r\\'),(707,684863687011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','dracosilv','dracosilver@wi.rr.com','Jonathan Herr','3505 69th St','Kenosha','WI','UNITED STATES','53142','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 18:06:15',0,NULL,3,0,1,1,NULL,'dracosilv\r、'),(708,564357748013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','pushap905','paulsidhu28@rogers.com','Gurpaul Sidhu','1328 Godwick drive','Mississauga','ON','CANADA','l5n7x3','(416) 828-2985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 18:17:17',0,NULL,3,0,2,1,NULL,'pushap905\r\r新地址\rGurpaul Sidhu\r3350 Thomas Street Unit 14 Mississauga Ontario L5M0R2\rCanada\r\\'),(709,684470851011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','maros730522','maros73@gmail.com','Maros Urminsky','77 Verdemont<br>Snugborough road','Blanchardstown','Dublin','IRELAND','D15','0833341699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 19:53:32',0,NULL,3,0,2,1,NULL,'maros730522\r\\'),(710,564369080013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','therealtomahawk','felipe@gaete.cl','Felipe Gaete','Bergen 211, dept 1004<br>Las Condes','Santiago','Region Metropolitana','CHILE','7560786','562-7161351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 18:47:07',0,NULL,3,0,3,1,NULL,'therealtomahawk\rRA022494705CN\r\\'),(711,761111738012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','gd_n','gd_n2@yahoo.com','Georgi Nalbantov','Slavianska 85','Plovdiv','Plovdiv','BULGARIA','4000','+359878440198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 19:36:02',0,NULL,3,0,2,1,NULL,'gd_n\r欧标\r\\'),(712,564395180013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','woofer2010','alexraik@mail.ru','Raikov Alexey','110-2-141, Leninskiy pr.','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198303','+7-921-322-4045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 19:50:22',0,NULL,3,0,3,1,NULL,'woofer2010\rRA022494696CN\r\\'),(713,0,230600160103,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 20:11:28',0,NULL,3,0,1,1,NULL,'michael2289xd'),(714,513366184003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','tgri5349','taryn_griffin@comcast.net','Taryn Griffin','556 Tudor Rd','San Leandro','CA','UNITED STATES','94577','(510) 499-9221','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 20:36:29',0,NULL,3,0,1,1,NULL,'tgri5349\r、'),(715,761152683012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','puddingkappes','kettner@gmx.net','Viktor Makelki','Frischmuthstrasse 5','Grevenbroich','','GERMANY','41515','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:40:57',0,NULL,3,0,2,1,NULL,'puddingkappes\r\\'),(716,761109985012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','jnsamuelson91','jnsamuelson@gmail.com','Jared Samuelson','24 Mattison way','Salem','NY','UNITED STATES','12865','(518) 728-5449','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 20:45:28',0,NULL,3,0,1,1,NULL,'jnsamuelson91\r、'),(717,564417765013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','serandinas','sdaoviedo@hotmail.com','SERGIO DAVILA ANDRES','C/. CARDENAL ALVAREZ MARTINEZ 8 4ºA','OVIEDO','Asturias','SPAIN','33011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:47:15',0,NULL,3,0,3,1,NULL,'serandinas\rRA022494736CN\r\\'),(718,564418264013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',9.99,'eastar4','moldovan.vyacheslav','moldovan.v@hotmail.com','Moldovan Vyacheslav','Profsojuznaia str, 98, 1, 299','Moscow','','RUSSIAN FEDERATION','117485','(917) 5790360','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:49:23',0,NULL,3,0,2,1,NULL,'moldovan.vyacheslav\r\\'),(719,761158350012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',81.95,'eastar4','oswellh','cliffordh@mac.com','Darold Howard','PO Box 1256<br>1840 Hwy 87','Crystal Beach','TX','UNITED STATES','77650','(409) 256-4123','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 20:52:18',0,NULL,3,0,1,1,NULL,'oswellh'),(720,513378463003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','har84man','har8man@gmail.com','Harutyun Manukyan','Vrt.Papazyan st #61','Yerevan','Kanaker Zeytoun','ARMENIA','0037','37499250929','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-23 21:12:38',0,NULL,3,0,3,1,NULL,'har84man\rRA022494529CN\r\\'),(721,564435190013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.85,'eastar4','cfanjul','info@cyberdyne.com.ar','JORGELINA GARABAN','5101 NW 105th Ct','Doral','FL','UNITED STATES','33178-3216','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 21:39:40',0,NULL,3,0,1,1,NULL,'cfanjul'),(722,761188424012,220711639863,'New Logitech Rechargeable battery 890 880 950mA+charger',1,'BALO001+BAIN002',14.99,'eastar4','lotusmach10','paulandkay1993@sbcglobal.net','Paul Pakizer','3747 Deer Springs Dr','Rochester Hills','MI','UNITED STATES','48306','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 21:47:23',0,NULL,3,0,1,1,NULL,'lotusmach10'),(723,519233885004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','aliexas','aliexas@yahoo.co.uk','Aleksandr Ostanin','LA Drape.Internet House<br>Aston Lane North.Preston Brook','Runcorn','Cheshire','UNITED KINGDOM','WA7 3PE','07913573945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 22:16:36',0,NULL,3,0,3,1,NULL,'aliexas\rRA022494121CN\r\\\r\r'),(724,761222438012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',27.98,'eastar4','cmangeri','mangericrafters@comcast.net','Christopher Mangeri','1607 Heather Dr','Downingtown','PA','UNITED STATES','19335-3577','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 23:08:34',0,NULL,3,0,1,1,NULL,'cmangeri\r再发一个保护屏\r、'),(725,684913090011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mikroft','acwleung@shaw.ca','Andrew Leung','2482 Triumph St.','Vancouver','BC','CANADA','V5K 1S5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 19:39:28',0,NULL,3,0,2,1,NULL,'mikroft\r\\'),(726,761225388012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.88,'eastar4uk','087lagunaman2','johnjamesgalligan@o2.ie','james galligan','ballinaloe','coole','Westmeath','IRELAND','wh','0872232287','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-23 23:22:41',0,NULL,3,0,3,1,NULL,'087lagunaman2\r英标\rRA022494206CN\r\\  '),(727,0,220758608676,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','williaal80','williaal80@yahoo.com','Audrey Williams','787 Old Brook Rd','Charlottesville','VA','UNITED STATES','22901','(434) 202-1590','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 23:46:11',0,NULL,3,0,1,1,NULL,'williaal80\r、'),(728,685029175011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'eastar4','dorit710','rvnsh@walla.com','reuven shloosh','kikar zabotinski 7/10','tiberias','','ISRAEL','14227','052-4236738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 23:58:35',0,NULL,3,0,11,1,NULL,'dorit710'),(729,564475769013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','ultek02','jangstadt@gmail.com','Jeffery Angstadt','19935 Paso Robles Ave','Redding','CA','UNITED STATES','96003-7835','(530) 227-8154','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 00:03:20',0,NULL,3,0,1,1,NULL,'ultek02\r、'),(730,564480527013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','requin03','yanquenneville@videotron.ca','Yan Quenneville','1595 boul. du  souvenir #902','laval','QC','CANADA','H7N 4Z7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 00:35:33',0,NULL,3,0,3,1,NULL,'requin03\rRA022494550CN   '),(731,685052975011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','phil31589','plynch@dsisd.k12.mi.us','Phil Lynch','322 S 16th St','Escanaba','MI','UNITED STATES','49829-2630','(906) 786-2396','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 01:21:36',0,NULL,3,0,1,1,NULL,'phil31589'),(732,564498225013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','palacesong','korosh@gmail.com','Alexander Afshar','90 William St<br>Apt 15E','New York','NY','UNITED STATES','10038-0106','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 01:46:42',0,NULL,3,0,1,1,NULL,'palacesong'),(733,0,220758608683,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',9.99,'eastar4','nate64516tc','nate645@hotmail.com','Nathan Giles','430 Charter Ct','Lawrenceville','GA','UNITED STATES','30046-8308','(678) 886-5421','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 02:04:09',0,NULL,3,0,1,1,NULL,'nate64516tc\r、'),(734,564504347013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','xetsus09','xetsus@gmail.com','Jorge Alberto Sanchez Diaz','Fernando Castillo # 7','Texcoco','Mexico/Texcoco/Unidad ISSSTE','MEXICO','56230','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,0,2,1,NULL,'xetsus09\r\\'),(735,761319620012,220475280848,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10',1,'BTLE2001',9.99,'eastar4','llaval22','llaval22@yahoo.com','Kelly Taylor','754 W Pinkley Ave','Coolidge','AZ','UNITED STATES','85128-4218','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 04:59:05',0,NULL,3,0,1,1,NULL,'llaval22\\'),(736,519308937004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','garfld02','rick@fromorbit.com','Rick Garfield','C/- The PA People<br>9 - 11 LEEDS STREET','RHODES','New South Wales','AUSTRALIA','2138','0287558700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 05:20:05',0,NULL,3,0,3,1,NULL,'garfld02      澳标\rHSPL010\rRA022494400CN\r\\'),(737,684959090011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','kdpaine4a1h','kdpaine@kdpaine.com','KDPaine & Partners, LLC','51 Durham Point Rd','Durham','NH','UNITED STATES','03824-3100','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 21:13:06',0,NULL,3,0,1,1,NULL,'kdpaine4a1h'),(738,513476982003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',2,'HSMO006',23.98,'cnfaner','mejzeej','youahlubmailee@yahoo.com','Youa Thao','1836 W Weiland Ln<br>Apt 3','Appleton','WI','UNITED STATES','54914-2078','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 05:46:41',0,NULL,3,0,1,1,NULL,'mejzeej'),(739,513479779003,130489883385,'New Sony Ericsson HBH-PV702 BLUETOOTH HEADSET track#',1,'HSSE003',21.9,'cnfaner','10usmanali','maakabata@gmail.com','muhammed javed','225,oak view dr','regina','SK','CANADA','s4r7e8','(306) 205-3503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 06:11:34',0,NULL,3,0,3,1,NULL,'10usmanali\rHSSE003\rRA022494311CN\r\\'),(740,564540864013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','cncjunky','cmcjunky@hotmail.com','brian lutzen','N82W22020 Dubnicka Dr','sussex','WI','UNITED STATES','53089','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 06:28:34',0,NULL,3,0,1,1,NULL,'cncjunky'),(741,684994394011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',14.98,'eastar4','richardc8113','prnrich@aol.com','Richard Cohen','42  Newton  St','New Bedford','MA','UNITED STATES','02740','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 22:17:11',0,NULL,3,0,1,1,NULL,'richardc8113'),(742,564548413013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','jeffreyhill1998','sales@overstockandstuff.net','amanda hill','7741 e vancouver pl','tucson','AZ','UNITED STATES','85730-3421','(520) 940-4669','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 07:31:51',0,NULL,3,0,1,1,NULL,'jeffreyhill1998\r、'),(743,564090637013,230544190510,'NEW original Motorola H700 Gold DG Bluetooth Headset',1,'HSMO012',17.9,'eastar4','kariwka2007','inkognito2004@one.lv','Gleb Maslovs','18210 Oxnard St<br>Tarzana Unit 143','Tarzana','CA','UNITED STATES','91356-1720','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 07:33:40',0,NULL,3,0,1,1,NULL,'kariwka2007\r'),(744,519323418004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',2,'HSNO022',29.96,'cnfaner','tahantahan','raxpaks@hotmail.com','Ragnar Kivisaar','Janese 26','Tartu','','ESTONIA','51009','372 56931255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 07:42:44',0,NULL,3,0,3,1,NULL,'tahantahan\r欧标\rHSNO022   银色的\rRA022491010CN\r\\'),(745,685053823011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','chengyunthirteen','thirteen.li13@gmail.com','Dian(Kimi) Wang','540 Lakeshore Road West','Oakville','ON','CANADA','L6K 3P1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 01:27:29',0,NULL,3,0,2,1,NULL,'chengyunthirteen\r\\'),(746,519334658004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','arn2523','praparlk@yahoo.com','Praparl Kanjanophas','10 Rongmuang2 (Praram6soi3) Rongmuang Patumwan','Bangkok','Bangkok','THAILAND','10330','6626139314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:07:54',0,NULL,3,0,3,1,NULL,'arn2523\rHSPL011\rRA022491054CN\r\\'),(747,564564175013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','sirarchy9977','shatrov@inbox.ru','Arkadiy Shatrov','49, 26/1, Stoykosti str.','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198261','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:20:11',0,NULL,3,0,2,1,NULL,'sirarchy9977\r\\'),(748,685018365011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','dickcu2125','dickcu@comcast.net','Dick Curtis','4490 248th Ln SE','Issaquah','WA','UNITED STATES','98029','(425) 369-9518','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 23:23:54',0,NULL,3,0,1,1,NULL,'dickcu2125'),(749,685146300011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',138.99,'eastar4','bigmadmex','sifuentj@yahoo.com','joshua sifuentes','136 N Porter St','Waynesburg','PA','UNITED STATES','15370-1430','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 09:21:29',0,NULL,3,0,1,1,NULL,'bigmadmex\r、'),(750,761370003012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','akebono123','i.ivanov@spnet.net','Ivan Ivanov','52 Borisova Str<br>flat 6','Ruse','Ruse','BULGARIA','7012','+359887758006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:24:32',0,NULL,3,0,2,1,NULL,'akebono123\r欧标\r\\'),(751,519338352004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','ilskryabin','lolzeppelin@gmail.com','Илья Плотников','Новосибирская, д.24 к.5','Пермь','Пермский край','RUSSIAN FEDERATION','614033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:34:53',0,NULL,3,0,3,1,NULL,'ilskryabin\rWWSI005\rRA022491947CN\r\\'),(752,684594327011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','yiri_ma','dss@mail.ru','Kirill Vasilyev','Molodezhnaya<br>3/336','Moscow','','RUSSIAN FEDERATION','119226','+79653081275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:40:58',0,NULL,3,0,2,1,NULL,'yiri_ma\r\\'),(753,685156495011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','cmpmal','cmpmal111@yahoo.com.au','Malcolm Pryor','12 Kanooka Ave.,','Ashwood','Victoria','AUSTRALIA','3147','(039) 888-8778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 10:07:00',0,NULL,3,0,2,1,NULL,'cmpmal\r\\'),(754,564574522013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','charmo-71','canddchalmers@bigpond.com','chris chalmers','23  dalray  crescent','new gisborne','Victoria','AUSTRALIA','3438','0354288571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 10:19:57',0,NULL,3,0,3,1,NULL,'charmo-71\rMOSA002\rRA022494339CN\r\\'),(755,761386026012,220748684477,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',2.99,'eastar4uk','darrenbeedie1976','darrenbeedie@hotmail.co.uk','Darren Beedie','4 Hillcrest','Fraserburgh','Aberdeenshire','UNITED KINGDOM','AB43 9NB','01346510718','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 10:26:00',0,NULL,8,0,17,0,NULL,'darrenbeedie1976'),(756,761390178012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','darrenbeedie1976','darrenbeedie@hotmail.co.uk','Darren Beedie','4 Hillcrest','Fraserburgh','Aberdeenshire','UNITED KINGDOM','AB43 9NB','01346510718','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 10:41:48',0,NULL,3,0,3,1,NULL,'darrenbeedie1976\r再发一个40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable\rOTCN001+OTCN002\r\r\\'),(757,564583923013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','dr_ahmad','dr_ahmad_banai@yahoo.com.au','ahmad banai','238 old northern road','castle hill','New South Wales','AUSTRALIA','2154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 11:19:12',0,NULL,3,0,3,1,NULL,'dr_ahmad\rMOSA002\rRA022494325CN\r\\'),(758,761400802012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','bestdeal02','hondaguy28@gmail.com','Vinny Huynh','8 Travis Rd','shrewsbury','MA','UNITED STATES','01545-6316','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 11:23:50',0,NULL,3,0,1,1,NULL,'bestdeal02'),(759,519356190004,140393734505,'%%% NEW Lowepro ROVER PLUS AW Photo Camera Bag Backpack',1,'',107.99,'cnfaner','humanness_restate','raaymann007@yahoo.de','Danilo Raaymann','Bornaische Straße 25','Leipzig','','GERMANY','04277','Invalid Request','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-24 11:24:18',0,NULL,3,0,5,1,NULL,'humanness_restate\r\rCP226379453CN\r'),(760,564485248013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','mros4881','mariwils@gmail.com','Mari Rosenberger','209 Crescent Lane, Apt A','Cliffside Park','NJ','UNITED STATES','07010','(201) 787-4398','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 00:46:07',0,NULL,3,0,1,1,NULL,'mros4881\rLK035155538CN  我又该了一个补发了\re邮宝没有走掉还在上门拦收里'),(761,761411373012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','hifista','info@artdigital.sk','Ivan Filgas','Tomasikova 1','Kosice','','SLOVAK REPUBLIC','040 01','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 12:00:55',0,NULL,3,0,2,1,NULL,'hifista\r\\'),(762,519363428004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','krbo2009','0krbo0@gmail.com','Nenad Krbavac','Naselje Lutvinka K','Slavonski Brod','','CROATIA','35000','+385981399349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 12:08:51',0,NULL,3,0,3,1,NULL,'krbo2009\rOMHJ001\rRA022491023CN\r\\'),(763,761414781012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','ady_dj','amrsic@hotmail.com','Adnan Mrsic','Rolf Hofmos Gate 17','Oslo','Oslo','NORWAY','0655','98853123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 12:12:09',0,NULL,3,0,2,1,NULL,'ady_dj\r\\'),(764,519382477004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','bigbertieman','russell.gillen@ntlworld.com','russell gillen','92 moorfield avenue','port glasgow','Inverclyde','UNITED KINGDOM','PA145XT','01475713909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 13:46:45',0,NULL,3,0,3,1,NULL,'bigbertieman\rOMHJ001\rRA022491955CN\r\\'),(765,685218943011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','smlfinder','mwaschke@gmx.net','Matthias Waschke','Hirtenweg 24','Taufkirchen','','GERMANY','82024','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 13:57:54',0,NULL,3,0,2,1,NULL,'smlfinder\r\\'),(766,761446585012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','romus24','mchrzanowiecki@plusnet.pl','Marek Chrzanowiecki','Sikorskiego<br>40/10','Luboń','wielkopolskie','POLAND','62030','61 6499042','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 14:05:32',0,NULL,3,0,2,1,NULL,'romus24\r\\'),(767,685222655011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',11.95,'eastar4','crush31','joelwk@hotmail.com','Joel Kepecs','2116 Baldwin Park Dr','Mount Pleasant','SC','UNITED STATES','29466','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 14:08:59',0,NULL,3,0,1,1,NULL,'crush31'),(768,685223619011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',5,'CASS002',43.5,'eastar4','has.2009','mete@eosbil.com.tr ','Mete Can GURCAN','Perpa B Blok Kat 6 No 653<br>Sisli','Istanbul','','TURKEY','34384','+90-532-668-1191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 14:12:39',0,NULL,3,0,3,1,NULL,'has.2009\rCASS002\rRA022492046CN\r\\'),(769,0,230599769177,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',15.99,'eastar4','coolwinger2','danygagne88@hotmail.com','DANY GAGNE','UdeS (Fac. sciences Local D3-1027-2)<br>2500, boul. de l\'Universite','Sherbrooke','QC','CANADA','J1K 2R1','(819) 437-8888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 14:34:35',0,NULL,3,0,2,1,NULL,'coolwinger2\r\\'),(770,0,220758137616,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32.5,'eastar4','afrika-bambatafotos','tomas.martoch@email.cz','Tomas Martoch','Y Soft Corporation<br>Podnikatelska 4, Technology Park','Brno','','CZECH REPUBLIC','612 00','+420-608-403 450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 14:40:52',0,NULL,3,0,3,1,NULL,'afrika-bambatafotos\rOTRA002\rRA022491037CN\r\\'),(771,0,320674541405,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','tminted','marcus@rectorseal.com','marcus taylor','2601 Spenwick Dr<br>Rectorseal Corp','Houston','TX','UNITED STATES','77055','(281) 658-8770','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-24 15:47:30',0,NULL,3,0,1,1,NULL,'tminted'),(772,761502045012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','rhw61','rward1961@yahoo.com','Roland Ward','700 Castner Rd','Waldoboro','ME','UNITED STATES','04572-5859','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 16:29:27',0,NULL,3,0,1,1,NULL,'rhw61'),(773,513589967003,130490976227,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',15.99,'cnfaner','nightalon','nightalon@gmail.com','Barrett Williams','206 W 106th St<br>Apt 52','New York','NY','UNITED STATES','10025-3673','(917) 846-8761','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 16:41:52',0,NULL,3,0,1,1,NULL,'nightalon'),(774,685289918011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','risto1966','risto.espo@nesteoil.com','Risto Espo','Kukkumäenkuja 12 as 19','Espoo','ESPOO','FINLAND','02280','+358504584783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 17:37:57',0,NULL,3,0,2,1,NULL,'risto1966\r\\'),(775,0,320674542999,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',11.98,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 17:41:07',0,NULL,3,0,1,1,NULL,'michael2289xd\r一共买了两个'),(776,513610304003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',44.99,'cnfaner','bejzer','alexgrud@hot.ee','aleksei grudin','raadiku 19-56','tallinn','Harjumaa','ESTONIA','13817','+37255591633','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 17:55:37',0,NULL,3,0,3,1,NULL,'bejzer\rHSNO019+CCNO001\rRA022492050CN\r\\'),(777,564682466013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','deins321seins','mail@halebi.de','Erol Halebi','Jakob Becker Strasse 31','Landau','','GERMANY','76829','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 18:06:46',0,NULL,3,0,2,1,NULL,'deins321seins\r\\'),(778,761544381012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.5,'eastar4uk','ldartoraleandro','ldartora@gmail.com','Leandro Dartora','Manoel da Nobrega, 614','Cascavel','Parana','BRAZIL','85803-640','00554599064139','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-24 18:14:30',0,NULL,3,0,3,1,NULL,'ldartoraleandro\rRELO002\rRA022491045CN\r\\'),(779,519457892004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','kleclerc3','kleclerc3@verizon.net','Kellie Leclerc','22 Adams St','Silver Creek','NY','UNITED STATES','14136','(716) 934-3408','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 18:51:22',0,NULL,3,0,1,1,NULL,'kleclerc3'),(780,564689884013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','tonysx-maslist','bpmftom@windstream.net','Michele Rispoli','628 SW Van Buren Rd','Mayo','FL','UNITED STATES','32066-6202','(954) 605-9927','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 19:08:22',0,NULL,3,0,1,1,NULL,'tonysx-maslist'),(781,761580207012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','10cvetan','jaguar_1990@abv.bg','Cvetan Smilenov','27/6<br>Malo Konare','Malo Konare','Pazardjik','BULGARIA','4450','0359883430004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 19:17:06',0,NULL,3,0,2,1,NULL,'10cvetan\r\\'),(782,564712430013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','parmakit','polo_g40@bluewin.ch','Gerber Stefan','Gnappen 1206b','Grünenmatt','','SWITZERLAND','3452','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 19:28:04',0,NULL,3,0,3,1,NULL,'parmakit\rMOSA002\rRA022494342CN\r\\'),(783,519474486004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','paulct974','paul.chane-tune@live.fr','Paul CHANE TUNE','9 Impasse des églantines<br>Domaine Indigo','Sainte-Marie','Réunion','REUNION','97438','02.62.53.10.88','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 19:36:52',0,NULL,3,0,3,1,NULL,'paulct974\rHSNO022\rRA022492029CN\r\\'),(784,685310276011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','sawa232','rafal1375@yahoo.co.uk','Rafal Wojciech Kowalski','10 Monarch Court<br>Cook Street','Wednesbury','West Midlands','UNITED KINGDOM','WS10 9FD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 18:12:46',0,NULL,3,0,2,1,NULL,'sawa232\r\\'),(785,761614954012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','777energy777','valentina.lizenberg@gmx.de','Valentina Lizenberg','Heinrich-Böllstr.5','Cloppenburg','','GERMANY','49661','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 20:10:14',0,NULL,3,0,2,1,NULL,'777energy777\r欧标\r\\'),(786,761629187012,220741015891,'New Motorola H350 Bluetooth Wireless Headset H 350',1,'HSMO005',12.99,'eastar4','shaharsoper2011','shaharsoper@hotmail.co.il','shahar eliyau','biyalik 19, apt.13<br>apt.13','holon','israel','ISRAEL','58333','0527457458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 20:37:54',0,NULL,5,0,18,0,NULL,'shaharsoper2011'),(787,685380455011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','baroper2','baroper@gmail.com','Bill Roper','1441 Highwood Blvd.','Devon','AB','CANADA','T9G2E9','(780) 504-7809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 20:24:29',0,NULL,3,0,2,1,NULL,'baroper2\r\\'),(788,761634294012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','sabrina.alireza','dimartino.sabrina@yahoo.com','Hooman Mokri','Torparegatan 48<br>58332 Linkoping','Linkoping','Linkoping','SWEDEN','58332','46707404037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 20:45:31',0,NULL,3,0,2,1,NULL,'sabrina.alireza\r欧标\r\\'),(789,761643098012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','femills1','francismills1@aol.com','nigel mills','2a straid road','ballycastle','Antrim','UNITED KINGDOM','bt54 6hq','07775918663','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 21:05:34',0,NULL,3,0,3,1,NULL,'femills1\rOTRA002\rRA022491108CN\r\\'),(790,685379600011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','csabah_123hu','csabah@t-online.hu','Csaba Harangozó','Bányász utca 15.','Tapolca','','HUNGARY','8300','+36304064586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 21:16:05',0,NULL,3,0,2,1,NULL,'csabah_123hu\r\\'),(791,0,230600020600,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','webwebes','alejandro_spa@hotmail.com','Claudio Vazquez Gonzalez','C/ Itaca nº 33<br>Mairena del Aljarafe','Sevilla (Andalucia)','Andalucía Ceuta y Melilla','SPAIN','41927','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 22:09:32',0,NULL,3,0,3,1,NULL,'webwebes\rOTRA002\rRA022491978CN\r\\'),(792,761684193012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','vevgeniev','cannibalcho@yahoo.com','Veselin  Evgeniev','4247 Wesley Ter','Schiller Park','IL','UNITED STATES','60176-1925','(773) 807-9941','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 22:19:27',0,NULL,3,0,1,1,NULL,'vevgeniev\r、'),(793,761704435012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',33.9,'eastar4uk','stevijospen','shaun.spenner@sky.com','SHAUN SPENNER','321 BILLET ROAD','WALTHAMSTOW','LONDON','UNITED KINGDOM','E17 5PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 23:11:15',0,NULL,8,0,17,0,NULL,'stevijospen'),(794,761709143012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',13.99,'eastar4uk','stevijospen','shaun.spenner@sky.com','SHAUN SPENNER','321 BILLET ROAD','WALTHAMSTOW','LONDON','UNITED KINGDOM','E17 5PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 23:20:39',0,NULL,3,0,3,1,NULL,'stevijospen\r再发两个MOTOROLA H710 BLUETOOTH HEADSET  BLACK    英标\rHSMO014*2+HSMO018\rRA022492032CN\r\\\r'),(795,519546174004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','marioe1313','pleonero@yahoo.com','mario Chica','PO Box 531534','Grand prairie','TX','UNITED STATES','75053-1534','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 23:35:18',0,NULL,3,0,1,1,NULL,'marioe1313'),(796,685468676011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','spyro5756','bobliguori5756@aol.com','robert liguori','260 Bel-air Dr','massapequa park','NY','UNITED STATES','11762-3209','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 23:58:07',0,NULL,3,0,1,1,NULL,'spyro5756'),(797,761762483012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',2,'HSNO022',20.8,'eastar4uk','prockey111','j.e.hamer@web.de','Bettina Kimpfbeck','Westerwaldstr. 19 A','Ehringshausen-Greifenthal','','GERMANY','35630','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-25 02:11:19',0,NULL,3,0,3,1,NULL,'prockey111\rHSNO022     欧标\rRA022492015CN \r\\'),(798,513755194003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','shopper_ez','hall_erin@hotmail.com','Erin Hall','4 Millson Close','Bundoora','Victoria','AUSTRALIA','3083','0394674835','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 02:36:09',0,NULL,3,0,3,1,NULL,'shopper_ez\rBAZA001\r\\\rRA022491995CN\r'),(799,685525521011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','aceswild9','chitty61@hotmail.com','Matthew Chidester C/O 507 Student Center','4201 S Washington St','Marion','IN','UNITED STATES','46953-4974','(740) 262-6593','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 03:35:10',0,NULL,3,0,1,1,NULL,'aceswild9'),(800,685533156011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','sli80','stradith@gmail.com','Samson Li','4136 Winnifred Street','Burnaby','BC','CANADA','V5J 2S4','(604) 838-1441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 04:19:37',0,NULL,3,0,2,1,NULL,'sli80\r\\'),(801,519572190004,140428312392,'2.1 Acer Aspire 9300 bluetooth module we offer track#',1,'BTAC2108',16.59,'cnfaner','hfer3733','leonj100k@yahoo.com','Hugo L. Fernandez','5 Madison Ave<br>Apt 2','Plainfield','NJ','UNITED STATES','07060-1162','(908) 754-2542','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 01:51:33',0,NULL,3,0,1,1,NULL,'hfer3733\racer 4pin1.25 18cm\rLK033726935CN'),(802,761814296012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','gigman01','mikethomas1@earthlink.net','Michael D Thomas','618 E Dalton Ave','Glendora','CA','UNITED STATES','91741-2704','(626) 224-6716','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 06:30:04',0,NULL,3,0,1,1,NULL,'gigman01'),(803,761765056012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',3,'ANTY001*3',10.74,'eastar4','spagnoli','powerstrokerexhaustbrake@yahoo.com','Jerome Karsonovich','472 Madison Street','Sharon','PA','UNITED STATES','16146','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 02:19:30',0,NULL,3,0,1,1,NULL,'spagnoli'),(804,685512413011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',38.97,'eastar4','celerinaman','maritrju@yahoo.com','lucien willocks','po box 85202','lexington','SC','UNITED STATES','29073-0025','(803) 518-8020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 02:42:33',0,NULL,3,0,1,1,NULL,'celerinaman\r一共买了三个\\'),(805,685564406011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','slgeo78','slgeo@mail.ru','Gegiya Vyacheslav','1-i Koroleva Str. , Apt.141<br>+79034000736','Rostov-on-Don','Rostovskaya oblast','RUSSIAN FEDERATION','344092','+79034000736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 07:35:24',0,NULL,3,0,2,1,NULL,'slgeo78\r\\'),(806,564874825013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','paul_in_sweden','paul.seymour@mail.com','Paul Seymour','23 ironside St','Weston','Australian Capital Territory','AUSTRALIA','2611','612 62883276','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 07:42:11',0,NULL,3,0,3,1,NULL,'paul_in_sweden\rMOSA002\rRA022491085CN\r\\\r'),(807,685524825011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ggal555','dlaeoqls7771@naver.com','byung sun choi','354 S Normandie Ave','Los Angeles','CA','UNITED STATES','90020-3182','(213) 258-7272','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 03:32:06',0,NULL,3,0,1,1,NULL,'ggal555\rLK033747612CN'),(808,564546756013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','alone_091','trsmarquezroman@telefonica.net','Miguel Angel Román Márquez','C La Viña nº 45 Vivienda A','Velilla de San Antonio','Madrid','SPAIN','28891','679451115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 09:06:06',0,NULL,3,0,3,1,NULL,'alone_091\rMOSA003   \rRA022491920CN\r\\'),(809,519639330004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',2,'ANYA001',28.9,'cnfaner','ksy_com','ksycom@gmail.com','KSY.Computer','43 Sangchuto Rd.<br>T.Tamakam','Moung','Kanchanaburi','THAILAND','71000','6634624422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 10:13:18',0,NULL,3,0,3,1,NULL,'ksy_com\rRA022491068CN\r\\'),(810,685610180011,320557629748,'New Motorola H3 Bluetooth Wireless Headset H 3',1,'HSMO003',14.75,'eastar4','bromobutane','zhenhao.peh@gmail.com','Peh Zhen Hao','Blk 634 Hougang Ave 8<br>#10-35','Singapore','','SINGAPORE','530634','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 10:52:21',0,NULL,3,0,2,1,NULL,'bromobutane\r、'),(811,685622883011,320497200017,'New Apple AR9280 AR5BXB92 Mini PCI-E AGN 300M+2 antenna',1,'WLAP008+ANAP001',20.99,'eastar4','ewgen1982','ewgen116@gmail.com','Ewgenij Tetjuev','Rossijskaja, 218-116','Cheljabinsk','','RUSSIAN FEDERATION','454090','(904) 3063952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 11:42:24',0,NULL,3,0,2,1,NULL,'ewgen1982\r\\'),(812,761895863012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.5,'eastar4uk','rjw5000','robjwarrington@hotmail.co.uk','Robert Warrington','NWF Agriculture<br>Wardle','Nantwich','Cheshire','UNITED KINGDOM','cw5 6aq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 12:02:00',0,NULL,3,0,3,1,NULL,'rjw5000\rRELO002\rRA022491350CN\r'),(813,685631004011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','jeeyoung0314','jyoung0314@hotmail.com','Kim, Jeongkyu','#306 Annex Soongsil University,<br>Sangdo1-dong, Dongjak-gu,','Seoul','','KOREA,REPUBLIC OF','156-743','(821) 090-4597 ext.: 87','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 12:34:10',0,NULL,3,0,2,1,NULL,'jeeyoung0314\r\\'),(814,761906834012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','pat43081','pwarczak@msn.com','Patrick Warczak Jr','415 Valleyview Dr','Kent','OH','UNITED STATES','44240-4523','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 12:38:24',0,NULL,3,0,1,1,NULL,'pat43081\r、'),(815,564926431013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',20.95,'eastar4','e**ch','simonezracohen@hotmail.com','EZRA CH. COHEN','Rua Sergipe 475 -Sala 204','Sao Paulo','Sao Paulo','BRAZIL','01243001','55+11+36617983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 12:39:44',0,NULL,3,0,2,1,NULL,'e**ch\r、'),(816,685650038011,320441564467,'2.1 Acer Aspire 5540 5542 Bluetooth Module EDR + cable',1,'BTAC2102',16.59,'eastar4','macsob1981','mark.sobczyk@googlemail.com','Marek Sobczyk','115 Lincoln Way<br>North Wingfield','Chesterfield','Derbyshire','UNITED KINGDOM','s42 5rr','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 13:16:38',0,NULL,3,0,2,1,NULL,'macsob1981\racer 4pin1.25 4cm\r\\'),(817,685659957011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',2,'RCLO006',99.98,'eastar4','danylebon','dlalancette57@hotmail.com','dany lalancette','599<br>rue lavallée','roberval','QC','CANADA','g8h1s4','(418) 275-9040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 13:48:08',0,NULL,3,0,3,1,NULL,'danylebon\rRCLO006\rRA022491859CN\r'),(818,513855616003,130490602150,'New Intel 512ANX 5150 HMW Half Mini PCI-E WIFI Card',1,'WLIN004',31.98,'cnfaner','mikhail2507','mikhail.statsenko@gmail.com','Mikhail Statsenko','Kapotnya, 5 Kvartal 8-162','Moscow','','RUSSIAN FEDERATION','109649','(916) 959 - 3346','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 13:50:20',0,NULL,3,0,3,1,NULL,'mikhail2507\rWLIN004\rRA022491451CN\r'),(819,564946400013,230601283994,'New Shure E2c Sound Isolating headset transparent ver',2,'HSSH002',71.98,'eastar4','jdog51','jarodrichardson@gmail.com','Jarod Richardson','604 E 1st St','Hillsboro','KS','UNITED STATES','67063-1624','(620) 532-4543','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:06:32',0,NULL,3,0,1,1,NULL,'jdog51\r、'),(820,0,220759571354,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32.49,'eastar4','pyth0ss','peterbelanger@videotron.ca','Pierre Belanger','137 Tremblay Street','Sainte-Anne-de-Bellevue','QC','CANADA','H9X3Z7','(514) 783-0666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 14:09:19',0,NULL,3,0,3,1,NULL,'pyth0ss\rOTRA002\rRA022491553CN\r'),(821,685674999011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','axl-rose','cristiann82@hotmail.com','Cristi DeWolf','133 Lou Vicy Ln','Bells','TX','UNITED STATES','75414-3379','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:33:52',0,NULL,3,0,1,1,NULL,'axl-rose\rPOLO001\r、'),(822,761948192012,220759518181,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.99,'eastar4uk','dnkyshopper','dnky2@hotmail.com','Duncan Griffiths','unit A5, CCTV4u<br>Maritime Park','Pembroke Dock','Pembrokeshire','UNITED KINGDOM','SA72 6UL','08452263191','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 14:38:04',0,NULL,3,0,3,1,NULL,'dnkyshopper\rCALO001\rRA022491465CN\r'),(823,519317051004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','francespal','frances_palomata@yahoo.com','Lizabeth Palomata','6451 San Pablo Ave','Oakland','CA','UNITED STATES','94608-1264','(408) 966-2268','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 14:49:30',0,NULL,3,0,1,1,NULL,'francespal\r、'),(824,564960398013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',3,'WWOT001+ANCN001',143.04,'eastar4','jltibo','jltibo@hotmail.com','Jean-Luc Thibault','1661 de l\'industrie','Beloeil','QC','CANADA','J3G 4S5','(450) 536-1692','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 15:00:47',0,NULL,3,0,3,1,NULL,'jltibo\rWWOT001+ANCN001\rRA022491479CN\r'),(825,564925582013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','1492galeon','galeonesperdidos@orange.es','Jose Luis Brea Herrera','C/. Bariloche, 5. 3º C','Madrid','Madrid','SPAIN','28042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 15:58:41',0,NULL,3,0,3,1,NULL,'1492galeon\rMOSA001\rRA022491624CN\r'),(826,685707626011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','delightfuly','dmitrykuz.eb@gmail.com','DMITRY KUZNETSOV','bulvar Dmitriya Donskogo, dom 13, kv. 105','Moscow','','RUSSIAN FEDERATION','117216','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 16:07:15',0,NULL,3,0,2,1,NULL,'delightfuly\r\\'),(827,685710738011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','gasciut','dfhockeyplaya7@aol.com','Gary Asciutto','113 Pine Lake Dr','central','SC','UNITED STATES','29630-9315','(803) 238-1028','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:17:36',0,NULL,3,0,1,1,NULL,'gasciut\r、'),(828,685714224011,320676244896,'New Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','jhderonck','jderonck@ix.netcom.com','Jay DeRonck','59 Ringgold St','West Hartford','CT','UNITED STATES','06119-2156','(860) 232-5777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:37:48',0,NULL,3,0,1,1,NULL,'jhderonck\r、'),(829,564987236013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','jwcameo','jwerlin1@rochester.rr.com','Jeff Werlin','PO Box 422','Fishers','NY','UNITED STATES','14453-0422','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:38:58',0,NULL,3,0,1,1,NULL,'jwcameo\r、'),(830,564988886013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','buffy2','rajohnson@intergate.com','Robert Johnson','25 Deer Run Rd','Wappingers Falls','NY','UNITED STATES','12590-4501','(845) 298-8438','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:45:10',0,NULL,3,0,1,1,NULL,'buffy2\r、'),(831,761995021012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',4,'HSPL011',88,'eastar4','calebhaus1','caleb.musicface@gmail.com','caleb haus','6179 N Constance Ave','fresno','CA','UNITED STATES','93722-3379','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:47:45',0,NULL,3,0,1,1,NULL,'calebhaus1\r、'),(832,762003848012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',14.49,'eastar4','zandieloo','scheree_productions@reallyfast.biz','Charles Sherrard','615 E Wonsley Dr<br>apt 248','Austin','TX','UNITED STATES','78753-6519','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:59:07',0,NULL,3,0,1,1,NULL,'zandieloo\racer 5pin1.25 6cm \r、'),(833,685744737011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','ayres_neto_2','ayresneto_2@hotmail.com','Ayres Netto','Av. Itacoatiara, 221<br>Bairro: Cachoeirinha','Manaus','Amazonas','BRAZIL','69065-090','55 92 81273232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 17:40:30',0,NULL,3,0,2,1,NULL,'ayres_neto_2\r\\'),(834,565022065013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','kacem14','bmorsli@hotmail.com','Belkacem Morsli','265 Long Elmes','Harrow','Middlesex','UNITED KINGDOM','HA3 6LE','0204260116','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 18:31:33',0,NULL,3,0,2,1,NULL,'kacem14\rCAB-6060\r\\'),(835,762050639012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',2,'HSMO016',45.38,'eastar4','ciftampa','paula@ciflorida.com','George Southworth-Paula','11317 N 52nd St<br>Concrete Impressions Of Florida, Inc.','Tampa','FL','UNITED STATES','33617','(813) 899-4284','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 18:37:16',0,NULL,3,0,1,1,NULL,'ciftampa\r、'),(836,519750563004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','davidd3710','david_a_davis@hotmail.com','David Davis','1056 E Brookview Ln','Peoria','IL','UNITED STATES','61615-9567','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 18:53:07',0,NULL,3,0,1,1,NULL,'davidd3710\r、'),(837,565041616013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','frsm11','franxi_7@hotmail.com','Fco Rafael Sabariego Menjibar','Pasaje Pintor Ramirez n 3','Córdoba','Andalucía Ceuta y Melilla','SPAIN','14006','605038849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 19:23:09',0,NULL,3,0,2,1,NULL,'frsm11\r欧标\r\\'),(838,565042709013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','ask4dee','ask4d@longandfoster.com','Deeda Carstens','300 Shannon Court','Virginia Beach','VA','UNITED STATES','23452','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 19:25:52',0,NULL,3,0,1,1,NULL,'ask4dee\r、'),(839,685818909011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','crubirubi','rubi.cohen@gmail.com','Rubi Cohen','12 Y.L.Gordon St.','Hertzelia','','ISRAEL','46491','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 20:12:34',0,NULL,3,0,2,1,NULL,'crubirubi\r、'),(840,685827351011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','fmelom','f.melo@live.com.pt','Francisco Melo','Rua 10 de Junho, n.º 54 N','Vila do Conde','Aveleda','PORTUGAL','4485-029','(351) 913940155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 20:28:33',0,NULL,3,0,2,1,NULL,'fmelom\r、'),(841,565072212013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','henk0782','hendrik@buitendemarge.nl','Henk Bergsma','Bernardus Gewinstraat 17c','Rotterdam','','NETHERLANDS','3031SB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 20:45:26',0,NULL,3,0,2,1,NULL,'henk0782\r\\'),(842,685837357011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','skatesurfsnowclothing','mathewmaloney@gmail.com','Mathew Maloney','60 MacLaren Street<br>Apt 505','Ottawa','ON','CANADA','K2P0K7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 21:05:43',0,NULL,3,0,2,1,NULL,'skatesurfsnowclothing\r\\'),(843,760934197012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','thierry_1988','thierry1988@gmail.com','Lam Thierry (Boite 41503)','5 rue Henri Barbusse','Aubervilliers','Île-de-France','FRANCE','93300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 21:44:24',0,NULL,3,0,2,1,NULL,'thierry_1988\r\\'),(844,514002315003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'cnfaner','orthowest','orthowest@ameritech.net','Michael Banks','7255 Old Oak Blvd., Ste C405','Middleburg Heights','OH','UNITED STATES','44130-3331','(440) 816-5380','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 22:17:35',0,NULL,3,0,1,1,NULL,'orthowest\r、'),(845,685888530011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY001*3',22.95,'eastar4','kiattivikrai','uthai.k@gmail.com','Uthai Kiattivikrai','222/17 Mu 2<br>Bangkanun','Bangkruay','Nonthaburi','THAILAND','11130','66818322555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 22:56:08',0,NULL,3,0,2,1,NULL,'kiattivikrai\r\\'),(846,565111624013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','wangholm','frankwang.ca@gmail.com','Yongyi F Wang','10 Holm Cres','Thornhill','ON','CANADA','L3T 5J3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 22:57:05',0,NULL,3,0,2,1,NULL,'wangholm\r\\'),(847,762196127012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.5,'eastar4uk','fashionetslondon','info@fashionets.com','Fashionet Saree','15 Gillett Avenue','London ','London','UNITED KINGDOM','e6 3aw','7891810329','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 23:46:58',0,NULL,3,0,3,1,NULL,'fashionetslondon\rRELO002\rRA022491540CN\r'),(848,760100381012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',5.98,'eastar4uk','junacik','tomas352@post.sk','Frano Tomas','Tematinska 8','Nove Mesto n/v','Slovakia','SLOVAK REPUBLIC','91501','+421904261303','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 00:01:23',0,NULL,3,0,2,1,NULL,'junacik\r\\'),(849,762210786012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','jeffleblanc759','jfleblanc@constructionlfg.com','Jean-Francois Leblanc','178, Route 132 Est','Saint-Omer','QC','CANADA','G0C 2Z0','(418) 364-7082 ext.: 235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 00:45:05',0,NULL,3,0,2,1,NULL,'jeffleblanc759\r、'),(850,685928156011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','tbird21957','nelsongeli@hotmail.com','E M Nelson','4643 Brightmore Rd','Bloomfield Hills','MI','UNITED STATES','48302-2123','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 01:18:49',0,NULL,3,0,1,1,NULL,'tbird21957\r、'),(851,565150225013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','veneno.78','makeyourself78@yahoo.es','Pablo Morales','Nelson 1838<br>Ñuñoa','Santiago','Metropolitana','CHILE','7780288','83345175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 02:01:32',0,NULL,3,0,3,1,NULL,'veneno.78\rMOSA002\rRA022491672CN\r'),(852,565150988013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','rd0','pub_radu@syskey.com','Radu Duta','351 87th St','Brooklyn','NY','UNITED STATES','11209-5105','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 02:03:35',0,NULL,3,0,1,1,NULL,'rd0\r、'),(853,519867223004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','jeduardox','jeduardo@cefetes.br','Jose Eduardo Mendonca Xavier','R. Constante Sodre, 1053 - Garden, 1404B<br>Praia do Canto','Vitoria','ES','BRAZIL','29055-420','+55 27 93117690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 02:03:58',0,NULL,3,0,3,1,NULL,'jeduardox\rOTRA002\rRA022491584CN\r'),(854,762235400012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','r101j','randalljr@myfastmail.com','Randall Whiteman','1533 Molly Ct','stockton','CA','UNITED STATES','95206-5611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 02:08:12',0,NULL,3,0,1,1,NULL,'r101j\r、'),(855,514051196003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','medicalchest','spacesector666@gmail.com','Andy Maljin','400 Barcelone','Dollards Des Ormeaux','QC','CANADA','H9B 3M1','(514) 315-0722','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 02:32:10',0,NULL,3,0,3,1,NULL,'medicalchest\rCRLO001+POLO001\rRA022491289CN\r'),(856,685944767011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','foureyes0','eyesfour@aol.com','Gregory Faith','5343 W. Ave. M2','Quartz Hill','CA','UNITED STATES','93536-3026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 02:28:11',0,NULL,3,0,1,1,NULL,'foureyes0\r、'),(857,685979853011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ricardogsaraujo','ricardogualda@gmail.com','Ricardo Araujo','20 Manhattan Close<br>Point Cook','Melbourne','Victoria','AUSTRALIA','3030','0404251234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 05:47:25',0,NULL,3,0,2,1,NULL,'ricardogsaraujo\r、'),(858,519900979004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','elilevy1212','elilevy2@zahav.net.il','Eli Levy','Harv Pinto 2<br>appartment 13','Petch Tikva','NA','ISRAEL','49294','972-54-2493507','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 06:49:04',0,NULL,3,0,3,1,NULL,'elilevy1212\rHSMO007\rRA022491575CN\r'),(859,685995310011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','maxter_pl','makster@tlen.pl','Kazimierz Napieracz','36 Grantley Street','Grantham','Lincolnshire','UNITED KINGDOM','NG31 6BW','07840644990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 07:23:37',0,NULL,3,0,2,1,NULL,'maxter_pl\\'),(860,565212923013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','mouseblue14','trezise@ymail.com','Kathy Trezise','PO Box 1038<br>Geelong','Geelong','Victoria','AUSTRALIA','3220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 09:41:15',0,NULL,3,0,2,1,NULL,'mouseblue14\r、'),(861,686032592011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','citroen-afy','xantia-afy@hotmail.com','keijaerts','roterlaan 40','Kortessem','','BELGIUM','3721','011727572','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 09:54:31',0,NULL,3,0,2,1,NULL,'citroen-afy\r欧标\r、'),(862,686034221011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',16.59,'eastar4','robnepprm','nepprm@gmail.com','Rob Martin','1888 East 61st Avenue Basement','Vancouver','BC','CANADA','V5P 2K1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 10:03:56',0,NULL,3,0,2,1,NULL,'robnepprm\racer 4pin1.25 6cm \r\\'),(863,565234040013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.85,'eastar4','yoshie1976','joshlockhartmobile@gmail.com','Joshua Lockhart','8 Ewenton St','Balmain','New South Wales','AUSTRALIA','2041','0298108394','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 11:04:23',0,NULL,3,0,2,1,NULL,'yoshie1976\r、'),(864,686056644011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','lyza59','eddy.barbier@wanadoo.fr','eddy barbier','11 lotissement les bleuets','oye plage','Nord-Pas-de-Calais','FRANCE','62215','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 11:16:47',0,NULL,3,0,2,1,NULL,'lyza59\r\\'),(865,565243528013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','ken425ken','kenneththompson@live.com','ETC Thompson, Kenneth','PSC 451  Box 700','FPO','AE','AA','09834-2800','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 11:42:54',0,NULL,3,0,1,1,NULL,'ken425ken\r、'),(866,762372000012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',15.99,'eastar4uk','cockney0_1','chrisward46@hotmail.com','Chris Ward','2 Hudson Close<br>Lower Wick','Worcester','Worcestershire','UNITED KINGDOM','WR2 4DP','01342328056','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 11:51:13',0,NULL,3,0,3,1,NULL,'cockney0_1\rOTGR001\rRA022491845CN\r'),(867,686071592011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','yabeug','eugenegrant@gmail.com','Eugene Grant','160 Collinswood<br>CollinsAvenue','Dublin ','Dublin','IRELAND','D9','0868417450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 12:05:08',0,NULL,3,0,2,1,NULL,'yabeug\r\\'),(868,762385322012,220459522492,'Acer Aspire 5680 5630 3690  Bluetooth Module 2.0+cable',1,'BTAC2021',14.49,'eastar4','lmvbbb','gereis@t-online.de','G. Eiserbeck','Am Kuschelhain 27','Velten','','GERMANY','16727','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 12:36:17',0,NULL,3,0,2,1,NULL,'lmvbbb\racer 8pin1.00 8cm\r\\'),(869,762393110012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','black_dragons_enterprises','driftrr@hotmail.com','David Flinn','440 SE Excel St','sheridan','OR','UNITED STATES','97378-1962','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 12:45:42',0,NULL,3,0,1,1,NULL,'black_dragons_enterprises\rMX20T  \r、'),(870,762405279012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','hjoci61','hjoci64@googlemail.com','jozef Horváth','13 the quays','moy','Tyrone','UNITED KINGDOM','bt717tg','07751927939','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 13:17:59',0,NULL,3,0,3,1,NULL,'hjoci61\rHSNO006   英标\rRA022491275CN\r'),(871,762404646012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','brijm1967','alsnbrn@aim.com','Brian Murray','hunters way<br>pulpit lane','oving','Buckinghamshire','UNITED KINGDOM','hp22 4ez','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 13:19:27',0,NULL,3,0,3,1,NULL,'brijm1967\rOTRA002\rRA022491213CN\r'),(872,761942096012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','santistuff2','michael@flexloop.com','Flexloop Systems','1260 E Woodland Ave<br>Ste 23','Springfield','PA','UNITED STATES','19064-3956','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 13:20:23',0,NULL,3,0,1,1,NULL,'santistuff2\r、'),(873,762407403012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','ecle7855','eduardo.clerigues@gmail.com','Eduardo Clerigues','Avda. Dr. J.J. Domine 18 - 46','VALENCIA','Comunidad Valenciana','SPAIN','46011','693835441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 13:22:10',0,NULL,3,0,2,1,NULL,'ecle7855\rMX20T\r\\'),(874,762412353012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','markush9297','mhlastec@googlemail.com','Markus Hlastec','Blumenstrasse 24','Duisburg','','GERMANY','47179','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 13:34:31',0,NULL,3,0,2,1,NULL,'markush9297\r、'),(875,565277775013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','slv_789','slv789@gmail.com','Salavat Khafizov','ul. 8 marta, 32, kv.106','Ufa','Republic of Bashkortostan','RUSSIAN FEDERATION','450078','(7) 91734090952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 14:06:34',0,NULL,3,0,2,1,NULL,'slv_789\r、'),(876,686121853011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','hnoy7657','herve.noyon@yahoo.fr','Hervé NOYON','24, avenue Raymond Boivin','PESSAC','Aquitaine','FRANCE','33600','05.56.46.26.25','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 14:18:29',0,NULL,3,0,2,1,NULL,'hnoy7657\r、'),(877,762442511012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','nokiane64','nokiane@hotmail.com','JOSE GABRIEL MIGUEL LAVIN','PABLO DE ALZOLA Nº 25-- 4º C','BILBAO','País Vasco','SPAIN','48012','630379157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 14:43:57',0,NULL,3,0,2,1,NULL,'nokiane64\r、'),(878,762473477012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','kasper992000','nevesyscommunications@yahoo.com','Jean H Nevelus','4681 Chief Joseph Cir','Douglasville','GA','UNITED STATES','30135-8461','(347) 489-8741','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 15:50:52',0,NULL,3,0,1,1,NULL,'kasper992000\rMX20T\r、'),(879,686156964011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','091568','russi@bonafidemanagement.com','Ricardo Russi','13067 SW 133rd Ct','Miami','FL','UNITED STATES','33186-5849','(305) 244-1035','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 15:52:31',0,NULL,3,0,1,1,NULL,'091568\r、'),(880,686164483011,320676244896,'New Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','plathome','jucoalco1@yahoo.com','Julio Cordero','5812 21st Ave<br>Apt 2F','Brooklyn','NY','UNITED STATES','11204-2031','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 16:00:44',0,NULL,3,0,1,1,NULL,'plathome\r、'),(881,762479911012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','sunrise-citizen','sunrise.citizen@gmail.com','Steve Hopkins','3030 NW 113th Ave','Sunrise','FL','UNITED STATES','33323-1625','(954) 651-2037','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 16:05:33',0,NULL,3,0,1,1,NULL,'sunrise-citizen\rMX20T\r、'),(882,0,220758137995,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32.5,'eastar4','nanuk1sk','nanuk1sk@gmail.com','Dusan Janik','Na Návsi 525/6C','Dolni Mecholupy','Prague 10','CZECH REPUBLIC','10900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:06:18',0,NULL,3,0,3,1,NULL,'nanuk1sk\rOTRA002\rRA022491301CN\r'),(883,514202416003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',26.95,'cnfaner','fabiovalinhos7355','fabiovalinhos@gmail.com','Fábio de Albuquerque Vilalba','Rua Joaquim Martins, 364','Valinhos','SP','BRAZIL','13277-124','55 (019) 3869-1848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:07:58',0,NULL,3,0,3,1,NULL,'fabiovalinhos7355\rHSUE002\rRA022491394CN\r'),(884,520022280004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','09timka','turbo.gtr@hotmail.com','Leonid Timofejev','Isruties 14-48','Vilnius','','LITHUANIA','06220','+37067666068','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:16:04',0,NULL,3,0,3,1,NULL,'09timka\rHSNO022  欧标\rRA022491227CN\r'),(885,759263043012,220578466424,'NEW GENUINE NOKIA BH-102 BLUETOOTH HEADSET BH 102',1,'HSNO001',19.99,'eastar4','khalilafandiyev','efendiyev_xelil@mail.ru','Khalil Afandiyev','Nizami district<br>Sherifli 96/20','Baku','Azerbaijan/Baku/Nizami','AZERBAIJAN','AZ1118','0503790395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:32:03',0,NULL,3,0,2,1,NULL,'khalilafandiyev\r单机\r、'),(886,565326281013,230601283994,'New Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','olkip','o.kiptily@gmail.com','Olga Kiptily','4<br>Somerville','Didcot','Oxfordshire','UNITED KINGDOM','ox118ud','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:33:39',0,NULL,3,0,3,1,NULL,'olkip\rHSSH002\rRA022492179CN\r'),(887,565329282013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','4120100027034','pharaoh588@hotmail.com','Titaree Kajtanyakij','265/3 Soi Ngamwongwan3<br>Ngamwongwan Road','Muang','Nonthaburi','THAILAND','11000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:44:09',0,NULL,3,0,2,1,NULL,'4120100027034\r、'),(888,762502269012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',27.98,'eastar4uk','melvyn0722','chris_millard@sky.com','christopher  millard','19  Cowleaze','Chinnor','oxfordshre','UNITED KINGDOM','OX39 4TD','07834639154','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 16:45:00',0,NULL,3,0,3,1,NULL,'melvyn0722\rHSMO018   英标\rRA022491385CN\r'),(889,0,220758136424,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',26.48,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 17:09:41',0,NULL,3,0,1,1,NULL,'4278dennis\r一共买了两个保护屏\r、'),(890,565351890013,230601283994,'New Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','andym67','andymoss67@hotmail.com','Andrew Moss','45 Blackwood St<br>Knightswood','Glasgow','Glasgow (City of)','UNITED KINGDOM','G13 1AL','01236722154','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 17:39:57',0,NULL,3,0,3,1,NULL,'andym67\rHSSH002\rRA022492182CN\r'),(891,0,230601702906,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',11,'eastar4','stephnalty','stephnalty@yahoo.com','steph nalty','2105 tetlow pl','sarasota','FL','UNITED STATES','34239-4111','(843) 469-3663','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-26 17:48:27',0,NULL,3,0,1,1,NULL,'stephnalty\r、'),(892,514247801003,130490253015,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',2,'BAIN001',19.98,'cnfaner','tmtdigirad','mriveraalarcon@gmail.com','mauricio rivera alarcon','tangue 565','ovalle','IV region','CHILE','1840000','053-620207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 18:14:42',0,NULL,3,0,3,1,NULL,'tmtdigirad\rBAIN001\rRA022492165CN\r'),(893,565373001013,230601283994,'New Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','inchwormz','jason@parentingbynature.com','Jason Champion','4186 Orkney Beach Rd.','Orillia','ON','CANADA','L3V 6H7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 18:29:27',0,NULL,3,0,3,1,NULL,'inchwormz\rHSSH002\rRA022492355CN\r\\'),(894,686242905011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','elkgene','elkgene@juno.com','eugene kanski','127 Spanish Moss Ln','lake jackson','TX','UNITED STATES','77566-4314','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 18:32:21',0,NULL,3,0,1,1,NULL,'elkgene\r、'),(895,762566920012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',16.95,'eastar4uk','mirzailyas','m.m.ilyas786@gmail.com','ILYAS2011 MIRZA','44 HAMMPSHIRE AVENUE<br>SLOUGH','SLOUGH','Berkshire','UNITED KINGDOM','SL1 3AQ','7411633665','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 18:36:21',0,NULL,3,0,3,1,NULL,'mirzailyas\rHSMO014  英标\rRA022491363CN\r'),(896,520085288004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','whitetitan7','hatman@live.se','Michael Sannemo-Targama','Skogsbacken 22','Sundbyberg','Sundbyberg','SWEDEN','17241','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 19:01:35',0,NULL,3,0,3,1,NULL,'whitetitan7\rWLAT002\rRA117710378CN\r\\'),(897,762589213012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','smolstar','tema_67region@mail.ru','Artem Antonov','29 Koneva st.<br>181','Smolensk','','RUSSIAN FEDERATION','214019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 19:11:15',0,NULL,3,0,2,1,NULL,'smolstar\r、'),(898,565403670013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','colinchem','c.g.cameron@gmail.com','Colin G Cameron','659 South Rawdon Road','Mt. Uniacke','NS','CANADA','B0N 1Z0','(626) 757-0611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 19:41:13',0,NULL,3,0,2,1,NULL,'colinchem\r\\'),(899,520103692004,140516080226,'New in box Logitech H530 USB Headset ear-cup 981-000195',1,'HSLO002',48.5,'cnfaner','ccpeng1980','peng.terry@gmail.com','Yi-Ting','No.163, Ln. 192, Sec. 1, Fengxing Rd.<br>Tanzi Dist.','Taichung City','Taiwan','TAIWAN','42743','(092) 139-5657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 19:49:02',0,NULL,3,0,14,1,NULL,'ccpeng1980\rHSLO002\r010202949315\r'),(900,762619120012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','alabama_pink','ebil_t@yahoo.com','Tunzala Abil','Qaradag rayonu, Sahil qesebesi, M.Seyidov kuchesi 3/26','Baku','-','AZERBAIJAN','AZ 1083','+994124461605','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 19:58:22',0,NULL,3,0,2,1,NULL,'alabama_pink\r\\'),(901,0,230599765719,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',11.5,'eastar4','aiea.reyn','reynnylen@hotmail.com','Reyn Nylen','98-1038 Moanalua Rd<br>Apt 108','Aiea','HI','UNITED STATES','96701-4610','(808) 375-3651','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-26 20:10:27',0,NULL,3,0,1,1,NULL,'aiea.reyn\r、'),(902,762640585012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',2,'HSSE004',31.8,'eastar4uk','aquica','aquica@hotmail.com','Anna Melander','Banérgatan 13','Timrå','none','SWEDEN','86131','070-2448074','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 20:32:50',0,NULL,3,0,3,1,NULL,'aquica\rHSSE004  欧标\rRA022491329CN\r'),(903,565425547013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',2,'RELO002',25.98,'eastar4','vbam1877','viestursb@v-vdg.pro','Viesturs Bambans','11687 SW Teal Blvd Apt.F.','Beaverton','OR','UNITED STATES','97007','(503) 781-6724','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 20:34:07',0,NULL,3,0,1,1,NULL,'vbam1877\r、'),(904,762650214012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',43.68,'eastar4','szandal','belez@prohome.hu','Tibor Olmosi','Angol utca 34. (A16 Irodahaz.)','Budapest','Pest megye','HUNGARY','1149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 21:04:19',0,NULL,3,0,3,1,NULL,'szandal\rWWOT001\rRA022491156CN\r'),(905,686380078011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY001*3',48.89,'eastar4','sabrewolf_rex','nikolov.andon@gmail.com','andon nikolov','Esperantotie 2','Espoo','','FINLAND','02230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 23:09:19',0,NULL,3,0,3,1,NULL,'sabrewolf_rex\r再发一个 IBM版AR5008\rWLAT001+ANTY001*3\r+WLAT003\rRA022491235CN\r'),(906,565483171013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','urbancamel','urbancamel@gmail.com','Michael Aossey','4621 Country Walk Lane','Sylvania','OH','UNITED STATES','43560','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 23:39:25',0,NULL,3,0,1,1,NULL,'urbancamel\r、'),(907,762737043012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',17.4,'eastar4','namttams','sm_att@hotmail.com','Matthew  Hart','56 Snows Rd<br>Stirling','Adelaide','South Australia','AUSTRALIA','5152','0883709328','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 00:08:17',0,NULL,3,0,2,1,NULL,'namttams\rCAB-SS-2660\r\\'),(908,565515233013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','2000isoy','craft.mark@lincoln.navy.mil','Elizabeth Craft','4518 Eastlawn Ave','Woodbridge','VA','UNITED STATES','22193-2604','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 02:04:34',0,NULL,3,0,1,1,NULL,'2000isoy\r、'),(909,686443750011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','dssjallen','dssjallen@nc.rr.com','Daniel Allen','840 W Chatham St<br>Apt i','Cary','NC','UNITED STATES','27511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 02:41:25',0,NULL,3,0,1,1,NULL,'dssjallen\r、'),(910,514409149003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','hue_bui','anhuebui@hotmail.com','Anna Nguyen','16 Morven St','Old Guildford','New South Wales','AUSTRALIA','2161','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 04:43:43',0,NULL,3,0,3,1,NULL,'hue_bui\rHSUE004\rRA022491142CN\r '),(911,520226663004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','resab892','resa892@bellsouth.net','Teresa Miller','892 Armena Rd','Leesburg','GA','UNITED STATES','31763-4218','(229) 436-5080','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 04:44:59',0,NULL,3,0,1,1,NULL,'resab892\r、'),(912,686468005011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY001*3',16.99,'eastar4','mdbecker','markglobal@suddenlink.net','Marcus Becker','3808 Sterling Pointe Dr.<br>Unit E-1','Winterville','NC','UNITED STATES','28590','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 04:45:10',0,NULL,3,0,1,1,NULL,'mdbecker\r、'),(913,565545795013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',2,'WLAT008',33.7,'eastar4','dalesbud8','djelliott81@gmail.com','David Elliott','1050 Grant St','Beloit','WI','UNITED STATES','53511-5014','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 05:11:26',0,NULL,3,0,1,1,NULL,'dalesbud8\r、'),(914,686473648011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','kenskh','skhui@singnet.com','Sim Kwang Hui','47<br>Fulton Road','Singapore','Singapore','SINGAPORE','578930','(+65) 97355919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 05:22:04',0,NULL,3,0,11,1,NULL,'kenskh\rRA022491125CN\r'),(915,565549386013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',2,'BALO001',16.98,'eastar4','shammijayaraj','shammijayaraj@hotmail.com','shammi jayaraj','3117 E Coconino Dr','Gilbert','AZ','UNITED STATES','85298-8705','(480) 782-7959','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 05:42:31',0,NULL,3,0,1,1,NULL,'shammijayaraj\r、'),(916,686487643011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','thebuyeraccount284','thebuyeraccount285@live.ca','Bowen Liu','#30-9699 152B St','Surrey','BC','CANADA','V3R 0G5','(604) 931-9183','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 06:47:33',0,NULL,3,0,2,1,NULL,'thebuyeraccount284\r\\'),(917,565561755013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',2,'HSMO006',23.8,'eastar4','0503olson','stillhereinca2@gmail.com','claire olson','70 Sklar St<br>Apt 1208','ladera ranch','CA','UNITED STATES','92694-0777','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 07:22:51',0,NULL,3,0,1,1,NULL,'0503olson\r、'),(918,762843081012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',3,'OTGR001+OTGR002',119.7,'eastar4','speedsterporsche','rommel.cruz@tdsb.on.ca','Rommel    Cruz','107 Frankdale Ave','Toronto','ON','CANADA','M4J 4A4','(416) 466-8732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 07:32:07',0,NULL,3,0,3,1,NULL,'speedsterporsche\rOTGR001*3+OTGR00\r2*3\rRA022491332CN\r\r'),(919,565565424013,230397452111,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',13.49,'eastar4','torulf','torulf@improvisera.net','Torulf Ohman','Edeforsgatan 46','Lulea','Norrbotten','SWEDEN','97438','+46702695704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 07:39:02',0,NULL,3,0,2,1,NULL,'torulf'),(920,686506665011,320585234549,'New Intel 512ANX 5150 Half Mini PCI-E WIFI Card+antenna',1,'WLIN004+ANTY001',33.98,'eastar4','ldel7324','hobereau@gmail.com','Laurent Delebecque','Mercier Ferrier','Faux la montagne','Limousin','FRANCE','23340','0660278850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 08:09:38',0,NULL,3,0,2,1,NULL,'ldel7324\r\\'),(921,686506368011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jeff3yan3','jeff3yan@gmail.com','Jeffrey Yan','50 Wilmay avenue<br>Papatoetoe','Auckland','','NEW ZEALAND','2025','+64211589611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 08:11:15',0,NULL,5,0,18,1,NULL,'jeff3yan3\r'),(922,514454563003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',19.9,'cnfaner','marting811','martingruen@aon.at','Martin Grün','Platti 317','Kappl','','AUSTRIA','6555','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 09:28:26',0,NULL,3,0,3,1,NULL,'marting811\rHSNO016  欧标\rRA022491377CN\r'),(923,565596773013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','58415','kolbasa76@yandex.ru','Vetchinkin Evgeniy','ul. 22 April, dom 8-v, kv.4','Omsk','','RUSSIAN FEDERATION','644088','0079131410180','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 09:53:45',0,NULL,3,0,2,1,NULL,'58415\r、'),(924,565606753013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','mikehampy','mikehamp78@gmail.com','Claire Milligan','4 Pledger Close','Diamond Creek','Victoria','AUSTRALIA','3089','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 10:26:55',0,NULL,3,0,3,1,NULL,'mikehampy\rMOSA003\rRA022491686CN\r'),(925,565612080013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','lamarshj','jefflamarsh@hotmail.com','Jeffrey LaMarsh','5889 Skeena St.','Powell River','BC','CANADA','V8A 4V5','(604) 414-0220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 10:45:49',0,NULL,3,0,2,1,NULL,'lamarshj\r\\'),(926,564249772013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','2004chandrashekar','vivekrao2@hotmail.com','chandrashekar gopal','36, corryton court','Wattle grove','New South Wales','AUSTRALIA','2173','0298253968','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 11:29:59',0,NULL,3,0,3,1,NULL,'2004chandrashekar\rMOSA002\rRA022491757CN\r'),(927,686579859011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','dom1047','dominique.saint-loubes@wanadoo.fr','dominique saint - loubes','1705 cheminde pecau','bon-encontre','Aquitaine','FRANCE','47240','0553471991','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 11:38:13',0,NULL,3,0,2,1,NULL,'\rdom1047\r\\'),(928,686605357011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','ozzy_rus','ozzy_rus@tvcom.ru','Anatoly  O Ozeryanskiy','bul. Guseva , 4-37','Tver','Tver\' region','RUSSIAN FEDERATION','170030','+7 903 8011410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 12:20:38',0,NULL,3,0,2,1,NULL,'ozzy_rus\r、'),(929,762993564012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',3,'HSPL002',31.5,'eastar4uk','jjon7584','ivanstaxis@btconnect.com','Janet Jones-Parry','Is Silyn, 14 Hen Lon<br>Penygroes','Caernarfon','Gwynedd','UNITED KINGDOM','LL54 6RG','01286881590','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 13:25:26',0,NULL,3,0,3,1,NULL,'jjon7584\rHSPL002\rRA022491292CN\r'),(966,687192529011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','rfreyer8','rf8883@gmail.com','Richard Freyer','11/155 Castlereagh St','Sydney','New South Wales','AUSTRALIA','2000','0292613400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 05:09:17',0,NULL,3,0,2,1,NULL,'rfreyer8\r、'),(930,0,220759571828,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','jlneiman1234','neimansbrushstrokes@hotmail.com','Jessica Neiman','207 Greenwich St','Kutztown','PA','UNITED STATES','19530-1412','(610) 223-8422','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-27 14:12:59',0,NULL,3,0,1,1,NULL,'jlneiman1234\r、'),(931,686674120011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','antoinedp','antoinedepreux@hotmail.com','Antoine de Preux','Teufenertrasse 95','Sankt Gallen','','SWITZERLAND','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 14:43:05',0,NULL,3,0,2,1,NULL,'antoinedp\r\\'),(932,763041913012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','jackorgel','orge7j6ck@earthlink.net','John F. Pacelli','2113 Gray St','Schenectady','NY','UNITED STATES','12306-4301','(518) 355-0708','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 14:53:24',0,NULL,3,0,1,1,NULL,'jackorgel\r、'),(933,520375251004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','abdfarae2009','abdfarae@hotmail.com','abdulla salih mohd','al-madra<br>gsm 92955775','Samail','oman','OMAN','219/620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 15:03:20',0,NULL,3,0,3,1,NULL,'abdfarae2009\rWWSI005\rRA022491641CN\r'),(934,565707214013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','bob.airky','airky777@gmail.com','Bob Randriambololona','4257, Kimber','Pierrefonds-montreal','QC','CANADA','H9H5C4','(514) 627-0123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 15:18:28',0,NULL,3,0,3,1,NULL,'bob.airky\rMOSA002\rRA022491669CN\r'),(935,565707386013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','cliffyo','cliffyo@frontiernet.net','Clifford Young','PO Box 290','Downsville','NY','UNITED STATES','13755','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 15:18:57',0,NULL,3,0,1,1,NULL,'cliffyo\r、'),(936,0,320677133271,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32,'eastar4','alain15050','alainbarbier5@aol.com','alain BARBIER','60 rue vincent faita','NIMES','Languedoc-Rousillon','FRANCE','30000','0466289612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 16:25:38',0,NULL,3,0,3,1,NULL,'alain15050\rOTRA002\rRA022491638CN\r'),(937,565751355013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','rayval_0','rayval@o2.co.uk','Rayval Rodman','25 Inchgarvie Pk','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH309RN','07752302333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 16:43:33',0,NULL,3,0,2,1,NULL,'rayval_0\rCAB-6060\r\\'),(938,565755634013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','coffeeman410','snmeagher@gmail.com','sean meagher','1702 aberdeen rd','parkville','MD','UNITED STATES','21234-5102','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 16:52:31',0,NULL,3,0,1,1,NULL,'coffeeman410\r、'),(939,520435821004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','mamamia1236','info@exumrecording.com','Scott Exum','1066 Camellia St','Escondido','CA','UNITED STATES','92027-1532','(760) 739-9700','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 17:07:17',0,NULL,3,0,1,1,NULL,'mamamia1236\rOMHJ001\r、'),(940,565810655013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','chipgolf','bryan@neighborspizza.com','Bryan Watari','1957 McGowan Pkwy<br>Ste 1','Olivehurst','CA','UNITED STATES','95961-4770','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 18:09:29',0,NULL,3,0,1,1,NULL,'chipgolf\r、'),(941,514690153003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',21.9,'cnfaner','slesas','slesas666@yahoo.com','Aldas Kvaščiauskas','skuodo 51','Kaunas','','LITHUANIA','45126','867635340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 18:44:44',0,NULL,3,0,3,1,NULL,'slesas\rHSSE004\rRA022491567CN\r'),(942,514697960003,130458358024,'New Motorola HS810 Bluetooth Wireless Headset track#',2,'HSMO017',43.98,'cnfaner','123michee','homi01@msn.com','Michee Homidas','8048 Deerwood Cir','Tampa','FL','UNITED STATES','33610-9557','(813) 966-6524','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 18:51:15',0,NULL,3,0,1,1,NULL,'123michee\r、'),(943,763316729012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','dj.c','efoparties@optonline.net','greg cooper','7a shadyside ave','port washington','NY','UNITED STATES','11050-2414','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 19:42:47',0,NULL,3,0,1,1,NULL,'dj.c\r、'),(944,565894288013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',8,'CASS003',69.6,'eastar4','gauravgoyal0022','gauravgoyal022@gmail.com','Gaurav Goyal','3 Maiden Place','reading','Berkshire','UNITED KINGDOM','RG63HA','07934012852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 19:47:50',0,NULL,3,0,3,1,NULL,'gauravgoyal0022\rCASS003*8\rRA022491315CN\r'),(945,565924537013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','maxromanoff','hurtman@mail.wplus.net','Romanov Maxim','Leninsky prospekt<br>dom 95 korpus 2, kv 636','St. Petersburg','','RUSSIAN FEDERATION','198330','+79119117911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 20:30:15',0,NULL,3,0,2,1,NULL,'maxromanoff\r\\'),(946,763390276012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','mhpyke','marktidcombe@yahoo.co.uk','Mark Tidcombe','3 Gifford Rd','Bristol','Avon','UNITED KINGDOM','BS10 7LR','01179087519','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 20:41:34',0,NULL,3,0,3,1,NULL,'mhpyke\r英标   HSNO006\rRA022491403CN\r'),(947,565969929013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','warriortamer','krisking1977@gmail.com','Kristopher King','114 waterwheel drive','commerce','GA','UNITED STATES','30529','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 21:53:20',0,NULL,3,0,1,1,NULL,'warriortamer\r、'),(948,687053013011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','fluffymoosedad','breconsulting@shaw.ca','Ross Ehalt','8 Hyde Court','St. Albert','AB','CANADA','T8N 5W6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 22:01:13',0,NULL,3,0,2,1,NULL,'fluffymoosedad\r\\'),(949,514823134003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',22.99,'cnfaner','mmurphy.5150','mmurphy.5150@juno.com','Mark Murphy','3 Ring Neck Rdg','Lloyd Harbor','NY','UNITED STATES','11743-9719','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 22:26:13',0,NULL,3,0,1,1,NULL,'mmurphy.5150\r、'),(950,687075081011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','sarasimssara','sarasimonson@gmail.com','Sara Simonson','520 W 48th St<br>Apt 5P','New York','NY','UNITED STATES','10036-1146','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 22:44:27',0,NULL,3,0,1,1,NULL,'sarasimssara\r、'),(951,687083969011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','bluechilli1967','martin@bluechilli.co.uk','Martin Stone','1, Blagden Close<br>Greenham','Newbury','Berks','UNITED KINGDOM','RG19 8SF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 23:06:30',0,NULL,3,0,2,1,NULL,'bluechilli1967\r\\'),(952,687086106011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',11.95,'eastar4','mpc650','andre.b.marques@gmail.com','André Marques','Rua Manuel de Arriaga N6 1A','Odivelas','Ramada','PORTUGAL','2620-319','965660389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 23:12:54',0,NULL,3,0,2,1,NULL,'mpc650\r\\'),(953,763502209012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.88,'eastar4uk','ashrafb123','info@frognal.co.uk','Ashraf  Borghol','283 Finchley Road','London','London','UNITED KINGDOM','nw36nd','07770224712','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 23:58:27',0,NULL,3,0,3,1,NULL,'ashrafb123\r英标   HSNO005\rRA022491346CN \r\r'),(954,566019381013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','ivannick6363','goddard6363@yahoo.com','Ivan Goddard','2481 Cranston Rd','letts','IA','UNITED STATES','52754-9512','(563) 262-8008','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 00:35:39',0,NULL,3,0,1,1,NULL,'ivannick6363\r、'),(955,687117626011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','fwarch','fwarchuleta@hotmail.com','Franklin Archuleta','128 Sydneys Way','Buda','TX','UNITED STATES','78610','(512) 312-2831','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 00:40:03',0,NULL,3,0,1,1,NULL,'fwarch\rLK034402989CN\r、'),(956,520676046004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','deeehmon','nobumen@gmail.com','Patricio Meneses','psj.Buzeta #4430, Quinta normal','Santiago','Metropolitana','CHILE','8510612','0056991000888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 00:53:28',0,NULL,3,0,3,1,NULL,'deeehmon\rOTRA002\rRA022491655CN\r'),(957,687133757011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','scottmenard','scottmenard@bellsouth.net','scott menard','170 Old Carrollton Rd','roopville','GA','UNITED STATES','30170','(770) 547-5305','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 01:23:51',0,NULL,3,0,1,1,NULL,'scottmenard\r、'),(958,566035372013,230601283994,'New Shure E2c Sound Isolating headset transparent ver',3,'HSSH002',197.97,'eastar4','geds2001','kenhebb@yahoo.com','Ken Hebb','1439 Highway E','Owensville','MO','UNITED STATES','65066-2255','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 01:27:23',0,NULL,3,0,1,1,NULL,'geds2001\r、'),(959,687137876011,320676244896,'New Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',65.99,'eastar4','mmcroskey','mark.mcroskey@gmail.com','Mark McRoskey','502 E Boone Ave<br>MSC 2446','Spokane','WA','UNITED STATES','99258-1774','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 01:34:33',0,NULL,3,0,1,1,NULL,'mmcroskey\r、'),(960,520692813004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','danylina','dayli01@msn.com','Lina Heiser','4001 Beneva Rd<br>Apt 410','sarasota','FL','UNITED STATES','34233','(941) 822-2129','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 02:00:31',0,NULL,3,0,1,1,NULL,'danylina\r、'),(961,0,220758134612,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','amgjay','amgdirectj@aol.com','Jay Ruditis','679 Nieves Ln','Saint Augustine','FL','UNITED STATES','32086-7706','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 02:22:04',0,NULL,3,0,1,1,NULL,'amgjay\r、'),(962,566056791013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',21.98,'eastar4','ss67332010','sanderssavage2@bellsouth.net','sammurelle savage','5740 S W 26TH ST APT#A','HOLLYWOOD','FL','UNITED STATES','33023','(954) 865-3585','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 02:52:52',0,NULL,3,0,1,1,NULL,'ss67332010、'),(963,514894790003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','komatsuyuri','yurikomatsu@gmail.com','Yuri Komatsu','João Dantas Figueira 1285<br>Jardim Brasília','Paranaíba','Mato Grosso do Sul','BRAZIL','79500000','+556736681650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 03:10:52',0,NULL,3,0,3,1,NULL,'komatsuyuri\rMOSA002\rRA022491258CN\r'),(964,514911568003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','dialmanik','manik@dialtrade.com','Ibrahim Adam','Dialcomplex.2/52Orchidmagu.<br>Mafannu','Male\'.','Maafannu','MALDIVES','2002','+960-3331983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 04:58:02',0,NULL,3,0,3,1,NULL,'dialmanik\rOTGR001\rRA022492196CN\r'),(965,763600582012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','vasammo','vsamoylov@pochta.ru','Vadim Samoylov','69-9<br>Gorkogo st.','Biysk','Altay region','RUSSIAN FEDERATION','659301','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-28 05:00:33',0,NULL,3,0,2,1,NULL,'vasammo\r欧标\r\\'),(967,763602363012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','jnsar64','jnsar64@yahoo.com.ar','Jose Sanguedolce','Tomas Moro 1782<br>Las Condes','Santiago','Chile','CHILE','7550000','(829) 648-99','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 05:10:02',0,NULL,3,0,2,1,NULL,'jnsar64\r\\'),(968,520727039004,140427917560,'2.1 Acer Aspire 7738G bluetooth module we offer track#',1,'BTAC2104',16.59,'cnfaner','goliat_pl','golji@poczta.onet.pl','Tomasz Gralewski','Slowicza 23','Żary','lubuskie','POLAND','68200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 05:19:04',0,NULL,3,0,3,1,NULL,'goliat_pl\racer 4pin1.25 6cm \rBTAC2104\rRA022491831CN \r'),(969,687195222011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',3,'WLAP001',44.43,'eastar4','inetsion','eddie_lau@hotmail.com','Eddie Lau','11 Jalan Puteri 3/1<br>Bandar Mahkota Cheras','Kajang','Selangor','MALAYSIA','43200','0122778788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 05:26:51',0,NULL,3,0,3,1,NULL,'inetsion\rWLAP001\rRA022491139CN\r'),(970,566092484013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','jb114.seo','lssjb114@paran.com','Jeongbeom Seo','Room #412, compact house<br>602-19, Namhyeon-dong, Gwanak-gu','Seoul','','KOREA,REPUBLIC OF','151-801','010-4775-5440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 06:43:20',0,NULL,3,0,3,1,NULL,'jb114.seo\rMOSA002\rRA022491111CN\r\r'),(971,687227850011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','mortan1979','mortan@email.ru','Dmitriy Urusov','ulitsa Saltykovskaya<br>dom 29 korpus 1 kvartira 195','Moskow','Moskow','RUSSIAN FEDERATION','111672','+79265919115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 08:19:37',0,NULL,3,0,2,1,NULL,'mortan1979\r\\'),(972,0,220758138156,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','tugageek','luismiguelsnt@gmail.com','Luís Miguel Santos','Av. Marechal Gomes da Costa, N.º21-D 2.º Piso<br>(Sorel Serviços)','Lisboa','Portugal','PORTUGAL','1800-255','+351 919 233 918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 08:20:28',0,NULL,3,0,3,1,NULL,'tugageek\rOTRA002\rRA022492514CN\r\\'),(973,763662771012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','azra2009','fantastischshop@gmx.de','Salim Ünyeli','Bülowstr. 9','Düsseldorf','','GERMANY','40476','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 09:48:50',0,NULL,3,0,2,1,NULL,'azra2009\r\\'),(974,520764125004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',2,'HSPL010',49.98,'cnfaner','redsoxfollower','jgcowden@yahoo.com','James G Cowden','18 Highland Ave','Barrington','RI','UNITED STATES','02806-4714','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 09:55:14',0,NULL,3,0,1,1,NULL,'redsoxfollower\r\\'),(975,566091802013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',2,'WLIN010',41.9,'eastar4','jttj2011','piypay@yandex.ru','Alexander Shatalov','ul. Rodonitovaya, dom 32, kv. 154','Yekaterinburg','Sverdlovsk region','RUSSIAN FEDERATION','620073','+79221172121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 10:04:12',0,NULL,3,0,3,1,NULL,'jttj2011\rWLIN010\rRA022492545CN\r\\'),(976,519965279004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','weezy024','kcopeland22@yahoo.com','Ken Copeland','404 Poinsetta St','Lake Jackson','TX','UNITED STATES','77566-5440','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 11:15:32',0,NULL,3,0,1,1,NULL,'weezy024\r\\'),(977,520783303004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','maveolento','mauri.kiviranta@gmail.com','Mauri Kiviranta','viskaripolku 3 A 4','turku','','FINLAND','20210','+358440823675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 11:43:59',0,NULL,3,0,3,1,NULL,'maveolento\rOMHJ001\rRA022492474CN\r\\'),(978,763714082012,220759518181,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.99,'eastar4uk','nht1969','sc0rp10ns69@hotmail.com','Neil Hopkin-Thomas','5 Glan-Y-Mor<br>The knap','Barry','The Vale of Glamorgan','UNITED KINGDOM','CF62 6FF','07540939550','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 12:39:52',0,NULL,3,0,3,1,NULL,'nht1969\rCALO001\rRA022492531CN\r\\ '),(979,565023106013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',41.2,'eastar4','wagnertw','wagnerw@mail.com','Wagner T. Watanabe','Av Rogério Delalibera, 332','Londrina','Paraná','BRAZIL','86035175','+55 44 96329171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 12:47:06',0,NULL,3,0,3,1,NULL,'wagnertw\rANCN001+WWSI004\r\\\rRA022492528CN\r'),(980,763723660012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',23.85,'eastar4','chrisygeezer','chris@wherestony.co.uk','Chris Adams','Winterflood Securities Ltd<br>The Atrium Building, 25 Dowgate Hill','Cannon Bridge','london','UNITED KINGDOM','EC4R 2GA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 13:14:40',0,NULL,3,0,2,1,NULL,'chrisygeezer\r\\'),(981,520803687004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','thatslifemusic','info@fsgrafik.de','fsgrafik','Frank Stickel<br>Hauptstraße 32','Wankheim','','GERMANY','72127','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 13:26:48',0,NULL,3,0,3,1,NULL,'thatslifemusic\rHSNO022    欧标\rRA022492593CN\r\\'),(982,566168314013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','ihartavi','ihartavi@gmail.com','Ibrahim H.HARTAVIOGLU','Eskipazar Mah. Hopa Cad.<br>Ozen Apt. Daire-11','Cayeli','RIZE','TURKEY','53400','5527159163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 13:26:50',0,NULL,3,0,3,1,NULL,'ihartavi\rOTRA002\rRA022492491CN\r\\'),(983,687314526011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','eitantr1','eitantr@gmail.com','Eitan Traistman','Ygaal Yadin 51/31','modieen','','ISRAEL','71720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 13:41:37',0,NULL,3,0,3,1,NULL,'eitantr1\rRCLO006\rRA022492647CN\r\\'),(984,687316981011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','mgar4579','martin.garcia@mavs.uta.edu','Martin Garcia','3928 6th Ave','Fort Worth','TX','UNITED STATES','76110','(817) 924-0852','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 13:46:21',0,NULL,3,0,1,1,NULL,'mgar4579\r\\'),(985,763744144012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',3,'HSNO005',44.25,'eastar4','panosvxr','astrarsp@gmail.com','Panagiotis Fryssas','Alis Teriant 6','Mytilene','AL','GREECE','81100','00302251029857','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 14:08:50',0,NULL,3,0,3,1,NULL,'panosvxr\rHSNO005   欧标\rRA022492633CN\r\\'),(986,761277297012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',2,'HSMO018',21.98,'eastar4','howxx','wehow@hotmail.com','W. Edward Howard, Jr.','102 Haygood Ave','Lexington','SC','UNITED STATES','29072','(803) 659-6996','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 14:14:11',0,NULL,3,0,1,1,NULL,'howxx'),(987,763749371012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','dream459','anthony@saviniconstruction.com','Anthony Savini','16902 Shingle Point Rd','milton','DE','UNITED STATES','19968-2554','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 14:25:40',0,NULL,3,0,1,1,NULL,'dream459\r\\'),(988,515010055003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','erivanmelo','erivancmelo@hotmail.com','Erivan carlos de Melo','Rua, da Estrela, 203<br>Parnamirim','Recife','Pernambuco','BRAZIL','52060160','+55 81 99733351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 14:40:37',0,NULL,3,0,3,1,NULL,'erivanmelo\rHSPL005   单机\rRA022492505CN\r\\'),(989,566193712013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','milbeyer','milbeyer@yahoo.com.br','Rodrigo Guessada','R AUDALIO GONCALVES DOS SANTOS 217<br>JARDIM THOMAZ','SAO PAULO','SP','BRAZIL','05833040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 15:03:48',0,NULL,3,0,2,1,NULL,'milbeyer\r\\'),(990,515022107003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','jonys-il','jonys1982@gmail.com','jonny s','Arava 11<br>Israel','holon','ID','ISRAEL','58422','0545832815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 15:26:26',0,NULL,3,0,3,1,NULL,'jonys-il\rHSMO018\rRA022492602CN\r\\'),(991,762284650012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','blander38490','dipmann2002@yahoo.com','Brandon Anderson','PO Box 1051','Palm Springs','CA','UNITED STATES','92263-1051','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 16:12:03',0,NULL,3,0,1,1,NULL,'blander38490\r\\'),(992,566213759013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','synebrukhoff1974','synebrukhoff@gmail.com','Evgeny Zhavoronkov','Marshala Kozheduba, 14-27','Moscow','Russian Federation','RUSSIAN FEDERATION','109559','0079150997706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 16:12:59',0,NULL,3,0,2,1,NULL,'synebrukhoff1974\r\\'),(993,0,220758136774,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',27.49,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 16:22:16',0,NULL,3,0,1,1,NULL,'4278dennis\r一共买了两个保护屏'),(994,515037942003,130490963329,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'cnfaner','alex_arkadyev','arcadyev@gmail.com','Alexander Arkadyev','Grazhdanskiy prospect,<br>dom 115, k.1, kv. 105','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','195299','+7-921-7457930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 16:26:23',0,NULL,3,0,3,1,NULL,'alex_arkadyev\rWLIN010\rRA022492559CN\r\\'),(995,520850313004,140519359288,'NIB Kensington Expert Mouse Optical UsbTrackball K64325',3,'OTKE001',237,'cnfaner','indexpinc','marcoindexp@gmail.com','Georgina Hernandez','9950 Marconi Dr<br>Ste 101','San Diego','CA','UNITED STATES','92154-7272','(619) 661-1820','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 16:32:54',0,NULL,5,0,18,0,NULL,'indexpinc\r'),(996,763808146012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.5,'eastar4uk','reonwai','reon_nite4ever@hotmail.com','Sai Wah Wai','apt27 mckee ave heath square dublin11 ireland','Finglas','Dublin','IRELAND','11','0871638824','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-28 16:42:01',0,NULL,3,0,3,1,NULL,'reonwai\rRELO002\rRA022492576CN\r\\'),(997,685912669011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','jbrady9999','jimrbrady@gmail.com','James Brady','3036 Thrushwood Dr','Austin','TX','UNITED STATES','78757','(512) 657-6106','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 17:12:32',0,NULL,3,0,1,1,NULL,'jbrady9999、'),(998,0,320676730064,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','ricca1997','rsavarese1@comcast.net','RICCARDO SAVARESE','1 Edgewood Dr','pittsgrove','NJ','UNITED STATES','08318-4189','(856) 521-0303','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 17:28:33',0,NULL,3,0,1,1,NULL,'ricca1997\r\\'),(999,515061733003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','chris291176','axoumissa@yahoo.gr','Christoforos Papasavvas','Agiou Haralambous 10A Lakatamia','Nicosia','','CYPRUS','2334','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 17:42:13',0,NULL,3,0,3,1,NULL,'chris291176\rOTGR001\rRA022492620CN\r\\'),(1000,763847510012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','pra15bcoy','norman.laird@googlemail.com','Norman Laird','Broombank<br>Mintlaw','Peterhead','Aberdeenshire','UNITED KINGDOM','AB424ET','01771623044','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 17:58:30',0,NULL,3,0,3,1,NULL,'pra15bcoy\rOTCN002\rRA022492562CN\r\\'),(1001,566248759013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','ryangosson','rsgosson@lakeheadu.ca','Ryan Gosson','196 Princess Street<br>Apt. 4','Saint John','NB','CANADA','E2L2N8','(506) 977-1418','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 18:00:22',0,NULL,3,0,2,1,NULL,'ryangosson\r\\'),(1002,566253444013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.85,'eastar4','jenzek','jenz.ek@gmail.com','Jenz Ek','Blystigen 6C','Falun','SE','SWEDEN','79156','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 18:06:24',0,NULL,3,0,2,1,NULL,'jenzek\r\\'),(1003,520889659004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','sar2t','sarthost@gmail.com','Andrei Zlotnikau','Checherskaya 29-16','Gomel','','BELARUS','246038','375336831313','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 18:31:17',0,NULL,3,0,3,1,NULL,'sar2t\rHSPL001\rRA022492580CN\r\\'),(1004,763888507012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','rmcleskey','ryanmcleskey@yahoo.com','Ryan McLeskey','426 Eagle Dr','Ione','CA','UNITED STATES','95640','(209) 337-8548','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 19:08:03',0,NULL,3,0,1,1,NULL,'rmcleskey、'),(1005,566286450013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',2,'WLAT001',29.98,'eastar4','brenoalbuquerque','brenoemaria@hotmail.com','breno albuquerque','Oscar Gomes Moreira Junior n°890','Uberlândia','Minas Gerais','BRAZIL','38412-044','+553432369785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 19:23:20',0,NULL,3,0,2,1,NULL,'brenoalbuquerque\r\\'),(1006,0,320674543993,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','chubbs2','jenbob10@ptd.net','robert mcneal','141 Millers Gap Rd','marysville','PA','UNITED STATES','17053','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 19:47:29',0,NULL,3,0,1,1,NULL,'chubbs2、'),(1007,687490917011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','nan-marge','dsmith7018@yahoo.com','Danny Smith','24401 S Ribbonwood Dr','Sun Lakes','AZ','UNITED STATES','85248-7749','(734) 775-4344','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 20:01:20',0,NULL,3,0,1,1,NULL,'nan-marge、'),(1008,520930171004,140515701798,'New GENUINE NOKIA BH-205 BLUETOOTH HEADSET track#',2,'HSNO009',31,'cnfaner','micanco1970','micanco@inwind.it','Michelangelo Ancona','Piazza Vittorio Emanuele, 30','Bari-Loseto','BA','ITALY','70129','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 20:05:30',0,NULL,3,0,3,1,NULL,'micanco1970\r欧标   HSNO009\r\rRA117710466CN\r\\'),(1009,520929753004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','jcase212','j.case14@yahoo.com','Jeff Case','557 Enright Ave','Cincinnati','OH','UNITED STATES','45205-2132','(513) 498-3203','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 20:09:22',0,NULL,3,0,1,1,NULL,'jcase212、'),(1010,685200834011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','sofiaquensel','sofiaquensel@hotmail.com','Sofia Quensel','Karinsgatan 20','Malmö','','SWEDEN','21459','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 20:20:30',0,NULL,3,0,2,1,NULL,'sofiaquensel\r\\'),(1011,763955159012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','master_brett','master_brett@yahoo.com','Brett Davis','6421 Sunnybrook Dr','North Richland Hills','TX','UNITED STATES','76180','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 20:44:25',0,NULL,3,0,1,1,NULL,'master_brett\r美标\r、'),(1012,566321763013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','derrick910318','dr.derrick.t@gmail.com','Dominic Lai','Dom 39/1, K.12-13<br>Ulitsa Akademika Volgina','Moscow','Moscow','RUSSIAN FEDERATION','117437','9166202283','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 20:48:30',0,NULL,3,0,2,1,NULL,'derrick910318\r\\'),(1013,763958202012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','doxie1','vaughn30577@yahoo.com','RICHARD VAUGHN','3311 Rooster Ln','Hiawassee','GA','UNITED STATES','30546','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 20:51:55',0,NULL,3,0,1,1,NULL,'doxie1\r\\'),(1014,687534557011,320575306082,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',14.95,'eastar4','paperman_2008','paperman@realsilver.ru','Aleksey Kozlov','Perovskaya st., 58-131','Moscow','','RUSSIAN FEDERATION','111394','+79854106310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 21:21:23',0,NULL,3,0,2,1,NULL,'paperman_2008\r\\'),(1015,687138042011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tarheelborn1','tarheelborn1@yahoo.com','Alex Copple','2601 University Ave SE<br>Apt 230','minneapolis','MN','UNITED STATES','55414-3297','(763) 412-9393','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 22:01:27',0,NULL,3,0,1,1,NULL,'tarheelborn1、'),(1016,763995984012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','crmichelini','crmalpha2@hotmail.com','Christopher Michelini','5201 W County Road 400 N','Muncie','IN','UNITED STATES','47304-9049','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 22:06:25',0,NULL,3,0,1,1,NULL,'crmichelini\r\\'),(1017,566351217013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','heyyu223','johnyu@guess.com','JOHN YU','1444 S Alameda St','Los Angeles','CA','UNITED STATES','90021-2433','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 22:10:46',0,NULL,3,0,1,1,NULL,'heyyu223\r\\'),(1018,764000869012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',23.85,'eastar4','mmapplebeck','mmapplebeck@gmail.com','Marc A. Mapplebeck','C/O City Animal Hospital Ltd<br>Devon Park Plaza','Fredericton','NB','CANADA','E3A 3N2','(506) 471-7044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 22:18:11',0,NULL,3,0,2,1,NULL,'mmapplebeck\r\\'),(1019,764001537012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','mcface5','evan.mcewen@gmail.com','Evan McEwen','180 Second Avenue','Ottawa','ON','CANADA','K1S 2H7','(613) 600-2958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 22:20:19',0,NULL,3,0,2,1,NULL,'mcface5\r\\'),(1020,687560112011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','kb9mzx','galenf2847@aol.com','Galen Fromm','11590 State Highway 107','Hamburg','WI','UNITED STATES','54411-9160','(414) 807-8976','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 22:25:20',0,NULL,3,0,1,1,NULL,'kb9mzx、'),(1021,764043433012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','hyrchung','rchunghy@aol.com','Ronald Chung','Unit 107B, 1/F, Building 5, No.6 Science Park West Avenue<br>Shatin, Hong Kong','default','','HONG KONG','default','60216900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 00:37:18',0,NULL,3,0,2,1,NULL,'hyrchung\r\\'),(1022,566398190013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 01:35:15',0,NULL,3,0,2,1,NULL,'update_marcelo\r\\'),(1023,764066288012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','dogdude62','dogdude62@hotmail.com','William Perkins','115 Bragdon Rd','Freeport','ME','UNITED STATES','04032','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 01:40:41',0,NULL,3,0,1,1,NULL,'dogdude62、'),(1024,521018877004,140516104473,'Logitech Charging Cradle L-LG7 for Harmony 880 890 pro',1,'CRLO002',9.99,'cnfaner','alternatif2','stef98436@hotmail.com','Olivier Stephane','43 rue Dagobert','Candiac','QC','CANADA','J5R6E8','(450) 659-8297','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 01:57:00',0,NULL,3,0,3,1,NULL,'alternatif2\rCRLO002\rRA022492488CN\r\\'),(1025,687637481011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','quandaar','quandaar@hotmail.com','Soren Fox','320 River St','Iowa City','Ia','UNITED STATES','52246-3531','(319) 541-3209','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 02:57:21',0,NULL,3,0,1,1,NULL,'quandaar、'),(1026,687639656011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','samdramtheory','mytheory@gmail.com','Valentin Kravtchenko','834 3e avenue','verdun','QC','CANADA','h4g2x6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 03:07:32',0,NULL,3,0,2,1,NULL,'samdramtheory\r、'),(1027,764094832012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','wjk350','bluwil@aol.com','Willie Kirby','350 Sinbad Ave','Opa Locka','FL','UNITED STATES','33054','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 03:23:38',0,NULL,3,0,1,1,NULL,'wjk350、'),(1028,764097171012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ppacciardi','ppacciardi@aol.com','Pierluigi Pacciardi','6891 Kenyon Ave','Hesperia','CA','UNITED STATES','92345-7268','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 03:31:13',0,NULL,3,0,1,1,NULL,'ppacciardi'),(1029,764108909012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','grandizom','fernandes@grandizom.com.br','fernando fernandes','RUA FRANCISCA JULIA, 44 - ANIL','RIO DE JANEIRO','RJ','BRAZIL','22755-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 04:26:39',0,NULL,3,0,2,1,NULL,'grandizom\r、'),(1030,515238299003,130489927197,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'cnfaner','deniseism','denisemccooey@comcast.net','denise mccooey','4504 Somerset Ln','kent','WA','UNITED STATES','98032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 05:31:20',0,NULL,3,0,1,1,NULL,'deniseism\r、'),(1031,515239849003,130490963329,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'cnfaner','rsletters','skletters@yandex.ru','Konstantin Strukov','dom.39 kv.21<br>Naro-Fominskie raion','pos.Selyatino','Moskovskaya oblast','RUSSIAN FEDERATION','143345','+79169558544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 05:45:10',0,NULL,3,0,3,1,NULL,'rsletters\rRA022492341CN\r\\'),(1032,566448144013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',43.98,'eastar4','brvclickhit2009','clickhit2009@yahoo.com','Budiman Rubia Viqih','Jl. Margonda Raya, Gg. H. Fatimah, Kemiri Muka, RT.002 RW.011<br>No.11A / 1A, Beji','Depok','Jawa Barat','INDONESIA','16423','085693133939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 06:38:14',0,NULL,3,0,3,1,NULL,'brvclickhit2009\rRA022492267CN\r\\'),(1033,684734671011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',8,'CASS003',69.6,'eastar4','anjanaelzabeth','gigivikraman@gmail.com','Gigi Vikraman','Al Dana Centre,410<br>Maktoum Road','Deira','Dubai','UNITED ARAB EMIRATES','64329','00971-559454771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 06:48:32',0,NULL,3,0,3,1,NULL,'anjanaelzabeth\rRA022492324CN\r\\  '),(1034,764145481012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','matoupri','matoupri@free.fr','Damien MATHEY','27 rue du pont tournant','LES FORGES','Lorraine','FRANCE','88390','03.29.35.74.74','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-29 07:35:28',0,NULL,3,0,3,1,NULL,'matoupri\rOTRA002\rRA117710364CN\r\\'),(1035,687690848011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',3,'OTCN002',11.97,'eastar4','gi-zu-ex','nathan-hein@wanadoo.nl','Neddim Hein','Suze Groenewegstraat 53','Tiel','','NETHERLANDS','4003ZT','0628294329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 07:42:56',0,NULL,3,0,2,1,NULL,'gi-zu-ex\r、'),(1036,764148606012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',11.9,'eastar4uk','rob_keeling','rob@rjkeeling.co.uk','Rob Keeling - Queen Elizabeth`s Grammar School','The Green Road','Ashbourne','Derbyshire','UNITED KINGDOM','DE6 1EP','01335343685','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 07:49:01',0,NULL,3,0,3,1,NULL,'rob_keeling\rOTCN004*10\rRA117710276CN\r'),(1037,515258138003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',19.9,'cnfaner','angelo*andrzej','andrew1863@poczta.fm','Andrzej Tkacz','Gajowa 1/11','Częstochowa','śląskie','POLAND','42200','34 3662202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 08:25:41',0,NULL,3,0,3,1,NULL,'angelo*andrzej\r欧标\rHSNO016\rRA117710165CN\r'),(1038,687337151011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','nord975','rid75@ukr.net','Mykhaylo Degtyarenko','p.o.box 701','Sumy','','UKRAINE','40003','+38 066 217-54-62','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 08:48:09',0,NULL,3,0,2,1,NULL,'nord975'),(1039,520806420004,140428311581,'2.1 Acer Aspire 9410 bluetooth module we offer track#',1,'BTAC2108',16.59,'cnfaner','jlpitre','jeanlou.pitre@gmail.com','Jean-Lou Pitre','609 Canso St., Apt 1','Dieppe','NB','CANADA','E1A 2A3','(506) 860-3471','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 10:09:56',0,NULL,3,0,3,1,NULL,'jlpitre\racer 4pin1.25 18cm\rBTAC2108\rRA117710174CN\r\\'),(1040,521090874004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','darkkevind','darkkevind@hotmail.com','Kevin Dark','Riverside House, 4 Walls Yard<br>South Street','Rochford','Essex','UNITED KINGDOM','SS4 1GR','07813335117','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 10:18:00',0,NULL,3,0,3,1,NULL,'darkkevind\rWWSI005\r\rRA117710510CN\r\\'),(1041,521102464004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',2,'HSPL001',23.76,'cnfaner','dr.wael-galal','wgalal@yahoo.com','Dr. Wael Galal Mostafa','King Fahad Hospital, B.O.Box: 204<br>Anesthesia Department, OR (3rd floor)','Al-Baha','Al-Baha','SAUDI ARABIA','65411','+966595788630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 11:28:41',0,NULL,3,1,3,1,NULL,'dr.wael-galal\rHSPL001\rRA117710347CN'),(1042,764205446012,220692197062,'IBM Ericsson F3507G 3G WWAN card+antenna FRU43Y6513',1,'WWOT002+ANCN001',73.9,'eastar4','naransula','burakbeyhan@yahoo.com','Burak Beyhan','Mersin Universitesi, Mimarlik Fakultesi<br>Ciftlikkoy Kampusu, Yenisehir','Mersin','','TURKEY','33343','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 11:45:29',0,NULL,5,0,18,0,NULL,'naransula'),(1043,687751403011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','hinoi_jane1983','m.tonkin@ntlworld.com','Hinoi Tonkin','43 Wilton Way<br>Grangetown','Middlesbrough','Cleveland','UNITED KINGDOM','TS67QP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 11:50:57',0,NULL,3,0,2,1,NULL,'hinoi_jane1983'),(1044,764233621012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','pdsh7190','pj_1345@yahoo.com','Peter O\'Neill','1345 Old Black Horse Pike','Blackwood','NJ','UNITED STATES','08012-4734','(856) 228-7190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 12:57:10',0,NULL,3,0,1,1,NULL,'pdsh7190'),(1045,687772017011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','123-roudoudou','eric.plazen@laposte.net','PLAZEN eric','lieu-dit BERGERAT','MONTJOIE en Couserans','Midi-Pyrénées','FRANCE','09200','0561048793','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 12:59:50',0,NULL,3,0,2,1,NULL,'123-roudoudou'),(1046,687775656011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',3,'WLAP001',44.43,'eastar4','ltkoscianski','lkoscianski@ecmacservices.com','Larry Koscianski','2047 S Park Dr<br>Eastern Carolina Macservices Ste B','Winterville','NC','UNITED STATES','28590-9936','(252) 353-6227','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 13:11:17',0,NULL,3,0,1,1,NULL,'ltkoscianski'),(1047,0,320676726450,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','skip-br','skip.br@gmail.com','Ricardo Takahashi','Rua Rio Amazonas, 27','São Paulo','São Paulo','BRAZIL','08041-260','55 11 6153-9052','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 14:48:44',0,NULL,3,0,3,1,NULL,'skip-br\rRA117710320CN\r\r'),(1048,515344180003,130466041485,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.99,'cnfaner','anton.mingazov','a.mingazov@gmail.com','Anton Mingazov','Chkalova 11-18','Dzerginsk','Nijegorodskaya obl','RUSSIAN FEDERATION','606000','+79625180963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 15:41:47',0,NULL,3,0,3,1,NULL,'anton.mingazov\rWWSI005+ANCN001\r\rRA117710568CN\r\\'),(1049,566567728013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','zzubr','eshgin@gmail.com','Eshgin Mammadov','Tabriz 83<br>flat(manzil)7','Baku','BAKU','AZERBAIJAN','az1072','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 16:23:06',0,NULL,3,0,2,1,NULL,'zzubr'),(1050,687852284011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','osudonkey','colinbwebb@gmail.com','Colin Webb','11805 Woodbridge Rd','Oklahoma City','OK','UNITED STATES','73162-3218','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 16:47:08',0,NULL,3,0,1,1,NULL,'osudonkey'),(1051,764055070012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','501robert1976','rob_williams76@yahoo.com','robert williams','299 Fox Chase Dr','greers ferry','AR','UNITED STATES','72067-8501','(501) 825-8944','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 17:37:24',0,NULL,3,0,1,1,NULL,'501robert1976'),(1052,520781241004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','i100nets','sreiner@gmail.com','Vladimir Shreiner','Torujoe 21-1','Kohtla-Jarve','Ida-Virumaa','ESTONIA','30323','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 18:10:50',0,NULL,3,0,3,1,NULL,'i100nets\rWWSI005\r\rRA117710571CN\r\\'),(1053,521202262004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','newcom8','newcomer39@hotmail.com','Thomas Newcomer','21338 Lynn Dr','Lexington park','MD','UNITED STATES','20653','(301) 862-4589','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 18:15:28',0,NULL,3,0,1,1,NULL,'newcom8'),(1054,687886776011,320575306082,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',14.95,'eastar4','666mimi999','mimikoca@yahoo.com','Dhimiter Koca','Rruga \"Myslym Shyri\" Nr.134 Tirane','Tirane','','ALBANIA','134','0355683093207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 18:23:49',0,NULL,3,0,2,1,NULL,'666mimi999'),(1055,520985763004,140516092415,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'cnfaner','707ginger2','ldecota@cssara.org','Lynne DeCota','412 Adobe Canyon Rd','Kenwood','CA','UNITED STATES','95452','(707) 833-2013','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 18:27:48',0,NULL,3,0,1,1,NULL,'707ginger2'),(1056,687911402011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','andrewns240','andrewns@gmail.com','Andreas Saltos','118 N Howard St<br>Apt 515','Baltimore','MD','UNITED STATES','21201-3431','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 18:55:01',0,NULL,3,0,1,1,NULL,'andrewns240'),(1057,566627546013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','ediiazcos','ediazcos@gmail.com','Edgar A. Díaz Cosme','Arquimedes 202 #702<br>Colonia Polanco Reforma','Miguel Hidalgo','Distrito Federal','MEXICO','11550','555-255-1568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 19:08:40',0,NULL,3,0,2,1,NULL,'ediiazcos'),(1058,764399851012,220681549785,'New Nokia LD-3W Bluetooth GPS Module Battery+Carcharger',1,'OTCR001',19.55,'eastar4uk','its_od','andrew.odonnell00@gmail.com','Andrew O\'Donnell','16 RATHMINES PARK','RATHMINES','DUBLIN','IRELAND','6','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-29 19:22:23',0,NULL,3,0,3,1,NULL,'its_od\rRA117710404CN\r'),(1059,521231325004,140490658273,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',42.99,'cnfaner','dimon1981saler','dimandroid1981@gmail.com','Dmitriy Larchenko','Molodeghnaya, house 9, flat 35','Fryanovo','Moscow region, Shchelkovo district','RUSSIAN FEDERATION','141147','+79653390298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 19:30:23',0,NULL,3,0,3,1,NULL,'dimon1981saler\rwwsi004+ancn001\rRA117710333CN\r'),(1060,521233867004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','ingylevi','andyng31@hotmail.com','andrew ng','72 Kingsway,Newton','chester','Cheshire','UNITED KINGDOM','CH2 2LL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 19:37:47',0,NULL,3,0,3,1,NULL,'ingylevi\rOTRA002\rRA117710381CN\r'),(1061,515424231003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',2,'HSNO019+CCNO001',89.98,'cnfaner','pedro50321','tompaul@netcologne.de','Tom Paul','Franz-von-Kempis-Weg 1','Bornheim','','GERMANY','53332','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 19:39:19',0,NULL,3,0,3,1,NULL,'pedro50321\rHSNO019+CCNO001\rRA117710316CN\r\\'),(1062,764450152012,220682002486,'2.1 Acer Aspire 5338 5536 5236 Bluetooth Module +cable',1,'BTAC2105',16.59,'eastar4','cbservers','zarth@nepeanvalley.com.au','Sharon Zarth','12 Jular Place','Jamisontown','New South Wales','AUSTRALIA','2750','0402876310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 20:25:04',0,NULL,3,0,2,1,NULL,'cbservers\racer 4pin1.25 8cm '),(1063,687999688011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','dutchiechrissie','ebay@van-munster.com','Chris van Munster','De Beumkes 6','Rijssen','','NETHERLANDS','7462 pv','+31 548542344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 21:24:09',0,NULL,3,0,2,1,NULL,'dutchiechrissie'),(1064,764494253012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','spartaah','xz32@hotmail.com','Alejandro Castellanos','18 calle 31-32<br>zona 7 Villa Linda 2','Guatemala','Guatemala','GUATEMALA','01007','(502) 400-6668 ext.: 9','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 21:47:11',0,NULL,3,0,2,1,NULL,'spartaah'),(1065,688019998011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','lesliesol','leslie@solengineering.com','Leslie Howard','2831 Camino Del Rio S<br>Ste 109','San Diego','CA','UNITED STATES','92108-3827','(619) 270-8539','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 22:13:44',0,NULL,3,0,1,1,NULL,'lesliesol'),(1066,521289000004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','hermano2020','hermano2020@verizon.net','Herman C McCrea','1759 N Dover St','Philadelphia','PA','UNITED STATES','19121','(215) 765-2485','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 22:25:56',0,NULL,3,0,1,1,NULL,'hermano2020'),(1067,764513622012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','dk_schneider','schneider.heating@rogers.com','Kaisa Schneider','141 Rebecca St','Stratford','ON','CANADA','N5A 3P4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 22:33:31',0,NULL,3,0,2,1,NULL,'dk_schneider'),(1068,566543009013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','mrd169','jeremy.furman@gmail.com','Jeremy Furman','1050 Lenox Park Blvd<br>Apt 17106','Atlanta','GA','UNITED STATES','30319','(352) 281-1220','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 22:39:07',0,NULL,3,0,1,1,NULL,'mrd169'),(1069,521292089004,140515704012,'New GENUINE NOKIA HS-36W  BLUETOOTH HEADSET track#',1,'HSNO026',15.5,'cnfaner','mickey7034','kapoormickey123@yahoo.com','mickey','5418 cleveland hwy','cohutta','GA','UNITED STATES','30710-9510','(404) 966-6822','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 22:39:41',0,NULL,3,0,1,1,NULL,'mickey7034'),(1070,0,230601698326,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32.49,'eastar4','universalmajor1970','javierx7@gmail.com','Javier Andres Manriquez Gebert','El Escorial 370 depto 603','Temuco','Novena Region de la Araucania','CHILE','n/a','0056997317446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 22:45:26',0,NULL,3,0,3,1,NULL,'universalmajor1970\rOTRA002\rRA117710395CN\r\\'),(1071,515483815003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',41.99,'cnfaner','szogun80','szogun80@hotmail.com','SLAWOMIR SOKOLSKI','7307 W MONTROSE AVE','NORRIDGE','IL','UNITED STATES','60706-1157','(773) 627-9839','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 22:48:52',0,NULL,3,0,1,1,NULL,'szogun80'),(1072,688034933011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.9,'eastar4','uniquerican23','emmanuelruiz81@hotmail.com','emmanuel ruiz','3204 vermeer dr','virginia beach','VA','UNITED STATES','23453-3062','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-29 22:58:42',0,NULL,3,0,1,1,NULL,'uniquerican23'),(1073,764528749012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','duckman1221','duckman1221@gmail.com','Chris Duckett','532 S Hardy Ave','Independence','MO','UNITED STATES','64053-1508','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 23:16:07',0,NULL,3,0,1,1,NULL,'duckman1221'),(1074,688043360011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','fbarini','fabianobarini@hotmail.com','Fabiano Barini','Av. Rio Branco, 217 / 227','Franca ','Sao Paulo','BRAZIL','14405-080','(16) 3721-1654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 23:27:26',0,NULL,3,0,2,1,NULL,'fbarini'),(1075,521305707004,140393734505,'%%% NEW Lowepro ROVER PLUS AW Photo Camera Bag Backpack',1,'',107.99,'cnfaner','manticdk','liljekrans@gmail.com','Danni Liljekrans','Døgnposten 657 / ID: 51801803','Odense M','Denmark','DENMARK','5230','004551801803','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-29 23:51:11',0,NULL,3,0,5,1,NULL,'manticdk\rCP226344785CN\r'),(1076,764554400012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','thanz','jmthanz@yahoo.com','jonathan mariano','DepEd, Pagadian City Division<br>San Jose Heights','pagadian city','zamboanga del sur','PHILIPPINES','7016','9298438569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 00:40:56',0,NULL,3,0,2,1,NULL,'thanz'),(1077,566737845013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','yaboy1956','buenterprises@yahoo.com','Alvin Wright','8448 Crossland Loop<br>Ste 142','Montgomery','AL','UNITED STATES','36117-0951','(334) 649-3045','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 01:10:34',0,NULL,3,1,1,1,NULL,'yaboy1956'),(1078,566745545013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',61.8,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 01:48:45',0,NULL,3,0,3,1,NULL,'update_marcelo\rWWSI005\r\rRA117710599CN\r\\'),(1079,566768672013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','grisho69','grisho69@hotmail.com','Grigor Georgiev','61 DELLBROOK CRES.','TORONTO','ON','CANADA','M9L 1E3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 03:45:00',0,NULL,3,0,2,1,NULL,'grisho69\r\\'),(1080,764614653012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','bettiesbaby','misscreek@sbcglobal.net','Nicole Creek','1440 S Curson Ave','Los Angeles','CA','UNITED STATES','90019-3804','(323) 692-9298','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 04:13:20',0,NULL,3,0,1,1,NULL,'bettiesbaby\r\\'),(1081,688117516011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','konstk_2009','konstk@yandex.ru','Konstantin Krivonogov','Samarskaya oblast\'<br>Sverdlova 14 - 99','Togliatti','','RUSSIAN FEDERATION','445039','79272167459','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 04:17:22',0,NULL,3,0,2,1,NULL,'konstk_2009\r\\'),(1082,764614838012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',69.9,'eastar4','qebex','jazzaddict@gmail.com','CHENG PENG YU','16/170 High Street','Northcote','Victoria','AUSTRALIA','3070','0433641085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 04:17:22',0,NULL,3,1,3,1,NULL,'qebex\rWWOT002\rRA117710418CN\r\r'),(1083,764623557012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',3,'SCLO002',16.5,'eastar4','vjreeves1','vernon.reeves@att.net','Vernon Reeves','910 Willow Brook Dr','Allen','TX','UNITED STATES','75002-2317','(214) 240-6088','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 05:00:24',0,NULL,3,0,1,1,NULL,'vjreeves1\r\\'),(1084,566789790013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','luckyluckyoye','rattan3000@gmail.com','Jagdeep Rattan','28 Giraffe Ave.','Brampton','ON','CANADA','L6R1Y9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 06:22:15',0,NULL,3,0,2,1,NULL,'luckyluckyoye\r\\'),(1085,764642857012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','demaupassant','jbiggs@userealsugar.com','Josh Biggs','2901 McIntosh Dr','Longmont','CO','UNITED STATES','80503','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 06:39:24',0,NULL,3,1,1,1,NULL,'demaupassant\r美标\r\\'),(1086,764643534012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','2009firebull77','agsanchez@live.com','Andrés García','monasterio de yuste n10','valladolid','Castilla y León','SPAIN','47015','667289115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 06:48:27',0,NULL,3,1,2,1,NULL,'2009firebull77\r\\'),(1087,566791731013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',12.88,'eastar4','grayeagle097','grayeagle@rnsmte.com','Bill Davis','234 FR 512','Young','AZ','UNITED STATES','85554','(928) 462-3886','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 06:48:49',0,NULL,3,1,1,1,NULL,'grayeagle097\r华硕 8pin 1.0 6cm\r\\'),(1088,566800380013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','ericlansky','erickamsky@gmail.com','Eric Vladimirsky','2700 Cahuenga Blvd E<br>Apt 3109','Los Angeles','CA','UNITED STATES','90068-2103','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 07:34:43',0,NULL,3,1,1,1,NULL,'ericlansky\r\\'),(1089,759216196012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','bachta_cz','jbachtik@seznam.cz','Stepan Bachtik','Jircharska 46','Zelezny Brod','','CZECH REPUBLIC','46822','+420775706593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 08:46:42',0,NULL,3,1,2,1,NULL,'bachta_cz\\'),(1090,688176554011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',14.49,'eastar4','petobalazs1975','petobalazs@citromail.hu','Balazs Petö','Forggensee str. 78','Schwangau','','GERMANY','87645','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 09:15:58',0,NULL,3,0,2,1,NULL,'petobalazs1975\racer 4pin1.25 15cm\\ '),(1091,566818309013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','tooqayer','mulenkov@gmail.com','Il\'ya Mulenkov','10 Grodnenskaya Str. App.20','Moscow','RU','RUSSIAN FEDERATION','121471','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 09:26:59',0,NULL,3,1,2,1,NULL,'tooqayer\\'),(1092,688186219011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jeff3yan3','jeff3yan@gmail.com','Jeffrey Yan','50 Wilmay avenue<br>Papatoetoe','Auckland','','NEW ZEALAND','2025','+64211589611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 09:54:59',0,NULL,3,1,2,1,NULL,'jeff3yan3\r\\'),(1093,688193629011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','peccator1988','peccatorr@gmail.com','Сергей Кузнецов','ул. Стельмаха, дом №40<br>Stelmaha street, house № 40','Одесса','','UKRAINE','65006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 10:25:05',0,NULL,3,1,2,1,NULL,'peccator1988\r\\'),(1094,764705830012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',10,'HSMO011',99.9,'eastar4','nanjopas','pgarceau@sogetel.net','Pascal Garceau- Dist Toiture Mauricienne','555 St-Malo','Trois-Rivieres','QC','CANADA','G8V 0A8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 10:53:08',0,NULL,3,1,3,1,NULL,'nanjopas\rHSMO011\rRA117710554CN\r、'),(1095,688206684011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','celery_crunch','bluecontour@gmail.com','Joy H.','26 Raymond St<br>Eastwood','Sydney','New South Wales','AUSTRALIA','2122','0298763214','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 11:11:58',0,NULL,3,1,2,1,NULL,'celery_crunch\r\\'),(1096,688207187011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','erik_fra_oslo','erikjahren1@hotmail.com','Erik Jahren','Hallings Gate 5','Oslo','','NORWAY','0170','004797041597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 11:13:29',0,NULL,3,1,2,1,NULL,'erik_fra_oslo\r\\'),(1097,764714227012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','kittychow','sonshines14@gmail.com','Shirley Ann Loomis','5729 Main St<br># 181','Springfield','OR','UNITED STATES','97478-5426','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 11:22:45',0,NULL,3,1,1,1,NULL,'kittychow\r、'),(1098,515606422003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',3,'HSPL005',40.74,'cnfaner','*****power','huseyincelik-25@hotmail.com','MERYEM ÇELİK','NAMIK KEMAL MAH.CENGIZ TOPEL CD<br>TURBEDAR SOKAK.NO:12-3','ÜMRANİYE-STANBUL','','TURKEY','34765','5359872000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 11:26:59',0,NULL,3,1,3,1,NULL,'*****power\r欧标\rHSPL005\rRA117710642CN\r\\'),(1099,521423929004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',2,'HSPL001',23.76,'cnfaner','imranabid2010','imranabids@yahoo.com','imranabid safi','84 frank towell court,<br>glebelands road','london','Middlesex','UNITED KINGDOM','tw14 9bw','07946853716','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:05:50',0,NULL,3,1,3,1,NULL,'imranabid2010\rHSPL001\rRA117710625CN\r\\'),(1100,688219663011,320618271608,'New 3.0 Bluetooth Module BCM92070MD+cable  HP CQ42  G42',1,'BTHP3001',29.99,'eastar4','germanskynet','german-skynet@bk.ru','German Shramov','9/22, Gogol str.','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49044','+380674097000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:15:55',0,NULL,3,1,2,1,NULL,'germanskynet\rHP 5pin1.0 20cm\r\\'),(1101,688226547011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','kubik106','nosleeep@gmail.com','Jakub Nespala','AGEM Computers s.r.o.<br>Panonska 42','Bratislava','','SLOVAK REPUBLIC','85101','00421903850370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:18:52',0,NULL,3,1,2,1,NULL,'kubik106\r\\'),(1102,566863518013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','modestadt2010','ted.gaier@gmx.de','Karsten Etz','Karolinger Str. 23','Düsseldorf','','GERMANY','40223','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 13:08:42',0,NULL,3,1,2,1,NULL,'modestadt2010\r\\'),(1103,764758376012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','madmax71470','cralling@thework-shop.com','Craig Alling','22 Sherwood Ave','Derby','CT','UNITED STATES','06418','(203) 732-1055','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 13:34:01',0,NULL,3,1,1,1,NULL,'madmax71470\r、'),(1104,688266167011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',4,'RELO002',51.96,'eastar4','crayon1226','peteryick@hotmail.com ','Peter Yick','76 Windsor Ave<br>Croydon Park','Sydney','New South Wales','AUSTRALIA','2133','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 14:27:15',0,NULL,3,1,3,1,NULL,'crayon1226\rRELO002\rRA117710639CN\r\\'),(1105,521455756004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'cnfaner','jjrbvba','info@jjr.be','John Vande Kerckhove','Wespelaarsebaan 126B','Boortmeerbeek','','BELGIUM','3190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 14:31:14',0,NULL,3,1,3,1,NULL,'jjrbvba\rANYA001\rRA117713136CN\r\\'),(1106,566893299013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','mlo2012','tu_padre_yo_2009@hotmail.com','Mario Lopez','137 Shirley ave<br>Apt 2','Revere','MA','UNITED STATES','02151-3240','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 15:05:22',0,NULL,3,1,1,1,NULL,'mlo2012\racer 4pin1.25 15cm\r、'),(1107,688278411011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','yerachmiel70','neal.fridman@gmail.com','Neal Fridman','4602 Beaconsfield Ct','Toledo','OH','UNITED STATES','43623-3205','(419) 407-7607','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 14:55:25',0,NULL,3,1,1,1,NULL,'yerachmiel70\rapple USB 猫 旧 2针 旧的\r\\'),(1108,521472872004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','jaggapan2533','juggapanke@gmail.com','jaggapan panyosaranya','59/269 Moo. 16 Srinakarin Road,<br>Tombon Bangkaew','Bangplee','Samutprakan','THAILAND','10540','(66)817507855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 15:32:56',0,NULL,8,1,17,0,NULL,'jaggapan2533'),(1109,521475709004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','jaggapan2533','juggapanke@gmail.com','jaggapan panyosaranya','59/269 Moo. 16 Srinakarin Road,<br>Tombon Bangkaew','Bangplee','Samutprakan','THAILAND','10540','(66)817507855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 15:43:32',0,NULL,8,1,17,0,NULL,'jaggapan2533'),(1110,521476388004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','jaggapan2533','juggapanke@gmail.com','jaggapan panyosaranya','59/269 Moo. 16 Srinakarin Road,<br>Tombon Bangkaew','Bangplee','Samutprakan','THAILAND','10540','(66)817507855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 15:45:33',0,NULL,3,1,3,1,NULL,'jaggapan2533\r再发两个New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET\rHSPL011+HSPL001*2\rRA117710611CN\r\\'),(1111,764813769012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','tigerwgn','jballenger@hkaa.com','John Ballenger','PO Box 860<br>337 Spartangreen Blvd.','Duncan','SC','UNITED STATES','29334','(864) 617-1412','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 15:52:05',0,NULL,3,1,1,1,NULL,'tigerwgn\r、'),(1112,521477061004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','conniejesse','connie_rodriguez79@yahoo.com','Connie Rodriguez','20101 Hamilton Ave<br>Ste 200','Torrance','CA','UNITED STATES','90502-1371','(310) 800-9251','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 15:52:55',0,NULL,8,1,17,0,NULL,'conniejesse'),(1113,515672242003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','barujy','barujcohen@gmail.com','Baruch Cohen','Harav Uziel 9/7<br>Bait Vagan','Jerusalem','DC','ISRAEL','96423','972-54-7893198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 16:10:09',0,NULL,3,1,3,1,NULL,'barujy\rHSPL005\rRA117710483CN\r\\'),(1114,686316975011,320676244896,'New Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','paul-567','paul_saper@hotmail.com','Paul Saper','Osloer Straße 5','Köln','','GERMANY','50765','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 16:27:18',0,NULL,3,1,2,1,NULL,'paul-567\r\\'),(1115,521510676004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','nenadprenenad','nenadpre@gmail.com','Nenad Preradovic','Dolgovaske gorice 242 a','Lendava','','SLOVENIA','9220','0038640818531','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 17:40:18',0,NULL,3,0,3,1,NULL,'nenadprenenad\rOTCR001\rRA117710545CN\r、'),(1116,521516296004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','conniejesse','connie_rodriguez79@yahoo.com','Connie Rodriguez','20101 Hamilton Ave<br>Ste 200','Torrance','CA','UNITED STATES','90502-1371','(310) 800-9251','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 17:57:02',0,NULL,3,1,1,1,NULL,'conniejesse\r一共买了两个\r\\'),(1117,764898498012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','mattbakerdesigns','mattbakerdesigns@hotmail.com','matt baker','2837 NW 6th Ter','cape coral','FL','UNITED STATES','33993','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 18:32:35',0,NULL,3,1,1,1,NULL,'mattbakerdesigns\r、'),(1118,764902326012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','tocutenva09','tocutenva@aol.com','CRYSTAL SIMMONS','751 BRAKE RD','ELLISTON','VA','UNITED STATES','24087-4429','(540) 588-4423','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 18:39:31',0,NULL,3,1,1,1,NULL,'tocutenva09\r、'),(1119,521463920004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','danielandkristitoms1002','danielandkristitoms@yahoo.com','Kristi Toms','409 Jey Dr','Elizabethtown','KY','UNITED STATES','42701-4207','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 18:45:16',0,NULL,3,1,1,1,NULL,'danielandkristitoms1002\r、'),(1120,521542486004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','bradleys112200','angel@inn-serve.com','Angel Bradley','512 22nd Ave<br>Citizens National Bank Building Ste 513','Meridian','MS','UNITED STATES','39301-5800','(601) 686-0208','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 19:05:31',0,NULL,3,1,1,1,NULL,'bradleys112200\r、'),(1121,688405444011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','robantsto','robstorino@yahoo.com','Robert Storino','19121 Allison Square','West Windsor','NJ','UNITED STATES','08550','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 19:19:56',0,NULL,3,1,1,1,NULL,'robantsto\r、'),(1122,764944947012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','music4ever22','unlcornhusker4life@yahoo.com','Erica Bell','13091 Potter st','omaha','NE','UNITED STATES','68142-1528','(402) 502-5205','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 19:43:59',0,NULL,3,1,1,1,NULL,'music4ever22'),(1123,764949750012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','gerard3380','gerard_lynott@hotmail.com','Gerard Lynott','15084 Jupiter Hills Ln','Haymarket','VA','UNITED STATES','20169-3133','(703) 472-8269','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 19:52:28',0,NULL,3,1,1,1,NULL,'gerard3380\r、'),(1124,521562005004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','vtbog','morfar@mail.ru','Valery Bogdanov','Leninskij pr. 93-2-322','Saint-Petersburg','','RUSSIAN FEDERATION','198330','+7-911-967-18-93','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 19:53:20',0,NULL,3,1,3,1,NULL,'vtbog\r欧标   HSNO022\rRA117710537CN\r\\'),(1125,764955356012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','caja7558','caja7558@aol.com','RICHARD FAYSON','29 E Constitution Dr','SMYRNA','DE','UNITED STATES','19977-4061','(302) 494-0144','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 19:59:51',0,NULL,3,1,1,1,NULL,'caja7558\r、'),(1126,567025164013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','wasatch84103','pleo84103@yahoo.com','Paul Leo','26 Juego Rd','Santa Fe','NM','UNITED STATES','87508-4298','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 21:00:12',0,NULL,3,1,1,1,NULL,'wasatch84103\r、'),(1127,567036636013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','ni_mohr','kiar_mohr@ukr.net','Oleksiy Onyshchenko','27, Kopernyka str., ap. 22','Kyiv','','UKRAINE','04116','+380 (50) 4499092','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 21:33:22',0,NULL,3,1,2,1,NULL,'ni_mohr\r\\'),(1128,765011255012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','vasileioslos','bacilis_los@hotmail.com','VASILIS LOS','IOUSTINIANI 40','chios','CHIOS','GREECE','82100','00302271029707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-30 21:36:50',0,NULL,3,1,2,1,NULL,'vasileioslos\r欧标\r\\'),(1129,688483915011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',8,'CASS003',69.6,'eastar4','m660xyg','huwdw@hotmail.com','Mr Huw Watkins','Old Post Office<br>LLangawsai','Aberystwyth','Ceredigion','UNITED KINGDOM','sy231HD','01970627769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 21:44:59',0,NULL,3,1,3,1,NULL,'m660xyg\rCASS003\rRA117710656CN\r\\'),(1130,765027572012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','csl-racer','csl-racer@gmx.de','Eric Tierling','In der Meffert 37','Leichlingen','','GERMANY','42799','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 22:13:12',0,NULL,3,1,2,1,NULL,'csl-racer\r欧标\r\\'),(1131,684176622011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','jfbimkiii','jfbimkiii@hotmail.com','JF Bienvenu','2190 Gertrude','Carignan','QC','CANADA','j3l4h1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 22:16:58',0,NULL,3,1,2,1,NULL,'jfbimkiii\r\\'),(1132,567049766013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','ahmed873','abdel._@msn.com','Abdelhak Hamrioui','De Terp 19','Veenendaal','Utrecht','NETHERLANDS','3905AK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 22:19:57',0,NULL,3,1,2,1,NULL,'ahmed873\racer 4pin1.25 15cm\r\\'),(1133,765029799012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',12.5,'eastar4','jjjmac75','jjjmac75@aol.com','James J McGuire','1923 Limestone Dr','Hummelstown','PA','UNITED STATES','17036-7073','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 22:33:11',0,NULL,3,1,1,1,NULL,'jjjmac75\racer 6pin1.25 23cm \r、'),(1134,567060058013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',21.98,'eastar4','ranbito26','ranbito26@yahoo.com','Arsenia','304 Smith st','New BedFord','MA','UNITED STATES','02740','(508) 525-2636','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 23:08:37',0,NULL,3,1,1,1,NULL,'ranbito26\r、'),(1135,765050338012,220546768421,'1000000000000000% New Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','revkelley','revkelley1@yahoo.com','Adam Kelley','261 Parker Farms Rd','wallingford','CT','UNITED STATES','06492-2858','(203) 823-3969','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 23:20:47',0,NULL,3,1,1,1,NULL,'revkelley\r、'),(1136,567073697013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','phaoost','phaoost@gmail.com','Yevgeny Kosarzhevsky','111-41, vul. Lynkova','Minsk','N/A','BELARUS','220124','+375296700352','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 00:05:40',0,NULL,3,1,2,1,NULL,'phaoost\r\\'),(1137,521636433004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','sssei2000','stevearhino@hotmail.com','Steve Lush','485 Grays rd. unit B','hamilton','ON','CANADA','L8E 2Z5','(905) 296-5834','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 00:34:03',0,NULL,3,1,3,1,NULL,'sssei2000\rBALO007\rRA117710523CN\r\\'),(1138,521638684004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','087kappen','aljamol@rocketmail.com','SOPHY KURIAKOSE','APPT-61,MERRION VILLAGE<br>MERRION ROAD','BALLSBRIDGE','DUBLIN','IRELAND','4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 00:40:17',0,NULL,5,0,18,1,NULL,'087kappen\rHSNO017   英标  HSNO017\r黑色的  '),(1139,688549224011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','toxskitz1988','timlarsen@iprimus.com.au','Tim Larsen','3 Harman Close, Doncaster East','Melbourne','Victoria','AUSTRALIA','3109','0398464421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 01:21:41',0,NULL,3,1,2,1,NULL,'toxskitz1988\r\\'),(1140,688552036011,320441946859,'2.1 HP TX2500 TX2500z TX2z Bluetooth Module EDR+cable',1,'BTHP2112',12.8,'eastar4','xbadboy17','nigga4ever17@msn.com','marco duarte','newcomen rd<br>140','Bedworth','West Midlands','UNITED KINGDOM','CV12 0ep','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 01:30:21',0,NULL,3,1,2,1,NULL,'xbadboy17\rHP 8pin 0.8 3cm\r\\'),(1141,567092721013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','sbeivides','beividesb@yahoo.com','Benjamin Beivides','11907 Lesser St','Norwalk','CA','UNITED STATES','90650-4052','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 01:36:48',0,NULL,3,1,1,1,NULL,'sbeivides\r、'),(1142,763538924012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','patg999','patg999@hotmail.com','Patrice Gagné','100 pie xii','chicoutimi','QC','CANADA','g7g 5h1','(418) 696-9550','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 02:25:16',0,NULL,3,0,3,1,NULL,'patg999\rRA117710608CN\r\\'),(1143,567107505013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','swoosh1392','swoosh1325@yahoo.com','Kim Bussey','6415 Buckhead Ct','wesley chapel','FL','UNITED STATES','33545','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 02:41:44',0,NULL,3,1,1,1,NULL,'swoosh1392\r、'),(1144,567107694013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','applejpapple','691599206@qq.com','ping ji','22-1225 ouimet','montreal','QC','CANADA','h4l3p8','(514) 518-8876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 02:44:28',0,NULL,3,1,2,1,NULL,'applejpapple\r\\'),(1145,765126533012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',50.3,'eastar4','v.nowords','vkrylov@gmail.com','Volodymyr Krylov','#400-1632 Dickson Avenue','Kelowna','BC','CANADA','V1Y 7T2','(250) 859-9217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 03:51:10',0,NULL,3,1,3,1,NULL,'v.nowords\rWLIN012\rRA117710497CN\r\\'),(1146,688588720011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','chrissena','chris_sena87@hotmail.com','Christopher Sena','1F2<br>12 Antigua Street','Edinburgh','City of Edinburgh','UNITED KINGDOM','EH1 3NH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 04:05:30',0,NULL,3,1,2,1,NULL,'chrissena\r\\'),(1147,567129875013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','yan011','yanivr@012.net','yaniv ramon','ehad haam 138/5','TEL AVIV','','ISRAEL','64253','+97256333521','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 05:11:10',0,NULL,3,1,3,1,NULL,'yan011\rMOSA002\rRA117710470CN\r、'),(1148,688601221011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','preetdhillon84','ebay84@ymail.com','Preet Dhillon','78 McMahon Road','Reservoir','Victoria','AUSTRALIA','3073','0394021775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 05:15:34',0,NULL,3,1,2,1,NULL,'preetdhillon84\r澳标\r\\'),(1149,688612059011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.8,'eastar4','gospodin','gregs_mail@cox.net','Gregory S Davis','8617 E PIERCE ST','SCOTTSDALE','AZ','UNITED STATES','85257','(480) 941-9022','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 06:19:46',0,NULL,3,1,1,1,NULL,'gospodin\racer 4pin1.25 6cm\rLK035216515CN\r、'),(1150,765166337012,220501825899,'2.1 Acer Aspire 4720 4720G 4720Z Bluetooth Module+cable',1,'BTAC2115',12.8,'eastar4','evgeniy_simonov','seanet1@yandex.ru','Evgeniy Simonov','Morskaya nab. 35-3-17','Sankt-Petersburg','Sankt-Petersburg','RUSSIAN FEDERATION','199155','(931)2933748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 07:17:06',0,NULL,3,1,2,1,NULL,'evgeniy_simonov\racer 5pin1.25 20cm \r\\'),(1151,567148266013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','cdaccuphasee','cdaccuphase@yahoo.com.vn','Chau Sang Kinh','685/30/63 Xo Viet Nghe Tinh P26 Binh thanh','Ho chi minh','Ho chi minh','VIET NAM','70000','+84908196044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 07:35:17',0,NULL,3,1,2,1,NULL,'cdaccuphasee\r\\'),(1152,521359148004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',44.98,'cnfaner','khoidt','doantrankhoi@gmail.com','Khoi Doan Tran','P701-702 Tungshing Square, 02 Ngo Quyen str.','Hanoi','Hanoi','VIET NAM','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 07:41:56',0,NULL,3,1,3,1,NULL,'khoidt\rRA117713119CN\r\\ '),(1153,515898290003,130490963194,'Intel 5300 AGN MIMO half size Mini PCI-E Card+tyco ante',5,'WLIN009+ANTY002',114.75,'cnfaner','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 08:28:59',0,NULL,3,1,3,1,NULL,'saiajin77\rWLIN009+ANTY002\rRA117710687CN\r\\'),(1154,765185708012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',5,'ANTY001*3',17.9,'eastar4','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 08:43:40',0,NULL,3,0,2,1,NULL,'saiajin77\r\\'),(1155,688642912011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','joelskitchen7120joel','joelskitchen71@yahoo.com','Joel Manriquez','21 Hazel Park Terrace<br>08-12 Hazel Park Condominium','default','','SINGAPORE','678946','+65 9858 6695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 08:58:26',0,NULL,3,1,2,1,NULL,'joelskitchen7120joel\r\\'),(1156,567164579013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','arnepors84','arnepors@vip.cybercity.dk','Visma - Arne Pors','Hørkær 26','Herlev','','DENMARK','2730','004528518364','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 09:20:31',0,NULL,3,1,3,1,NULL,'arnepors84\rMOSA002\rRA117710695CN\r\\'),(1157,688653734011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','2010logan1700','okurylyshyn@gmail.com','Oleh Kurylyshyn','Oleny Stepanyvny str. 33/16','Lviv','','UKRAINE','79016','+380936746204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 09:38:45',0,NULL,3,1,2,1,NULL,'2010logan1700\r欧标\r\\'),(1158,765201538012,220705174844,'New  Motorola H500 Bluetooth Wireless Headset pink',3,'HSMO006',27.78,'eastar4uk','spacestar8811','i.72.j@wp.pl','JOLA JAROS','88 PANCROFT','ABRIDGE,ROMFORD','Essex','UNITED KINGDOM','RM4 1DA','07916611568','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-31 09:45:59',0,NULL,3,1,3,1,NULL,'spacestar8811\r英标   HSMO006\rRA117713989CN\r\\'),(1159,688652202011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','cngdnh','cngdnh@gmail.com','Cuong Dinh','USS MASON DDG-87<br>SUPPLY DEPARTMENT','FPO','AE','AA','09578-1302','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 09:50:11',0,NULL,3,1,1,1,NULL,'cngdnh\r、'),(1160,765207686012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',16.5,'eastar4','kobicna','kobicna@gmail.com','kobi cnaany','300 Antibes Drive,<br>1511 apartment','toronto','ON','CANADA','M2R 3N8','(972) 508-6586 ext.: 85','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:09:45',0,NULL,3,1,2,1,NULL,'kobicna\r再发一个罗技CRADLE   旧的\r\\'),(1162,765218659012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','dearos','pauldear@exemail.com.au','Paul DEAR','PO Box 2001','Dangar','New South Wales','AUSTRALIA','2309','61412112587','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:49:11',0,NULL,3,1,2,1,NULL,'dearos\r\\'),(1161,515917588003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','staskhod','stas1073@gmail.com','Stanislav Khodakovsky','Dikla,47','En Absor','South','ISRAEL','85405','+972547915995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:31:22',0,NULL,3,1,3,1,NULL,'staskhod\rHSMO011\rRA117710801CN\r\\'),(1163,765218587012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','fastfist','van.williams@swbell.net','Van V. Williams','125 W Chapel Downs Dr','Southlake','TX','UNITED STATES','76092-6109','(817) 442-8672','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 10:50:15',0,NULL,3,1,1,1,NULL,'fastfist\r、'),(1164,521730569004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','sturchikhin','tursom@gmail.com','Semen Turchikhin','Bataysky proyezd, 51, 88','Moscow','Moscow','RUSSIAN FEDERATION','109144','+79169235104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 11:00:16',0,NULL,3,1,3,1,NULL,'sturchikhin\rWLIN010+ANTY002\rRA117710660CN\r\\'),(1165,521609468004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','la_bela','attila.laszlo@iconsulting.hu','László Attila','Fehérvári út 24<br>4.em. 3.','Budapest','PEST','HUNGARY','1117','+36302315604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 12:38:06',0,NULL,3,0,3,1,NULL,'la_bela\rWLAT008\rRA117710758CN\r\\'),(1166,567213944013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',3,'CRLO002',29.7,'eastar4','ghan7513','jdh329@comcast.net','Gwen Hanuscin','1341 Bradford Ln','Bensalem','PA','UNITED STATES','19020-3845','(215) 639-6401','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 13:31:18',0,NULL,3,1,1,1,NULL,'ghan7513\r、'),(1167,521427086004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','keyvan.akrami','keyvanakrami@yahoo.com','keyvan akrami','5055 w hacienda ave<br>Unit 1017','Las Vegas','NV','UNITED STATES','89118-0324','(702) 409-2342','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'keyvan.akrami'),(1168,515961273003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','starbucksplanet','starbucksplanet@hotmail.com','ken yee','Compassvale Lane<br>Apt Blk205B #02-01 Singapore 542205','Singapore','none','SINGAPORE','542205','98180226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 14:19:12',0,NULL,3,1,3,1,NULL,'starbucksplanet\rWWSI002+ANCN001\rRA117710744CN\r\\'),(1169,521777558004,140428317924,'2.1 Acer Aspire 6930 bluetooth module we offer track#',1,'',13.99,'cnfaner','sturmlicht1','pronschke@alice-dsl.net','Peter Ronschke','Bahnhofstr. 120','Steinhagen','','GERMANY','33803','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 14:49:28',0,NULL,3,0,3,1,NULL,'sturmlicht1\racer 5pin1.25 6cm \rBTAC2113\rRA117710735CN\r\\'),(1170,0,230601700749,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',33.5,'eastar4','rodrigl69','ebay2@astormentas.com','Luis Rodrigues','R Lusiadas 131','Lisboa','','PORTUGAL','1300-369','351960000686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 14:54:21',0,NULL,3,1,3,1,NULL,'rodrigl69\rOTRA002\rRA117710727CN\r\\'),(1171,567242610013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','bet1039','bjftaz@cox.net','Betty Farmer','5956 Highway 392 W','harrison','AR','UNITED STATES','72601-6375','(870) 577-1039','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 15:25:21',0,NULL,3,1,1,1,NULL,'bet1039\r、'),(1172,765317828012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','rrhernandez02','rrhernandezii@gmail.com','Richard Hernandez','1004 Tennant St','Amarillo','TX','UNITED STATES','79104-3312','(806) 220-7693','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 15:39:33',0,NULL,3,1,1,1,NULL,'rrhernandez02\r、'),(1173,567252249013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',61.8,'eastar4','prug30','jonathan.grenier@isg.ca','Jonathan Grenier','14856 Rue Jean-Simon','Mirabel','QC','CANADA','J7N1V2','(514) 667-1432','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 15:59:10',0,NULL,3,1,3,1,NULL,'prug30\rWWSI005\rRA117710713CN\r\\'),(1174,764610379012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','selonromice','chennian.cn@gmail.com','NIAN CHEN','9309 Kittansett Dr<br>APT E','CHARLOTTE','NC','UNITED STATES','28262-7475','(704) 488-4228','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 16:55:16',0,NULL,3,1,1,1,NULL,'selonromice\r、'),(1175,765358884012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','aalj4220','aamax@stpetershigh.essex.sch.uk','AA ALJEBAIY','48 BRITANNIA ROAD<br>WARLEY','BRENTWOOD','Essex','UNITED KINGDOM','CM14 5LG','01621787863','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-31 17:15:27',0,NULL,3,1,3,1,NULL,'aalj4220\rOTCN003\r\\\rRA117710673CN\r'),(1176,567283335013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',2,'WLDL001',16.7,'eastar4','sajken704','sajken@gmail.com','Aleksandr Logvinenko','2-ой проезд Бабушкина 13','Луганск','Луганск','UKRAINE','91025','+380508533461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 17:40:15',0,NULL,3,1,2,1,NULL,'sajken704\r\\'),(1177,688823788011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','sgrnapalm','guillaumegoudreault@gmail.com','Guillaume Goudreault','825 app102 rue wolfe','Montréal','QC','CANADA','h2l5g1','(514) 572-5480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 18:04:26',0,NULL,3,1,2,1,NULL,'sgrnapalm\r\\'),(1178,516021264003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',16.75,'cnfaner','kischbrazil','kisch@bol.com.br','Altamaiel Kisch','r: Washington Luiz n° 10<br>Bairro: Labate','Lins','São Paulo','BRAZIL','16400550','551491512195','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 18:11:50',0,NULL,3,1,3,1,NULL,'kischbrazil\rHSNO005+CCNO001\r\\\rRA117710846CN\r'),(1179,516028629003,130458358283,'New  NOKIA BH-202 BLUETOOTH HEADSET +Carcharger',1,'HSNO006+CCNO001',16.95,'cnfaner','lovell-sera','lovell01@mcsnet.ca','Lovell Untereiner','Po Box 7835 Stn Main','Bonnyville','AB','CANADA','T9N 2J1','(780) 826-8919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 18:13:15',0,NULL,3,1,3,1,NULL,'lovell-sera\rHSNO006+CCNO001\rRA117710850CN\r\\'),(1180,567306831013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','2009global6','chaimmeron@gmail.com','chaim schwartz','4 Meron Dr<br>Unit 302','monroe','NY','UNITED STATES','10950-5700','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 18:42:02',0,NULL,3,1,1,1,NULL,'2009global6\r、'),(1181,567307823013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',10.99,'eastar4','aper8463','perezabraham2010@yahoo.com','Simon Perez','306 S Mclin ST','Rome','GA','UNITED STATES','30161','(706) 409-5469','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 18:46:14',0,NULL,3,1,1,1,NULL,'aper8463\r、'),(1182,688823556011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','kohcg','geoffreykoh@comcast.net','CHIKGUAN KOH','1068 Turquoise Ter','UNION CITY','CA','UNITED STATES','94587-8523','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 19:13:29',0,NULL,3,1,1,1,NULL,'kohcg\r、'),(1183,688869699011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','ogami.itto.2007','docrash@gmail.com','102910811 Andre Almeida, Sc Liquidations','612 Devine St<br>Unit Y','Columbia','SC','UNITED STATES','29201-5214','(803) 601-3204','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 19:53:30',0,NULL,3,1,1,1,NULL,'ogami.itto.2007\r、'),(1184,765459085012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',3,'CASS002',26.1,'eastar4','bolocz','bola_orisajinmi@yahoo.co.uk','akinbola orisajinmi','6 hawkins drive','grays','Essex','UNITED KINGDOM','rm16 6gg','01375481007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 20:06:46',0,NULL,3,1,2,1,NULL,'bolocz\r\\'),(1185,0,220760436654,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','jeffe503','eddysx6@hotmail.com','Jeff Eddy','6625 SW 207th Ave','Aloha','OR','UNITED STATES','97007-4140','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-31 20:18:32',0,NULL,3,1,1,1,NULL,'jeffe503\r、'),(1186,765453345012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','robnme2010','eroman@alloypolymers.com','ELIZABETH ROMAN','3310 Deepwater Terminal Rd','RICHMOND','VA','UNITED STATES','23234-1828','(804) 334-6030','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 20:31:37',0,NULL,3,1,1,1,NULL,'robnme2010\r、'),(1187,516080558003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',41.99,'cnfaner','badih234','thebigboss_badi3@hotmail.com','badih el moghrbai','al goz','sharjah','sharjah','UNITED ARAB EMIRATES','22446','0502027678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 20:35:14',0,NULL,3,0,3,1,NULL,'badih234\rHSNO019\rRA117710775CN\r\\'),(1188,516087571003,130498781630,'100% Lowepro Mini Trekker AW Photo Camera Bag Backpacks',1,'',64,'cnfaner','m_fotis','mfotis71@gmail.com','Fotis Mandalis','Saranta Ekklision 52<br>Nea Smyrni','Athens','Greece','GREECE','17124','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-31 20:53:30',0,NULL,3,0,3,1,NULL,'m_fotis\rRA117713326CN\r\\'),(1189,688922146011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.8,'eastar4','moir5345','michel-rault2@wanadoo.fr','Michel RAULT','20 rue des friches','NANTES','Pays de la Loire','FRANCE','44300','02.40.59.52.02','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 21:11:30',0,NULL,3,1,2,1,NULL,'moir5345\racer 4pin1.25 6cm\r\\'),(1190,566895112013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','snell1884','ssnell@selbys.com','steve snell','1914 North Ave W','missoula','MT','UNITED STATES','59801-5534','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 21:29:27',0,NULL,3,1,1,1,NULL,'snell1884\r\\'),(1191,516099394003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','airplusairplus1','simon.lou@genesysamerica.com','Simon Lou','5005 Cedar Oak Ter','fremont','CA','UNITED STATES','94536-6527','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 21:31:03',0,NULL,3,0,1,1,NULL,'airplusairplus1\r\\'),(1192,521912090004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','noiszl','fabio_mian@yahoo.com.br','Fábio Mian','RUA MAJOR DIOGO, 801 AP. 64<br>BELA VISTA','SAO PAULO','São Paulo','BRAZIL','01324-001','55.11.91916577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 22:10:58',0,NULL,3,1,3,1,NULL,'noiszl\rOTCR001\rRA117710761CN\r\\'),(1193,765526817012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','noirmarginal','richardcoutu@videotron.ca','richard coutu','49 des fromagers','st-basile le grand','QC','CANADA','j3n1y6','(450) 723-0532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 22:40:57',0,NULL,8,1,17,0,NULL,'noirmarginal'),(1194,765531741012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','noirmarginal','richardcoutu@videotron.ca','richard coutu','49 des fromagers','st-basile le grand','QC','CANADA','j3n1y6','(450) 723-0532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 22:43:25',0,NULL,3,1,3,1,NULL,'noirmarginal\rHSPL001+CCPL001\r一共买了两个\rRA117710789CN\r\\'),(1195,688961190011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','sytzedebok','sytze@sytzedebok.nl','Sytze de Bok','Korfakker 78','Eindhoven','','NETHERLANDS','5625 SP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 22:56:19',0,NULL,3,1,2,1,NULL,'sytzedebok\r\\'),(1196,521922516004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','xorxorxorxor','xorxorxorxorxor@gmail.com','Sangha Im','2070 University Ave<br>Apt 109','Berkeley','CA','UNITED STATES','94704-5302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 22:58:04',0,NULL,3,1,1,1,NULL,'xorxorxorxor\r、'),(1197,765540056012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.9,'eastar4','chris1eet','chris1eet@ameritech.net','Chris Miller','8016 S Pulaski Rd<br>Apt 3W','Chicago','IL','UNITED STATES','60652-2333','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 23:09:55',0,NULL,3,1,1,1,NULL,'chris1eet\r、'),(1198,688976711011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',2,'RCLO006',99.98,'eastar4','rddc1998','ramdc98@yahoo.com','Romeo De Claro','9410 Old Georgetown Rd','Bethesda','MD','UNITED STATES','20814-1722','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 23:54:30',0,NULL,3,1,1,1,NULL,'rddc1998\r、'),(1199,765560298012,220759953524,'New APPLE iMac G6  Bluetooth Wireless Keyboard',1,'KBAP003',77,'eastar4','cuico','leobruce59@hotmail.com','Leo Bruce','Bustos 2410 Dpto 504<br>Providencia','Santiago','','CHILE','999','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 00:19:21',0,NULL,3,1,3,1,NULL,'cuico\rKBAP003\rRA117713312CN\r\\'),(1200,516141974003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','user7110690g7h','julia0000@charter.net','KENDALL H. MEAD JR.','4412 CHAPPELL ST.','MOLINE','MI','UNITED STATES','49335','(616) 877-4285','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 00:54:57',0,NULL,3,1,1,1,NULL,'user7110690g7h\r、'),(1201,567423890013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',2,'HSMO006',23.8,'eastar4','9491sts','kb0nai@sbcglobal.net','steven stuckey','1541 del rosa way','sparks','NV','UNITED STATES','89434','(775) 359-0373','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 01:19:08',0,NULL,3,1,1,1,NULL,'9491sts\r、\r'),(1202,521949871004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','johannawu','johannawu@gmail.com','Johanna Wu','722 Bexley Road','West Lafayette','IN','UNITED STATES','47906','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 01:22:51',0,NULL,3,1,1,1,NULL,'johannawu\r、'),(1203,567412717013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',1,'BAZA001',75.6,'eastar4','legacytime','jon@legacytime.com','Jon Schneider','5397 Carmel Knolls Dr','San Diego','CA','UNITED STATES','92130-3207','(619) 884-6577','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 01:47:44',0,NULL,3,1,1,1,NULL,'legacytime\r、'),(1204,765599501012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','scott801','scopix@aol.com','Scott Saunders','800 Hampton Dr<br>Ste F','Venice','CA','UNITED STATES','90291-6009','(646) 298-5257','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 02:32:48',0,NULL,3,1,1,1,NULL,'scott801\r、'),(1205,765605060012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ironkun','trbetachf@gmail.com','Elon Suen','5585 Dumfries St','Vancouver','BC','CANADA','v5p3a5','(604) 739-3071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 02:50:14',0,NULL,3,1,2,1,NULL,'ironkun\r\\'),(1206,516162121003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','d.gouriou','dgouriou@videotron.ca','Josée Laberge','22 Des saules','Austin','QC','CANADA','J0B1B0','(450) 699-0575','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-01 02:55:01',0,NULL,3,1,3,1,NULL,'d.gouriou\rOTJE001\rRA117710832CN\r\\  '),(1207,567450213013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','bonsaymaker','omamiralles@gmail.com','Omar Miralles','4200 Medallion Ct<br>Apt 307','louisville','KY','UNITED STATES','40219-1669','(502) 714-3059','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 03:24:52',0,NULL,3,1,1,1,NULL,'bonsaymaker\r、'),(1208,567456473013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','quickonlinebuyer','yasir-hasan@hotmail.com','Yasir Hasan','6980 Dunnview court','Mississauga','ON','CANADA','L5N 7E4','(647) 881-4511','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 04:06:57',0,NULL,3,0,2,1,NULL,'quickonlinebuyer\r\\'),(1209,765624231012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ahmedali5439','ahmed_ali5439@yahoo.com','ahmed shuaibi','1215 Mission 66<br>vicksburg','vicksburg','MS','UNITED STATES','39183-3136','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 04:11:53',0,NULL,3,1,1,1,NULL,'ahmedali5439\r、'),(1210,689045964011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','der023va','deriter.toby@gmail.com','Toby de Riter','38 outlook drive','berwick','Victoria','AUSTRALIA','3806','0397961584','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 04:38:45',0,NULL,3,1,2,1,NULL,'der023va\r\\'),(1211,689045707011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','ziegfrid13','volga019@yahoo.com','Olga Aimanova','2107 - 5 Massey Sq','Toronto','ON','CANADA','M4C 5L6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 04:42:18',0,NULL,3,1,2,1,NULL,'ziegfrid13\r\\'),(1212,689066744011,320519280803,'New Altec Lansing T612 Multimedia Speaker System',1,'SPAL002',180,'eastar4','sboo6712','steveski_@hotmail.com','Steven Paul Boomsma','61 Scorpio Drive<br>Mckail','Albany','Western Australia','AUSTRALIA','6330','0439953423','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-01 06:39:20',0,NULL,3,1,4,1,NULL,'sboo6712\rSPAL002\rYW864488631CN\r'),(1213,567485446013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','tipmen999','wts32@msstate.edu','Demetri Pappas','1144 Glasgow Cv','Starkville','MS','UNITED STATES','39759-7135','(662) 322-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 07:50:47',0,NULL,3,1,1,1,NULL,'tipmen999\r\\'),(1214,689088484011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',2,'HSNO017',37.8,'eastar4','zelduh','hope@business-affairs.tv','M. Hope Aguilar','10515 Woodbine St','Los Angeles','CA','UNITED STATES','90034','(310) 496-6525','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-01 08:28:02',0,NULL,3,1,1,1,NULL,'zelduh\r\\'),(1215,765691841012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','zima78-1','sasha_lena@bk.ru','Святослав Иванов','Аллея Поликарпова д. 5 кв.556','Санкт Петербург','','RUSSIAN FEDERATION','197341','+79213067864','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 09:46:55',0,NULL,3,1,2,1,NULL,'zima78-1\r欧标\r\\'),(1216,689112993011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','lucianomario47','lisarowmountaineering@yahoo.com','Lou Zamberlan','31 Ourimbah Street','LISAROW','New South Wales','AUSTRALIA','2250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 10:11:54',0,NULL,3,1,3,1,NULL,'lucianomario47\rWLAP009\rRA117710863CN\r\\'),(1217,689119485011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','fbarini','fabianobarini@hotmail.com','Fabiano Barini','Av. Rio Branco, 217 / 227','Franca ','Sao Paulo','BRAZIL','14405-080','(16) 3721-1654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 10:38:40',0,NULL,3,1,2,1,NULL,'fbarini\r\\'),(1218,567532153013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',9.8,'eastar4','dactasam','evgeny@samoyloff.net','Evgeny Samoylov','Startovaya 3 - 57','Novosibirsk','','RUSSIAN FEDERATION','630073','79133777076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 12:19:40',0,NULL,3,1,2,1,NULL,'dactasam\r\\'),(1219,689153176011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','andrewc1957','info@architype.biz','Andrew Cronin','Unit 11, 155 Mt Alexander Road','Flemington','Victoria','AUSTRALIA','3031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 12:38:47',0,NULL,3,1,2,1,NULL,'andrewc1957\r\\'),(1220,689171554011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','asica1111','fredconstruction@yahoo.com','Magdalena Sobczak','630 Arlene Dr','Wood Dale','IL','UNITED STATES','60191-1704','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 13:37:09',0,NULL,3,1,1,1,NULL,'asica1111\racer 8pin1.00 8cm \r\\'),(1221,522074305004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','royiz-972','royi.zigler@gmail.com','Royi Zigler','Royi Zigler, Broadcom<br>Dune Networks, Industial park','Yakum','','ISRAEL','60972','(972) 52-337440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 14:18:45',0,NULL,3,1,3,1,NULL,'royiz-972\rHSMO007\rRA117710877CN\r\\'),(1222,689188788011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','the.aquitaine','the.aquitaine@yahoo.com','Jimmy McCelvey','1840 County Road 4545','Kennard','TX','UNITED STATES','75847','(972) 207-3924','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 14:40:35',0,NULL,3,1,1,1,NULL,'the.aquitaine\r\\'),(1223,765788300012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','woosle97','amos0@hotmail.com','Amos Park','9946 Keele St.','Maple','ON','CANADA','L6A 3Y4','(416) 937-3312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 14:53:40',0,NULL,3,1,2,1,NULL,'woosle97\r\\'),(1224,689205050011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jerry.vos','jerry.vos@gmail.com','Richie Vos','1000 N Lasalle Blvd, Apt 310','Chicago','IL','UNITED STATES','60610','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 15:20:00',0,NULL,3,1,1,1,NULL,'jerry.vos\r\\'),(1225,765814505012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','bayern.hymne','bayern.hymne@gmx.de','Ulrich Kern','Lindenstrasse 82','Holzkirchen','','GERMANY','83607','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 15:56:47',0,NULL,3,1,2,1,NULL,'bayern.hymne\r\\'),(1226,567584734013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','lucaternes','lucatern@hotmail.com','luis carlos ternes','capitao cruz - 2319','montenegro','rio grande do sul','BRAZIL','95780-000','55 51 3632-2790','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 15:56:54',0,NULL,3,1,2,1,NULL,'lucaternes\r\\'),(1227,765820586012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',15,'eastar4uk','d13ark','deanobarker@hotmail.com','Dean Barker','10 Farm Close','Crowthorne','Berkshire','UNITED KINGDOM','RG45 6SE','01344775006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-01 16:12:27',0,NULL,3,1,3,1,NULL,'d13ark\r英标\rHSMO017\rRA117710996CN\r\\'),(1228,516300347003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',83.99,'cnfaner','antti_ast','anttiast@gmail.com','Antti Åström','Norkkotie 1 G 23','Oulu','Pohjois-Pohjanmaa','FINLAND','90540','+358456717700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 16:20:03',0,NULL,3,1,3,1,NULL,'antti_ast\rWWOT003\rRA117710885CN\r\\'),(1229,765826961012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','popsoul89','lilken601@hotmail.com','Kenneth McLaurin','510 N 38th Ave<br>Apt 39','Hattiesburg','MS','UNITED STATES','39401-5727','(601) 323-1853','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 16:27:59',0,NULL,3,1,1,1,NULL,'popsoul89\r\\'),(1230,765844916012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 17:07:31',0,NULL,3,1,3,1,NULL,'avextra-co-uk\rOTCN004*10\rRA117710894CN\r\\'),(1231,0,220762610888,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',18.98,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 17:24:10',0,NULL,3,1,1,1,NULL,'4278dennis\r再发一个 罗技保护屏\r\\'),(1232,689216542011,320391125338,'New 2.0 Bluetooth Module for Gateway P-7811 7805U 7801U',1,'BTGA2001',12.5,'eastar4','atomant-124','apadgett1@nyc.rr.com','anthony padgett','30 Bush Street, Apt. 4B<br>please deliver by 1pm','Brooklyn','NY','UNITED STATES','11231','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 17:32:21',0,NULL,3,1,1,1,NULL,'atomant-124\r\\'),(1233,516341812003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','cesarcandido','cesarhc@gmail.com','Cesar Candido','Rua Julio Rodrigues Mendes, 23 apto - 32','São Paulo','São Paulo','BRAZIL','02245080','55-11-2983-4450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 18:38:20',0,NULL,3,1,3,1,NULL,'cesarcandido\rHSMO018\rRA117710903CN\r\\'),(1234,567638132013,230601299524,'New Leather Case Built-in Bluetooth Keyboard For iPad',1,'KBAP001',39.8,'eastar4','hek1185','hkluber@yahoo.com','Heidi Kluber','268 Hometown Pkwy','Kyle','TX','UNITED STATES','78640-5711','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 18:51:47',0,NULL,5,0,18,0,NULL,'hek1185'),(1235,689301980011,320402073547,'HP DV6000 DV6000t DV6000z Bluetooth Module 2.0+cable',1,'BTHP2010',12.5,'eastar4','amel1641','info@crowncitycomputer.com','Ara Melkizian','2061 N Los Robles Ave<br>Ste 206','Pasadena','CA','UNITED STATES','91104-1167','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 19:10:05',0,NULL,3,1,1,1,NULL,'amel1641\rHP 8pin 1.25 18cm \r\\'),(1236,522160537004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','chrischixxx','maackralf@wtnet.de','Ralf Maack','Rechnung<br>Poppenbütteler Str. 266a','Norderstedt','','GERMANY','22851','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 19:26:38',0,NULL,3,1,3,1,NULL,'chrischixxx\rWWSI005\rRA117710948CN\r\\'),(1237,516366445003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','jonaslemos','lemos.jonas@gmail.com','Jonas Lemos','Rua Maritin Carvalho,Number 144','Diadema','São Paulo','BRAZIL','09950-040','055-011-89633879','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 19:52:37',0,NULL,3,0,2,1,NULL,'jonaslemos\r\\'),(1238,522169302004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','angelo*andrzej','andrew1863@poczta.fm','Andrzej Tkacz','Gajowa 1/11','Częstochowa','śląskie','POLAND','42200','34 3662202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 20:13:28',0,NULL,3,1,3,1,NULL,'angelo*andrzej\rHSNO022   欧标\rRA117710925CN\r\\'),(1239,689344500011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jeremiahjdclinton','jeremiahjoshuadeanclinton@gmail.com','SirGerald Clinton','921 Old Marion Rd NE<br>Apt 121','Cedar Rapids','IA','UNITED STATES','52402-5757','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 20:34:48',0,NULL,3,1,1,1,NULL,'jeremiahjdclinton\r\\'),(1240,0,220762610770,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','alex02au','alex01au@hotmail.com','Alan Au','1 Gower St','Hurlstone Park','New South Wales','AUSTRALIA','2193','0414867689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 20:50:23',0,NULL,3,1,3,1,NULL,'alex02au\rOTRA002\rRA117710934CN\r、'),(1241,522189622004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','traderdny','dundeetrader@m-mfg.info','Javan Martin','4898 John Green Rd','Dundee','NY','UNITED STATES','14837-9422','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 20:58:46',0,NULL,3,1,1,1,NULL,'traderdny\r\\'),(1242,522202008004,140481827793,'New Plantronics Voyager 851/855 Bluetooth Headse track#',1,'HSPL009',43.9,'cnfaner','rahrig7','jakemissions@yahoo.com','Jacob Rahrig','509 W Marshall St','Marshall','MN','UNITED STATES','56258-1320','(918) 853-3738','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 21:42:39',0,NULL,3,1,1,1,NULL,'rahrig7\r\\'),(1243,0,320679119415,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6,'eastar4','bears6963','kconover66@gmail.com','Keith T. Conover','518 Lum ave','Kalamazoo','MI','UNITED STATES','49048-2139','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 21:46:29',0,NULL,3,1,1,1,NULL,'bears6963\r\\'),(1244,522207949004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','ratio1974','h_escalonag@yahoo.com','Hugo Escalona','Martin de Zamora 5695, D504<br>Las Condes','Santiago','Santiago / RM','CHILE','7580216','5623797578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 22:09:04',0,NULL,3,0,3,1,NULL,'ratio1974\rHSPL001\rRA117710829CN\r\\'),(1245,765989809012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','shctuh','hutchsuc@yahoo.com','Alvin Hutchinson','849 Leisure Land Dr','Big Cabin','OK','UNITED STATES','74332','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 22:10:43',0,NULL,3,1,1,1,NULL,'shctuh\r\\'),(1246,567707538013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',2,'HSNO022',29.8,'eastar4','tilchi','claudia.tilch@gmx.de','Claudia Tilch','Veielbrunnenweg 58','Stuttgart','','GERMANY','70372','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 22:21:31',0,NULL,3,1,2,1,NULL,'tilchi\r欧标\r\\'),(1247,766005694012,220458920723,'Acer Aspire 3810 3810T  Bluetooth Module 2.0+cable',1,'BTAC2017',12.5,'eastar4','bmelabguy','sqwong01@hotmail.com','Stan  Wong','214 Avocet Ct','Foster City','CA','UNITED STATES','94404-1424','(650) 345-8903','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 23:02:22',0,NULL,3,0,1,1,NULL,'bmelabguy\r改发acer 5pin 1.25 3cm\rAspire Timeline 1810 1410 1410T\rBTAC2010\\\r'),(1248,516425087003,130490260658,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.99,'cnfaner','happy_shopper100','magclark@telus.net','Magda Clark','52 Windermere Rd Sw','Calgary','AB','CANADA','T3C 3K5','(403) 240-0319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 23:51:29',0,NULL,3,1,3,1,NULL,'happy_shopper100\rWLAP001\rRA117710815CN\r\\'),(1249,689407122011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','otterscout','davismad1@yahoo.com','Marianne Davis','826 Elm St','El Cerrito','CA','UNITED STATES','94530-2921','(510) 525-7772','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 23:51:35',0,NULL,3,1,1,1,NULL,'otterscout\r\\\r'),(1250,522231292004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','jardel-ce','jardel_ce@hotmail.com','Jardel Magalhaes Sa / Maria Edneida','RUA VILEBALDO AGUIAR 2220<br>APT 703','Fortaleza','Ceara','BRAZIL','60190780','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 00:16:57',0,NULL,3,1,3,1,NULL,'jardel-ce\rOTCR001\rRA117710982CN\r\\'),(1251,766028878012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',5,'TRMX003',39.75,'eastar4','dreamw41','dreamw88@hotmail.com','Lee Weaver','5420 Eagle Cloud Trl<br>Apt 302','Raleigh','NC','UNITED STATES','27606-3789','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 00:25:07',0,NULL,3,1,1,1,NULL,'dreamw41\r\\'),(1252,689419339011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','katherine7562','kannelisti@gmail.com','Katherine Listi','5627 Vickery Blvd','Dallas','TX','UNITED STATES','75206-6234','(214) 557-7974','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 00:39:11',0,NULL,3,1,1,1,NULL,'katherine7562\r\\'),(1253,567739020013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',2,'RELO002',25.98,'eastar4','robdam1001','robdam@comcast.net','rob damiani','363 mountainside west<br>aka Main Street','farmington','CT','UNITED STATES','06032','(860) 677-0407','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 01:02:07',0,NULL,3,1,1,1,NULL,'robdam1001\r\\'),(1254,516435745003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.99,'cnfaner','vacuum_guy','stanleysystems@gmail.com','Igor Smoter','Box 57, Site 228, RR2','Dryden','ON','CANADA','P8N 2Y5','(807) 755-1654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 01:04:48',0,NULL,3,1,3,1,NULL,'vacuum_guy\rPOLO001\rRA117711002CN\r\\'),(1255,689425427011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','alvoonline','josealves2010@gmail.com','José Alves de Andrade Filho','Rua Praia de Boa Viagem, 2245<br>Ponta Negra','Natal','RN','BRAZIL','59094-320','+55 84 8816 2705','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 01:08:00',0,NULL,3,1,2,1,NULL,'alvoonline\r\\'),(1256,567752119013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','rphbeach','rphbeach@msn.com','Russell  Hayman','10118 North Ave','Ocean City','MD','UNITED STATES','21842-9708','(410) 213-1948','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 02:12:37',0,NULL,3,1,1,1,NULL,'rphbeach\r\\'),(1257,522249163004,140481827924,'New Plantronics Explorer 220 BLUETOOTH HEADSE+carcharge',1,'HSPL001+CCPL001',15.88,'cnfaner','divine_1','divine_bb@yahoo.com','Adebayo Majolagbe','2807 Coronella Ct','Upper Marlboro','MD','UNITED STATES','20774','(240) 481-8787','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 02:17:29',0,NULL,3,1,1,1,NULL,'divine_1\r\\'),(1258,766053669012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','10001th_maniac','alexeisenhut@gmail.com','Alex Eisenhut','450 St-Pierre<br>suite 300','Montreal','QC','CANADA','H2Y2M9','(514) 284-5252 ext.: 37','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 02:21:12',0,NULL,3,1,2,1,NULL,'10001th_maniac\r\\'),(1259,516449581003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','skyking5431josh','skyking5431@yahoo.com','Josh King','14239 N Lewis Rd','Clio','MI','UNITED STATES','48420-8837','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 02:27:00',0,NULL,3,1,1,1,NULL,'skyking5431josh\r\\'),(1260,567735149013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.99,'eastar4','caye416','carl_md@hotmail.com','Carlito B. Sta.Ana','12 Inocencia st., tugatog','Malabon City','METRO MANILA','PHILIPPINES','1470','639944887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 03:40:26',0,NULL,3,1,2,1,NULL,'caye416\r\\'),(1261,567767113013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','globalbuyer','mrinal@hotmail.co.uk','Mrinal Kumar','Jetset Journeys Pvt. Ltd., D-82 Amar Colony (Basement)<br>Lajpat Nagar IV','New Delhi','Delhi','INDIA','110024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 03:47:09',0,NULL,3,1,2,1,NULL,'globalbuyer\r\\'),(1262,689459634011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',12.8,'eastar4','ctajiuh','vovka8686@mail.ru','Vladimir Ahryukov','st. Archedinskaya, 50','Frolovo','Volgograd Region','RUSSIAN FEDERATION','403531','(917)725-8710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 03:55:23',0,NULL,3,1,2,1,NULL,'ctajiuh\racer 8pin1.00 15cm\r\\'),(1263,522265909004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','i699045','imustapha@hotmail.com','ibrahim Mustapha','12143 rue l\'archeveque','montreal','QC','CANADA','h1h3c2','(514) 582-2829','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 04:07:42',0,NULL,3,1,3,1,NULL,'i699045\rHSPL001\rRA117710979CN\r\\'),(1264,567776797013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','franksagid','frank_sagid@hotmail.com','Frank Feijoo','Sector Quitumbe calle Amauta lote 13 y calle 5','Quito','Pichincha','ECUADOR','EC170146','593 22677 842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 05:03:44',0,NULL,3,1,2,1,NULL,'franksagid\r\\'),(1265,766096292012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','skovgard3','chrisskovgard@gmail.com','Chris Skovgard','1 Grand Ave<br>Santa Lucia 235','San Luis Obispo','CA','UNITED STATES','93407-9000','(562) 355-7367','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 05:40:27',0,NULL,3,1,1,1,NULL,'skovgard3\r\\'),(1266,567784608013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','morejesper','morejesse@gmail.com','Jesse More','814 Johns Close','Edmonton','AB','CANADA','T6L6P2','(780) 884-3345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 06:09:54',0,NULL,3,1,2,1,NULL,'morejesper\r\\'),(1267,689486593011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','lui_0209','lui_0209@yahoo.com.sg','Lui Kwok Heng','Blk 239 Compassvale Walk #10-562','Singapore','Singapore','SINGAPORE','540239','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 06:42:36',0,NULL,3,1,11,1,NULL,'lui_0209\r、'),(1268,567801026013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','zumbamel','zumbamelly@aol.com','Melanie Smith','6688 Golden Star Cv','Bartlett','TN','UNITED STATES','38134-1800','(901) 217-3115','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 08:06:48',0,NULL,3,1,1,1,NULL,'zumbamel\r\\'),(1269,766130785012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','atillaaslan09','atilla_aslan_01@hotmail.com','atilla aslan','merkez mah. erdemoglu bulvari  151/b  ERDEMLI/MERSIN','mersin','turkey','TURKEY','33740','905446693564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 08:21:29',0,NULL,3,1,2,1,NULL,'atillaaslan09\r\\'),(1270,689508919011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','shiney19','stormy19@btinternet.com','Pam Swan C/o Modern Bookbinders Limited','Pringle Street','Blackburn','Lancashire','UNITED KINGDOM','BB1 1SA','01254265483','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 08:24:22',0,NULL,3,1,3,1,NULL,'shiney19\rMOAP001\rRA117713935CN\r\\'),(1271,766179271012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','khsw_be','kenhuysmans@gmail.com','Ken Huysmans','Varenstraat 9','Moerbeke-Waas','Oost-Vlaanderen','BELGIUM','9180','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 11:20:43',0,NULL,3,1,2,1,NULL,'khsw_be\r\\'),(1272,567836794013,230563830400,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',22.99,'eastar4','vitesa','chento.ts@gmail.com','Vicente M. Terrada Sara','Avda. de Andalucia, 25','El Puerto de Santa María (Cádiz)','Andalucía Ceuta y Melilla','SPAIN','11500','630016505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 11:34:32',0,NULL,3,1,2,1,NULL,'vitesa\r\\'),(1273,766184352012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',21.9,'eastar4','ppistik6','ppistik@gmail.com','Stefan Laso','Borova 31','Zilina','SK','SLOVAK REPUBLIC','01007','0948506098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 11:37:51',0,NULL,3,1,2,1,NULL,'ppistik6\r欧标\r\\'),(1274,766188208012,220682003790,'2.1 Acer As 6530G Extensa 5235 Bluetooth Module+cable',1,'BTAC2113',12.8,'eastar4','f64098','fscheffski@sf-mail.de','Frank Scheffski','Waldheimer Straße 56','Nossen','','GERMANY','01683','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 11:50:42',0,NULL,3,1,2,1,NULL,'f64098\racer 5pin1.25 6cm\r\\'),(1275,766202028012,220713846430,'New GENUINE NOKIA HS 11W BLUETOOTH HEADSET',1,'HSNO023',9.69,'eastar4uk','miickeyy2010','meekaaeel_nawaz@hotmail.com','Miickeyy Nawaz','43 oxford road<br>acocks green','birmingham','West Midlands','UNITED KINGDOM','b276ds','01217076151','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 12:35:15',0,NULL,3,1,3,1,NULL,'miickeyy2010\rHSNO023\r英标 \rRA117711271CN\r\\'),(1276,766218632012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','ejbrent','johnbrent@live.co.uk','E.J.Brent','21, Byron Road<br>Rustington','Littlehampton','West Sussex','UNITED KINGDOM','BN16 2NZ','01903776849','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 13:24:55',0,NULL,3,1,3,1,NULL,'ejbrent\rOTCN003\rRA117711268CN\r\\'),(1277,689589459011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','huubear87','roach_knight87@hotmail.com','Huu Nguyen','66 Monks park ave,horfield','Bristol','Bristol','UNITED KINGDOM','BS70UH','01179236405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 13:25:06',0,NULL,3,1,2,1,NULL,'huubear87\r\\'),(1278,522358610004,140482633217,'New NOKIA BH-600 BLUETOOTH HEADSET+Carcharger track#',1,'HSNO016+CCNO001',21.9,'cnfaner','carlisha2','lashawnserrano@yahoo.com','carlisha serrano','1805 McClure St','Homestead','PA','UNITED STATES','15120','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 13:59:39',0,NULL,3,1,1,1,NULL,'carlisha2\r\\'),(1279,766254830012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',2,'HSMO008',21.9,'eastar4','postalbiskit','postalbiskit@aol.com','Ruben Martinez','4986 Auburn Dr<br>Apt A','San Diego','CA','UNITED STATES','92105-3643','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 15:04:19',0,NULL,3,1,1,1,NULL,'postalbiskit\r\\'),(1280,516582394003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','ranieri.nando','nando.ranieri@libero.it','BRATTA GIUSEPPE','GUIDO DORSO 30/B','BARI','BA','ITALY','70125','3387762605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 15:34:39',0,NULL,3,1,3,1,NULL,'ranieri.nando\rHSMO006\r欧标\rRA117711299CN\r\\'),(1281,766269901012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','tgilbert2112','tgilbertmm@yahoo.com','Tim Gilbert','1139 Reservoir Rd','New Holland','PA','UNITED STATES','17557-9553','(610) 563-7181','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 15:40:45',0,NULL,3,1,1,1,NULL,'tgilbert2112\r\\'),(1282,567901417013,230576095186,'Logitech MX518 MX 518 Gaming Optical USB Mouse 90% new',1,'MOLO003',32.9,'eastar4','jameslowz28','dcorbitt@neo.rr.com','James L Corbitt','3389 State Route 39','Shelby','OH','UNITED STATES','44875-9470','(567) 216-2248','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 16:04:05',0,NULL,3,1,1,1,NULL,'jameslowz28\\'),(1283,567904310013,230393146792,'2.1 Acer Aspire 6930 6530 6930G Bluetooth Module+cable',1,'BTAC2113',12.8,'eastar4','jojojox2','i__23@hotmail.com','Iván Díaz Carrera','c/ Doctor Ayela 16, 4to IZQ','Alicante','Comunidad Valenciana','SPAIN','03013','651467704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 16:13:58',0,NULL,3,1,2,1,NULL,'jojojox2\racer 5pin1.25 6cm  \r\\'),(1284,689653761011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','rafalbos','azzazz@hotmail.co.uk','Rafal Bos','118 Piggot St.','London','London','UNITED KINGDOM','E14 7DW','07871830364','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 16:24:21',0,NULL,3,1,2,1,NULL,'rafalbos\racer 8pin1.00 8cm\r\\'),(1285,766297728012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','daviddgibbons','davidgibbons1234@comcast.net','david gibbons','11009 Rosemont dr','rockville','MD','UNITED STATES','20852','(301) 231-8612','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 16:46:58',0,NULL,3,1,1,1,NULL,'daviddgibbons\r\\'),(1286,689697491011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','gremlin48230','ugottahaveit@gmail.com','Bill Youngblood','35400 Bob Hope Dr<br>Ste 109','Rancho Mirage','CA','UNITED STATES','92270','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 18:01:22',0,NULL,3,1,1,1,NULL,'gremlin48230\r\\'),(1287,689698835011,320679575677,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',25.9,'eastar4uk','behc-7','tsc.behc@gmail.com','Evgeny Chorpita','55-18 Vosstaniya str<br>+7 911 712 9060','Saint-Peterburg','RU','RUSSIAN FEDERATION','191123','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-02 18:07:17',0,NULL,3,1,3,1,NULL,'behc-7\rWWSI004\r\\\rRA117711325CN\r'),(1288,516632300003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','miqbal494','miqbal20170@yahoo.com','mohammad iqbal','518 Early Fall Ct','herndon','VA','UNITED STATES','20170-4202','(703) 435-1566','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 18:21:43',0,NULL,3,1,1,1,NULL,'miqbal494\r\\'),(1289,689741486011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',2,'UDAP001',75.98,'eastar4','gyros4free','thomas.tsiakalakis@gmail.com','Thomas Tsiakalakis','Freudenthalstraße 19','Augsburg','','GERMANY','86179','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 19:26:49',0,NULL,3,0,3,1,NULL,'gyros4free\rUDAP001   \rRA117716234CN\r\\'),(1290,567989957013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',37.2,'eastar4','477marc1','marcvanoppen@live.be','Marie-Josee Corstjens','Bergerstraat 91','Neeroeteren','','BELGIUM','3680','0477957644','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:18:29',0,NULL,3,1,3,1,NULL,'477marc1\rWWSI004+ANCN001\rRA117711342CN\r\\'),(1291,567997579013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','whitefoxwr','kuzoku@gmx.de','Andre Haberle','Koblenzer Straße 8','Braunschweig','','GERMANY','38116','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:39:56',0,NULL,3,1,2,1,NULL,'whitefoxwr\r\\'),(1292,766431368012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',12.5,'eastar4','zekezgilpin','zekezg21@gmail.com','Zeke Gilpin','2141 Patterson Mill Rd','yadkinville','NC','UNITED STATES','27055-5347','(336) 679-9105','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 21:02:13',0,NULL,3,1,1,1,NULL,'zekezgilpin\r\\'),(1293,766461600012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','lutontown1979','darran_mcevoy@yahoo.co.uk','Darran','Harveys, Portfield Retail Park<br>Portfield Way','Chichester','West Sussex','UNITED KINGDOM','PO19 7YH','07702139625','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 22:09:36',0,NULL,3,1,3,1,NULL,'lutontown1979\rOTRA002\rRA117711285CN\r\\'),(1294,766416993012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','drewchristianhill','drewhill87@ymail.com','Andrew Hill','31441 paseo riobo','San Juan capistrano','CA','UNITED STATES','92675-5524','(949) 887-7379','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 22:19:32',0,NULL,3,1,1,1,NULL,'drewchristianhill\r\\'),(1295,0,320676728747,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','garytl57','gleonard@neo.rr.com','Gary Leonard','12155 Marlboro Ave NE','Alliance','OH','UNITED STATES','44601','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-02 22:39:27',0,NULL,3,1,1,1,NULL,'garytl57\r\\'),(1296,766485600012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','kremnant','remnant@comcast.net','Karen Remolino','1831 Ludlow St','Rahway','NJ','UNITED STATES','07065','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 23:18:11',0,NULL,3,1,1,1,NULL,'kremnant\\'),(1297,766485993012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',50.3,'eastar4','nestor729','eric71911@comcast.net','Eric Hoffmann','1035 W Huron St<br>Unit 504','Chicago','IL','UNITED STATES','60642','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 23:18:59',0,NULL,3,1,1,1,NULL,'nestor729\r\\'),(1298,568058367013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','wulfy19','dave.dewulf@gmail.com','Dave Dewulf','409 Gilpin Dr','Newmarket','ON','CANADA','L3X3H3','(289) 221-5333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 00:51:34',0,NULL,3,1,3,1,NULL,'wulfy19\rRCLO003\r\rRA117716279CN\r\\'),(1299,766517102012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',4,'OTAP001',42.76,'eastar4','2011efrank','frank_brasilia@yahoo.com.br','FRANK JOSE MACHADO DA SILVA','QN 122 CONJ 01 LT 3<br>SAMAMBAIA NORTE','BRASILIA','Distrito Federal','BRAZIL','72304-101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 01:07:21',0,NULL,3,1,3,1,NULL,'2011efrank\rOTAP001\rRA117711308CN\r\\'),(1300,766536778012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','d-mashi75','mashima@xj.commufa.jp','daisuke mashima','69-7<br>yatsurugicho gou','iwakura','Aichi','JAPAN','4820031','(0587)38-2454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 02:23:24',0,NULL,3,1,3,1,NULL,'d-mashi75\rOTGR001+OTGR002\rRA117716248CN\r\\\r'),(1301,516568930003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','kakashisama25','diego_rodolfo@yahoo.com.br','Diego Freitas','Rua Bacabal, 708<br>casa 2','São José dos Campos','São Paulo','BRAZIL','12235680','551239335357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 02:35:44',0,NULL,3,1,3,1,NULL,'kakashisama25\rHSAO018\rRA117716251CN\r\\'),(1302,522559353004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','luiz_neto','luizlou@yahoo.com.br','Luiz Louzada Neto','Rua Serra da Saudade nº 347','Americana','São Paulo','BRAZIL','13470-412','19 92799259','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 03:11:38',0,NULL,3,1,3,1,NULL,'luiz_neto\rOTRA002\rRA117711210CN\r\\'),(1303,766555066012,220762109483,'New Sennheiser CX280 CX-280 In-Ear Headphones Earphones',1,'',35.99,'eastar4','ts_dante117','tsong117@hotmail.com','Hak song','2208 Haggin Oaks Blvd','Bakersfield','CA','UNITED STATES','93311-1511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 03:32:41',0,NULL,3,0,1,1,NULL,'ts_dante117\r\\'),(1304,766564942012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','gc.','gcoon@mindspring.com','George Coon','8971 Western Pines Dr','Douglasville','GA','UNITED STATES','30134-1783','(770) 949-5836','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 04:19:35',0,NULL,3,0,1,1,NULL,'gc.\\'),(1305,766563822012,220455473916,'HP DV2000 DV2100 DV2200  Bluetooth Module 2.0+ cable',1,'BTHP2003',12.5,'eastar4','meesa.velazquez','melissa.velazquez@q.com','Melissa Velazquez','4724 S 2675 W','Roy','UT','UNITED STATES','84067-1800','(801) 698-3753','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 04:58:22',0,NULL,3,1,1,1,NULL,'meesa.velazquez\rHP 8pin 1.0 12cm \r\\'),(1306,568108752013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','regismarques2009','regis_marques@hotmail.com','Reginaldo Marques de Oliveira','Rua: Icatu Nº 2030<br>Conjunto Residencial 31 de Marco','Sao Jose dos Campos','Sao Paulo','BRAZIL','12237010','55-12-91782051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 05:44:47',0,NULL,3,1,2,1,NULL,'regismarques2009\r\\'),(1307,689816191011,320411515152,'UNLOCKED Option GTM382 PCI-E 7.2Mbps Modem WWAN GTM 382',1,'WWOP003',43.95,'eastar4','horowitz_dan','horowitzdan1@gmail.com','Dan Horowitz','Heil Hayam 7','Rishon Lezion','','ISRAEL','75702','0502288425','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 05:58:45',0,NULL,3,1,3,1,NULL,'horowitz_dan\r送螺丝  WWOP003\rRA117713670CN\r\\'),(1308,689944140011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','hro-u5299','nichtschonwieder@weinenvorglueck.de','Lautenschläger','Adolf-Becker-Straße 15','Rostock','','GERMANY','18057','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 07:36:39',0,NULL,3,1,2,1,NULL,'hro-u5299\r\\'),(1309,689494580011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','chocalate.lover2011','chocolate.lover2011@hotmail.com','J A QI','1/14 Vanderbilt Avenue','Truganina','Victoria','AUSTRALIA','3029','03836087290432441316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 07:46:33',0,NULL,3,1,2,1,NULL,'chocalate.lover2011\r\\'),(1310,766627786012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',2,'WLAT009',102.73,'eastar4','huszar.adam','oregonlogos@gmail.com','Ádám Huszár','István 41','Gyöngyöstarján','Heves','HUNGARY','3036','+36204474046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 08:43:24',0,NULL,3,1,3,1,NULL,'huszar.adam\r再发一个New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card\rUnlocked\r\r 两个NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna\rWLAT009+WWSI005+ANCN001+WLAT005  \rRA117716217CN\r\\\r'),(1311,690010076011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','javel10','johan93@lyse.net','Johan Vika Waage','Nordstrandveien 65','Stavanger','vassøy','NORWAY','4076','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 10:39:09',0,NULL,3,1,2,1,NULL,'javel10\r\\'),(1312,0,230603572046,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',12.99,'eastar4','gweilo88','willquinn@fastmail.fm','Caroline Driscoll','Flat 9H, Block 5, Tung Chung Crescent<br>Tung Chung, Hong Kong','default','','HONG KONG','default','+852 94871930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 10:57:47',0,NULL,3,1,2,1,NULL,'gweilo88\r\\'),(1313,690021374011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','s.harald','ebay@eye-of-the-tiger.com','Harald   Löffler','Lenaustraße 1','Ostfildern','','GERMANY','73760','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 11:06:53',0,NULL,3,1,2,1,NULL,'s.harald\r\\'),(1314,766698900012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','toyaman','hirok@mx35.tiki.ne.jp','Hiroki Hasegawa','Kuboki 111<br>Okayama Kenritsu Daigaku, Design Gakubu','Soja-shi','Okayama','JAPAN','719-1197','(0866) 94-2067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 11:33:42',0,NULL,3,1,2,1,NULL,'toyaman\r\\'),(1315,522656600004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','022593065','eliezer.hazout@zoran.com','eliezer Hazout','Mali Yaakov Moshe 4-4 Qiryaat shmuel','Haifa','ID','ISRAEL','26385','+972-4-8418464','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 12:02:36',0,NULL,3,1,3,1,NULL,'022593065\rOMHJ001\rRA117711223CN\r\\'),(1316,766717382012,220502385280,'New 2.1 Bluetooth Module for Gateway P-7811 7805U 7801U',1,'BTGA2101',12.8,'eastar4','a.alitkin','tlkn@rambler.ru','Anatoliy Alitkin','Naberejnaya, 71','Esik','KZ','KAZAKHSTAN','040400','+7-705-184-35-27','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 12:17:27',0,NULL,3,1,2,1,NULL,'a.alitkin\r\\'),(1317,766740551012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','stefan_georgiev_popov','stefan.popov@gmail.com','Stefan Popov','Beim Weisenstein 14<br>Ap. 6','Saarbruecken','','GERMANY','66125','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 13:08:40',0,NULL,3,0,3,1,NULL,'stefan_georgiev_popov\rMOMI001\rRA117716265CN\r\\'),(1318,568217434013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','ouioui2821','yann.jacques@ouioui-online.fr','yann jacques','8 rue des oiseaux','Savigny le temple','Île-de-France','FRANCE','77176','0679132040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 13:22:11',0,NULL,3,1,2,1,NULL,'ouioui2821\r\\'),(1319,522691430004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','megaredrider','rrefom@gmail.com','Sergey Shurupov','Leninskiy prospekt, dom.44, kv.158','Moscow','RU','RUSSIAN FEDERATION','119334','8-905-557-90-32','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 13:56:17',0,NULL,3,1,3,1,NULL,'megaredrider\rWLIN010+ANTY002\rRA117711237CN\r\\'),(1320,766779861012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','jhkingsr','jhkingsr@northstate.net','Jeffery King','2566 Peppertree Ridge Rd','Randleman','NC','UNITED STATES','27317','(336) 495-5835','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-03 14:24:59',0,NULL,3,1,1,1,NULL,'jhkingsr\r\\'),(1321,689515149011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.8,'eastar4','druffkappell','denstedter@web.de','Gerd Wiegand','Steinweg 19 a','Dieburg','','GERMANY','64807','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 14:47:00',0,NULL,3,1,2,1,NULL,'druffkappell\r\\'),(1322,690121736011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','speedster200413','rav.panesar@gmail.com','Ravinder Panesar','27 Rectory Road','Southall','London','UNITED KINGDOM','UB24EN','07879493568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 14:49:38',0,NULL,3,1,2,1,NULL,'speedster200413\r\\'),(1323,516915107003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',21.9,'cnfaner','ciobanash','eciobanu@mountaincable.net','Edward Ciobanu','15 Brantdale Avenue','Hamilton','ON','CANADA','L9C 1B6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 14:52:43',0,NULL,3,1,3,1,NULL,'ciobanash\rHSSE004\rRA117711245CN\r\\'),(1324,568256901013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','bluelightcrafts','heatherprusse@hotmail.com','Heather Prusse','663 E Elgin St','Gilbert','AZ','UNITED STATES','85295-1579','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 15:08:17',0,NULL,3,1,1,1,NULL,'bluelightcrafts\r\\'),(1325,690134000011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','powerdbycosworth','escort_rsturbo427@hotmail.com','andy akkermans','woeringenstraat 17','berchem','antwerpen','BELGIUM','2600','0473867606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 15:16:41',0,NULL,3,1,2,1,NULL,'powerdbycosworth\r\\'),(1326,690138750011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','emilsigandersen','emilsig@hotmail.com','Emil Sig Andersen','gammelstrupvej 22','brædstrup','standard','DENMARK','8740','75752675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 15:28:38',0,NULL,3,1,2,1,NULL,'emilsigandersen\r\\'),(1327,690179519011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','pat_realtor','pat_realtor@yahoo.ca','Petcharart Thangamornrart','12 Catherwood Crt','Scarborough','ON','CANADA','M1W 1S1','(416) 833-3984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 16:19:10',0,NULL,3,1,2,1,NULL,'pat_realtor\r\\'),(1328,766887445012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.8,'eastar4','wagnergung','mirko.wagner79@gmail.com','Mirko Wagner','Grießbacher Haupstraße 56','Drebach OT Grießbach','','GERMANY','09430','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 16:59:45',0,NULL,3,1,2,1,NULL,'wagnergung\rHP 6pin 1.0 12cm \r\\'),(1329,568324340013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','nachete_r','irivaspreciados@yahoo.es','IGNACIO RIVAS PRECIADOS','SAN FERNANDO Nº2 10ºA','SANTANDER','Cantabria','SPAIN','39010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 17:28:13',0,NULL,3,1,3,1,NULL,'nachete_r\rMOSA002\rRA117711427CN\r\\'),(1330,766913927012,220681549405,'New SAMSUNG WMN1000A ULTRA SLIM WALL-MOUNT LED 26\"-37\" ',1,'MOSA001',46,'eastar4uk','max-munki','diethardkuehl@alice-dsl.net','Diethard Kühl','Lohmannweg 3','25436','','GERMANY','Tornesch','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 17:29:28',0,NULL,3,1,3,1,NULL,'max-munki\rMOSA001\rRA117716075CN\r\\'),(1331,568351127013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',2,'BAZA001',151.2,'eastar4','cloudancer972','rdfoutch@att.net','Rick Foutch','4416 Seville Ln','McKinney','TX','UNITED STATES','75070-4438','(972) 529-0528','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'cloudancer972'),(1332,568358550013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','tr_superstore','superstoretr@windowslive.com','Serdar Keles','Ortaklar C. Ünsal Sk. No:5/5 Mecidiyeköy','Istanbul','','TURKEY','34394','+902129999999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 18:04:54',0,NULL,3,1,2,1,NULL,'tr_superstore\r欧标\r\\'),(1333,568375506013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','ktracid','stefan.zafiratos@gmail.com','Stefan Zafiratos','302-5900 Olive Ave<br>Buzzer 43','Burnaby','BC','CANADA','V5H 2P6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 18:24:10',0,NULL,3,1,2,1,NULL,'ktracid\r\\'),(1334,522834887004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','nickk9','nickk@oracle.ntt.ru','Nick Kolosov','p.o. box 97','Moscow','Moscow','RUSSIAN FEDERATION','129090','(7919)1061184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 18:33:16',0,NULL,3,1,3,1,NULL,'nickk9\rWLAT002  发新的\rRA117716203CN\r\\'),(1335,568381803013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','alicelockhartkitty','lockhartkitty@yahoo.com','Alice Lockhart','1304 Stacie Dr','Elizabeth City','NC','UNITED STATES','27909-9281','(252) 264-1305','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 18:33:43',0,NULL,3,1,1,1,NULL,'alicelockhartkitty\r\\'),(1336,766991828012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','tcnra','c.lochmuller@frontier.com','charles lochmuller','2819 mcdowell rd','durham','NC','UNITED STATES','27705','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 18:37:50',0,NULL,3,1,1,1,NULL,'tcnra'),(1337,568388284013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','lembergaviation','jpl@lembergaviation.com','Jani Lemberg','Bergkullantie 33','KIRKKONUMMI','-','FINLAND','02400','00358407779449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 18:41:25',0,NULL,3,1,2,1,NULL,'lembergaviation\r\\'),(1338,690358477011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','k2intimidator8','adam.winker@cellnet.com','Adam Winker','7780 Pinto Ln','Lino Lakes','MN','UNITED STATES','55014','(612) 578-2050','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 19:24:38',0,NULL,3,1,1,1,NULL,'k2intimidator8\r\\'),(1339,767071476012,220759518767,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',10.99,'eastar4uk','runeandre2009','ra.fr@hotmail.com','Rune Andre Frøyen','Plassen 7','Florø','sogn og fjordane','NORWAY','6900','004791356439','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 19:48:30',0,NULL,3,1,2,1,NULL,'runeandre2009\r\\'),(1340,568438219013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','comic_collectable_toyz','dbmitchell@blueyonder.co.uk','David Mitchell','11 Wallington Avenue, Cullercoats','North Shields','Tyne and Wear','UNITED KINGDOM','NE30 3SH','07779347045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 19:55:21',0,NULL,3,1,2,1,NULL,'comic_collectable_toyz\r\\'),(1341,522914129004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','macjag1999','allenpchan@yahoo.com','A. Chan','2425 Ortega St','San Francisco','CA','UNITED STATES','94122-4157','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 20:46:59',0,NULL,3,1,1,1,NULL,'macjag1999\r\\'),(1342,767187561012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','nikkostuff','rpsna70@aol.com','Rudy Pantun Soaloon Napitupulu','Jl. Beton No: 90 (D/h No: 1), Kampung - Ambon','Jakarta - Timur','DKI Jakarta','INDONESIA','13210','0214896284','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 23:12:05',0,NULL,3,1,3,1,NULL,'nikkostuff\rHSPL010\rRA117711206CN\r\\'),(1343,517169387003,130458358014,'Genuine Motorola H710  Bluetooth Headset offer track#',1,'HSMO014',26.59,'cnfaner','krvtradingco','hunneydoo@yahoo.com','Lyle Crawford','2219 Rembach Ave','Bodfish','CA','UNITED STATES','93205-9668','(760) 417-9011','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 23:33:07',0,NULL,3,1,1,1,NULL,'krvtradingco\r\\'),(1344,766371351012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',34.8,'eastar4','gabr','olegbrov@yahoo.com','Oleg Brovender','1333 Greeby St','Philadelphia','PA','UNITED STATES','19111-5526','(215) 288-5307','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 23:48:56',0,NULL,3,1,1,1,NULL,'gabr\r\\'),(1345,568526149013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','calvineng','calvineng@usa.net','Calvin Eng','No. 10 Lorong 1 Jalan Mendu','Kuching','Sarawak','MALAYSIA','93200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 23:52:09',0,NULL,3,1,2,1,NULL,'calvineng\r\\'),(1346,767204441012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.8,'eastar4','rmhua','ryanmcloud@gmail.com','Yuran Hua','1066 S SUGAR MAPLE PL','BLOOMINGTON','IN','UNITED STATES','47403-4574','(810) 335-2611','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 23:54:02',0,NULL,3,1,1,1,NULL,'rmhua\rHP 6pin 1.0 12cm \r\\'),(1347,767207839012,220502334400,'2.1 HP V3000 V3100 V3400 V3600 Bluetooth Module+ cable',1,'BTHP2103',12.8,'eastar4','compupiojo','chermozalawyer@gmail.com','Cesar Augusto Hermoza Gonzales','Jr. Santiago Rodriguez 254 Zona B San Juan de Miraflores','Lima','Lima','PERU','L 29','4663114','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 00:00:36',0,NULL,3,1,2,1,NULL,'compupiojo\rHP 8pin 1.0 12cm \r\\'),(1348,568532902013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','diga_tururu','diga_tururu@hotmail.com','Fco Javier Valero Martinez','Avda. Andalucia Nº3, 4ºC','San Sebastian de los Reyes','Madrid','SPAIN','28702','619718842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 00:18:01',0,NULL,3,1,2,1,NULL,'diga_tururu\r\\'),(1349,517189826003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','samantha18nj','samanthareed1992@hotmail.com','samantha reed','120 Centre St','nutley','NJ','UNITED STATES','07110-2828','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 00:53:25',0,NULL,3,1,1,1,NULL,'samantha18nj\r\\'),(1350,568553998013,230544190510,'NEW original Motorola H700 Gold DG Bluetooth Headset',2,'HSMO012',35.8,'eastar4','luciagormazmunoz','igormazmz@gmail.com','LUCIA  GORMAZ    .   rut  5.595.866-1','PAUL CLAUDEL 1490  depto  24<br>VITACURA','SANTIAGO','METROPOLITANA','CHILE','7630000','56  02  4185601','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 01:28:57',0,NULL,3,1,3,1,NULL,'luciagormazmunoz\rHSMO012\rRA117711651CN\r\\'),(1351,767248845012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','art1saf','art1saf@yahoo.com','arthur safalow','137 willis ave','mineola','NY','UNITED STATES','11501','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 01:38:50',0,NULL,3,1,1,1,NULL,'art1saf\r\\'),(1352,690545098011,320676254425,'Slim Bluetooth Wireless Keyboard for iPad iPhone iPod',1,'KBAP002',28.99,'eastar4','nlar5931','nlargavista@gmail.com','Nova Largavista','5253 Monroe Ave<br>Apt. #3','San Diego','CA','UNITED STATES','92115-4705','(619) 889-4568','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 01:56:47',0,NULL,3,1,1,1,NULL,'nlar5931\\'),(1353,767255618012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','bjamesedw','bbjamesed@aol.com','Emmett Barnes','1508 Shady Oaks Rd','Terry','MS','UNITED STATES','39170-9290','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 01:57:06',0,NULL,3,1,1,1,NULL,'bjamesedw\r\\'),(1354,767259770012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','dsieme01','dsieme01@hotmail.com','Daniel Siemens','225 SE Country Ln','Lees Summit','MO','UNITED STATES','64063-6025','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 02:08:29',0,NULL,3,1,1,1,NULL,'dsieme01\r\\'),(1355,690554397011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','thespiders2','chris-garten@hotmail.de','Christian Ott','Matenzeile 16','Berlin','','GERMANY','13053','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 02:22:54',0,NULL,3,1,2,1,NULL,'thespiders2\r\\'),(1356,568571909013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',3,'OMHJ001',41.97,'eastar4','classicscooterparts','worldrareitems2008@gmail.com','Howard Ngo','3071 Centerwood Way','San Jose','CA','UNITED STATES','95148-2656','(408) 417-5296','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-04 02:31:26',0,NULL,3,1,1,1,NULL,'classicscooterparts\r\\'),(1357,690561434011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','fivos_k','fkanellis@gmail.com','Foivos Kanellis','133 Peterborough St<br>Apt 8a','Boston','MA','UNITED STATES','02215','(857) 294-4179','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 02:46:51',0,NULL,3,1,1,1,NULL,'fivos_k\\'),(1358,767278386012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','jmichaelreynolds','michael.reynolds@comcast.net','Michael Reynolds','60 Montgomery St','Cambridge','MA','UNITED STATES','02140','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 03:04:00',0,NULL,3,1,1,1,NULL,'jmichaelreynolds\r\\'),(1359,522726961004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','onedieseldoctor','fourfriends@msn.com','William E. Friend','1259 N Church St<br>Power Equipment Company Bldg 2','Moorestown','NJ','UNITED STATES','08057','(856) 316-8808','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 03:07:59',0,NULL,3,1,1,1,NULL,'onedieseldoctor\r\\'),(1360,767279333012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','apisitpornpimol1','michiko_us@hotmail.com','APISIT GARPTIP','2216 49th Way N','West Palm Beach','FL','UNITED STATES','33417-3924','(561) 693-5267','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 03:09:00',0,NULL,8,1,17,0,NULL,'apisitpornpimol1'),(1361,690568513011,320631786282,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',15.5,'eastar4','apisitpornpimol1','michiko_us@hotmail.com','APISIT GARPTIP','2216 49th Way N','West Palm Beach','FL','UNITED STATES','33417-3924','(561) 693-5267','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 03:16:15',0,NULL,3,1,1,1,NULL,'apisitpornpimol1\r再发一个NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg\r\\'),(1362,767320341012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','bolocz','bola_orisajinmi@yahoo.co.uk','akinbola orisajinmi','6 hawkins drive','grays','Essex','UNITED KINGDOM','rm16 6gg','01375481007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 06:18:19',0,NULL,3,1,3,1,NULL,'bolocz\rCASS003\rRA117711515CN\r\\'),(1363,690610112011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','schweich777','schweich1991@gmail.com','Paul Schäfer','Brunnenstraße 5','Schweich','','GERMANY','54338','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 06:43:48',0,NULL,3,1,2,1,NULL,'schweich777\r\\'),(1364,568616354013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','ezio1914','ezio1914@yahoo.com','ED  DeBatte','59 Drew Rd','Holmes','NY','UNITED STATES','12531-4505','(845) 536-1774','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-04 07:09:52',0,NULL,3,1,1,1,NULL,'ezio1914\\'),(1365,568620435013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','tampromise2010','tampromise@gmail.com','Diskov Igor','Diskov Igor<br>Shershneva 28-1','Belgorod','','RUSSIAN FEDERATION','308007','+79626267076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 07:35:19',0,NULL,3,1,2,1,NULL,'tampromise2010\r\\'),(1366,767341072012,220546768421,'1000000000000000% New Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','107okp','djrowell@bigpond.net.au','Dudley  R Rowell','18 Cosette Street','Bracken Ridge','Queensland','AUSTRALIA','4017','0732617161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 07:54:07',0,NULL,3,1,2,1,NULL,'107okp\r\\'),(1367,523060791004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','darkkevind','darkkevind@hotmail.com','Kevin Dark','Easier2move<br>4 Walls Yard','Rochford','Essex','UNITED KINGDOM','SS4 1GR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 08:28:34',0,NULL,3,1,3,1,NULL,'darkkevind\rWWSI005\rRA117711705CN\r\\'),(1368,767357879012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','kyeongjang','kyeongjinjang@empal.com','kyeongjin jang','5831 amapola dr','san jose','ca','UNITED STATES','95129-3056','(408) 777-9826','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 09:04:09',0,NULL,3,1,1,1,NULL,'kyeongjang\r\\'),(1369,690645839011,320394934550,'Acer Aspire 6920 6920G Bluetooth Module 2.0 EDR+cable',1,'BTAC2016',12.5,'eastar4','1979bfs','bfs1979@hotmail.com','Benjamin Fernández Santana','C/ TECEN 143','LAS PALMAS DE G.C.','Canarias','SPAIN','35009','606103656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 09:20:20',0,NULL,3,1,2,1,NULL,'1979bfs\racer 8pin0.8 16cm  \r\\'),(1370,568637074013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','hailingonme','dnaumoff@internode.on.net','David Naumoff','2 Macalpine Retreat Kinross','Perth','Western Australia','AUSTRALIA','6028','0407470759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 09:24:38',0,NULL,3,1,3,1,NULL,'hailingonme\rMOSA001\rRA117716129CN\r\\'),(1371,767370606012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',14.9,'eastar4uk','tara_1964','bluecatnl@gmx.net','Marleen van den Haak','Grimberg-Huijserstraat 3','Rotterdam','','NETHERLANDS','3066 JD','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 09:45:38',0,NULL,3,1,2,1,NULL,'tara_1964\r\\'),(1372,690671163011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','readydigital','readydigital@hotmail.com','Chon Han','2 Jalan Mutiara<br>#12-02 Mutiara Crest','Singapore','','SINGAPORE','249183','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 10:52:29',0,NULL,3,1,11,1,NULL,'readydigital\r\\'),(1373,767398417012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.9,'eastar4','zholeynik','bhbl@mail.ru','Bobylev Andrei','pereulok Maikopski 12/2','Tuapse','Krasnodarski krai','RUSSIAN FEDERATION','352802','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 11:34:22',0,NULL,3,1,2,1,NULL,'zholeynik\r\\'),(1374,517301920003,130490963329,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'cnfaner','crawl78','marco.mengotto@libero.it','Dell Italia - Marco Mengotto','Via Piero e Alberto Pirelli, 6, 2° Piano','Milano','MI','ITALY','20126','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 11:41:52',0,NULL,3,1,3,1,NULL,'crawl78\rWLIN010\rRA117716194CN\r\\'),(1375,767421027012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','watsonct21','watsonct21@comcast.net','Chad Watson','17795 Idawood Path','Lakeville','MN','UNITED STATES','55044','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 12:29:33',0,NULL,3,1,1,1,NULL,'watsonct21\r美标\r\\'),(1376,523104548004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',1,'HSJA002',21.5,'cnfaner','kafkasmurat','mmehtap@gelirler.gov.tr','Murat Mehtap','T.C. Maliye Bakanligi Gelir Idaresi Baskanligi Ek Hizmet Binasi<br>Yeni Ziraat Mah. Etlik Cad. No:16 Diskapi (Dahili:1220)','Ankara','TÜRKİYE','TURKEY','06110','+905334935701','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 12:36:11',0,NULL,3,1,3,1,NULL,'kafkasmurat\rHSJA002欧标\rRA117711634CN\r\\'),(1377,523106934004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','racquetguys','twrussell1974@gmail.com','RCS Racquet Sports','31 Passmore Ave., Unit 3','Toronto','ON','CANADA','M1V 3H4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 12:42:11',0,NULL,3,1,3,1,NULL,'racquetguys\rHSPL010\rRA117711625CN\r\\'),(1378,690708908011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',2,'HSJA002',29.8,'eastar4uk','red.star.670','silviotaube@web.de','Silvio Taube','Akazienweg 12','Emmerich am Rhein','','GERMANY','46446','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 12:56:08',0,NULL,3,1,3,1,NULL,'red.star.670\r欧标HSJA002\rRA117711603CN\r\\'),(1379,568696544013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','phukk','phukk@bolina.hsb.se','Emil Janstad','Ellstorpsgatan 1A','Malmö','Skåne','SWEDEN','21217','0737-441007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 13:53:41',0,NULL,3,1,2,1,NULL,'phukk\r\\'),(1380,767437906012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','mu96ut99','nspiros@yahoo.com','NICOLE TUORI','8796 Jimson Ct','SYLVANIA','OH','UNITED STATES','43560-9828','(419) 517-3522','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 14:04:55',0,NULL,3,1,1,1,NULL,'mu96ut99\r\\'),(1381,568696547013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','mike-calitae','mike.kosovo@hotmail.co.uk','Michael MARDON','3 Cotterell Road<br>Broadclyst','EXETER','Devon','UNITED KINGDOM','EX5 3RZ','07854849867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 14:08:35',0,NULL,3,1,2,1,NULL,'mike-calitae\r\\'),(1382,767460823012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','ericjosefsson','eric.josefsson@gmail.com','Eric Josefsson','Ringgatan 5','Skänninge','','SWEDEN','59632','+46702705174','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 14:20:38',0,NULL,3,1,2,1,NULL,'ericjosefsson\r欧标\r\\'),(1383,690741222011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.8,'eastar4','blueboyindy','billy.sexton@gmail.com','Bill Sexton','7055 Sandalwood Dr','Indianapolis','IN','UNITED STATES','46217-4141','(317) 313-8050','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 14:29:56',0,NULL,3,1,1,1,NULL,'blueboyindy\rHP 8pin 1.25 25cm\r\\'),(1384,517346984003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','arthurreis','arthurrs@ig.com.br','Arthur Reis Santos','Rua Otto Bender, 137<br>Mandaqui','São Paulo','SP','BRAZIL','02418-030','(5511) 8119-6120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 15:01:37',0,NULL,3,1,3,1,NULL,'arthurreis\rMOSA002\rRA117716089CN\r\\'),(1385,767485203012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',31.3,'eastar4uk','rossash2008','colinaauchnie@hotmail.co.uk','COLIN AUCHNIE','7 WOODLANDS TURRIFF','TURRIFF','Aberdeenshire','UNITED KINGDOM','AB53 4BR','01888563836','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-04 15:25:41',0,NULL,3,1,3,1,NULL,'rossash2008\r英标  一共买了两个\rHSPL010\rRA117716163CN\r\\'),(1386,690764019011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','7tt','ttokio@gmx.net','Sayaka KIRA','Anzengruberstrasse 8/1','Linz','','AUSTRIA','4020','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 15:30:18',0,NULL,3,1,2,1,NULL,'7tt\racer 8pin1.00 8cm \r\\'),(1387,562931196013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',3,'OTCN001',11.97,'eastar4','montreal-pos','info@montreal-pos.com','Parvane - Laser Clinic','8381 Old Courthouse Rd<br>Ste 300','Vienna','VA','UNITED STATES','22182-3818','(514) 671-0346','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 16:49:18',0,NULL,3,1,1,1,NULL,'montreal-pos\r\\'),(1388,523179873004,140516095525,'New Logitech Rechargeable battery 890 880 950mA+charger',10,'BALO001+BAIN002',159.9,'cnfaner','bellobelli','mttoksoylu@live.com','Erkin Canoglu','330 College st','Amherst','MA','UNITED STATES','01002-2331','(401) 688-9025','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 17:17:57',0,NULL,3,1,1,1,NULL,'bellobelli\r\\'),(1389,690740044011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','anthonytjandra','anthony.tjandra@gmail.com','Sumahdi Jap','Blk 370G, Alexandra Rd, The Anchorage #15-10','default','','SINGAPORE','159960','6564726404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 17:30:27',0,NULL,3,1,11,1,NULL,'anthonytjandra\r\\'),(1390,767551600012,220713846430,'New GENUINE NOKIA HS 11W BLUETOOTH HEADSET',1,'HSNO023',9.69,'eastar4uk','hank2997','martyn.moore2@btopenworld.com','martyn moore','8 forest crescent<br>barncourt','omagh','tyrone','UNITED KINGDOM','bt784hs','07768671236','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-04 17:33:47',0,NULL,3,1,3,1,NULL,'hank2997\r英标   HSNO023\rRA117711475CN\r\\'),(1391,690823147011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','hughdale','aitalaakso@hotmail.com','Hannu Aitalaakso','Artemisgatan 5 B','Stockholm','','SWEDEN','11542','08-6640572','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 17:39:09',0,NULL,3,1,2,1,NULL,'hughdale\r\\'),(1392,567545189013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',41.9,'eastar4','msadati','marcelo_adati@yahoo.com.br','Marcelo Suenaga Adati','Rua Ibituruna, 241<br>Apto 82','São Paulo','São Paulo','BRAZIL','04302-051','55 11 8115-4566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 17:54:31',0,NULL,3,1,3,1,NULL,'msadati\rHSNO019\rRA117716115CN\r\\'),(1393,523209562004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','eitanc57','eitan579@walla.co.il','eitan cohen','ein ganim 57','petah-tikva','','ISRAEL','49444','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 18:28:56',0,NULL,3,1,3,1,NULL,'eitanc57\rHSSA001\rRA117716061CN\r\\'),(1394,690838964011,320679562348,'New Sennheiser MX680i Adidas Sports Earphones for iPod',1,'HSSS004',29.59,'eastar4uk','glinn88','linn_rolland@hotmail.com','Linn Rolland','Kronstadveien 5E','Bergen','Bergen','NORWAY','5053','+4748116749','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 18:49:37',0,NULL,3,1,3,1,NULL,'glinn88\rHSSS004\rRA117711373CN\r\\'),(1395,690870363011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','airplay912','radovan.kukutsch@centrum.cz','Ivan Kana','Hobzikova 34','Opava','','CZECH REPUBLIC','74601','+420775698099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 19:13:10',0,NULL,3,1,2,1,NULL,'airplay912\r\\'),(1396,690877827011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','airplay912','radovan.kukutsch@centrum.cz','Radovan Kukutsch','P. Bezruce 1650','Petrvald u Karvine','','CZECH REPUBLIC','73541','+420775698099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 19:24:28',0,NULL,3,1,2,1,NULL,'airplay912\r\\'),(1397,568815384013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.8,'eastar4','oggiebackup','threads@gmail.com','Peter Ogborn','Flat 1<br>10 Shelley Close','Bournemouth','Dorset','UNITED KINGDOM','BH1 4JP','01202398861','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 19:28:04',0,NULL,3,1,2,1,NULL,'oggiebackup\r\\'),(1398,767642297012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',9,'ANTY001*3',32.22,'eastar4','mattzank','mzank@att.net','Matthew J Zank','W229 N591 Foster Ct.','Waukesha','WI','UNITED STATES','53186','(262) 548-6235 ext.: 111','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 19:50:09',0,NULL,3,0,1,1,NULL,'mattzank\r\\'),(1399,517454228003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','petrx1','jancax1@gmail.com','Petr Ludvík','Národní 1010','Prachatice','','CZECH REPUBLIC','38301','+420608982650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 19:51:41',0,NULL,3,1,3,1,NULL,'petrx1\rHSMO018\r欧标\rRA117716150CN\r\\'),(1400,523280807004,140516076074,'Logitech MX518 MX 518 Gaming Optical USB Mouse track#',1,'MOLO003',32.9,'cnfaner','danielquelha','daniel.quelha@gmail.com','Daniel Souza','Rua Hildebrando Cordeiro<br>30 - Casa','Curitiba','Paraná','BRAZIL','80740-350','(55) 41 3301-3818','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 21:47:00',0,NULL,3,1,3,1,NULL,'danielquelha\rMOLO003\rRA117711435CN\r\\'),(1401,690956187011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','mightysmallballs','xayide@bredband.net','Henrik Sigfrid','Bäckalyckevägen 33E','Jönköping','','SWEDEN','55313','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 22:04:04',0,NULL,3,1,2,1,NULL,'mightysmallballs\r\\\r\r'),(1402,523287127004,140482241394,'New Genuine Motorola H555 Bluetooth Headset track#',2,'HSMO008',27.98,'cnfaner','kururu_brazil','yonekura@terra.com.br','Marcos Yonekura','Rua Gomes Pedrosa, 70<br>Interlagos','São Paulo','São Paulo','BRAZIL','04805-340','8782-0686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 22:06:59',0,NULL,3,1,3,1,NULL,'kururu_brazil\rHSMO008\rRA117711360CN\r\\'),(1403,568875441013,230495606381,'New in box NOKIA HS-11W BLUETOOTH HEADSET HS 11W',1,'HSNO024',17.7,'eastar4','debcris1','sxcgal75@gmail.com','Debbie Connolly','87 Tindle st','Redbank Plains','Queensland','AUSTRALIA','4301','0400690792','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 22:16:42',0,NULL,3,1,2,1,NULL,'debcris1\r澳标\r\\'),(1404,517499685003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','crazystargrl','movetheneedlecreations@yahoo.com','Anna Leehey','819 N Euclid Ave','Oak Park','IL','UNITED STATES','60302-1520','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 22:23:24',0,NULL,3,1,1,1,NULL,'crazystargrl\r\\'),(1405,767694204012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',35.88,'eastar4','dorothy2942','jywelborn@sbcglobal.net','dorothy welborn','840 redbud dr','redding','CA','UNITED STATES','96001-0141','(530) 243-7887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 22:25:47',0,NULL,3,1,1,1,NULL,'dorothy2942\r\\'),(1406,568884592013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','flobeetle','flolavillat@gmail.com','LAVILLAT FLORIAN','25 chemin de la bourdaine','SILLINGY','Rhône-Alpes','FRANCE','74330','06.18.89.84.05','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 22:54:17',0,NULL,3,1,3,1,NULL,'flobeetle\rMOSA002\rRA117711458CN\r\\'),(1407,767737186012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','guylaine2553','guylaine_duval@hotmail.com','guylaine duval','1041 ch. des sables','Ascot Corner','QC','CANADA','j0b1a0','(819) 829-0174','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 23:14:28',0,NULL,3,1,2,1,NULL,'guylaine2553\r\\'),(1408,767738105012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',4,'HSSH001',143.96,'eastar4','imdelaw1','shirankochavi@yahoo.com','NRG Energy, Inc.    Attn: Shiran Kochavi','211 Carnegie Ctr','Princeton','NJ','UNITED STATES','08540-6213','(609) 240-7838','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 23:20:36',0,NULL,3,1,1,1,NULL,'imdelaw1\r\\'),(1409,767736350012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','jazz3303','userco9863@aol.com','Barry R Cook','316 RUTLEDGE AVENUE','EAST ORANGE','NJ','UNITED STATES','07017','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 23:20:50',0,NULL,3,1,1,1,NULL,'jazz3303\r\\'),(1410,568900856013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','wittaya.r','wittaya_r@msn.com','WITTAYA ROCHKITTICHAROEN','91/511 Ramintra 44 Ramintra road','Buengkum','Bangkok','THAILAND','10230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 00:07:58',0,NULL,3,1,2,1,NULL,'wittaya.r\r\\'),(1411,517523284003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',21.9,'cnfaner','elci_rbr','elayaraja.kasirajan@gmail.com','Elayaraja Kasirajan','250 Main St<br>Apt 524','Hartford','CT','UNITED STATES','06106-1872','(860) 816-0754','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 00:12:36',0,NULL,3,1,1,1,NULL,'elci_rbr\r\\'),(1412,691015937011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','bls851','brandi_lee22@hotmail.com','Brandi Swystun','36 Howell Avenue','Saskatoon','SK','CANADA','S7L 3S8','(306) 370-8008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 00:52:58',0,NULL,3,1,2,1,NULL,'bls851\r\\'),(1413,767771361012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','johnnyray59','raydeb2007@intrstar.net','Johnny Daughtry','599 Bernice Rd','Clinton','NC','UNITED STATES','28328','(910) 533-2058','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 01:04:30',0,NULL,3,1,1,1,NULL,'johnnyray59\\'),(1414,568912661013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','marinaside0','lmmrogers@hotmail.com','lesley rogers','501-1560 homer mews','vancouver','BC','CANADA','v6z 0a5','(604) 648-2114','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 01:05:03',0,NULL,3,1,2,1,NULL,'marinaside0\r\\'),(1415,691022682011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','electricbug2007','electricbug@gmail.com','Matt Tibold','25 Neltner Drive','St. Andrews','MB','CANADA','R1A 3A4','(204) 338-9438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 01:18:35',0,NULL,3,1,2,1,NULL,'electricbug2007\r\\'),(1416,568921329013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',2,'WLDL001',16.7,'eastar4','amehanna-50','ahmed.mehanna@mcphs.edu','ahmed mehanna','6 Fairhaven Cir','Sudbury','MA','UNITED STATES','01776-2041','(978) 443-1474','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 01:41:39',0,NULL,3,1,1,1,NULL,'amehanna-50\r÷'),(1417,523334666004,140482241394,'New Genuine Motorola H555 Bluetooth Headset track#',1,'HSMO008',13.99,'cnfaner','ftho7291','galalica@aol.com','Frankie Thomas','1733 N E 4th AVE.','Gainesville','FL','UNITED STATES','32641','(352) 376-0160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 01:57:10',0,NULL,3,1,1,1,NULL,'ftho7291\r\\'),(1418,568928999013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','adrianevale','adrianevale@hotmail.com','Gerson Silva','CAVP, Chacara 03 Casa 18 - Rua do Joquey<br>Colonia Agricola Vicente Pires,','BRASÍLIA','DISTRITO FEDERAL','BRAZIL','72005115','55 61 84740000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 02:13:31',0,NULL,3,1,3,1,NULL,'adrianevale\rOTRA002\rRA117711413CN\r\\'),(1419,568941581013,230576095186,'Logitech MX518 MX 518 Gaming Optical USB Mouse 90% new',1,'MOLO003',32.9,'eastar4','dogarr','dogarr@hotmail.com','James Diggs','301 advance stage tabata<br>1-27-12 tabata shinmachi, Kita-Ku','Tokyo','Tokyo','JAPAN','1140012','09091079603','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 03:17:54',0,NULL,3,0,3,1,NULL,'dogarr\rMOLO003\rRA117711395CN\r\\'),(1420,767837351012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',6,'TRMX003',47.7,'eastar4','adeptmaster','rokeeffe@twcny.rr.com','Robert OKeeffe','7664 1/2 Thompson Rd','North Syracuse','NY','UNITED STATES','13212-1853','(315) 263-8544','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 05:28:44',0,NULL,3,1,1,1,NULL,'adeptmaster\r\\'),(1421,691088217011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','gunm83','jimmy.gallet@laposte.net','GALLET Jimmy','Rés. Coletto Bat A3, 2e etage porte droite','Cogolin','Provence-Alpes-Côte d\'Azur','FRANCE','83310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 06:25:54',0,NULL,3,1,2,1,NULL,'gunm83\r\\'),(1422,767865900012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','hawkeyeru','hawkeye@rbcmail.ru','Alexander Paramonov','22 Partsjezda, 173a-66<br>173a-66','Samara','Samara region','RUSSIAN FEDERATION','443081','8-919-800-2473','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 07:46:55',0,NULL,3,1,2,1,NULL,'hawkeyeru\r\\'),(1423,568984209013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','wmkarelia','mikolaptz@mail.ru','Nikolay Suykonen','Baltiyskaya 65, flat 33','Petrozavodsk','Karelia','RUSSIAN FEDERATION','185026','+7 911-400-32-39','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 08:30:54',0,NULL,3,1,2,1,NULL,'wmkarelia\r\\'),(1424,767877733012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','stephens1105','stephen1105@yahoo.com','Stephen Steeneck','2676 Old Yorktown Rd','Yorktown Heights','NY','UNITED STATES','10598-3139','(914) 302-6965','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 08:38:50',0,NULL,3,1,1,1,NULL,'stephens1105\r\\'),(1425,691133541011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','fanchheiz','fanchheiz@hotmail.fr','francois graindorge','kerascoet','treouergat','Bretagne','FRANCE','29290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 09:57:33',0,NULL,3,1,2,1,NULL,'fanchheiz\r\\'),(1426,569000156013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',3,'CACN004',50.64,'eastar4','murzilich','chip_set@inbox.ru','Ks\'onzenko Sergey','Geroiv Dnipra street, 18','Petrivske village','Kiev','UKRAINE','08141','+380505974862','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 10:07:00',0,NULL,3,1,3,1,NULL,'murzilich\rCACN004\rRA117711356CN\r\\'),(1427,691135791011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',1,'TRMX001',8.55,'eastar4','ian.chapman','ian.chapman@amiga-hardware.com','Ian Chapman','Woodside Plaza<br>240 St Georges Tce','Perth','Western Australia','AUSTRALIA','6000','0405841783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 10:08:02',0,NULL,3,0,2,1,NULL,'ian.chapman\r\\'),(1428,691139053011,320598677665,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card not IBM',1,'WLIN012',50.3,'eastar4','terra_operative','jaredcabot@live.com.au','Jared Cabot','37 Condamine Street','Runcorn','Queensland','AUSTRALIA','4113','0412556660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 10:19:54',0,NULL,3,1,3,1,NULL,'terra_operative\rWLIN012\rRA117711339CN\r\\'),(1429,517624216003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','555linas','lalminas@hotmail.com','Leandras Alminas','Debreceno 34-50','Klaipeda','','LITHUANIA','94147','+37068256018','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 10:57:32',0,NULL,3,1,3,1,NULL,'555linas\rHSNO008   欧标\rRA117711311CN\r\\'),(1430,767929856012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','borilt','borilt@gmail.com','Tomas Boril','Vackova 378','Liberec 23','','CZECH REPUBLIC','46312','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 11:54:30',0,NULL,3,1,2,1,NULL,'borilt\r\\'),(1431,767942829012,220704222400,'Logitech diNovo Bluetooth ultra-flat Keyboard+mediapad',1,'KBLO001',59.99,'eastar4','taimou','taimou@gmail.com','Richard Chuck','Level 3, 2 Dawn Fraser Avenue<br>Sydney Olympic Park','Sydney','New South Wales','AUSTRALIA','2127','0424159107','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 12:40:07',0,NULL,3,1,3,1,NULL,'taimou\rKBLO001\rRA117713564CN\r\\'),(1432,767951408012,220653561343,'New Atheros DualBand AR9287 Wireless  Half Card+antenna',1,'WLAT007+ANTY001',16.95,'eastar4','42galli','guellenstern@ifdnet.com','Markus Güllenstern','Riemekestr. 107','Paderborn','','GERMANY','33102','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:01:00',0,NULL,3,1,2,1,NULL,'42galli\r\\'),(1433,767951660012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','norlo21','norlo_21@hotmail.com','NORBERTO LOPEZ','laguna de la magdalena 261<br>ventura puente','morelia','michoacan','MEXICO','58020','443-312-13-24','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:02:58',0,NULL,3,1,2,1,NULL,'norlo21\r\\'),(1434,517649322003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'',31.98,'cnfaner','jamesallmond','jamesallmond@cox.net','James Allmond','640 Forest Lake Dr N','Macon','GA','UNITED STATES','31210','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 13:03:56',0,NULL,3,0,1,1,NULL,'jamesallmond\r\\'),(1435,767955049012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','wuestenwirt5','pe-ge@web.de','Gehring Peter','Balingerstrasse 52','Balingen-Frommern','','GERMANY','72336','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:11:36',0,NULL,3,1,2,1,NULL,'wuestenwirt5\r\\'),(1436,691201843011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','alligator626','alligator626ge@yahoo.com','Anton Ivanov','Obuhovskoy Oborony prospekt, 21-47<br>+7(905)209-2509','St.Petersburg','','RUSSIAN FEDERATION','192019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 14:00:21',0,NULL,3,1,2,1,NULL,'alligator626\r\\'),(1437,691241847011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','hugo7098','hgermain@cablovision.com','Hugo Germain','5 rue perrault','warwick','QC','CANADA','j0a1m0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 15:51:26',0,NULL,3,1,3,1,NULL,'hugo7098\rRCLO006\rRA117711387CN\r\\'),(1438,691247683011,320441946712,'2.1 HP NW8240 NW8440 Bluetooth Module EDR + cable',1,'BTHP2101',12.8,'eastar4','ur2sirius','chwatd@verizon.net','Dennis Chwat','1613 9th St','Manhattan Beach','CA','UNITED STATES','90266-6128','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 16:05:43',0,NULL,3,1,1,1,NULL,'ur2sirius\rHP 8pin 1.0 3cm\\'),(1439,517694918003,130489927197,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'cnfaner','corp2k','multi2k@hotmail.com','SeungJae Lee','111-705 Hankang APT Kayang1-Dong<br>Kangseo-Gu Seoul','default','','KOREA,REPUBLIC OF','157-752','+821020425207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 16:17:18',0,NULL,3,1,3,1,NULL,'corp2k\rOTHP003\rRA117711648CN\r\\'),(1440,521427086004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','keyvan.akrami','keyvanakrami@yahoo.com','keyvan akrami','5055 w hacienda ave<br>Unit 1017','Las Vegas','NV','UNITED STATES','89118-0324','(702) 409-2342','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 16:44:42',0,NULL,3,1,1,1,NULL,'keyvan.akrami\r\\'),(1441,691276975011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','doron-se','doronse@hotmail.com','Doron Senger','Orlanskey 21/9','Petach Tikva','','ISRAEL','49571','972-54-7444217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:14:47',0,NULL,3,1,2,1,NULL,'doron-se\r\\'),(1442,517720841003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','yorgovan*','yohann@desygn.fr','Yohann GILLES','1465, avenue de Maurin<br>Cité fleurie - D7','MONTPELLIER','Languedoc-Roussillon','FRANCE','34000','0467693390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:38:20',0,NULL,3,1,3,1,NULL,'yorgovan*\rHSMO011   欧标\rRA117716132CN\r\\'),(1443,691290431011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','mountduke2004','dirk.ermert@t-online.de','Dirk Ermert','Eichenweg 1','Bergheim','','GERMANY','50126','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:47:46',0,NULL,3,1,2,1,NULL,'mountduke2004\r\\'),(1444,768069087012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','annaandythai','thantai2002ca@yahoo.com','van hung thai','2747 rue benjamin - sulte.','montreal','QC','CANADA','h3m1s3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:49:44',0,NULL,3,1,2,1,NULL,'annaandythai\r\\'),(1445,768075533012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',5,'CASS002',43.5,'eastar4','newdimension2011','netco2011@hotmail.co.uk','Rita Radia','8 Coniston Gardens','Ilford','Essex','UNITED KINGDOM','ig45lu','02085505815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:58:05',0,NULL,3,1,3,1,NULL,'newdimension2011\rCASS002\rRA117711461CN\r\\'),(1446,569119122013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','ladean6562','dietblkchic@yahoo.com','ladean graham','1010 Hunterstone Dr<br>Apt 203','leland','NC','UNITED STATES','28451','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 18:06:07',0,NULL,3,1,1,1,NULL,'ladean6562\r\\'),(1447,517736295003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','mccragger1337','mccragger@web.de','Christoph Neikes','Weseler Straße 139','Oberhausen','','GERMANY','46149','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 18:19:29',0,NULL,3,1,3,1,NULL,'mccragger1337\rHSUE004\rRA117716146CN\r\\'),(1448,691311094011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','felipeveiga','felipeveigapedreiro@hotmail.com','Felipe Veiga Pedreiro','Setor Oeste, Rua 9, N° 1000, Ed. Quarup, Apto 701','Goiânia','Goiás','BRAZIL','74120010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 18:22:05',0,NULL,3,0,3,1,NULL,'felipeveiga\rUDAP001\rRA117711563CN\r\\'),(1449,768089821012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','wheaton-2001','asalmon@salmonfamily.com','andrew salmon','85 Beaumont Dr','northbridge','MA','UNITED STATES','01534-1093','(617) 835-2225','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 18:22:54',0,NULL,3,1,1,1,NULL,'wheaton-2001\r\\'),(1450,768091016012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',4,'OTAP001',42.76,'eastar4','gadgetsthestreak','ismith000@sympatico.ca','Ian Smith','6 Willowdale Crescent','Port Dover','ON','CANADA','N0A 1N5','(519) 583-0751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 18:26:43',0,NULL,3,1,3,1,NULL,'gadgetsthestreak\rOTAP001\rRA117711501CN\r\\'),(1451,768095580012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',2,'WLDL001',11.5,'eastar4uk','erwepero','chapy_1969@hotmail.com','jaume sanchez rincon','avd. catalunya 123','la granada del penedes','Cataluña','SPAIN','08792','938975009','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-05 18:33:14',0,NULL,3,1,2,1,NULL,'erwepero\r\\'),(1452,517743438003,130490223099,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',32.49,'cnfaner','singingfrogscom','stremayne@sbcglobal.net','Scott Tremayne','539 Thistle Circle','Martinez','CA','UNITED STATES','94553','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 18:40:00',0,NULL,3,1,1,1,NULL,'singingfrogscom\r再发一个新的蓝电池\r\\'),(1453,768112780012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','techiebulldog','chanh@thao.ca','chanh thao','5055 Heatherleigh Ave, unit #100','Mississauga','ON','CANADA','L5V2R8','(905) 502-1999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 19:01:23',0,NULL,3,1,2,1,NULL,'techiebulldog\r\\'),(1454,768020569012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',41.75,'eastar4','bigbadtxwolf','other@bthomas.us','William Thomas','1500 Plantation Oaks Dr<br>Apt 104','Trophy Club','TX','UNITED STATES','76262-5551','(682) 502-4768','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 19:10:06',0,NULL,3,0,1,1,NULL,'bigbadtxwolf\r一共买了五个\r\\'),(1455,516876153003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','gio-manou','gioman13@gmail.com','GIORGOS MANOUSOPOULOS','IATROPOULOU 1','KALAMATA','MESSINIA','GREECE','24100','27210-93563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 19:22:01',0,NULL,3,1,3,1,NULL,'gio-manou\r欧标  HSMO006\rRA117711546CN\r\\'),(1456,691359080011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','al8983h','kimyun@aol.com','ALLAN HEW','18231 Barroso St','Rowland Heights','CA','UNITED STATES','91748-4404','(626) 965-2723','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 19:48:23',0,NULL,3,1,1,1,NULL,'al8983h'),(1457,768163801012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','robert_david','robert.david.public@gmail.com','Robert David','Kobyliska 24','Prague 8','Czech','CZECH REPUBLIC','18400','+420602343607','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 20:30:18',0,NULL,3,1,2,1,NULL,'robert_david\r\\'),(1458,569180290013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','giroudf','francois.giroud@che.dupont.com','francois GIROUD','14 ch des Marais','Cointrin','GENEVA','SWITZERLAND','1216','41227175058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 20:41:08',0,NULL,3,1,3,1,NULL,'giroudf\rOTRA002\rRA117711585CN\r\\'),(1459,523570899004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','sagibit1','rinatt14@walla.com','Rinat Biton','Mor 5','Arad','Israel','ISRAEL','89066','972506437518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 20:42:24',0,NULL,3,1,3,1,NULL,'sagibit1\rOMHJ001\rRA117711532CN\r\\'),(1460,768180745012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','markcata','mcatalanot@aol.com','Mark Catalanotti','313 N Broadway<br>Apt 2','Redondo Beach','CA','UNITED STATES','90277-2800','(310) 798-0548','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 21:03:54',0,NULL,3,1,1,1,NULL,'markcata\r\\'),(1461,569197214013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','819gary','grailer1@telus.net','Gary Railer','480 Mount Belcher Hts','Salt Spring Island','BC','CANADA','V8K 2J6','(250) 537-4207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 21:33:41',0,NULL,3,1,2,1,NULL,'819gary\r\\'),(1462,768196958012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','saitay1133','saitay@btinternet.com','sait ay','35 guernsey house<br>clifton road','lodon','London','UNITED KINGDOM','n1 2tr','07917441963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 21:37:42',0,NULL,3,1,2,1,NULL,'saitay1133\r\\'),(1463,691417546011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.8,'eastar4','kbechr','kyrib80-eshops@yahoo.gr','Bechrakis Kyriakos','26 Aristeidoy Street Cholargos','Athens, Greece','','GREECE','15562','00306972922291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 21:53:03',0,NULL,3,1,3,1,NULL,'kbechr\rMOSA001\rRA117711594CN\r\\'),(1464,569204384013,230563830400,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',22.99,'eastar4','spirow590046','spirow59@hotmail.com','Agne Mattsson','Ostra Storgatan 41','Gnesta','','SWEDEN','64632','0046705617098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 21:59:56',0,NULL,3,1,2,1,NULL,'spirow590046\r\\'),(1465,517811560003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','has.hc','haspel@gmx.at','Mathias Haspel','Bonygasse 37/1<br>Krautgartner z.Hd Haspel','Vienna','Wien','AUSTRIA','1120','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 22:03:25',0,NULL,3,1,3,1,NULL,'has.hc\rWWSI002+ANCN001\rRA117711489CN\r\\'),(1466,517814167003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','emrahsteel','emrahcelik@msn.com','EMRAH CELIK','ALTINTEPE MAH.GALIPBEY CD. DEFNE SOK. MELTEM APT. 8/19 MALTEPE','ISTANBUL','','TURKEY','34840','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 22:16:56',0,NULL,3,1,3,1,NULL,'emrahsteel\rHSNO008  欧标\rRA117711492CN\r\\'),(1467,691426114011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','sybercy','dersarasi@hotmail.com','Sinan Can Ertanhan','Basak Sok. Selen Apt. No:36 B-Blok D:B1 Yesilyurt','Istanbul','','TURKEY','34149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 22:17:13',0,NULL,3,1,2,1,NULL,'sybercy\r\\'),(1468,768220458012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','chub_21','jchan_21@hotmail.com','Jason Chan','605 West Kent Avenue<br>Mattson Technology Canada','Vancouver','BC','CANADA','V6P6T7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 22:39:31',0,NULL,3,1,2,1,NULL,'chub_21\r\\'),(1469,569225676013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','bigal1016','ans1050@verizon.net','Allen Strauss','50 Vender lane','Mays Landing','NJ','UNITED STATES','08330','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 23:32:38',0,NULL,3,1,1,1,NULL,'bigal1016\r\\'),(1470,691454616011,320666180879,'NIB Genuine Sony Ericsson HBH-DS220 Bluetooth  Headset',1,'HSSE006',67.9,'eastar4','half-mvsa','dragonbooster_93@hotmail.com','Marinalva Assunção','Av. Professor Plínio Bastos, bairro: Olaria<br>Casa nº: 530','Rio de Janeiro','Rio de Janeiro','BRAZIL','21021-350','55 (21) 22600131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 23:57:22',0,NULL,3,1,3,1,NULL,'half-mvsa\rHSSE006\rRA117711550CN\r\\'),(1471,569234866013,230603109640,'New CX680 Sennheiser Adidas Sports Earphones Earbuds',1,'',40.99,'eastar4','resnos','kenny.befus@gmail.com','Kenny Befus','6500 Champion Grandview Way<br>#35104','Austin','TX','UNITED STATES','78750','(512) 904-9989','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 00:18:13',0,NULL,3,0,1,1,NULL,'resnos\r\\'),(1472,569241005013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','jlondon141','jlondon141@insightbb.com','Jonathan A London','826 Fern Hill St','Bowling Green','KY','UNITED STATES','42101-4450','(270) 991-8904','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 00:48:43',0,NULL,3,1,1,1,NULL,'jlondon141\racer 4pin1.25 15cm\r\\'),(1473,768275741012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','policebrat58','walterjbrown@yahoo.com','Walter  J Brown','562 Roark Trce','Montgomery','AL','UNITED STATES','36116-6327','(334) 284-1443','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 01:46:49',0,NULL,3,1,1,1,NULL,'policebrat58\r\\'),(1474,767265405012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','flakeyfriend','melan1e@embarqmail.com','Melanie A. Huffnagle/Peters','160 W Railroad St','Reedsville','PA','UNITED STATES','17084-9120','(717) 667-9804','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 02:36:26',0,NULL,3,1,1,1,NULL,'flakeyfriend\r\\'),(1475,517866456003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','vira509','dennisvira@msn.com','Vira Garbisch','16434 N Sunrise Dr','Nine Mile falls','WA','UNITED STATES','99026-9464','(509) 468-2283','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 02:48:03',0,NULL,3,1,1,1,NULL,'vira509\r\\'),(1476,569272468013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','3cardtrick','deuce@mouseheaddesign.com','Andrew Dickinson','186 Wellington Street<br>Unit 1','Kingston','ON','CANADA','K4L 3E4','(613) 583-5221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 03:21:31',0,NULL,3,1,2,1,NULL,'3cardtrick\r\\'),(1477,517873579003,130504141009,'NEW Red Genuine Lowepro Topload Zoom Mini Camera Bag!',1,'',19.98,'cnfaner','shakeydddd','shakey4d@yahoo.com.au','Matt Ford - Fire Unit','Level 1, 10 Valentine Ave','Parramatta','New South Wales','AUSTRALIA','2150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 03:43:38',0,NULL,3,0,3,1,NULL,'shakeydddd\r红色的\rRA117712095CN\r、'),(1478,569277531013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','spallumcheen','hythrax@hotmail.com','sameer harji','212 Alfred Paterson Dr','Markham','ON','CANADA','L6E 2E7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 03:54:59',0,NULL,3,1,3,1,NULL,'spallumcheen\rMOSA002\r\rRA117711166CN\r\\'),(1479,768309126012,220689444211,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61 Z60',1,'WWSI002',37.45,'eastar4','saccin76','habbaji@gmail.com','Tae-Kwang, Youn','BITEK SYSTEM INC. Rm.719 Doosan Venture Digm, 126-1<br>Pyengchon-dong','Anyang-si','Gyeonggi-do','KOREA,REPUBLIC OF','431-070','82-10-9289-5389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 03:56:02',0,NULL,3,1,3,1,NULL,'saccin76\rWWSI002\rRA117711197CN\r\\'),(1480,0,320674543349,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 04:50:57',0,NULL,3,0,1,1,NULL,'michael2289xd\r一共要发四个  都是 细头的\rLK037352629CN \r\\'),(1481,768324560012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','guntastic','jgunty@nd.edu','Joshua Gunty','5459 S Cornell Ave<br>1-RR #104','Chicago','IL','UNITED STATES','60615-5769','(574) 309-2844','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 05:10:02',0,NULL,3,1,1,1,NULL,'guntastic\r\\'),(1482,768326973012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','andrewg105','andyg105@hotmail.co.uk','Andrew George','105 Trent Road<br>Shaw','Oldham','Lancashire','UNITED KINGDOM','OL2 7QH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-06 05:23:17',0,NULL,3,1,3,1,NULL,'andrewg105\r英标  银色带花的 HSSE005\rRA117716282CN\r\\'),(1483,569290079013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','waoma4jc','waoma@naver.com','Dong Hyun Kwon','156 Point DR Apt 60','Lynchburg','VA','UNITED STATES','24502','(434) 851-6066','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 05:25:42',0,NULL,3,1,1,1,NULL,'waoma4jc\r\\'),(1484,569291218013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','danval82','snowball122782@yahoo.com','Daniel A Valencia Jr.','11449 Rancho La Brea Dr.','Riverside','CA','UNITED STATES','92505','(951) 809-1713','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 05:36:32',0,NULL,3,1,1,1,NULL,'danval82\r\\'),(1485,523679191004,140516092415,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',22.28,'cnfaner','shopdrop247','fx1@tx.rr.com','GORDON DUNKIN','1105 Green Meadow Dr','RICHARDSON','TX','UNITED STATES','75081','(972) 249-5333','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 06:44:53',0,NULL,3,1,1,1,NULL,'shopdrop247\r再发一个New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh\r\\'),(1486,523683840004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','kochegin87','kochegin@gmail.com','Mikhail Kochegin','mkr. Aksai-2, d.7, kv.19','Almaty','KZ','KAZAKHSTAN','050031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 07:31:53',0,NULL,3,1,3,1,NULL,'kochegin87\r\\\rRA117711183CN\r'),(1487,768365720012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','zagorskasa','azagorskas@gmail.com','Nomeda Zagorskiene','Didlaukio 58-58','Vilnius','Lietuva','LITHUANIA','LT-08328','+370 655 45454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:27:28',0,NULL,3,1,2,1,NULL,'zagorskasa\r欧标\\'),(1488,768366777012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',15,'TRMX003',125.25,'eastar4','osi-network','osinetworks@orange.fr','COM 2 NETWORKS SAS','10 rue des Gaudines<br>Strategy Center - Bat D','SAINT-GERMAIN-EN-LAYE','Ile-de-France','FRANCE','78100','0139040221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:32:09',0,NULL,3,0,3,1,NULL,'osi-network\r发210T\rTRTT002*15\r\rRA117716835CN\r\\'),(1489,569315977013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','vearutop','nanopeni@gmail.com','Vyacheslav Poturaev','per. Novyi, 1 kv. 97','Tomsk','Tomskaya','RUSSIAN FEDERATION','634006','9039148918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:33:11',0,NULL,3,1,2,1,NULL,'vearutop\\'),(1490,517913155003,130458644390,'New GENUINE NOKIA BH-300 BLUETOOTH HEADSET track#',1,'HSNO013',15.6,'cnfaner','lvelikov','llv@mail.bg','Lyubomir Velikov','Kubrat 14 str.','Samuilovo','Sliven','BULGARIA','8865','+359899572010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:36:44',0,NULL,3,1,3,1,NULL,'lvelikov\r欧标  HSNO013\rRA117716296CN\r\\'),(1491,569316264013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','thegabber007','louis.vanlancker@hotmail.com','Louis Van Lancker','Rue de Cayoit 58','Leuze-en-Hainaut','','BELGIUM','7903','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:37:42',0,NULL,3,1,2,1,NULL,'thegabber007\\'),(1492,517914332003,130490194854,'Genuine Logitech Harmony 880 Universal Remote Control',1,'RCLO002',75.99,'cnfaner','yousef.elaiwat','yousef66@gmail.com','Yousef Elaiwat','Mob: +966503834834<br>P.O.Box 13215','Qatif','Eastren','SAUDI ARABIA','31911','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:42:33',0,NULL,3,1,3,1,NULL,'yousef.elaiwat\rRCLO002\rRA117716225CN\r\\'),(1493,523704937004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','sicabe1','capraro@pacific.net.sg','Silvana Hobcraft-Capraro','Via della Pace 20A','Locarno','','SWITZERLAND','6600','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 09:32:23',0,NULL,3,1,3,1,NULL,'sicabe1\rOMHJ001\rRA117713649CN\r\\'),(1494,768384469012,220763389217,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',15,'WWSI006',555,'eastar4uk','sjh34','c4steve@gmail.com','Stephen Hall (Icomera)','Innovation Centre Medway<br>Maidstone Road','Chatham','Kent','UNITED KINGDOM','ME5 9FD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-06 09:43:00',0,NULL,3,1,12,1,NULL,'sjh34\r\r2182244820\r'),(1495,569109370013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',10.99,'eastar4','prasangaperera2010','ebayprasanga@gmail.com','K L O Prasanga Perera','222-14-B Warahanthuduwa Road,<br>7th Lane Mihindu Mawatha,mahara,','Kadawatha','Western','SRI LANKA','11850','094773471320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 09:52:05',0,NULL,3,1,2,1,NULL,'prasangaperera2010\r、'),(1496,768394279012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','delchicharro','delchicharro@hotmail.com','Juan P. Jiménez Rodríguez','C/ Verode, 27   (Urbaniz. GUAJARA)<br>La Laguna','Santa Cruz de Tenerife','Canarias','SPAIN','C.P.38296','629986246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:22:37',0,NULL,3,1,2,1,NULL,'delchicharro\r、'),(1497,569335828013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','troedel-jan','a.lexow@web.de','A. Lexow','Geschwister - Scholl - Strasse  04','Schöneiche','','GERMANY','15566','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:36:17',0,NULL,3,1,2,1,NULL,'troedel-jan\r\\'),(1498,765215428012,220749207909,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.99,'eastar4uk','greg34gilles','ben1966@live.ca','gilles jutras','385 marquis','st-celestin','QC','CANADA','j0c 1g0','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 10:50:25',0,NULL,3,1,2,1,NULL,'greg34gilles\r\\'),(1499,691601055011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',1,'HSNO008',15,'eastar4','hell-20','aktasmami@hotmail.com','muhammet aktaş','karşıyaka mah. 2439/1 sokak no:27','denizli','türkiye / denizli / merkez','TURKEY','20200','05363708578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:53:24',0,NULL,3,1,2,1,NULL,'hell-20\r欧标\r\\'),(1500,761868269012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','frs_709','frs709@gmail.com','Haotian Wu','Snapphanevägen 6B,lgh 86','Karlskrona','Blekinge','SWEDEN','37140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 11:12:58',0,NULL,3,1,2,1,NULL,'frs_709\r\\'),(1501,691613204011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','eabrahams10','eabrahams_07@hotmail.com','Enrique Romero','PO BOx 742','Culebra','PR','UNITED STATES','00775-0742','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eabrahams10'),(1502,768418259012,220448682374,'Acer Aspire 4720 4720G 4720Z Bluetooth Module 2.0+cable',1,'BTAC2014',12.5,'eastar4','juliaf1949julia','juliaf1949@hotmail.com','Julia Fernandez','K31 Calle 9<br>La Monserrate','Hormigueros','PR','UNITED STATES','00660-1600','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 11:45:54',0,NULL,3,1,1,1,NULL,'juliaf1949julia\racer 5pin1.25 20cm \r\\'),(1503,691617095011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','efs.com','zefel@rogers.com','Efraim Fishman','ACCURA CANADA<br>25 Curity Avenue, Unit 2A','Toronto','ON','CANADA','M4B 3M2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 11:54:03',0,NULL,3,1,2,1,NULL,'efs.com\r\\'),(1504,768425598012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','hengtip','thadanabathptyltd@hotmail.com','Late Night Chemist Ryde','Shop 1/46-48 Blaxland Rd','Ryde','New South Wales','AUSTRALIA','2112','0298093928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 12:14:42',0,NULL,3,1,3,1,NULL,'hengtip\rOTGR001+OTGR002\rRA117713652CN\r\\'),(1505,768449353012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','jdpetrov69','jdpetrov@yahoo.com','Jovica Petrovski','14553 Barton Dr','Washington Township','MI','UNITED STATES','48094-3240','(586) 786-0275','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 13:23:01',0,NULL,3,1,1,1,NULL,'jdpetrov69\r\\'),(1506,0,320681209046,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',11.5,'eastar4','mexavon','mexavon@twcny.rr.com','Chet  Hains','84 Ames St','Mexico','NY','UNITED STATES','13114-3217','(315) 963-7357','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 13:40:15',0,NULL,3,1,1,1,NULL,'mexavon\r\\'),(1507,0,220765092420,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.49,'eastar4','mpsketch','paypal@mpsketch.com','Matt Proctor','2749 Ella Rae Ct','Lexington','KY','UNITED STATES','40511-8609','(859) 533-6555','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 13:42:08',0,NULL,3,1,1,1,NULL,'mpsketch\r\\'),(1508,0,320681208154,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','ghondo2000','ghondo@optonline.net','Gary Parlotto','30 Smokey Ridge Rd','Ringwood','NJ','UNITED STATES','07456-1930','(973) 831-7628','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 13:45:39',0,NULL,3,1,1,1,NULL,'ghondo2000\r\\'),(1509,517974571003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',34.68,'cnfaner','1805erika','erikaperniah@gmail.com','Erika Belinda Pernia Hernandez','Via Fonte Casella, 15','Montegranaro','Ascoli Piceno','ITALY','63014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 14:09:15',0,NULL,3,1,3,1,NULL,'1805erika \r欧标 HSMO006+HSMO016\r再发一个New Motorola H800 Bluetooth Wireless Headset \rRA117713618CN\r\\'),(1510,768471588012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','rabbitsfoot01','ltlowen@lowen.net','Lawrence T. Lowen','2 Executive Dr<br>Ste 560','Fort Lee','NJ','UNITED STATES','07024-3307','(201) 592-1700','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 14:27:34',0,NULL,3,1,1,1,NULL,'rabbitsfoot01\r\\'),(1511,569387971013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','chacacy','xdahermes@yahoo.co.jp','Kazuyuki Matsuo','5,22,19,202 Kitazawa Setagaya','Tokyo','Tokyo','JAPAN','1550031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 14:38:49',0,NULL,3,1,2,1,NULL,'chacacy\r\\'),(1512,569395570013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','platerb','platerb@gmail.com','Berl Stein','15 Ryder Cup Cir','Pittsford','NY','UNITED STATES','14534-1083','(585) 576-0977','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 15:10:55',0,NULL,3,1,1,1,NULL,'platerb\r\\'),(1513,768490437012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',1,'ANYA002',19.5,'eastar4','jasambond','vedran_radonic@yahoo.com','Vedran Radonić','Milana Rešetara 12','Zagreb','','CROATIA','10090','0922055172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 15:17:03',0,NULL,3,1,11,1,NULL,'jasambond\r\\'),(1514,518004836003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'',31.98,'cnfaner','easyleads','nlpbc@optonline.net','Mike J Lofrano','32 N Boston Rd','Jackson','NJ','UNITED STATES','08527-2452','(732) 240-9017','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 16:15:53',0,NULL,3,0,1,1,NULL,'easyleads\r\\'),(1515,0,320674798969,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 17:16:36',0,NULL,5,0,18,0,NULL,'michael2289xd'),(1516,768571951012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.49,'eastar4uk','ogaefumadr','sng@eircom.net','Stephen Graham','17 Devenish Road<br>Kimmage','Dublin','Dublin','IRELAND','12','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 18:14:25',0,NULL,3,1,3,1,NULL,'ogaefumadr\rRELO002\rRA117713621CN\r\\'),(1517,768575731012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.48,'eastar4uk','teal157','mauricefermoy@lineone.net','Maurice Fermoy','Handywater Farm<br>Sibford Gower','Banbury','Oxon','UNITED KINGDOM','OX15 5AE','07974303058','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-06 18:21:00',0,NULL,3,1,3,1,NULL,'teal157\rHSNO005  英标\rRA117713706CN\r\\ '),(1518,691765629011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','marcelobeltrame','marcelotrame@gmail.com','Marcelo BELTRAME','R. JOAQUIM ANTUNES, 852 AP22B<br>PINHEIROS','São Paulo','SP','BRAZIL','05415-001','55 11 94953331','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 18:31:30',0,NULL,3,1,3,1,NULL,'marcelobeltrame\rUDAP001\r\rRA117716866CN\r\\'),(1519,569476528013,230576481551,'10 pcs AUI Ethernet 10Base-T RJ45 Transceiver track#',5,'TRMX003*10',375,'eastar4','tnetusa','ebay@tnetus.com','T-NET TECHNOLOGY INC.','39 Plymouth St<br>Fl 1st Ste D','Fairfield','NJ','UNITED STATES','07004-1633','(718) 369-3828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 19:15:54',0,NULL,3,0,4,1,NULL,'tnetusa\rYW864489110CN\r'),(1520,518061862003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'',31.98,'cnfaner','darradserv','david@darrad.com','DARRAD Services','4457 Main St','Waitsfield','VT','UNITED STATES','05673-6028','(802) 496-2772','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 19:16:58',0,NULL,3,1,1,1,NULL,'darradserv\r\\'),(1521,569486896013,230412694830,'2.0 Bluetooth Module cable DELL mini10 10v 1010 1011',1,'BTDE2002',12.5,'eastar4','pascal2be','pascalvanpraet@hotmail.com','pascal vanpraet','kleine klijtstraat 48','deerlijk','','BELGIUM','8540','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 19:41:37',0,NULL,3,1,2,1,NULL,'pascal2be\r\\'),(1522,518072578003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',4,'OTJE001',63.6,'cnfaner','negraesimports','cesarnegraes@gmail.com','CESAR LUIZ NEGRAES','RUA DAS PALMEIRAS, 283 AP. 58<br>SANTA CECILIA','SÃO PAULO','São Paulo','BRAZIL','01226-010','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-06 19:45:28',0,NULL,3,1,3,1,NULL,'negraesimports\rOTJE001\rRA117713697CN\r\\'),(1523,768630616012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',3,'HSPL010',71.7,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 19:56:14',0,NULL,3,1,3,1,NULL,'solopo2009\rHSPL010  只发耳机  不给电源\rRA117713666CN\r\\'),(1524,569496974013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','talie1708','talie17@hotmail.com','nathalie beaumard','16 allee antoine sartori','alfortville','Île-de-France','FRANCE','94140','0663060575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:07:17',0,NULL,3,1,2,1,NULL,'talie1708\r欧标\r\\'),(1525,569496268013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','wupzank','kunzerne@gmail.com','Paw Kunz','ID: 29938666<br>Døgnposten 2662','2660 Brøndby','','DENMARK','2660','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:07:42',0,NULL,3,1,2,1,NULL,'wupzank\r银色的欧标\r\\'),(1526,569505285013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','rozner2606','r2606@zahav.net.il','Ofer Rozner','Israel Galili 15/2','Bear Sheva','','ISRAEL','84712','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:34:53',0,NULL,3,1,2,1,NULL,'rozner2606\r\\'),(1527,691832076011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','algahaim','t.piechota@interia.pl','Tomasz Piechota','218 The New Hardwicke<br>Catherines Lane, Church St.','Dublin','Dublin','IRELAND','7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:36:32',0,NULL,3,1,2,1,NULL,'algahaim\r\\'),(1528,768668251012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',2,'HSPL011',44,'eastar4','hershey101pr','malvarez248@aol.com','Mitchell Alvarez','95 Delmar St','Rochester','NY','UNITED STATES','14606-2512','(585) 802-0659','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 21:09:56',0,NULL,3,1,1,1,NULL,'hershey101pr\r\\'),(1529,768682445012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','chucksangel21777','chucksangel21777@yahoo.com','Chuck Evatt','901 E Kiehl Ave','sherwood','AR','UNITED STATES','72120-3031','(501) 902-8832','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'chucksangel21777'),(1530,691861402011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','mapel88','mapelboim@gmail.com','Maayan Apelboim','Itzhak sade 48','Ramat Hasharon','','ISRAEL','47259','050-5988287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 21:45:12',0,NULL,3,1,3,1,NULL,'mapel88\rRCLO006\rRA117716177CN\r\\'),(1531,568351127013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',2,'BAZA001',151.2,'eastar4','cloudancer972','rdfoutch@att.net','Rick Foutch','4416 Seville Ln','McKinney','TX','UNITED STATES','75070-4438','(972) 529-0528','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 22:57:56',0,NULL,3,1,1,1,NULL,'cloudancer972\r\\'),(1532,768706089012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',3,'BALO008',19.8,'eastar4','offensivestudio','offensivesoundstudio@hotmail.com','Joey Jermer','375 Clark St','Batavia','OH','UNITED STATES','45103-2814','(513) 260-9627','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 23:00:23',0,NULL,3,1,1,1,NULL,'offensivestudio\r\\'),(1533,768716645012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ernest01810','ernestmays@msn.com','Ernest mays','1627 E Shamwood St','West Covina','CA','UNITED STATES','91791-1321','(626) 523-5848','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 23:25:39',0,NULL,3,1,1,1,NULL,'ernest01810\r\\'),(1534,768718253012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','sheldonblue77','chris.sheldon@gmail.com','chris sheldon','3 gehrman ct','petrie','Queensland','AUSTRALIA','4502','0732855921','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 23:30:45',0,NULL,3,0,2,1,NULL,'sheldonblue77\r发210TS\r\\'),(1535,0,220765091535,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','pizzageek420','flybynht@gmail.com','Kevin Liesch','908 Eden Ave','Kaukauna','WI','UNITED STATES','54130-2658','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 23:56:08',0,NULL,3,1,1,1,NULL,'pizzageek420\r\\'),(1536,523941118004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','lilas0425','christine.huot@hotmail.com','Christine Huot','3135 Stornoway Circle','Oakville','ON','CANADA','L6M5H9','(647) 267-2028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 01:54:35',0,NULL,3,1,3,1,NULL,'lilas0425\rHSPL011\rRA117713683CN\r\\'),(1537,569586823013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','panchoavendano','favendan@gmail.com','FRANCISCO AVENDAÑO MORALES','AV. LAS FLORES 30, PIEDRA ROJA, CHICUREO, COLINA<br>SANTIAGO DE CHILE','SANTIAGO DE CHILE','','CHILE','9340713','56996090662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 02:24:58',0,NULL,3,1,3,1,NULL,'panchoavendano\rOTRA002\rRA117713635CN\r\\'),(1538,569587149013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','bittenbybug','l.bui@gmx.de','Bui, Tuan Linh','Apartment 8<br>90 Customhouse Street','Gisborne','','NEW ZEALAND','4040','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 02:27:25',0,NULL,3,1,2,1,NULL,'bittenbybug\r\\'),(1539,691939264011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.8,'eastar4','cheyenne39cs','aleymau.ebay@gmail.com','Claudia Cisneros','Genaro Garcia Ret. 29 Edif. 1 Int. 138<br>Col. Jardin Balbuena Del. Venustiano Carranza','Mexico, D.F.','Distrito Federal','MEXICO','15900','(52) 55-55712722','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 02:28:52',0,NULL,3,0,2,1,NULL,'cheyenne39cs\rHP 8pin 1.25 18cm \r\\'),(1540,768776989012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE003',27.98,'eastar4','mr2-cool','gadzooks33-buystuff@yahoo.com','Warren Douglass','1237 SW Kalyca Way','Aloha','OR','UNITED STATES','97006','(503) 349-0207','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-07 02:58:40',0,NULL,3,1,1,1,NULL,'mr2-cool\r\\'),(1541,569596869013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',26.1,'eastar4','red_staw','red.stawberry@gmail.com','Renny','6 Kiora st','Canley Heights','New South Wales','AUSTRALIA','2166','0412011063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 03:21:12',0,NULL,3,1,2,1,NULL,'red_staw\r\\'),(1542,656999124001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.99,'buysia','android-red','gsk66@comcast.net','Andy Kraska','18710 Archers Dr','Monument','CO','UNITED STATES','80132','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 03:38:30',0,NULL,3,1,1,1,NULL,'android-red\rLK037251917CN\r\\'),(1543,0,230605717592,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',10.5,'eastar4','slaphappie','erikbrandon@hotmail.com','Erik Brandon','2300 Loma Vista St','Pasadena','CA','UNITED STATES','91104-3401','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-07 04:16:46',0,NULL,3,1,1,1,NULL,'slaphappie\r\\'),(1544,569622230013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','elizabeth841410','elizabeth.buitrago@gmail.com','Elizabeth Buitrago','Rue du village 43','Lutry','','SWITZERLAND','1095','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 06:43:04',0,NULL,3,1,2,1,NULL,'elizabeth841410\r\\'),(1545,768822872012,220525323769,'NEW GENUINE NOKIA BH-302 BLUETOOTH HEADSET BH 302',1,'HSNO014',16.4,'eastar4','yiotayk_cy','yiotayk@yahoo.gr','Yiota Kyriacou','4, Marcou Dracou<br>Ayios Amvrosios','Lemesos','','CYPRUS','4710','35797779437','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 06:43:17',0,NULL,3,1,2,1,NULL,'yiotayk_cy\r欧标\r\\'),(1546,768824885012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',10.69,'eastar4','danart66','artdan@list.ru','Bogdanov Rafael','Pervomayskaya 43a - 9','Ufa','Bashkortostan','RUSSIAN FEDERATION','450112','+79373633360','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 06:53:05',0,NULL,3,0,2,1,NULL,'danart66\r\\'),(1547,691992209011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.8,'eastar4','k.tarrant','a.tarrant@leetbaka.com','Kevin Tarrant','108 Elk ST','Buffalo','NY','UNITED STATES','14210-1420','(716) 390-5829','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 06:56:45',0,NULL,3,0,1,1,NULL,'k.tarrant\rHP 8pin 1.25 18cm \r\\'),(1548,569633277013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','cormann23','christophcormann@web.de','Cormann, Christoph','Adalbertsteinweg 175a','Aachen','','GERMANY','52066','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 07:44:06',0,NULL,3,1,2,1,NULL,'cormann23\r\\\r'),(1549,569634101013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','hamikavag','hmayak.avagyan@gmail.com','Hmayak Avagyan','Qajaznuni Str. bld 2, Apt. 20','Yerevan','','ARMENIA','0070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 07:51:04',0,NULL,3,1,2,1,NULL,'hamikavag\r\\'),(1550,523992798004,140393734505,'%%% NEW Lowepro ROVER PLUS AW Photo Camera Bag Backpack',1,'',107.99,'cnfaner','stianmhell','stianmhell@hotmail.com','Stian M. Helland','Havnahagen','Fitjar','Fitjar','NORWAY','5419','41654541','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-07 08:09:09',0,NULL,3,0,5,1,NULL,'stianmhell\rCP226344539CN\r'),(1551,691926028011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','limbehexpert','limbehexpert@hotmail.com','Ang Marc','21 How Sun Walk','Singapore','','SINGAPORE','538443','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 08:21:21',0,NULL,3,1,11,1,NULL,'limbehexpert'),(1552,569650403013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','rosch1972','ebay@schreiber.co.at','Roland Schreiber','C/O Raiffeisenbank Leibnitz<br>Bahnhofstraße 2','Leibnitz','','AUSTRIA','8430','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 09:36:52',0,NULL,3,1,3,1,NULL,'rosch1972\rMOSA002 \r\r\\潘'),(1553,569653533013,230563830400,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',22.99,'eastar4','3dmultimedia','andribanez@terra.es','ANDRES IBAÑEZ MULLOR (3DMULTIMEDIA)','C/ F.SOLER I PUIGDOLLERS, 117 BJ6','SANT VICENÇ DE CASTELLET','Cataluña','SPAIN','08295','658796301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 09:58:41',0,NULL,3,1,2,1,NULL,'3dmultimedia\r\\'),(1554,569665728013,230412690655,'2.0 New ASUS Bluetooth Module +cable for EEEPC1101HA',1,'BTHU2001',12.5,'eastar4','briscosdad','stroeer@versanet.de','Armin Ströer','Alter Dortmunder Weg 21','Schwerte','','GERMANY','58239','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 11:05:07',0,NULL,3,1,2,1,NULL,'briscosdad\r华硕10pin 0.8 6cm \r、'),(1555,569669838013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',2,'BTDE2100',17.98,'eastar4','zard98','wineapple@gmail.com','jun soo Ko','601ho-201dong, Samsung Raemian 2-Cha Apt.<br>Banwol-dong','Hwaseong Si, Gyeonggi-Do','','KOREA,REPUBLIC OF','None.US','010-3230-0083','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 11:28:51',0,NULL,3,1,2,1,NULL,'zard98\r\\'),(1556,569690276013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','rui.mannuel','rui.ariana@gmail.com','Rui Teixeira','Rua dos Emigrantes 9','Velas','S Jorge - Açores','PORTUGAL','9800-564','295098149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 13:07:12',0,NULL,3,1,2,1,NULL,'rui.mannuel\r\\'),(1557,768938893012,220704222400,'Logitech diNovo Bluetooth ultra-flat Keyboard+mediapad',1,'KBLO001',59.99,'eastar4','souichiros','yshuto@nifty.com','Yasuhiro Shuto','6-1-16-803<br>Togoshi','Shinagawa-ku','Tokyo','JAPAN','1420041','819093073406','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 13:55:35',0,NULL,3,1,3,1,NULL,'souichiros\rKBLO001\rRA117712060CN\r\\'),(1558,518279011003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','sega_vs','sega1984@gmail.com','Sergey Vasiliev','Engelsa 74-89','Verkhnaya Salda','Sverdlovskaya oblast','RUSSIAN FEDERATION','624766','+7 909 0171040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 14:28:44',0,NULL,3,1,3,1,NULL,'sega_vs\rHSNO008欧标\rRA117716818CN\r\\'),(1559,692111783011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','crazyquay','fgatien@gmail.com','Frank Gatien','1240 Roland-Gagnon','Chambly','QC','CANADA','J3L 5N4','(450) 658-2438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 14:39:20',0,NULL,3,1,2,1,NULL,'crazyquay\r\\'),(1560,0,320682118806,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',11,'eastar4','santuar','diego281975@yahoo.com','Diego Munoz','7980 NW 50th St<br>Apt 207','Lauderhill','FL','UNITED STATES','33351','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 14:52:49',0,NULL,3,1,1,1,NULL,'santuar\r\\'),(1561,0,220765570782,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','jeb48','jim@bollman.com','Jim Bollman','3323 Eaton Rd','Williamson','NY','UNITED STATES','14589-9524','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-07 15:20:31',0,NULL,3,1,1,1,NULL,'jeb48\r\\'),(1562,0,320681689951,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',10.99,'eastar4','janebecker','buyhomes@charter.net','Jane Becker','67 Moscow Rd.','Jefferson','MA','UNITED STATES','01522','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 15:43:15',0,NULL,3,1,1,1,NULL,'janebecker\r\\'),(1563,768986071012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','snipes86','flaming-frets@sbcglobal.net','Jason Tamplin','7301 Kary Lynn Dr E','Watauga','TX','UNITED STATES','76148-1768','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 16:04:38',0,NULL,3,1,1,1,NULL,'snipes86\r\\'),(1564,518302886003,130490194854,'Genuine Logitech Harmony 880 Universal Remote Control',1,'RCLO002',75.99,'cnfaner','merverine','merv_sy@hotmail.com','Mervin Sy','2 Hiram Johnson Road','Stouffville','ON','CANADA','L4A 0H6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 16:08:27',0,NULL,3,1,3,1,NULL,'merverine\rRCLO002\rRA117716821CN\r\\'),(1565,692141782011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','joemcallister1968','joe@mcallisterdesign.com','Joe McAllister','15 Beaufort Drive<br>Knightsbridge','Londonderry','Londonderry','UNITED KINGDOM','BT47 6FG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 16:09:45',0,NULL,3,1,3,1,NULL,'joemcallister1968\rMOAP001\rRA117716906CN\r\\'),(1566,0,220765570780,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','minhsnguyen','msnguyen@portigent.com','Minh Nguyen','2677 Sequoia Creek Dr','San Jose','CA','UNITED STATES','95121-3207','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 16:12:42',0,NULL,3,1,1,1,NULL,'minhsnguyen\r\\'),(1567,524085141004,140516092415,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'cnfaner','dhyounker','don@cabridal.com','Donald Younker','1095 Riverwoods Dr','Akron','OH','UNITED STATES','44313-5953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-07 16:18:38',0,NULL,3,1,1,1,NULL,'dhyounker\r\\'),(1568,569740053013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','jamescheung97','jamescheung98@hotmail.com','James Cheung','Flat 2107 Block D<br>Mei Chung Court','Tai Wai','NT','HONG KONG','0','96516004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 16:30:11',0,NULL,3,1,2,1,NULL,'jamescheung97\r\\'),(1569,692154459011,320575299743,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',1,'WLAT003',31.9,'eastar4','bobertlo','bobertlo@gmail.com','robert lowry','9516 Penn Cir','bloomington','MN','UNITED STATES','55431-2425','(952) 884-6127','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 16:36:51',0,NULL,3,1,1,1,NULL,'bobertlo\r\\'),(1570,692158814011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mansuang','mansuang@gmail.com','Mansuang Pawong','iTech Mobile Shop<br>140/362 Soi Kangsadan, Saereesamphan Rd. Moo 14 Tambol Nai Muang','Muang Khon Kaen','Khon Kaen','THAILAND','40000','+66868555543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 16:46:09',0,NULL,3,1,2,1,NULL,'mansuang\r\\'),(1571,769007829012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','kuciniera','racizammit@yahoo.com','Simon Zammit','28 Amaryllis<br>st. magaret street','San Gwann','Europe','MALTA','sgn 1671','+35679421154','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 16:56:18',0,NULL,3,1,2,1,NULL,'kuciniera\r\r欧标\r\\'),(1572,769033295012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',3,'HSPL010',71.7,'eastar4','erod55car','rodrac0609@aol.com','Carlos Rodriguez','10003 nw 130 st','Hialeah','FL','UNITED STATES','33018','(786) 553-9098','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 18:03:07',0,NULL,3,1,1,1,NULL,'erod55car\r\\'),(1573,524122200004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','jovinceto','fagotne@mail.ru','Evgeny Tamarovsky','Vorovskogo 21A - 31','Chelyabinsk','Chelyabinsk','RUSSIAN FEDERATION','454092','+79026141839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 18:24:16',0,NULL,3,1,3,1,NULL,'jovinceto\rHSPL010\rRA117716897CN\r\\'),(1574,569777838013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','oukkan','2easy4me@gmail.com','Silvia Hernandez Rodriguez','Jose Manuel Riquelme #4, Poblacion Buenos Amigos Sur, Forestal Alto','Vina del Mar','Vina del Mar','CHILE','2520000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 18:24:36',0,NULL,3,1,2,1,NULL,'oukkan\r\\'),(1575,657232130001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.99,'buysia','domcal61','dcalabrese@wje.com','Dominic Calabrese','13581 Pond Springs Rd<br>Ste 107','Austin','TX','UNITED STATES','78729-4423','(512) 787-0549','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 18:27:58',0,NULL,3,1,1,1,NULL,'domcal61\r\\'),(1576,769071910012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','dalios1964','dalio@delfi.lv','Jurijs Ivanovs','Slavu 23a-10','Riga','','LATVIA','LV-1035','37129247420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 19:18:04',0,NULL,3,1,2,1,NULL,'dalios1964\r\\'),(1577,569797152013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','zeveimaxim','a1980h@mail.ru','Maxim Filkin','rotshild 98/4','rishon lezion','','ISRAEL','75208','0547615250','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 19:19:13',0,NULL,3,1,2,1,NULL,'zeveimaxim\r\\'),(1578,657256613001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.99,'buysia','acru7851','crztwtms@aol.com','alexander cruz','1500 E 63rd St','long beach','CA','UNITED STATES','90805-3114','(562) 428-7420','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 19:22:45',0,NULL,3,1,1,1,NULL,'acru7851\r\\'),(1579,769090809012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','trantuancuong','quocbao.do@gmail.com','Bao Do','Hebelstr. 16','Hirschberg-Leutershausen','','GERMANY','69493','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 19:30:25',0,NULL,3,1,2,1,NULL,'trantuancuong\r\\'),(1580,692240774011,320552968178,'New Motorola HS810 Bluetooth Wireless Headset HS-810',1,'HSMO017',20.99,'eastar4','ronaldbparks','ronaldbparks@hotmail.com','Ronald B Parks','5259 Zurich Pl NE','Albuquerque','NM','UNITED STATES','87111','(505) 296-6801','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 19:33:37',0,NULL,3,1,1,1,NULL,'ronaldbparks\r\\'),(1581,769093741012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',50.3,'eastar4','alik_31','alik31@hotmail.com','Alexander Alexeev','149 26th St NW<br>Apt 1619','Atlanta','GA','UNITED STATES','30309-2074','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 19:38:22',0,NULL,3,1,1,1,NULL,'alik_31\r\\'),(1582,692244323011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','trudofobique','trudofobic@gmail.com','Anton  Kostrzhevsky','Usievicha dom 23, kv 257','Moscow','Moscow','RUSSIAN FEDERATION','125315','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 19:41:18',0,NULL,3,1,2,1,NULL,'trudofobique\r\\'),(1583,0,320682118747,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',10,'eastar4','johannadt','johanna.tuballes@gmail.com','Johanna Tuballes','8447 Homelawn St','Jamaica','NY','UNITED STATES','11432-2154','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-07 19:53:58',0,NULL,3,1,1,1,NULL,'johannadt\r\\'),(1584,769110482012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','vasileioslos','bacilis_los@hotmail.com','VASILIS LOS','IOUSTINIANI 40','chios','CHIOS','GREECE','82100','00302271029707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 20:07:15',0,NULL,3,0,2,1,NULL,'vasileioslos\r\\'),(1585,569750459013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','jesse008','jroq@dslextreme.com','Jesse Rock','20555 Devonshire Street<br>Unit #206','Chatsworth','CA','UNITED STATES','91311-1123','(818) 209-9191','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 20:23:47',0,NULL,3,1,1,1,NULL,'jesse008\r\\'),(1586,569817320013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','polarb1957','polarb1957@bellsouth.net','David W. Hodgens','31 Stonecreek Dr SW','Cartersville','GA','UNITED STATES','30120','(770) 547-9190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 20:08:39',0,NULL,3,1,1,1,NULL,'polarb1957\r\\'),(1587,569830805013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.99,'eastar4','sergietgr','sergiogarcia82@hotmail.com','sergio garcia rodriguez','maestro chapi 1-18','massamagrell','Comunidad Valenciana','SPAIN','46130','619841876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 20:49:41',0,NULL,3,1,2,1,NULL,'sergietgr\r\\'),(1588,769142390012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','medina2532','medina2532@msn.com','Mildred Medina','2532 Shadybranch Dr','Orlando','FL','UNITED STATES','32822-4171','(407) 399-6433','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 21:10:51',0,NULL,3,1,1,1,NULL,'medina2532\r\\'),(1589,769143414012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','ppen111','petruspen@suomi24.fi','Petrus Pennanen','Pengerkatu 25 c 72','Helsinki','','FINLAND','00500','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 21:12:41',0,NULL,3,1,2,1,NULL,'ppen111\r\\'),(1590,569844676013,230603109640,'New CX680 Sennheiser Adidas Sports Earphones Earbuds',1,'HSSS001',40.99,'eastar4','sic6ixandrew','sic6ix@gmail.com','Andrew Gealy','124 Linden St','Ravenna','OH','UNITED STATES','44266-2519','(330) 842-2854','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 21:37:10',0,NULL,3,1,1,1,NULL,'sic6ixandrew\r\\'),(1591,769160421012,220765484379,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',37,'eastar4uk','ajk1337','arjan.koopen@xs4all.nl','Arjan Koopen','Blomikkers 9','Workum','','NETHERLANDS','8711DA','0515-541312','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 21:55:01',0,NULL,3,1,3,1,NULL,'ajk1337\rWWSI006\rRA117716870CN\r\\'),(1592,0,220765570781,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',11.49,'eastar4','d8veecroc8','sltrhl0710@aol.com','David Lee','408 S Curtis Ave<br>Apt 5','Alhambra','CA','UNITED STATES','91803-1722','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 22:21:10',0,NULL,3,1,1,1,NULL,'d8veecroc8\r\\'),(1593,569864023013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','gkin7416','g_dog_2@msn.com','Geoffrey Kinson','4524 Wolf Grove Rd','Lanark','ON','CANADA','k0g1k0','(613) 259-2440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 22:52:05',0,NULL,3,1,2,1,NULL,'gkin7416\r\\'),(1594,569864358013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','ishy','isarmientocom@gmail.com','Ismael Sarmiento','5842 SW 5th Ter','Miami','FL','UNITED STATES','33144-3908','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 22:54:18',0,NULL,3,1,1,1,NULL,'ishy\r\\'),(1595,657338988001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.99,'buysia','johnr1934john','johnobnr@aol.com','John Obenauer','37 Carrie Ct','Nutley','NJ','UNITED STATES','07110-3003','(973) 667-2522','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'johnr1934john'),(1596,657338988001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.99,'buysia','johnr1934john','johnobnr@aol.com','John Obenauer','37 Carrie Ct','Nutley','NJ','UNITED STATES','07110-3003','(973) 667-2522','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 22:55:15',0,NULL,3,1,1,1,NULL,'johnr1934john\r\\'),(1597,569868985013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','mikestv','mikestvd@hotmail.com','mike lankuts','4 catts place','gilmore','Australian Capital Territory','AUSTRALIA','2905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 23:17:05',0,NULL,3,1,2,1,NULL,'mikestv\r\\'),(1598,769194017012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','krypticdeath','contact.alexchavez@gmail.com','Alex Chavez','870 W 232nd St','Torrance','CA','UNITED STATES','90502-2584','(310) 367-9519','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 23:48:11',0,NULL,3,1,1,1,NULL,'krypticdeath\\'),(1599,692342718011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','kburris1960','kburris3@sbcglobal.net','Kelly Burris','1163 Halloran St','Cahokia','IL','UNITED STATES','62206-2107','(618) 337-4087','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 00:17:06',0,NULL,3,1,1,1,NULL,'kburris1960\r\\'),(1600,518446250003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',2,'OTJE001',31.8,'cnfaner','stankokaishev','stankokaishev@yahoo.com','Kaishev Stanko','3017 Hollow Valley Dr','Fort Worth','TX','UNITED STATES','76244-5534','(817) 262-8651','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-04-08 00:55:40',0,NULL,3,1,1,1,NULL,'stankokaishev\r\\'),(1601,692355092011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','mini2138','benb@tsn.cc','ben burg','369 high st','maitland','New South Wales','AUSTRALIA','2320','0417292515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 01:05:36',0,NULL,3,1,2,1,NULL,'mini2138\r\\'),(1602,769226776012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','arthurmota','arthursmota@gmail.com','Arthur Mota','Jonas Guerra Street, 67<br>Ap. 401','Recife','Pernambuco','BRAZIL','52040-253','55-81-96104358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 01:51:07',0,NULL,3,1,2,1,NULL,'arthurmota\r\\'),(1603,692370035011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','aleksandrazorkin','alexzorkin@gmail.com','Aleksandr Zorkin','Sibrevkoma str. 6-56','Novosibirsk','','RUSSIAN FEDERATION','630007','+7-383-2911-573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 02:01:42',0,NULL,3,1,2,1,NULL,'aleksandrazorkin\r\\'),(1604,569579326013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','klusiris','ksj0408@gmail.com','Seongju Kim','Hansin Hyu-Plus 1 Cha Apt. 103-1701, Gaeun-dong','Wonju-si','Gangwon-do','KOREA,REPUBLIC OF','220110','01094004453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 02:15:45',0,NULL,3,1,2,1,NULL,'klusiris\r\\'),(1605,569906223013,230504995230,'New Motorola H670 Bluetooth Wireless Headset H 670',1,'HSMO010',14.99,'eastar4','electrobay11','info.electrobay@gmail.com','Bhartendu Thakur','X-86, Bharat Vihar, Prem Nagar - II<br>Nangloi','New Delhi','Delhi','INDIA','110086','9999801444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 02:19:23',0,NULL,3,1,2,1,NULL,'electrobay11\r\\\r'),(1606,518467176003,130493270294,'New Sony Ericsson HBH-608 BLUETOOTH HEADSET track#',1,'HSSE007',19.9,'cnfaner','briannguyenq','briannguyenq@yahoo.com','Tuong Nguyen','2357 KILAUEA AVE','HILO','HI','UNITED STATES','96720','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 02:47:34',0,NULL,3,1,1,1,NULL,'briannguyenq\r\\'),(1607,518469407003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','mrsmaldonado05','mrsmaldonado05@hotmail.com','TAMARA MALDONADO','7631 S OGLESBY AVE','CHICAGO','IL','UNITED STATES','60649-4120','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 03:00:48',0,NULL,3,1,1,1,NULL,'mrsmaldonado05\r\\'),(1608,524254501004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','llebpmacp','llebpmacp@hotmail.com','Paul Campbell','108 Stonewall Dr','Carrollton','GA','UNITED STATES','30117-3515','(478) 456-7755','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 03:43:54',0,NULL,3,1,1,1,NULL,'llebpmacp\r\\'),(1609,569930361013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','darioribas','dario_ribas@yahoo.com.br','Dário Ribas','Rua NS-03, 117, Cidade dos Funcionarios','Fortaleza','Ceará','BRAZIL','60823-670','0-55-85-32758520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 04:45:48',0,NULL,3,1,3,1,NULL,'darioribas\rMOSA002\rRA117716883CN\r\\'),(1610,692417603011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.8,'eastar4','mick42101','ramila55@hotmail.com','MAHENDRA lad','55 mill street','wolverhampton','West Midlands','UNITED KINGDOM','wv14 0hn','07759444730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 05:54:19',0,NULL,8,1,17,0,NULL,'mick42101\racer 6pin1.25 23cm '),(1611,769165821012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',20,'TRMX003',167,'eastar4','etonishar','zycon3@comcast.net','Diamond Communications','11706 Garrison Forest Rd','Owings Mills','MD','UNITED STATES','21117','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 06:02:24',0,NULL,3,1,4,1,NULL,'etonishar\rmx20t   \rYW864941972CN'),(1612,569945631013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','etc_films','studioetc@gmail.com','Joel C K Chu','Flat 2, 19 New Compton Street','London','London','UNITED KINGDOM','WC2H 8DS','07883185163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 06:42:15',0,NULL,3,1,2,1,NULL,'etc_films\r\\'),(1613,691680336011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','bustedboy','bsteeer@gmail.com','Tomáš Míka','Nerudova 294/II','Soběslav','South Bohemia','CZECH REPUBLIC','392 01','728718731','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 06:46:42',0,NULL,3,0,2,1,NULL,'bustedboy\r\\'),(1614,692420139011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','mick42101','ramila55@hotmail.com','MAHENDRA lad','55 mill street','wolverhampton','West Midlands','UNITED KINGDOM','wv14 0hn','07759444730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 07:00:58',0,NULL,3,1,2,1,NULL,'mick42101\racer 8pin1.00 8cm \r再发一个2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable\racer 6pin1.25 23cm \r\\'),(1615,518499741003,130458644382,'New inBox GENUINE NOKIA BH-207 BLUETOOTH HEADSET track#',6,'HSNO010',137.94,'cnfaner','tele-stop','tele-stop@t-online.de','Thomas Groß','Poststr. 4','Beckingen','','GERMANY','66701','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 07:03:46',0,NULL,3,1,3,1,NULL,'tele-stop\rHSNO010\r欧标  \rRA117716676CN\r、'),(1616,692430507011,320422591058,'NEW AKE Expresscard express to Four USB 2.0 Ports BC268',2,'ADAK003',21.8,'eastar4','pixelparadise','wolfgang@winne.de','Wolfgang Winne','Birkenhof 5','Achim-Uphusen','','GERMANY','28832','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 07:05:41',0,NULL,3,1,2,1,NULL,'pixelparadise\r\\'),(1617,692440020011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','lilphillyboy','lilphillyboy@gmail.com','Harry Williamson','11411 Middleburgh Dr','Tomball','TX','UNITED STATES','77377-8612','(512) 659-5061','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 07:49:24',0,NULL,3,1,1,1,NULL,'lilphillyboy\r\\'),(1618,524285027004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','hansi-hand-enkel','m_roeller@gmx.de','Michael Röller','Otto-Dix-Ring 66','Dresden','','GERMANY','01219','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 07:56:15',0,NULL,3,1,3,1,NULL,'hansi-hand-enkel\rWLAT002\r\rRA117712405CN\r\\'),(1619,692460799011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','fmcduijn','frederik@duijn.net','Frederik Duijn','Postbus 24047','Den Haag','','NETHERLANDS','2490AA','0642089311','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 09:25:08',0,NULL,3,1,2,1,NULL,'fmcduijn\r、'),(1620,692466816011,320443640787,'Acer Timeline 1810 1410 1410T Bluetooth Module 2.0',1,'BTAC2010',35.45,'eastar4','wolfg72','wolfman31@gmx.de','Wolfgang Kriebel','Kreuzlach 13a','Neuendettelsau','','GERMANY','91564','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 09:56:27',0,NULL,3,1,3,1,NULL,'wolfg72\racer 5pin 1.25 3cm\r再发一个New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna\rRA117717005CN\r\\\r'),(1621,569979821013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','szomorcsabi','szomorcsaba@hotmail.com','Szomor Csaba','Beregszász street 6. F/1<br>Menedékes street 1. F/1','Budapest','','HUNGARY','1118','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 10:21:17',0,NULL,3,1,2,1,NULL,'szomorcsabi\\'),(1622,769347395012,220713846368,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET',1,'HSNO016',11.9,'eastar4uk','ragnarjonny','s.ragnar@yahoo.no','Ragnar Sundsås','Bleikenveien 173','Brandbu','','NORWAY','2760','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-08 10:23:23',0,NULL,3,1,2,1,NULL,'ragnarjonny\r欧标\\'),(1623,518536232003,130458926995,'New Ultimate Ears METRO.FI 220vi UE 220VI voice track#',1,'HSUE003',28.99,'cnfaner','arielm2828','rel.mta@gmail.com','Ariel Motola','wingate 55<br>apartment 9','beer sheva','','ISRAEL','84428','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 11:00:13',0,NULL,3,1,3,1,NULL,'arielm2828\rHSUE003\rRA117716662CN\r、'),(1624,692494422011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','paultje0070','paul.dingenouts@freeler.nl','Paul Dingenouts','Stinzenlaan Zuid 268','Breukelen','','NETHERLANDS','3621TJ','(0346) 265730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 11:38:31',0,NULL,3,1,2,1,NULL,'paultje0070\r\\'),(1625,524333792004,140482241394,'New Genuine Motorola H555 Bluetooth Headset track#',1,'HSMO008',13.99,'cnfaner','chardo1983','chardo2002@yahoo.com','Richard Bonessi','65 City Brook Rd','Naugatuck','CT','UNITED STATES','06770-3156','(203) 558-8545','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 12:49:34',0,NULL,3,1,1,1,NULL,'chardo1983\r÷'),(1626,692528911011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',2,'TRTS001*10',166,'eastar4','phil5841','philippe.olivi@laposte.net','OLIVI Philippe','98 bd Virgile BAREL','NICE','Provence-Alpes-Côte d\'Azur','FRANCE','06300','0679221901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 13:35:36',0,NULL,3,1,4,1,NULL,'phil5841\rYW864941880CN\r'),(1627,518573003003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','caroleichler70pk','caroleichler@yahoo.com','william eichler','1250 Thornton Dr','sequim','WA','UNITED STATES','98382','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 14:06:41',0,NULL,3,1,1,1,NULL,'caroleichler70pk\\'),(1628,0,220766021687,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',10.99,'eastar4','ne14me07166','ne14me7166@yahoo.com','Tina Smith','3050 Shady Oak Dr','Saint Charles','MO','UNITED STATES','63301-5004','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 14:37:36',0,NULL,3,1,1,1,NULL,'ne14me07166\\'),(1629,769423945012,220653561343,'New Atheros DualBand AR9287 Wireless  Half Card+antenna',2,'WLAT007+ANTY001',50.75,'eastar4','smorton39','ebay@boundlesss.com','Steve Morton','39 Old Good Hill Rd<br>Boundless Security Systems','Oxford','CT','UNITED STATES','06478-1508','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 14:45:49',0,NULL,3,1,1,1,NULL,'smorton39\\\r再发一个NEW Atheros AR5B93 Half Height Wireless WiFi card 300M'),(1630,524360009004,140515704012,'New GENUINE NOKIA HS-36W  BLUETOOTH HEADSET track#',1,'HSNO026',15.5,'cnfaner','gaglianogia','giagagliano@yahoo.it','giacomo gagliano','via n. martoglio, 5','Niscemi','CL','ITALY','93015','3383235241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 14:50:46',0,NULL,3,1,3,1,NULL,'gaglianogia\rHSNO026\r欧标\rRA117712626CN\r\\'),(1631,0,320682117454,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.5,'eastar4','hotrod5071','af30@sbcglobal.net','Melvin Jenkins','7518 Kleberg','San Antonio','TX','UNITED STATES','78250','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 15:48:46',0,NULL,3,1,1,1,NULL,'hotrod5071\r÷'),(1632,769457081012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',2,'HSSH001',71.98,'eastar4','kylekirch18','kizkracker30@sbcglobal.net','Kyle Kirchenbauer','224 Saint Paul Dr','Fremont','OH','UNITED STATES','43420-9291','(419) 307-7472','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 15:57:53',0,NULL,3,1,1,1,NULL,'kylekirch18\\'),(1633,0,220766022740,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',10.99,'eastar4','harborbikes','wifiskeens@gmail.com','Clarence Skeens','22618 Cuyama Ct','Apple Valley','CA','UNITED STATES','92307','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 16:18:30',0,NULL,3,1,1,1,NULL,'harborbikes\r÷'),(1634,692587409011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.9,'eastar4uk','morozhenoye74','jason@squodge.com','Mr. Wai Hung Jason Yip','46 Maple House<br>Idonia Street','Deptford','London','UNITED KINGDOM','SE8 4LT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 16:24:54',0,NULL,3,1,3,1,NULL,'morozhenoye74\rWLAP002\rRA117712348CN\r\\'),(1635,769484657012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',12.99,'eastar4uk','d13ark','deanobarker@hotmail.com','Dean Barker','10 Farm Close','Crowthorne','Berkshire','UNITED KINGDOM','RG45 6SE','01344775006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 17:03:23',0,NULL,3,1,3,1,NULL,'d13ark\rHSMO017\r英标\rRA117712705CN\r\\'),(1636,570080107013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','barbusps','barbusps@catt.com','Barbara Hickman','344 Sutton Dr','Ringgold','GA','UNITED STATES','30736-7264','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 17:30:18',0,NULL,3,1,1,1,NULL,'barbusps\r\\'),(1637,769503240012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',16.7,'eastar4','chilidogmtl','gabeko77@gmail.com','Gabriel Ko','19 Stayner  Apt #5','Westmount','QC','CANADA','H3Z 1W3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 17:42:27',0,NULL,3,1,2,1,NULL,'chilidogmtl\r\\'),(1638,769506981012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','lachman9311','michael.lachman@gmail.com','Michael Lachman','Loa Haari 9','Migdal Haemek','','ISRAEL','23505','+972-54-6215638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 17:51:20',0,NULL,3,1,2,1,NULL,'lachman9311\r\\'),(1639,769513528012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','juzt-me','the_puter_nut@yahoo.com','Jessica Langdeaux','4826  Wade Stedman Rd.','Wade','NC','UNITED STATES','28395-8550','(605) 881-5623','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 18:05:43',0,NULL,3,1,1,1,NULL,'juzt-me\r÷'),(1640,692634369011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','melisasouth','randmsouth@gmail.com','MELISA SOUTH','133 MEDITERRANEAN','AMHERSTBURG','ON','CANADA','N9V3X7','(519) 736-0905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 18:16:59',0,NULL,3,1,3,1,NULL,'melisasouth\rRCLO006\rRA117712643CN\r\\'),(1641,769527000012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',12.5,'eastar4','pjotrd','pm_dekker@live.nl','Piet Dekker','Tom Mandersstraat 74','Hengelo','The Netherlands','NETHERLANDS','7558 MR','+31 74 2483476','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 18:30:49',0,NULL,3,1,2,1,NULL,'pjotrd\racer 5pin1.25 15cm \r\\'),(1642,570106116013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',33.76,'eastar4','theigas','igasgeek@me.com','Igor Kapkov','Stachek, 88, 39','St. Petersburg','St Petersburg','RUSSIAN FEDERATION','198096','7-921-640-8585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 18:42:48',0,NULL,3,1,3,1,NULL,'theigas\rCACN004\rRA117712657CN\r\\'),(1643,524435086004,140515701798,'New GENUINE NOKIA BH-205 BLUETOOTH HEADSET track#',1,'HSNO009',15.5,'cnfaner','hagar.cohen','hagarcohenil@gmail.com','hagar cohen','3 stern street<br>apartment 7','kiryat ono','kiryat ono','ISRAEL','55602','+972503004728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 19:16:49',0,NULL,3,1,3,1,NULL,'hagar.cohen\rHSNO009\rRA117712630CN\r\\'),(1644,524435019004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',2,'HSJA002',43,'cnfaner','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 19:23:44',0,NULL,3,1,3,1,NULL,'vjendrisvelimir\rHSJA002  欧标\rRA117712731CN\r\\'),(1645,692674208011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','jenia_t','jenia11@hotmail.com','Evgeny Teplits','Liber Zeev 10/31','Natanya','','ISRAEL','42524','0546221244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 19:39:18',0,NULL,3,1,3,1,NULL,'jenia_t\rRCLO006\rRA117716954CN\r\\'),(1646,692671210011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','bc-nj','carscadden@gmail.com','Brian K. Carscadden','117 Thackeray Rd','Oakland','NJ','UNITED STATES','07436','(201) 786-8847','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 19:39:57',0,NULL,3,1,1,1,NULL,'bc-nj\\'),(1647,769593940012,220713846397,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET',1,'HSNO017',13.29,'eastar4uk','neilmaggi','neil.maggi@sky.com','Neil Hutchinson','2 Kingfisher Court','Normanton','West Yorkshire','UNITED KINGDOM','WF6 1ZW','01924894372','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 20:42:02',0,NULL,3,1,3,1,NULL,'neilmaggi\r英标 \rHSNO017\rRA117712422CN\r\\'),(1648,769604593012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',2,'OTGR001+OTGR002',79.8,'eastar4','strel','strel@mindspring.com','David P. Strelinger','3306 Horsehead Bay Dr NW','Gig Harbor','WA','UNITED STATES','98335-5841','(253) 509-4447','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 21:06:10',0,NULL,3,1,1,1,NULL,'strel\r÷'),(1649,692728870011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','manmohan','pnjpatel@yahoo.com','Punjabhai K. Patel','16209 Mount Baden Powell St','Fountain Valley','CA','UNITED STATES','92708','(714) 839-8637','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 21:55:05',0,NULL,3,1,1,1,NULL,'manmohan\r÷'),(1650,0,230606151421,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','custom-mugs4u','kevinwc@cox.net','Kevin Crowley','4020 Arville St<br>Apt 136','LAS VEGAS','NV','UNITED STATES','89103-5917','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 22:23:11',0,NULL,3,1,1,1,NULL,'custom-mugs4u\\'),(1651,692754821011,320679575380,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',12.95,'eastar4uk','thinkpad.parts','bingobargains3@googlemail.com','Chris Gates','22 Millbank','Cam','Gloucestershire','UNITED KINGDOM','GL11 5PT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 23:23:22',0,NULL,3,1,3,1,NULL,'thinkpad.parts\rWLAP001\rRA117712436CN\r\\'),(1652,524507988004,140429366442,'2.1 HP Pavilion DV1000 DV1100 bluetooth module track#',1,'BTHP2109',13.99,'cnfaner','asesor_en_digitales','rodrygo@chateando.tv','Rodrigo Pacheco','Sucua Oe1-49 y Gral. Urdaneta<br>Sector San Bartolo','Quito','Pichincha','ECUADOR','EC170148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 00:30:34',0,NULL,3,1,3,1,NULL,'asesor_en_digitales\rHP 8pin 1.25 3cm \rBTHP2109\rRA117712396CN\r\\'),(1653,570202792013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','randarichardson','randyr@mchsi.com','Randy Richardson','28785 Alicia Pl','Grand Rapids','MN','UNITED STATES','55744','(218) 326-3949','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 00:53:31',0,NULL,3,1,1,1,NULL,'randarichardson\\'),(1654,769694122012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',3,'MOLO002',116.7,'eastar4','kkbasol','kerimbasol@gmail.com','Kerim BASOL','Bostanci Cami Sk. Cesur Apt. No:13 D:3<br>Kadikoy','Istanbul','Istanbul','TURKEY','34744','+902164101810','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 02:13:04',0,NULL,3,1,3,1,NULL,'kkbasol\rMOLO002\\'),(1655,524528299004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',15.55,'cnfaner','autkosearch','koper123@hotmail.com','Dariusz Koper','155 Lower Notch Road','Little Falls','NJ','UNITED STATES','07424','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 02:35:57',0,NULL,3,1,1,1,NULL,'autkosearch\\'),(1656,570222117013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','jase4984','jase_4984@yahoo.com','Jason Moore','16 N Main St','York New Salem','PA','UNITED STATES','17371-2007','(717) 357-9787','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 02:41:24',0,NULL,3,1,1,1,NULL,'jase4984\\'),(1657,692804524011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.8,'eastar4','barryk76','barry@rochester.rr.com','barry kennedy','76 raines park','rochester','NY','UNITED STATES','14613','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 02:59:04',0,NULL,3,1,1,1,NULL,'barryk76\racer 6pin1.25 23cm \\'),(1658,570226880013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','the_real_seekad','bob.badr@gmail.com','bob badr','465 larente','Gatineau','QC','CANADA','j8p 5b3','(819) 669-6211','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 03:13:44',0,NULL,3,1,2,1,NULL,'the_real_seekad\r\\'),(1659,769734007012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','jozsef1957','787779@gmail.com','Jozsef Banhidi','Szent Korona utca 198','Budapest','','HUNGARY','1162','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 05:21:51',0,NULL,3,1,2,1,NULL,'jozsef1957\r\\'),(1660,570250991013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'eastar4','billyfooksheung','billyfooksheung@hotmail.com','Billy Fook Sheung','60 Raoul Rivet Street','Port Louis','','MAURITIUS','','(230)2125369','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 06:09:53',0,NULL,3,1,2,1,NULL,'billyfooksheung\r\\'),(1661,570252361013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','beef4love','jaepark79@gmail.com','Jae Hong Park','151 Soon-wha dong<br>Posco the # A-2401','Seoul','Jung-gu','KOREA,REPUBLIC OF','100130','(010) 355-1914 ext.: 3','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 06:21:17',0,NULL,3,1,3,1,NULL,'beef4love\rRCLO003\rRA117712524CN\r\\'),(1662,692845795011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','msmith36','emsmith@gol.com','Marvin Smith','374-4 Oya<br>Minuma-ku','Saitama-shi','Saitama','JAPAN','337-0014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 06:50:44',0,NULL,3,1,2,1,NULL,'msmith36\r\\'),(1663,769754288012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','razor_05','jozef_golias@yahoo.co.uk','Jozef Golias','66<br>Lopuchov','Raslavice','','SLOVAK REPUBLIC','08641','00421908952858','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-09 07:10:21',0,NULL,3,1,2,1,NULL,'razor_05\r只发耳机不给电源\r棕色的\r\\'),(1664,524564494004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','flhansen_dk','flemming.hansen@svendbo.dk','Flemming Hansen','Gammel Skaarupvaenge 16','Svendborg','','DENMARK','5700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 07:18:24',0,NULL,3,1,3,1,NULL,'flhansen_dk\rBALO007\rRA117712317CN\r\\'),(1665,769765190012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','thedan1','d_treadway@comcast.net','Danny Treadway','205 S Fairway Ave','Sherwood','AR','UNITED STATES','72120-5442','(501) 259-6730','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 07:49:54',0,NULL,3,1,1,1,NULL,'thedan1\r÷'),(1666,524583645004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','19071994','tempting89@mail.ru','Aliaksei Burshtyn','Street of Yankee Kupaly 74/57 ','Brest','Brest region','BELARUS','224020','80292073040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 09:18:54',0,NULL,3,1,3,1,NULL,'19071994\rHSNO022\r欧标\rRA117712612CN\r\\'),(1667,769797966012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','s11verdragon','silverdragon@gmail.com','Chris Bell','26 Lunn Ave<br>Mt Wellington','Auckland','','NEW ZEALAND','1047','064095277470','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-09 09:55:37',0,NULL,3,1,2,1,NULL,'s11verdragon\r\\'),(1668,692899233011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',9.99,'eastar4','steve73091','themadpeon@gmail.com','Stephen Donaldson','63 Dudley Street','Mansfield Park','South Australia','AUSTRALIA','5012','0402933013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:26:56',0,NULL,3,1,2,1,NULL,'steve73091\r\\'),(1669,692899779011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.9,'eastar4','kentellingsen','kent@radiosystemer.com','Kent Ellingsen','Olastien 5','Tromsø','Troms','NORWAY','9012','004799331213','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:27:50',0,NULL,3,1,3,1,NULL,'kentellingsen\rWWSI005+ANCN001\rRA117712334CN\r\\'),(1670,769813628012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','hallti.y01','timhall030290@hotmail.com','tim hall','31 southdown crescent<br>cheadle hulme','stockport','cheshire','UNITED KINGDOM','sk8 6eq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-09 10:50:12',0,NULL,3,1,3,1,NULL,'hallti.y01\r英标 \rHSPL011\rRA117712538CN\r\\'),(1671,769814853012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','123eturs','eturs@zahav.net.il','Etur Shani','moran 415','barkan','','ISRAEL','44820','97239060952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:53:50',0,NULL,3,1,2,1,NULL,'123eturs\r\\'),(1672,692908817011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','cedarsrus','andrew.guy@cedarsupport.co.uk','Andrew Guy','3 Cornflower Close','Cardiff','Cardiff','UNITED KINGDOM','CF140BD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 11:02:17',0,NULL,3,1,2,1,NULL,'cedarsrus\r\\'),(1673,692933818011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','hue_bui','anhuebui@hotmail.com','Anna Nguyen','16 Morven St','Old Guildford','New South Wales','AUSTRALIA','2161','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 12:39:57',0,NULL,3,1,2,1,NULL,'hue_bui\r、'),(1674,769854412012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','lotusmach10','paulandkay1993@sbcglobal.net','Paul Pakizer','3747 Deer Springs Dr','Rochester Hills','MI','UNITED STATES','48306','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 13:01:43',0,NULL,3,1,1,1,NULL,'lotusmach10\r÷'),(1675,518848818003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',2,'HSUE002',53.9,'cnfaner','samurai_jumpo','samuraijumpo@gmail.com','Anton Prygunov','Novocherkasskiy bulvar, dom 14, kv. 244','Moscow','','RUSSIAN FEDERATION','109651','+7-962-970-8975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 13:01:50',0,NULL,3,1,3,1,NULL,'samurai_jumpo\rHSUE002\rRA117712970CN\r\\'),(1676,769864180012,220749207909,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.99,'eastar4uk','trevorg4823','avengertj@yahoo.co.uk','Trevor Gocan','FLAT, A1 ODHAMS WALK, LONG ACRE,','LONDON','COVENT GARDEN','UNITED KINGDOM','WC2H 9SA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-09 13:28:44',0,NULL,3,1,3,1,NULL,'trevorg4823\rRELE001\rRA117712351CN\r\\'),(1677,570337099013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','juanhein20','juanhein@vodamail.co.za','Juan van der westhuizen','PO BOX 1061','Grabouw','Western Cape','SOUTH AFRICA','7180','+27829245930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 13:49:51',0,NULL,3,1,3,1,NULL,'juanhein20\rOTRA002\rRA117716937CN\r\\'),(1678,657947894001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','lpage_11','lowry_11@yahoo.com','Lowry Page','721 Kingston Ct','Apollo Beach','FL','UNITED STATES','33572-2428','(813) 785-3804','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'lpage_11'),(1679,657947894001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','lpage_11','lowry_11@yahoo.com','Lowry Page','721 Kingston Ct','Apollo Beach','FL','UNITED STATES','33572-2428','(813) 785-3804','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 14:26:14',0,NULL,3,1,1,1,NULL,'lpage_11\rLK038166676CN\r÷'),(1680,570364290013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','penible93','penible13@hotmail.fr','didier houssin','quartier siege','simiane','Provence-Alpes-Côte d\'Azur','FRANCE','13109','06.80.75.58.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:34:57',0,NULL,3,1,2,1,NULL,'penible93\rHP 8pin 1.0 23cm \r、'),(1681,692993677011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mexicanos69as','stephane.abadie@gmail.com','Stéphane Abadie','87 rue du 1er Mars 1943','Villeurbanne','Rhône-Alpes','FRANCE','69100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:39:29',0,NULL,3,1,2,1,NULL,'mexicanos69as\r\\'),(1682,570368663013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','sebasgomez','sebastiangomez55@yahoo.es','Juan Ignacio Pérez Martínez','Av. Autopista del Saler, 4 - Bloque 1<br>Esc. C - 11º - Pta. 73','Valencia','Comunidad Valenciana','SPAIN','46013','609530200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:50:40',0,NULL,3,1,2,1,NULL,'sebasgomez\r欧标\r\\'),(1683,570370108013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','alangoto14','alangoto@adinet.com.uy','Alvaro Gonzalez','Michigan 1361/4','Montevideo','Montevideo','URUGUAY','11400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:57:27',0,NULL,3,1,3,1,NULL,'alangoto14\rOTRA002\rRA117712541CN\r\\'),(1684,570376700013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',34.89,'eastar4','extra_bits_uk','jason.fell@hotmail.co.uk','Jason Fell','2 Beckley Cottages','Great Bookham','Surrey','UNITED KINGDOM','KT23 4RW','07522686855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 16:17:56',0,NULL,3,0,3,1,NULL,'extra_bits_uk\r再发一个优联\rOTHP003+RELO002\rRA117712665CN\r\\'),(1685,693013920011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','eesundin','eesu42@comcast.net','Eric E. Sundin','2058 Carillon Dr','Grayslake','IL','UNITED STATES','60030-4426','(847) 543-6717','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 16:20:33',0,NULL,3,1,1,1,NULL,'eesundin\r÷'),(1686,570379516013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','mtzapgar','lbrown1626@hotmail.com','Lorie Brown','PO Box 4344','Hot Springs National Park','AR','UNITED STATES','71914-4344','(501) 762-2855','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 16:27:36',0,NULL,3,1,1,1,NULL,'mtzapgar\r÷'),(1687,693017262011,320571360819,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',18.85,'eastar4','bilcat01','billyrichards@tesco.net','Billy Richards','94 Main Street','Winchburgh','West Lothian','UNITED KINGDOM','EH526RE','1506890532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 16:27:47',0,NULL,3,1,2,1,NULL,'bilcat01\r\\'),(1688,570382924013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','jdavis6217','jdavis6217@juno.com','J & K SERVICE','891 STREETMAN RD','ROYSE CITY','TX','UNITED STATES','75189-6317','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 16:38:02',0,NULL,3,1,1,1,NULL,'jdavis6217\\'),(1689,768642065012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',3,'HSPL011',66,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 17:03:07',0,NULL,3,1,3,1,NULL,'solopo2009\r只发耳机不给电源 \rHSPL011\rRA117712453CN\r\\'),(1690,769967547012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','jag-k150-j6c','genemc@cavemen.net','Eugene McGough','1009 S Country Club Cir','CARLSBAD','NM','UNITED STATES','88220-4616','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-09 17:33:03',0,NULL,3,1,1,1,NULL,'jag-k150-j6c 改发一个1510\r÷'),(1691,524703050004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',2,'MOSA001',143.8,'cnfaner','chavisatelnet','javier@satelnet.es','JAVIER FERNÁNDEZ GÓMEZ','C/MATA JOVE, Nº2 6ºC','GIJÓN','Asturias','SPAIN','33213','606116784','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 18:06:54',0,NULL,3,1,3,1,NULL,'chavisatelnet\rMOSA001\rRA117712674CN\r\\'),(1692,769995654012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','martin_j1','martin_j1@hotmail.com','M Jannat','701/6<br>LACHLAN STREET','WATERLOO','New South Wales','AUSTRALIA','2017','0400887264','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-09 18:26:38',0,NULL,3,1,3,1,NULL,'martin_j1\rOTRA002\rRA117712382CN\r\\'),(1693,570433425013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','dumdidom','dumdidom@hotmail.com','Carole St-Jean','154 Rue Desjardins','Magog','QC','CANADA','J1X 5R9','(514) 962-5810','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 19:03:40',0,NULL,3,1,2,1,NULL,'dumdidom\r\\'),(1694,518957291003,130490915279,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'cnfaner','sweet_pete73','kobe_bryant20@hotmail.com','Peter Nemec','321 Lonsdale Road<br>Suite E','Toronto','ON','CANADA','M4V 1X3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 19:23:31',0,NULL,3,1,3,1,NULL,'sweet_pete73\rCACN003\rRA117712572CN\r\\'),(1695,770029679012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','lban1828','lajessica252@hotmail.com','lajessica banks','105 grant street','garysburg','NC','UNITED STATES','27831','(252) 945-4354','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 19:26:45',0,NULL,3,1,1,1,NULL,'lban1828\\'),(1696,570452414013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','nsizov81','ngrechko@rambler.ru','Sizov Nikolay','25 Walpole Park S<br>Ste 4-EB103990','Walpole','MA','UNITED STATES','02081-2522','903 221 0637','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-09 19:56:18',0,NULL,3,1,2,1,NULL,'nsizov81  新地址Nikolay Sizov\rAviatorov St., 2, 150\rMoscow Moscow 119619\rRussian Federation\r\\\r'),(1697,570452835013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','pocoali','nfgriffin@verizon.net','Nancy Griffin','2651 Aspen Ct','Palm Harbor','FL','UNITED STATES','34684-1947','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 19:57:30',0,NULL,8,1,17,0,NULL,'pocoali'),(1698,518972491003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','nikojof','niko_jof@abv.bg','Nikolay Yosifov','h.k. Serdika, block 16, flat 14, ap. 53','Sofia','Sofia','BULGARIA','1330','+359888607561','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-09 20:07:53',0,NULL,3,1,3,1,NULL,'nikojof\rOTJE001\rRA117712691CN\r\\'),(1699,524746645004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','sgoldstien','sgoldstien@comcast.net','Stuart Goldstien','4682 White Rock Cir<br>Apt 3','Boulder','CO','UNITED STATES','80301-6712','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 20:12:20',0,NULL,3,1,1,1,NULL,'sgoldstien\r\\'),(1700,693130155011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','masteroll2010','abirman@mts.com.ua','Alexandr Birman','K.Libkneht, 1/3/29','Dnepropetrovsk','','UKRAINE','49030','+380503200088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 20:30:18',0,NULL,3,1,2,1,NULL,'masteroll2010\r\\'),(1701,570470348013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',10.99,'eastar4','harry_momo','shakedown@deadlegs.com','aron black','4686 Hingston','montreal','QC','CANADA','h4a2k1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 20:52:55',0,NULL,3,1,2,1,NULL,'harry_momo\r\\'),(1702,570473500013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','nohpipa','apiphon@hotmail.com','Apiphon Likasitthananon','12/6 Mooban Patchaya Home<br>Paholyothin 48 Bangkean','Bangkok','Bangkok','THAILAND','10220','66813154533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 21:05:53',0,NULL,3,1,2,1,NULL,'nohpipa\r\\'),(1703,770084122012,220759518727,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',24.9,'eastar4uk','synchronic29','keith_falzon@hotmail.com','keith falzon','16 bella vista court<br>rudolf street sliema','sliema','','MALTA','slm02','00356 79408180','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-09 21:17:28',0,NULL,3,1,3,1,NULL,'synchronic29\rMOLO002\rRA117712759CN\r\\'),(1704,570479012013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',3,'HSPL001',35.4,'eastar4','aroman6215','aroman6216@aol.com','Anthony Romano Jr.','6 Magnolia Ln','Colts Neck','NJ','UNITED STATES','07722','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 21:22:07',0,NULL,3,1,1,1,NULL,'aroman6215\\'),(1705,693189468011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','dhimitris2009','jimntan@gmail.com','Dhimitris Danis','Grammu 60','Igumenitsa','Thesprotia','GREECE','46100','2665028535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 23:03:29',0,NULL,3,1,2,1,NULL,'dhimitris2009\r欧标\r\\'),(1706,570508172013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'eastar4','simez1234','simez@sky.com','Jonathan Simon Richmond','44 High Street','Upton','West Yorkshire','UNITED KINGDOM','WF9 1HQ','07791877102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 23:27:16',0,NULL,3,1,2,1,NULL,'simez1234\r\\'),(1707,770135532012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',2,'HSMO018',21.98,'eastar4','qkrekdnf','dup@sfu.ca','da ur park','1580 taylor way','west vancouver','BC','CANADA','v7s 1n4','(604) 805-1913','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 23:50:01',0,NULL,3,1,2,1,NULL,'qkrekdnf\r\\'),(1708,768110243012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','satelight_man34237','chokman143669@aol.com','jerrett oakes','10230 Waterford Ave','englewood','FL','UNITED STATES','34224-7915','(941) 914-2510','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 23:57:07',0,NULL,3,1,1,1,NULL,'satelight_man34237\r÷'),(1709,693218265011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mal-ward','mal-ward@usa.net','Malcolm Ward','102/14 Orchards Ave','Breakfast Point','New South Wales','AUSTRALIA','2137','0405244875','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 00:56:40',0,NULL,3,1,2,1,NULL,'mal-ward\r\\'),(1710,524808419004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','aytlakhder','ilakhder@gmail.com','Ismail Lakhder','98 Cottage St','Franklin','MA','UNITED STATES','02038-2207','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 01:02:15',0,NULL,3,1,1,1,NULL,'aytlakhder\\'),(1711,570525748013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','vieras04','vieras@sbcglobal.net','David Viera','1639 Harlan Dr','Danville','CA','UNITED STATES','94526','(925) 855-8957','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 01:03:47',0,NULL,3,1,1,1,NULL,'vieras04\\'),(1712,519040160003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','nierobek','jniebud@yahoo.com','Jan Niebudek','3 Fern Rd','Andover','MA','UNITED STATES','01810','(978) 470-0455','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 01:16:57',0,NULL,3,1,1,1,NULL,'nierobek\\'),(1713,693224556011,320631786282,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',2,'HSPL002',31,'eastar4','wildeliz98','wilbertom@gmail.com','Wilberto Moczo','Villa Carolina<br>216-15 Calle 505','Carolina','PR','UNITED STATES','00985','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 01:20:43',0,NULL,3,1,1,1,NULL,'wildeliz98\r\\'),(1714,524822378004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','beneathshadows1313','beneathshadows13@aim.com','Joann Stamatopoulos','6715 N River Dr','Middle River','MD','UNITED STATES','21220-1033','(443) 604-1677','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 02:10:59',0,NULL,3,1,1,1,NULL,'beneathshadows1313\r÷'),(1715,693282754011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',14.9,'eastar4uk','robert_ludwig','weineger@gmx.de','Weigelt Gero','Grimmaische Str. 39','Mutzschen','','GERMANY','04688','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 06:00:32',0,NULL,3,1,2,1,NULL,'robert_ludwig\r欧标\r\\'),(1716,570577736013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','whkee','whkee@mac.com','Mike Wong Hong Kee','Singapore Polytechnic, School of EEE<br>500 Dover Road, Blk 12, 5 Floor','default','','SINGAPORE','139651','96620996','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 06:38:12',0,NULL,3,1,11,1,NULL,'whkee\r\\'),(1717,693294378011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','anelasxintus','ericchuah@gmail.com','Eric Chuah','52, Jalan tempua 4','Puchong Jaya','Selangor','MALAYSIA','47100','0123214253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 06:51:05',0,NULL,3,1,2,1,NULL,'anelasxintus'),(1718,693329809011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','gerry2rs','ebayonic@netspace.net.au','Gerald Genikas','13 Cowra Crescent','Park Holme','South Australia','AUSTRALIA','5043','0882771317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 08:49:47',0,NULL,3,1,3,1,NULL,'gerry2rs\rRCLO006\rRA117712569CN\r\\'),(1719,770277825012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',19.8,'eastar4','nagisaian','nice_boy_nz@hotmail.com','Ian green','1 Topliss Drive<br>torbay','Auckland','northshore','NEW ZEALAND','0632','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 09:05:01',0,NULL,3,0,2,1,NULL,'nagisaian\r再发一个\rApple Airmac/Airport Wireless WiFi Card iMac iBook eMac\r\\'),(1720,770294058012,220713846430,'New GENUINE NOKIA HS 11W BLUETOOTH HEADSET',2,'HSNO023',19.38,'eastar4uk','achoroshav77','achoroshav@yahoo.co.uk','aydan zekrie','111 sheviot gardens','london','London','UNITED KINGDOM','nw2 1qd','02082099510','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 09:41:05',0,NULL,3,1,3,1,NULL,'achoroshav77\r英标 HSNO023\rRA117712745CN\r\\'),(1721,570629055013,230603109640,'New CX680 Sennheiser Adidas Sports Earphones Earbuds',1,'HSSS001',40.99,'eastar4','anttibanana','antti.lehmusalho@iki.fi','Antti Lehmusalho','Sammonkatu 9 B 49','Tampere','','FINLAND','33540','+358584004274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 10:17:19',0,NULL,3,1,3,1,NULL,'anttibanana\rHSSS001\rRA117712590CN\r\\'),(1722,570645675013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',2,'MOSA002',149.6,'eastar4','mrmotorcross','scommons@tpg.com.au','S Commons','17 Harcus Close','Bonython','Australian Capital Territory','AUSTRALIA','2905','0414665319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 11:20:07',0,NULL,3,1,3,1,NULL,'mrmotorcross\rMOSA002\rRA117712688CN\r\\'),(1723,770336112012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','nikovas','nikovas@yahoo.com','Prigouri Adamantia','KASTALIAS 69','NEA KYPSELI','ATHENS','GREECE','11363','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 11:24:01',0,NULL,3,1,2,1,NULL,'nikovas\r欧标\r\\'),(1724,693389887011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'eastar4','stk1917','malatin@inbox.ru','Kirill Malatin','16/31 Barrikadnaya St., apt. 5','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198099','+79218719778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 11:29:35',0,NULL,3,1,3,1,NULL,'stk1917\rWWSI006\rRA117712515CN\r\\\r\r'),(1725,770355936012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',12.5,'eastar4','floyd-94','moumen94@gmail.com','Moumen','113 rue Gambetta','Villeneuve saint georges','Île-de-France','FRANCE','94190','01.43.82.84.49.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 12:11:55',0,NULL,3,1,2,1,NULL,'floyd-94\racer 4pin1.25 8cm \r\\'),(1726,570685590013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','emanuel333','efogl@yahoo.com','Emanuel Fogl','Lanište 17b','Zagreb','Zagreb','CROATIA','10000','0998460071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 13:36:20',0,NULL,3,1,2,1,NULL,'emanuel333\r\\'),(1727,693449860011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tedkaz','kaz9ted@yahoo.com','Ted J Kazanski','27111 SEA BREEZE WAY','WESLEY CHAPEL','FL','UNITED STATES','33544-6620','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 13:52:31',0,NULL,3,1,1,1,NULL,'tedkaz\r÷'),(1728,770409992012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','tibidubi','pro@solointernet.com','Lluís  Solà i Llinàs','Campins 13, 1r','Santa Maria de Palautordera','Cataluña','SPAIN','08460','933637668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 14:08:19',0,NULL,3,1,2,1,NULL,'tibidubi\r\\'),(1729,0,220767084265,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','amocogas','amocogas@aol.com','Bob Heligman','15151 Harrison St','Livonia','MI','UNITED STATES','48154-3956','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 14:44:42',0,NULL,3,1,1,1,NULL,'amocogas\\'),(1730,570714009013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','arbat-2008','francisco.diaza.46432c@correos.es','Francisco Diaz Alameda','Calle Tridente 15, 6','Alicante','Comunidad Valenciana','SPAIN','03540','630119685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 15:00:14',0,NULL,3,1,2,1,NULL,'arbat-2008\r\\'),(1731,0,320683130383,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',8.99,'eastar4','pocoali','nfgriffin@verizon.net','Nancy Griffin','2651 Aspen Ct','Palm Harbor','FL','UNITED STATES','34684-1947','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 15:09:59',0,NULL,3,1,1,1,NULL,'pocoali\r一共买了两个\\'),(1732,693495028011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','thmmax','maxi.hoeller@hotmail.com','Maximilian Höller','Fanggasse 2a','Absam','','AUSTRIA','6067','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 15:26:02',0,NULL,3,1,3,1,NULL,'thmmax\rUDAP001\rRA117712714CN\r\\'),(1733,0,220767081738,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','buntyboss007','sachinmore08@gmail.com','Sachin More','7722 Lucerne Dr<br>Middleburg Hts Apt N26','Cleveland','OH','UNITED STATES','44130-6581','(216) 544-2379','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 16:08:20',0,NULL,3,1,1,1,NULL,'buntyboss007\r÷'),(1734,0,230607375028,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','erniemase37','erniemase@yahoo.com','Ernie Mase','31 Ann St','East Haven','CT','UNITED STATES','06513','(203) 469-7391','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 16:24:47',0,NULL,3,1,1,1,NULL,'erniemase37\\'),(1735,693576833011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','siamdee08','timothyearl58@gmail.com','Tim Sawatzky','4932 48th Street<br>Box 561','Redwater','AB','CANADA','T0A2W0','(780) 919-3597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 17:21:24',0,NULL,3,1,2,1,NULL,'siamdee08\r\\'),(1736,770580054012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','kelnerk07','kelnerk@list.ru','Kirill Kelner','Yana Raynisa blvd. 47-1-320','Moscow','Moscow','RUSSIAN FEDERATION','125373','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 17:55:53',0,NULL,3,1,3,1,NULL,'kelnerk07\rOTRA002\rRA117712365CN\r\\'),(1737,519309660003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',83.99,'cnfaner','n_sasa','sasa@breeze.design.co.jp','Naoto Sasaki','Casa Omori B412, 2-18-23<br>omori-nishi','Ota-ku','Tokyo','JAPAN','1430015','090-7259-8280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 17:56:56',0,NULL,3,1,3,1,NULL,'n_sasa\rWWOT003\rRA117712263CN\r\\'),(1738,770587265012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','famidosi76','paul.ordi@hotmail.fr','Leroy Dominique','49 rue d\'Alincourt','Lillebonne','Haute-Normandie','FRANCE','76170','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 18:03:17',0,NULL,3,1,3,1,NULL,'famidosi76\rHSSE006\rRA117712802CN\r\\'),(1739,770200162012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','0846016','kulsidee@gmail.com','KULSIDEE SEELACHAROEN','Room 203A Ratchamakka MANSION<br>Soi Yasoob Ratchamakka road','Muang Nakornprathom','Nakornprathom','THAILAND','73000','662 645 6665','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 18:33:33',0,NULL,4,1,2,1,NULL,'0846016  paypal 付款有问题'),(1740,693675807011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','itccc','joe_ching@yahoo.com','Joe Ching','1923 N Tyra Ave','Boise','ID','UNITED STATES','83713-5801','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 18:56:51',0,NULL,3,1,1,1,NULL,'itccc\\'),(1741,525138569004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','dave_emmette','dcemmette@gmail.com','David Emmette','14135 Covered Bridge Rd','Lowell','MI','UNITED STATES','49331-9315','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 19:32:12',0,NULL,3,1,1,1,NULL,'dave_emmette\r÷'),(1742,693713964011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','bellhost','admin@bellhost.ru','Dmitry Lezhnin','Lenin Aw. 48-5','Yoshkar-Ola','Mari-El','RUSSIAN FEDERATION','424002','(904) 724-0330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 19:38:01',0,NULL,8,0,17,0,NULL,'bellhost'),(1743,570883213013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','bellhost','admin@bellhost.ru','Dmitry Lezhnin','Lenin Aw. 48-5','Yoshkar-Ola','Mari-El','RUSSIAN FEDERATION','424002','(904) 724-0330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 19:40:55',0,NULL,3,1,2,1,NULL,'bellhost\r再发一个Triple Tyco Universal Wireless Laptop Antenna Mini PCI\r\\'),(1744,693714894011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','solomongt','selegash@gmail.com','Solomon Gashaw Tadese','OLAV M TROVIKS VEI 48, H0306','OSLO','Oslo','NORWAY','0864','+4796841678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 19:45:18',0,NULL,3,1,2,1,NULL,'solomongt\r\\'),(1745,767278912012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','apisitpornpimol1','michiko_us@hotmail.com','APISIT GARPTIP','2216 49th Way N','West Palm Beach','FL','UNITED STATES','33417-3924','(561) 693-5267','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 19:53:39',0,NULL,3,1,1,1,NULL,'apisitpornpimol1\r÷'),(1746,570891712013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.99,'eastar4','rsoeting','robert@soeting.net','Robert Soeting','Peppelstraat 11','Vianen','','NETHERLANDS','4131 BG','0615599639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 19:55:25',0,NULL,3,1,2,1,NULL,'rsoeting\r\\'),(1747,570893310013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','docdz1976','docdz1976@gmail.com','Dmitry Zamansky','Uziel 10/8','Bat Yam','','ISRAEL','59463','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 19:59:29',0,NULL,3,1,2,1,NULL,'docdz1976\r\\'),(1748,570900310013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','mabahok','karlwisse@gmx.ch','Karl Wisse','26525886<br>Packstation 137','Koeln','','GERMANY','50935','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 20:11:05',0,NULL,3,1,3,1,NULL,'mabahok\rMOSA001\rRA117712277CN\r\\'),(1749,519402034003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','714501365','manuelbaez@sbcglobal.net','MANUEL BAEZ','723 S RESH ST','ANAHEIM','CA','UNITED STATES','92805-4408','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 20:21:13',0,NULL,3,1,1,1,NULL,'714501365\r÷'),(1750,519400731003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'cnfaner','professorv','gv@trace.wisc.edu','Gregg Vanderheiden','5825 Tree Line Dr<br>NO SIGNATURE REQUIRED','Fitchburg','WI','UNITED STATES','53711-5827','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 20:22:59',0,NULL,3,1,1,1,NULL,'professorv\r\\'),(1751,570909752013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','alexander5437','alex1702@gmx.de','Alexander  Finkhäuser','Schirrmannweg 20','Haan-Gruiten','','GERMANY','42781','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 20:29:30',0,NULL,3,1,2,1,NULL,'alexander5437\racer 4pin1.25 15cm\r\\'),(1752,0,230606818812,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',11,'eastar4','soupy3185','soupy3185@aol.com','Brian  DiPALMO','1063 Oaks Dr','Franklin Square','NY','UNITED STATES','11010-1937','(516) 352-2113','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 20:36:17',0,NULL,3,1,1,1,NULL,'soupy3185\r÷'),(1753,570916523013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','suzannet1957','htea316@yahoo.com','Suzanne Beasley','2 Elkhart ct','rosedale','MD','UNITED STATES','21237-1417','(433) 845-3222','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 20:46:18',0,NULL,3,1,1,1,NULL,'suzannet1957\r\\'),(1754,770783740012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','frdavidgreen','califda2005@yahoo.com','david guillouche','13047 Hubbard St<br>Unit 1','Sylmar','CA','UNITED STATES','91342-3353','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 22:26:48',0,NULL,3,1,1,1,NULL,'frdavidgreen\r\\'),(1755,525209322004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',2,'ANYA001',28.9,'cnfaner','silver_1976','concordia@ole.com','Francisco Vela Ledesma','c/ Veremundo perera nº 20  1ºdcha','Santa Cruz de Tenerife','Canarias','SPAIN','38006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 22:36:48',0,NULL,3,1,3,1,NULL,'silver_1976\rANYA001\rRA117712586CN\r\\'),(1756,693815473011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','seth7783','lambert7783@yahoo.com','Seth Lambert','1125 Mote Rd','Carrollton','GA','UNITED STATES','30117-6763','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 22:49:31',0,NULL,3,1,1,1,NULL,'seth7783\r÷'),(1757,570956863013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','pmask919','pkpbmaskell@gmail.com','Paul Maskell','5 Drysdale St','Kanata','ON','CANADA','K2K3L3','(613) 599-6915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 22:50:51',0,NULL,3,1,2,1,NULL,'pmask919\r\\'),(1758,570971745013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','jobanekpaul','pjnelson22@yahoo.com',' Paul   Nelson','88715 Faulhaber RD','Elmira','OR','UNITED STATES','97437','(541) 935-9556','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 23:51:07',0,NULL,3,1,1,1,NULL,'jobanekpaul\\'),(1759,693840318011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','btaconazo1','btaconazo@aol.com','harnold barbosa','5303 SE 99th Ave','portland','OR','UNITED STATES','97266-3711','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 00:05:07',0,NULL,3,1,1,1,NULL,'btaconazo1\\'),(1760,770831108012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','shctuh','hutchsuc@yahoo.com','Alvin Hutchinson','849 Leisure Land Dr','Big Cabin','OK','UNITED STATES','74332','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 00:05:41',0,NULL,3,1,1,1,NULL,'shctuh\r\\'),(1761,770836259012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',1,'BALO005',7.1,'eastar4','octinium','dduffy@gmail.com','William Duffy','1935 Flushing Ave','Ridgewood','NY','UNITED STATES','11385-1042','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 00:24:47',0,NULL,3,1,1,1,NULL,'octinium\r÷'),(1762,525233918004,140427937126,'2.1 Acer Aspire D250 bluetooth module we offer track#',1,'',13.99,'cnfaner','jfcosta.br','jflavio.br@gmail.com','Jorge Flavio Costa','Rua Tomas Soares de Souza, 675, Ap. 202<br>Res. Buganville, Catolé','Campina Grande','Paraíba','BRAZIL','58410235','+55 83 88892510','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 00:25:02',0,NULL,3,0,3,1,NULL,'jfcosta.br\rAcer 4pin 1.25 15cm\rBTAC2107\rRA117712325CN\r\\'),(1763,570984309013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','negritoyankee','el-negrito-de-magas@hotmail.com','Luis M Morales Torres','Hc 2 Box 6373','Guayanilla','PR','UNITED STATES','00656-9713','(787) 585-9485','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 00:35:05',0,NULL,3,1,1,1,NULL,'negritoyankee\r÷'),(1764,770847463012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','charlesh2107','charlesharvey@msn.com','Charles Harvey','2025 Forest Glen Ct','Tallahassee','FL','UNITED STATES','32303-5137','(850) 544-4650','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 00:49:50',0,NULL,3,1,1,1,NULL,'charlesh2107\r\\'),(1765,770870421012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','referinta','chesoherrera@hotmail.com','David Herrera','10400 Larose, app. 1','Montreal','QC','CANADA','H2B 2Z2','(514) 825-9747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 01:52:11',0,NULL,3,1,2,1,NULL,'referinta\r\\'),(1766,770869978012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','festivill','festivill@gmail.com','Federico Gustavo Estivill','El Condor 338','Dina Huapi','Rio Negro','ARGENTINA','R8406ASH','+541140402653','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 01:54:38',0,NULL,3,1,2,1,NULL,'festivill\r\\'),(1767,519494647003,130490223099,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',22,'cnfaner','rtil7963','tillmanrobert56@yahoo.com','Robert Tillman','2605 SW Joshua Ave','Bentonville','AR','UNITED STATES','72712-8323','(479) 659-2161','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 01:55:56',0,NULL,3,1,1,1,NULL,'rtil7963\r÷'),(1768,521332034004,140429365212,'2.1 HP Pavilion DV4 DV7 bluetooth module has track#',1,'BTHP2107',16.59,'cnfaner','lincolnsm250','lincoln_mil@yahoo.com.br','Daniele de Almeida dos Santos Amaro','Rua Francisco Lopes, S/N, Bloco 10, Ap 201 - PNR 1 da ESAO<br>Vila Militar','Rio de Janeiro','Rio de Janeiro','BRAZIL','21615-080','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 02:14:22',0,NULL,3,1,3,1,NULL,'lincolnsm250\rHP 8pin 1.0 23cm \rBTHP2107\rRA117716680CN\r、'),(1769,770892356012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','annaandythai','thantai2002ca@yahoo.com','van hung thai','2747 rue benjamin - sulte.','montreal','QC','CANADA','h3m1s3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 02:51:12',0,NULL,3,0,2,1,NULL,'annaandythai\r\\'),(1770,693901037011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','bootucke','bootucker@cfl.rr.com','Michelle Tucker','2746 Whistler St','Melbourne','FL','UNITED STATES','32904-7496','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 03:09:51',0,NULL,3,1,1,1,NULL,'bootucke\\'),(1771,770899203012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'eastar4','kkbasol','kerimbasol@gmail.com','Kerim BASOL','Bostanci Cami Sk. Cesur Apt. No:13 D:3<br>Kadikoy','Istanbul','Istanbul','TURKEY','34744','+902164101810','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 03:15:28',0,NULL,3,1,3,1,NULL,'kkbasol\rMOLO002\\\r潘'),(1772,770910114012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','huimingr7dex','huimingr@msn.com','Ming Ruan','9762 Innisbrook Blvd','Carmel','IN','UNITED STATES','46032','(317) 879-9488','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 04:01:01',0,NULL,3,1,1,1,NULL,'huimingr7dex\\'),(1773,693925022011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','bla_it','infosys@bla.com.au','Alan Wright','45 Aquarium Avenue','Hemmant','Queensland','AUSTRALIA','4174','0733900138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 05:07:11',0,NULL,3,1,2,1,NULL,'bla_it\r\\'),(1774,693925830011,320520042459,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'WLHP002',18.99,'eastar4','lawkoot','ykoot@hotmail.com','Y. Koot','Dignaland 88','Den Haag','','NETHERLANDS','2591CD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 05:12:12',0,NULL,3,1,2,1,NULL,'lawkoot\r\\'),(1775,571048971013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','mrman012','mrman012@telus.net','Dan DenHollander','43525 Lumsden Rd','Chilliwack','BC','CANADA','V2R 4R4','(604) 823-4494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 05:40:20',0,NULL,3,1,2,1,NULL,'mrman012\r\\'),(1776,525293873004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','cabcbentsai','cabcben@hotmail.com','Tsai I-Ping','1320 Flynn Crescent','Coquitlam','BC','CANADA','V3E 1Y2','(604) 800-2301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 05:43:31',0,NULL,3,1,3,1,NULL,'cabcbentsai\rWLAT002\rRA117712728CN\r\\'),(1777,571053529013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',20.95,'eastar4','upsdude73','jani.ebay@gmail.com','Jani Lustig','Kaskihakkio 4 B 5','ESPOO','','FINLAND','02340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 06:15:54',0,NULL,3,1,2,1,NULL,'upsdude73\r、'),(1778,770941895012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','wolk3d','wolk3d@gmail.com','verlan Iulian','1927 31st Ave','SAN FRANCISCO','CA','UNITED STATES','94116','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 06:41:22',0,NULL,3,1,1,1,NULL,'wolk3d\r\\'),(1779,571060198013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','mantik','mantas.bystautas@gmail.com','Mantas Bystautas','Verdelupio 19-27','Ariogala','Lithuania','LITHUANIA','60266','0037067952086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 07:05:10',0,NULL,3,1,2,1,NULL,'mantik\r\\'),(1780,571060955013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','wuka2oo2','wuka2002@o2.pl','Wojciech Kaczorowski','Kmicica 8a/2','Grodzisk Mazowiecki','mazowieckie','POLAND','05825','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 07:21:54',0,NULL,3,1,2,1,NULL,'wuka2oo2\r\\'),(1781,525306179004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','ilkayde','ilkaydemirhan@hotmail.com','ilkay demirhan','Lalahan Livestock Central Research Institute','Lalahan-Mamak','Ankara-TURKEY','TURKEY','06852','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 07:38:07',0,NULL,3,1,3,1,NULL,'ilkayde\rOTCR001\rRA117716910CN\r\\'),(1782,770965545012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','d.yousufi','d.yousufi@hotmail.com','David Yousufi','Legerland 30','Koog aan de Zaan','','NETHERLANDS','1541 NE','0614537086','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 08:23:15',0,NULL,3,1,3,1,NULL,'d.yousufi\rOTRA002\rRA117716923CN\r\\'),(1783,524312643004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','fingerin2000','gregory.depienne@yahoo.com','Gregory Depienne','9 Rue Victor Rogelet','Reims','Champagne-Ardenne','FRANCE','51100','06.62.39.64.69','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 08:59:00',0,NULL,3,1,3,1,NULL,'fingerin2000\rWLIN010+ANTY002\rRA117712952CN\r\\'),(1784,571080487013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','dankaholic256','ultimateplaya256@gmail.com','Daniel Kasal','74 Taylor St','Amherst','MA','UNITED STATES','01002-2135','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 09:17:09',0,NULL,3,1,1,1,NULL,'dankaholic256\r、'),(1785,693983584011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','tal_78360','tal.goldberg@gmail.com','Itzhak Goldberg','1 Meonot Bracha','Rishon Le\'zion','','ISRAEL','75315','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 09:42:25',0,NULL,3,1,2,1,NULL,'tal_78360\r\\'),(1786,571087967013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','ozziede','tsum@hutchison.com.au','Tony Sum / CO- Vodafone Hutchison Australia','Level 4<br>12 Help St','Chatswood','New South Wales','AUSTRALIA','2067','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 09:59:19',0,NULL,3,1,3,1,NULL,'ozziede\rMOSA003\rRA117716764CN\r、'),(1787,771000604012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 10:34:31',0,NULL,3,1,3,1,NULL,'avextra-co-uk\rOTCN004*10\r\rRA022493506CN\r\\'),(1788,694014343011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.8,'eastar4','artyrod1','artyrod@hotmail.com','Arturo Rodriguez','174 Burgess Pl','Passaic','NJ','UNITED STATES','07055','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 11:37:52',0,NULL,3,1,1,1,NULL,'artyrod1\racer 6pin1.25 23cm\r、'),(1789,771029892012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','robomatt101','mattjag@aol.com','Matthew Cardenas','2308 62nd St<br>Apt B','Lubbock','TX','UNITED STATES','79412-3306','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 12:10:25',0,NULL,3,1,1,1,NULL,'robomatt101\r÷'),(1790,694029665011,320665720437,'New Genuine Sony Ericsson HBH-608 Bluetooth  Headset',2,'HSSE007',39.8,'eastar4','estevaojrr1','estevaojrr@ig.com.br','Alan Antunes Rosendo','Cond. vert paradiso, Qd-J, lote-19<br>serraria','Maceió','Alagoas','BRAZIL','57048-375','8233288120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 12:33:48',0,NULL,3,1,3,1,NULL,'estevaojrr1\rHSSE007\rRA117716733CN、'),(1791,693954160011,320679575591,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',34,'eastar4uk','aleksey1979','3332961@gmail.com','Aleksey Rusin','Butlerova st. 24/258','Moscow','','RUSSIAN FEDERATION','117342','(495)333-2961','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 13:22:23',0,NULL,3,1,3,1,NULL,'aleksey1979\rWWOT001+ANCN001\rRA117716781CN\r、'),(1792,525370935004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','jonp1625','kjkpaul@yahoo.com','Kimberly Paul','1625 Cape May Rd','Baltimore','MD','UNITED STATES','21221-1612','(410) 391-6449','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 13:25:46',0,NULL,3,1,1,1,NULL,'jonp1625\r、'),(1793,525390179004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','myginny','silpheed@gmail.com','Jeewon Yu','NeutiMaeul 3 Danji APT 307-302<br>Jeongja-dong, Bundang-gu','Seongnam-si','Gyeonggi-do','KOREA,REPUBLIC OF','463-744','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 14:50:44',0,NULL,3,1,3,1,NULL,'myginny\rWWSI005\rRA117716778CN\r、'),(1794,0,230607783830,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',11.5,'eastar4','aeioumom','vowell58@yahoo.com','Josephine Vowell','47611 West Dry Creek Road','Halfway','OR','UNITED STATES','97834','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-11 14:58:43',0,NULL,3,1,1,1,NULL,'aeioumom\r、'),(1795,0,220767574721,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','greeneyedjoker420','supemecable@yahoo.com','Juan Padilla','2281 SW 81ST AVE<br>APT 128','DAVIE','FL','UNITED STATES','33324-5556','(786) 333-9471','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 15:12:04',0,NULL,3,1,1,1,NULL,'greeneyedjoker420\r÷'),(1796,525390611004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','farm29girl','mlinden@localnet.com','Marjorie Linden','402 Deerfield Ct','Hendersonville','NC','UNITED STATES','28792-8522','(828) 698-4957','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 15:19:19',0,NULL,3,1,1,1,NULL,'farm29girl\r、'),(1797,571165624013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','mosij0','dmosimann@sasktel.net','Jim Mosimann','Box 250','Edam','SK','CANADA','S0M0V0','(306) 397-2849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 15:41:07',0,NULL,3,1,2,1,NULL,'mosij0\r、'),(1798,694094308011,320602601396,'2.1 Acer Aspire 5580 5570 5570Z Bluetooth Module +cable',1,'BTAC2116',12.8,'eastar4','sysconindo','sammy@sysconindo.com','Samuel Budimartono','Jln.Pangeran Jayakarta 117 - B1<br>Jakarta Pusat','Jakarta','DKI','INDONESIA','10730','+62216599660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 15:47:33',0,NULL,3,1,2,1,NULL,'sysconindo\racer 6pin1.25 23cm\r、'),(1799,771109741012,220695326722,'2.1 Bluetooth cable Module screw 4 Lenovo Ideapad S10-2',1,'BTLE2102',12.8,'eastar4','geogain','geogain@yahoo.gr','Georgios Kainourgios','Paramythias 1','Thesprotikon','','GREECE','48300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 15:53:10',0,NULL,3,1,2,1,NULL,'geogain\r8pin 1.0 8cm \r、'),(1800,0,320683601720,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',14,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 16:38:07',0,NULL,3,1,1,1,NULL,'4278dennis\r÷'),(1801,694114454011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'',21.9,'eastar4','eaalle','lizzygriffin@yahoo.com','Elizabeth Griffin','4225 Botanical Ave<br>Fl 1','Saint Louis','MO','UNITED STATES','63110-3520','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 16:43:37',0,NULL,3,0,1,1,NULL,'eaalle\r÷'),(1802,771137295012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','murfhit','murfhit@hotmail.co.uk','Danny Walsh','59 Bryson Stret','Belfast','Antrim','UNITED KINGDOM','BT5 4ET','07765990712','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 16:52:21',0,NULL,3,1,3,1,NULL,'murfhit\rHSSE005\r英标\rRA117716720CN\r、'),(1803,771140363012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','nadavharel','nadav0harel@gmail.com','nadav harel','mapiley egoz 12','beit shemesh','israel','ISRAEL','99547','972029991204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 17:06:47',0,NULL,3,1,2,1,NULL,'nadavharel\r、'),(1804,771213399012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',1,'ANYA002',19.5,'eastar4','asiatradeinc-gmail','asiatradeinc@gmail.com','Varga Sandor','264/43 Rachadamnom Rd.  Thawang Muang','Nakhon si thammarat','Nakhon Si Thammarat','THAILAND','80000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 19:02:37',0,NULL,3,1,11,1,NULL,'asiatradeinc-gmail\rANYA002\r、'),(1805,771235087012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',2,'OTHP003',29.8,'eastar4uk','jpayton77','james.payton@gmail.com','James Payton','163 Spixworth Road<br>Old Catton','Norwich','Norfolk','UNITED KINGDOM','nr6 7dy','01603403407','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 19:35:51',0,NULL,3,1,3,1,NULL,'jpayton77\rOTHP003\rRA117716747CN\r、'),(1806,571256935013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',4,'HSMO018',43.96,'eastar4','haim2210','haimoked@bezeqint.net','Haim Oked','Hanakar 1','Beer Yaaqov','Israel','ISRAEL','70300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 19:51:28',0,NULL,3,1,3,1,NULL,'haim2210\rHSMO018\rRA117716755CN\r、'),(1807,519732506003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',15.99,'cnfaner','ziggy404','kendrickking@hotmail.com','Kendrick King','302 nw 17th ave','Fort lauderdale','FL','UNITED STATES','33311-8712','(954) 588-9337','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 19:55:39',0,NULL,3,1,1,1,NULL,'ziggy404\r、'),(1808,694229652011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','goldjohnny1220','arizzona@hotmail.com','John Izzo','6601 E Ironwood Dr','Paradise Valley','AZ','UNITED STATES','85253-2621','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 20:12:30',0,NULL,3,1,1,1,NULL,'goldjohnny1220\r、'),(1809,694231023011,320679575680,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',21,'eastar4uk','sjonny.d1','sjonny.d@gmail.com','Evgeny Dobrushin','Motzkin 21/24','Netaniya','','ISRAEL','42460','+972578120248','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 20:14:33',0,NULL,3,1,3,1,NULL,'sjonny.d1\rWWSI005\rRA117716795CN\r、'),(1810,694244028011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','rocketer9','erick_ballard@yahoo.com','Erick Ballard','3374 S 137th East Ave','Tulsa','OK','UNITED STATES','74134-4208','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 20:48:12',0,NULL,3,1,1,1,NULL,'rocketer9\r÷'),(1811,571282086013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','ziggyboy.417','ziggyboy3d@juno.com','Ryan Ziegler','5549 S Aaron Ave','Springfield','MO','UNITED STATES','65810-2045','(417) 234-9586','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 21:01:47',0,NULL,3,1,1,1,NULL,'ziggyboy.417\r、'),(1812,694256705011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','yana21x','yana21x@yahoo.com','Jana Strautane','24 Paget Road','Great Yarmouth','Norfolk','UNITED KINGDOM','NR30 2DN','07704410182','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 21:11:48',0,NULL,3,1,2,1,NULL,'yana21x\r、'),(1813,571286930013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','jorge23r','jorge23r@hotmail.com','Jorge Ribeiro','5540 Rhodes Street','Vancouver','BC','CANADA','V5R3N9','(604) 831-5764','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 21:18:01',0,NULL,3,1,2,1,NULL,'jorge23r\r、'),(1814,571300025013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','smr-tec','ebay@smr-tec.com','Sven Moreiko','Birkenweg 14','Bad Lauchstädt OT Schafstädt','','GERMANY','06246','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 22:10:50',0,NULL,3,1,3,1,NULL,'smr-tec\rMOSA002\rRA117716852CN\r.、'),(1815,569963278013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','bejaia06hamaoui','elkseur06@free.fr','hamaoui','13 rue kleber','drancy','Ile-de-France','FRANCE','93700','0665658462','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 22:19:14',0,NULL,3,1,3,1,NULL,'bejaia06hamaoui\rWWOT001+ANCN001\rRA117716716CN\r、'),(1816,571294783013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',9.8,'eastar4','321tocsin','post@tocsin.de','Manfred Bock','Frankenstr. 20','Remshalden','','GERMANY','73630','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 22:24:58',0,NULL,3,1,2,1,NULL,'321tocsin\r、'),(1817,771331698012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','avi300','avi10@live.com','A Tripathi','2009 Greene St<br>Apt 507','Columbia','SC','UNITED STATES','29205','(806) 470-2752','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 23:22:18',0,NULL,3,1,1,1,NULL,'avi300\r÷'),(1818,694305922011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',11.95,'eastar4','orsani','sanimail@gmail.com','Or Sani','Ha\'oren 60','Oranit','','ISRAEL','44813','+972506503148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 23:53:23',0,NULL,3,1,2,1,NULL,'orsani\r、'),(1819,771342534012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','publiur','caldera55@gmail.com','Carlos Sancho  Caldera','C/ Pedro teixeira 9','Madrid','Madrid','SPAIN','28020','680459344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 23:55:29',0,NULL,3,1,2,1,NULL,'publiur\r欧标\r、'),(1820,694317115011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','horns21','jwhite@planview.com','White Jason','3909 Coopers Hawk Cv','Austin','TX','UNITED STATES','78738-6526','(512) 423-8077','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 00:36:19',0,NULL,3,1,1,1,NULL,'horns21\r÷'),(1821,0,220767084369,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','dg006','dg006@yahoo.com','Diana Gonzalez','1129 N Marshall St<br>Apt 22','Milwaukee','WI','UNITED STATES','53202-3314','(414) 364-3870','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-12 01:08:28',0,NULL,3,1,1,1,NULL,'dg006\r、'),(1822,691613204011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','eabrahams10','eabrahams_07@hotmail.com','Enrique Romero','PO BOx 742','Culebra','PR','UNITED STATES','00775-0742','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 01:16:51',0,NULL,3,1,1,1,NULL,'eabrahams10\r÷'),(1823,659225570001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','ptagau','crmeyer2003@comcast.net','Charles R. Meyer','210 NE 41st St<br>Apt 104','Ankeny','IA','UNITED STATES','50021','(847) 903-8271','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 01:21:02',0,NULL,3,1,1,1,NULL,'ptagau\rLK038985619CN\r÷'),(1824,768682445012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','chucksangel21777','chucksangel21777@yahoo.com','Chuck Evatt','901 E Kiehl Ave','sherwood','AR','UNITED STATES','72120-3031','(501) 902-8832','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 01:21:39',0,NULL,3,1,1,1,NULL,'chucksangel21777\r、'),(1825,694333868011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jvilla742','jvilla321@gmail.com','Jeff Villanueva','1930 Decelles','Montreal','QC','CANADA','H4M1A8','(514) 692-0069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 01:42:08',0,NULL,3,1,2,1,NULL,'jvilla742\r、'),(1826,694337890011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ldimas26','gladib@cwpanama.net','Luis Dimas','8619 NW 68th St<br>Pty S0264','Miami','FL','UNITED STATES','33166-2667','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 01:52:16',0,NULL,3,1,1,1,NULL,'ldimas26\r÷'),(1827,571366899013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','mchinand','chinander@gmail.com','Michael Chinander','5009 S Dorchester Ave<br>Apt Bsmnt','Chicago','IL','UNITED STATES','60615-2928','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 03:27:31',0,NULL,3,1,1,1,NULL,'mchinand\r÷'),(1828,571371539013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','satellite-gt','glidden@caribe.net','Glidden A Torres','RR 1 Box 2232','Anasco','PR','PUERTO RICO','00610-9656','7877170335','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 03:59:41',0,NULL,3,1,1,1,NULL,'satellite-gt\r÷'),(1829,771413451012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','dolphinhawaii','branto@hawaii.rr.com','Brant Oshiro','1802 Hoohulu St.','Pearl City','HI','UNITED STATES','96782','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 04:11:46',0,NULL,3,1,1,1,NULL,'dolphinhawaii\r、'),(1830,771430484012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','tkjoseph','tkjoseph@yahoo.com.tw','LIU KUAN LIN','Rm. 3, 5F., No.172, Changchun Rd.,','Jungshan Chiu, Taipei,10485','Taiwan','TAIWAN','R.O.C.','(093)589-8081','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 05:43:31',0,NULL,3,1,2,1,NULL,'tkjoseph\r、'),(1831,571385888013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','shiron1972','shiron@yellow.plala.or.jp','YUICHIRO KANEDA','shimasaki 1-16-20<br>CIMA-206','Kumamoto','Kumamoto','JAPAN','8600073','0962004873','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 05:47:49',0,NULL,3,1,2,1,NULL,'shiron1972\r、'),(1832,571407509013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','masmaster','mshtephan@gmail.com','Maxim Shtephan','Kozatska st., 3<br>ZAT Chumak','Kakhovka','Kherson reg','UKRAINE','74800','380-504422022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 08:30:10',0,NULL,3,1,2,1,NULL,'masmaster\r、'),(1833,519872067003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','suprememaster1990','eloyvanschaik@gmail.com','Eloy van Schaik','Harmoniestraat 73','Helmond','','NETHERLANDS','5702 JD','020-7043-5364','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 08:44:28',0,NULL,3,1,3,1,NULL,'suprememaster1990\rHSUE004\rRA117716353CN\r、'),(1834,525631719004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',92.97,'cnfaner','never6910','malaspinapietro@alice.it','PIETRO MALASPINA','VIA S. AGATA AL FIUME, 36','REGGIO CALABRIA','RC','ITALY','89131','3339293127','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 08:50:18',0,NULL,3,0,3,1,NULL,'never6910\rWWSI005\rRA117716702CN\r、'),(1835,694426250011,320679575605,'New UNLOCKED Option GTM382 PCI-E 7.2Mbps WWAN GTM 382',1,'WWOP003',30,'eastar4uk','microsaci','info@microsaci.com','alberto prado mazagato','llul 102 bajos<br>MICROSACI','barcelona','Cataluña','SPAIN','08005','933001555','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 09:00:08',0,NULL,8,1,17,0,NULL,'microsaci\rWWOP003'),(1836,694427456011,320679575605,'New UNLOCKED Option GTM382 PCI-E 7.2Mbps WWAN GTM 382',1,'WWOP003',30,'eastar4uk','microsaci','info@microsaci.com','alberto prado mazagato','llul 102 bajos<br>MICROSACI','barcelona','Cataluña','SPAIN','08005','933001555','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 09:04:17',0,NULL,3,1,3,1,NULL,'microsaci\rWWOP003\r一共买了两个\r\rRA117729374CN'),(1837,571417790013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','toxicated101','matthew.wheatley1@ntlworld.com','Matthew Wheatley','27a<br>Sansome Place','Worcester','Worcestershire','UNITED KINGDOM','WR1 1UA','0190522316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 09:23:30',0,NULL,3,1,2,1,NULL,'toxicated101\r\\'),(1838,571421213013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','ogattaz','olivier@gattaz.com','isandlaTech, Mr Olivier Gattaz','255 chemin des arriots','montbonnot saint martin','Rhône-Alpes','FRANCE','38330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 09:47:54',0,NULL,3,1,2,1,NULL,'ogattaz\r\\'),(1839,771496871012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',14.99,'eastar4uk','eubookings','webmaster@eubookings.com','EU Bookings LTD.','Waterford City Enterprise Ctr, Waterford Bus. Pk.<br>Cork Road','Waterford','Waterford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 10:23:05',0,NULL,3,1,3,1,NULL,'eubookings\rOTGR001\rRA117729119CN\r\\'),(1840,694450241011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','redbaron137','marsnine@optusnet.com.au','Chak Ng','5 Lewis Grove','Mt Waverley','Victoria','AUSTRALIA','3149','0414539014','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 10:34:02',0,NULL,3,0,2,1,NULL,'redbaron137\r÷'),(1841,694454332011,320441575533,'2.1 Acer Extensa 4620 4620z 4220 Bluetooth Module cable',1,'BTAC2104',12.8,'eastar4','mrazicek92','crims@zoznam.sk','Jakub Mrazik','Tranovskeho 111/3','Liptovsky Mikulas','Zilinsky Kraj','SLOVAK REPUBLIC','03101','0907440447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 10:50:41',0,NULL,3,1,2,1,NULL,'mrazicek92\racer 4pin1.25 6cm \r÷'),(1842,771518030012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',10.69,'eastar4','bluecrew72','jamiebeckf@gmail.com','Jamie Feldman','45 Sunbird Crescent','Carrum Downs','Victoria','AUSTRALIA','3201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 11:34:14',0,NULL,3,1,2,1,NULL,'bluecrew72\r÷'),(1843,694471813011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','hbitton','hananko@gmail.com','Hanan Bitton','Hazait 75 / 12','Oranit','Israel','ISRAEL','44813','972543007580','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 12:00:17',0,NULL,3,1,3,1,NULL,'hbitton\rRCLO006\rRA117729136CN\r、'),(1844,694480269011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mr_bigtoe','steven-james@bigpond.com','Steve James','34 Warner Drive','Padbury','Western Australia','AUSTRALIA','6025','0894027501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 12:21:19',0,NULL,3,1,2,1,NULL,'mr_bigtoe\r÷'),(1845,694480899011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',37.8,'eastar4','i9wolf','stonehum@hotmail.com','Nik Wolf','P.O Box 824','Glenorchy','Tasmania','AUSTRALIA','7010','0487387851','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 12:25:18',0,NULL,3,1,3,1,NULL,'i9wolf\rWLAP002\rRA117729207CN\r\\'),(1846,525672286004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','kysa2','bokas@comcast.net','Edmundas Rainys','6036 Sherman Dr','Woodridge','IL','UNITED STATES','60517','(630) 362-2251','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 12:34:02',0,NULL,8,1,17,0,NULL,'kysa2'),(1847,519914384003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','kysa2','bokas@comcast.net','Edmundas Rainys','6036 Sherman Dr','Woodridge','IL','UNITED STATES','60517','(630) 362-2251','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 12:37:37',0,NULL,3,1,1,1,NULL,'kysa2\r一共买了一个水管一个花洒\r、'),(1848,771540743012,220705197816,'New in box  Motorola H700 Bluetooth Wireless Headset',1,'HSMO013',16.9,'eastar4uk','pbry2421','bryanandkirby@sky.com','peter bryan','114 high garrett,<br>braintree,','braintree','Essex','UNITED KINGDOM','cm75nt','01376326960','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-12 12:44:21',0,NULL,3,1,3,1,NULL,'pbry2421\rHSMO013\r英标\rRA117729737CN\r、'),(1849,694468576011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',32.9,'eastar4','zolee7','stargame.zolee@maffia.hu','Pusztaszeri Zoltán','Hobiart Basa st. 8','Szeged','HI','HUNGARY','6723','+36304413958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 13:00:07',0,NULL,3,1,3,1,NULL,'zolee7\r欧标  HSNO003\rRA117729175CN\r、'),(1850,694496562011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ryanverdana','massicotte_charles@yahoo.ca','Charles Massicotte','195, Sainte Cécile','Le Bic','QC','CANADA','G0L1B0','(418) 736-4797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 13:14:16',0,NULL,3,1,2,1,NULL,'ryanverdana\r÷'),(1851,525686814004,140516157546,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'TOIN002+BAIN002+BAIN001',49.9,'cnfaner','maxwell-58','maxwell-58@hotmail.com','brad smith','11 cherry rd eleebana','newcastle','New South Wales','AUSTRALIA','2282','0402308547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 13:41:53',0,NULL,3,0,3,1,NULL,'maxwell-58\rTOIN002+BAIN002+BAIN001\rRA117729445CN\r\\'),(1852,694519110011,320679575403,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.5,'eastar4uk','timgiles','tim@giles.my-bulldog.com','Timothy Giles','Kungsgatan 19b','Umeå','','SWEDEN','90321','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 14:24:32',0,NULL,3,1,2,1,NULL,'timgiles\r÷'),(1853,571483038013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','pdslab','tertrd@yahoo.com.sg','Terence Lee','Block 12 #07-07/08<br>Lorong Bakar Batu','Singapore','','SINGAPORE','348745','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 14:30:59',0,NULL,3,1,3,1,NULL,'pdslab\rMOSA002\rRA117716340CN\r、'),(1854,771582221012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','mal8721','djmalwilliams@gmail.com','Mal Williams','29 Gladstone road, Sholing','Southampton','Hampshire','UNITED KINGDOM','SO19 8GU','02380320931','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-12 14:40:08',0,NULL,3,1,3,1,NULL,'mal8721\rHSPL011\rRA117729198CN\r、'),(1855,771584072012,220741050719,'NEW GENUINE NOKIA BH-205 BLUETOOTH HEADSET BH 205',1,'HSNO009',15.5,'eastar4','6525moon6525','joaojmoura@gmail.com','João Moura (Ext.3311)','Rua Xavier Araujo,<br>Edificio Estação Laranjeiras','Lisboa','','PORTUGAL','1600-226','00351968355630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 14:47:04',0,NULL,3,1,2,1,NULL,'6525moon6525\r补一个欧标\r÷'),(1856,525722359004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','sonysen12345','sonysen8@gmail.com','sevtian agus prasetyo','jalan gergaji 3 no 27 rt04 rw 05 kelurahan mugassari','semarang','jawa tengah','INDONESIA','50243','(085) 641-3215 ext.: 50','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 16:06:56',0,NULL,5,1,18,1,NULL,'sonysen12345\rHSSA001\rpaypal有问题\r潘'),(1857,694573533011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','darshini1984','darshi.dalal@gmail.com','Darshini Dalal','4323 Colden St<br>Apt 20A','Flushing','NY','UNITED STATES','11355-5926','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 16:50:48',0,NULL,3,1,1,1,NULL,'darshini1984\r\\'),(1858,571531481013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','sigor220972','sigor72@mail.ru','Igor Selyutin','Kutuzova 6/1 kv 49','Pavlodar','','KAZAKHSTAN','140000','87182550675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 17:19:46',0,NULL,3,1,2,1,NULL,'sigor220972\r÷'),(1859,0,220767084472,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',26.99,'eastar4','rsdixon','scott_dixon@ccountry.net','Scott R. Dixon','838 Blackberry Ln','Ashland','OR','UNITED STATES','97520','(541) 482-0701','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 17:21:21',0,NULL,3,1,1,1,NULL,'rsdixon\r\\'),(1860,519985894003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','galewaves506','glick.eliot@gmail.com','Gudiya Ale','Mantri Elegance, Suite B-506<br>(Next to Shoppers Stop)','Bangalore','KA','INDIA','560076','9945575575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 17:21:39',0,NULL,3,1,3,1,NULL,'galewaves506\rBAZA001\rRA117729184CN\r\\'),(1861,525761318004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','a3_customize','atm.82@mail.ru','Alexandr Antonov','Fedorovskaya 5-188','Saratov','Saratov','RUSSIAN FEDERATION','410018','+79083770881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 18:13:35',0,NULL,3,1,3,1,NULL,'a3_customize\rOTGR001+OTGR002\r\rRA117729618CN'),(1862,694616680011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','chadlandwehr','thebob1911@gmail.com','chad landwehr','850 Chalfont Pl','coppell','TX','UNITED STATES','75019-2876','(972) 304-0124','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 18:16:46',0,NULL,3,1,1,1,NULL,'chadlandwehr\r\\'),(1863,694655691011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','trueduck2000','etn@free.fr','Etienne MERIAUX','81bis route de Clisson','St-SEBASTIEN sur LOIRE','Pays de la Loire','FRANCE','44230','02.28.21.03.46','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 19:29:38',0,NULL,3,1,2,1,NULL,'trueduck2000\r欧标\r÷'),(1864,771730850012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',2,'CRLO001+POLO001',35.8,'eastar4','lmaier9','lmaier@sio.midco.net','Larry Maier','2901 S Hidden Pl<br>Apt 14','Sioux Falls','SD','UNITED STATES','57106-7248','(605) 338-3020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 19:39:26',0,NULL,3,1,1,1,NULL,'lmaier9\r\\'),(1865,694670239011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','mathers5','matters55@hotmail.com','A v/d Lei','Oud Ambacht 225','DRACHTEN','','NETHERLANDS','9201 VT','0642111055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 19:57:36',0,NULL,3,1,2,1,NULL,'mathers5\r÷'),(1866,571596338013,230606464789,'Apple Airport Extreme WIFI PCI-E 802.11n + 2 Antenna',1,'WLAP005+ANAP001',21.98,'eastar4','pprauken','patpe527@gmail.com','Patrik Persson','Lugna Gatan 52','Malmö','','SWEDEN','211 59','+46703032181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 20:27:40',0,NULL,3,1,2,1,NULL,'pprauken\r÷'),(1867,520057803003,130490187857,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'cnfaner','risto.cvetkovski','risto@cvetkovski.mk','Risto Cvetkovski','Joakim Krocovski no.14','Skopje','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','1000','38971322122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 20:47:25',0,NULL,3,1,3,1,NULL,'risto.cvetkovski\rMOLO002\rRA117729140CN\r、'),(1868,771785813012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','dogdude62','dogdude62@hotmail.com','William Perkins','115 Bragdon Rd','Freeport','ME','UNITED STATES','04032','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 21:25:38',0,NULL,3,1,1,1,NULL,'dogdude62\r、'),(1869,769892037012,220759427746,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',2,'HSPL001',18.4,'eastar4uk','shanghaixiaoniucathy','cathy.yinjiazhen@gmail.com','Cathy Yin','RM3102, 3 Pan Peninsula Square','London','London','UNITED KINGDOM','E14 9HQ','07553013640','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-12 21:56:15',0,NULL,3,1,3,1,NULL,'shanghaixiaoniucathy\rHSPL001\r新地址\rEva X Zhang\rLevel 41, 8 Canada Square\rCanary Wharf\rE14 5HQ\rUnited Kingdom\rTel: +44 (0)7827356773,  +44(0)7760684447\rRA117729873CN\r、\r'),(1870,694747799011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','fchgs','fchgds@gmail.com','Fernando Chavez','Av. La Salle Calle Franz Tamayo 6','Santa Cruz de la Sierra','Santa Cruz','BOLIVIA','00000','(591)72669555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 23:29:20',0,NULL,3,0,2,1,NULL,'fchgs\r÷'),(1871,771834123012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','adonay_es','adonay_juan@hotmail.com','Juan CRUZ CALERO','c/ cantos 5 7d','Alcorcon (Madrid)','Madrid','SPAIN','28922','650884349','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 23:55:36',0,NULL,3,1,3,1,NULL,'adonay_es\rOTRA002\rRA117729860CN\r、'),(1872,520090963003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.99,'cnfaner','gnudarve','buck@wisewerks.com','Walter McGibbony','4008 1/2 Monroe St','Los Angeles','CA','UNITED STATES','90029-2906','(323) 304-4497','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 00:00:37',0,NULL,3,1,1,1,NULL,'gnudarve\r\\'),(1873,771806797012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',3,'HSPL010',71.7,'eastar4','grata1m','behanzin.reid.bills@gmail.com','Behanzin Reid','3716 Dyre Ave','Bronx','NY','UNITED STATES','10466','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 00:44:16',0,NULL,3,1,1,1,NULL,'grata1m\r\\'),(1874,525744822004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',61.98,'cnfaner','zahaini','zahainihamzah@gmail.com','LUQMANUL HAKIM BIN ABD. RAHIM','17-1B PUTRI APARTMENT,<br>JALAN SETIAWANGSA 21, TAMAN SETIAWANGSA,','KUALA LUMPUR','WP','MALAYSIA','54200','017-3308263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 00:59:05',0,NULL,3,1,3,1,NULL,'zahaini\rWWSI005\rRA117729153CN\r、'),(1875,571668919013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','classicscooterparts','worldrareitems2008@gmail.com','Howard Ngo','3071 Centerwood Way','San Jose','CA','UNITED STATES','95148-2656','(408) 417-5296','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-13 01:14:18',0,NULL,3,1,1,1,NULL,'classicscooterparts\r\\'),(1876,771855334012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','bastos5776','bastosfamily@msn.com','frank bastos','738 Dennis Pl<br>linden','Linden','NJ','UNITED STATES','07036-1231','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 01:15:24',0,NULL,3,1,1,1,NULL,'bastos5776\r\\'),(1877,694626279011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','anirodgers42','anirodgers@yahoo.com','Anita Rodgers','1999 Burdett Ave<br>White 3004','Troy','NY','UNITED STATES','12180-3743','(908) 319-9973','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 01:49:48',0,NULL,3,1,1,1,NULL,'anirodgers42\r\\'),(1878,694785067011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','zsectsz','sects@naver.com','Joon Lee','12918 SE Foster Rd<br>Bc Food Store','Portland','OR','UNITED STATES','97236-4524','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 02:00:56',0,NULL,3,1,1,1,NULL,'zsectsz\r\\'),(1879,525793978004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','tdrahrhe','ilehrhardts@yahoo.com','Dirk Ehrhardt','6271 N Celery Pl','Tucson','AZ','UNITED STATES','85741-3319','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 02:14:53',0,NULL,3,1,1,1,NULL,'tdrahrhe\r\\'),(1880,571681531013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','jimmysu26','wanqing111@gmail.com','can qiang su','9603 hwy 11 north rr2','Washago','ON','CANADA','L0k2b0','(416) 828-0181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 02:19:37',0,NULL,3,1,2,1,NULL,'jimmysu26\r黄色的\r÷'),(1881,771901492012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','robertorgp','gasperaltarobert@live.com','Roberto gaspar','2201 Lane St SE<br>Apt 3','wilson','NC','UNITED STATES','27893-6570','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 04:14:07',0,NULL,3,1,1,1,NULL,'robertorgp\r、'),(1882,694818559011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.8,'eastar4','togo30','antogo@aon.at','Antonio Gossner','Hallersdorf 49','Krottendorf','','AUSTRIA','8564','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 04:25:55',0,NULL,3,1,2,1,NULL,'togo30\racer 4pin1.25 6cm \r、'),(1883,571711235013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','vliscotile123','vlisco@telus.net','nico van der vlis','7469 banford rd.','chilliwack','BC','CANADA','v4z1c6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 05:21:02',0,NULL,3,1,2,1,NULL,'vliscotile123\r、'),(1884,694845887011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ssrankin','steve@serenitysys.com','Steve Rankin','1366 W Sequim Bay Rd','Sequim','WA','UNITED STATES','98382-8411','(360) 683-7229','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 06:56:33',0,NULL,3,1,1,1,NULL,'ssrankin\r、'),(1885,771935015012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','pcukoo','naijing.luo@nokia.com','naijing luo','174 Weyland Cir','north andover','MA','UNITED STATES','01845-4935','(978) 930-9090','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 07:06:33',0,NULL,3,1,1,1,NULL,'pcukoo\r、'),(1886,771939362012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','luca.razvan','razvan.luca@siemens.com','RAZVAN DANUT LUCA','C. Cosminului nr. 16, bl. 404b, sc.A, ap.3','Brasov','Brasov','ROMANIA','500147','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 07:24:06',0,NULL,3,1,2,1,NULL,'luca.razvan\r欧标\r、'),(1887,771940428012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','tiben105','hwyben105@hotmail.com','benoit soulieres','270 des gentianes','ste-sophie','QC','CANADA','J5J2X3','(450) 436-4389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 07:27:40',0,NULL,3,1,2,1,NULL,'tiben105\r、'),(1888,694858506011,320665720437,'New Genuine Sony Ericsson HBH-608 Bluetooth  Headset',1,'HSSE007',19.9,'eastar4','ashantib1984','ashanti1984@yahoo.de','Joanna Badera','Laubigstrasse 7','Kämpfelbach-Ersingen','','GERMANY','75236','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 07:55:06',0,NULL,3,1,2,1,NULL,'ashantib1984\r欧标、'),(1889,694858599011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','oliverjany','oliverjany@netcologne.de','Oliver Jany','Bahnhofstrasse 93','Niederkassel - Rheidt','','GERMANY','53859','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 08:01:10',0,NULL,3,1,2,1,NULL,'oliverjany\r、'),(1890,694866008011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','s1ns','sindoro.lin@hotmail.com','Sindoro Lin','55/569 George St','Sydney','New South Wales','AUSTRALIA','2000','0413810876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 08:28:45',0,NULL,3,1,3,1,NULL,'s1ns\rUDAP001\r\rRA117729238CN'),(1891,694367966011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','sunrayrabbit','flemij@rpi.edu','John Fleming','Po Box 3424','Eureka','CA','UNITED STATES','95502-3424','(781) 983-6384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 08:52:42',0,NULL,3,1,1,1,NULL,'sunrayrabbit\r\\'),(1892,525938792004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','kruno09','kruno.skaro@vip.hr','Krunoslav Škaro','Šetalište Pape Ivana Pavla II 29','Split','Croatia','CROATIA','21000','+385911620579','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 09:00:35',0,NULL,3,1,3,1,NULL,'kruno09\rOTCR001\rRA117729520CN'),(1893,571460459013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',21.9,'eastar4','verytolik','slimp@list.ru','Anatoliy Epifanov','Shelepihinskoe shosse, 15-50','Moscow','RU','RUSSIAN FEDERATION','123290','79265660330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 09:42:28',0,NULL,3,1,2,1,NULL,'verytolik\r\\'),(1894,571754021013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','namuni2k','namuni@gmail.com','Namhoon Kim','Lotte Apt. 112-2002<br>408, Bisan2-dong, Dongan-gu','Anyang-si','Kyounggi-do','KOREA,REPUBLIC OF','431-762','+82-10-2980-1231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 10:08:12',0,NULL,3,1,2,1,NULL,'namuni2k\r\\'),(1895,520196472003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',83.99,'cnfaner','devriye69','yasarakko@gmail.com','Yaşar AKKO','Perpa Ticaret Merkezi B Blok Kat:2 No:69<br>Okmeydanı-ŞİŞLİ','İSTANBUL','','TURKEY','34385','00902122215700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 10:32:32',0,NULL,3,1,3,1,NULL,'devriye69\rWWOT003\rRA117729652CN'),(1896,771985454012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','izmael53iz','izmael53@windowslive.com','RECEP KULAKSIZ','ATMEYDANI MAHALLESİ AVCILAR SOK.KULAKSIZ APT. NO.36 KAT 2','RİZE','RİZE / TURKİYE','TURKEY','530100','0464 2281902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 10:23:13',0,NULL,3,1,2,1,NULL,'izmael53iz\r欧标\r\\'),(1897,571764122013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','lbromain','lbromain@hotmail.com','Romain LADAN-BOCKAIRY','86 rue François Mitterrand','AMFREVILLE LA MIVOIE','','FRANCE','76920','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 11:00:40',0,NULL,3,1,2,1,NULL,'lbromain\r\\'),(1898,520203119003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','onchal62','opolat62@yahoo.com','ONUR POLAT','Gumruk Mustesarligi, Muhabere ve Elektronik Dairesi<br>Anafartalar caddesi No:6 Kat:14 Yuksek blok, Ulus','ANKARA','ALTINDAG','TURKEY','06100','903123067931','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 11:02:13',0,NULL,3,1,3,1,NULL,'onchal62\rHSNO008\r欧标\rRA117729578CN'),(1899,772004456012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','pekra76','mail@peter-kraut.de','Peter Kraut','Hauptstraße 7','Buchhofen','','GERMANY','94533','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 11:27:02',0,NULL,3,1,2,1,NULL,'pekra76\r\\'),(1900,770965480012,220713846430,'New GENUINE NOKIA HS 11W BLUETOOTH HEADSET',1,'HSNO023',4.69,'eastar4uk','rasyte1988','rasyte88@gmail.com','Liudas Navickas','Vyturiu 12, Garliava<br>Teleiciu km.','Kauno r.','','LITHUANIA','LT53273','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 12:27:38',0,NULL,3,1,2,1,NULL,'rasyte1988\r欧标\\'),(1901,525978067004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','ededsen','edwinovermars@yahoo.com','Edwin Overmars','Lloydstraat 26e','Rotterdam','','NETHERLANDS','3024 EA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 12:36:16',0,NULL,3,1,3,1,NULL,'ededsen\rWLIN010+ANTY002\rRA117729649CN'),(1902,772051003012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',12.5,'eastar4','satanabduljabar','tpbennion@tesco.net','Terry Bennion','21 Grosvenor Street<br>Longton','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','ST3 2LR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 13:44:12',0,NULL,3,1,2,1,NULL,'satanabduljabar\racer 4pin1.25 8cm\r\\'),(1903,772055448012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','orchard_tractor2','mike@heritageorchard.com','Mike EBAY Mintz','45 Westcott Rd','Harvard','MA','UNITED STATES','01451-1820','(508) 577-2855','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 13:56:40',0,NULL,3,1,1,1,NULL,'orchard_tractor2\rMX20T\r\\'),(1904,659815970001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','rys_store','ryan@rollinjunk.com','3D Mobile creations','933 E Crosstown pkwy','kalamazoo','MI','UNITED STATES','49001-2507','(269) 998-6597','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,' ','rys_store \rLK043483053CN  改的地址\r\\'),(1905,525988487004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','antoxa_2010','anton7712@yandex.ru','Vasyl Malyy','RUA DO BOSQUE, 510<br>BARRA FUNDA','SAO PAULO','SP','BRAZIL','01136-000','80938583602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 14:27:35',0,NULL,3,1,3,1,NULL,'antoxa_2010\rWWSI005\rRA117729581CN'),(1906,526004274004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','mdelachaise','mdyck1@gmail.com','Michael Dyck','10-300 River Ave','Winnipeg','MB','CANADA','r3l0b9','(204) 887-7081','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 14:35:43',0,NULL,3,1,3,1,NULL,'mdelachaise\rHSMO007\rRA117729621CN'),(1907,0,220768669878,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',13.5,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 14:37:08',0,NULL,3,1,1,1,NULL,'4278dennis\r\\'),(1908,0,230608645307,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','cryspal123','crystalpaller@yahoo.com','Crystal Paller','398 Cary Jay Blvd','Richmond Heights','OH','UNITED STATES','44143-1726','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-13 14:38:46',0,NULL,3,1,1,1,NULL,'cryspal123\r\\'),(1909,571814747013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 14:41:39',0,NULL,3,1,2,1,NULL,'vjendrisvelimir\r欧标\r\\'),(1910,772093671012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','spooky4131','mtizzy@cox.net','vicky tisdale','700 Pioneer Ln','gentry','AR','UNITED STATES','72734-8741','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 15:35:06',0,NULL,3,1,1,1,NULL,'spooky4131\r\\'),(1911,772104936012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','glendalahoz','astridglenn@yahoo.com','GLENDA LA HOZ','2557 97th St<br>Apt 1','EAST ELMHURST','NY','UNITED STATES','11369-1603','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 16:02:20',0,NULL,3,1,1,1,NULL,'glendalahoz\r\\'),(1912,571838685013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','choonghp88','hpchoong88@yahoo.com','Peng_Choong Ho','33 Jalan Damai Kasih 7<br>Alam Damai, Cheras','Kuala Lumpur','','MALAYSIA','56000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 16:05:35',0,NULL,3,1,2,1,NULL,'choonghp88\r\\'),(1913,571848289013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',2,'ADAK001',25.4,'eastar4','suc2151','trans21a@naver.com','SEONG DEOK, HWANG','HANYOUNG NUX CORPORATION<br>1381-3 JUAN-DONG, NAM-GU','INCHEON','','KOREA,REPUBLIC OF','402853','(821) 191-5401 ext.: 00','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 16:38:41',0,NULL,3,1,2,1,NULL,'suc2151\r\\\r\r'),(1914,526038234004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','uskudar-bilisim','ahmet@kantoglu.com','Ahmet KANTOGLU - USKUDAR BILISIM VE INTERNET HIZMETLERI','Icadiye Mahallesi  Cumhuriyet Caddesi No:47/E Buro: 6','ISTANBUL','USKUDAR','TURKEY','34674','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 16:43:06',0,NULL,3,1,3,1,NULL,'uskudar-bilisim\rBALO007\rRA117729516CN'),(1915,694969118011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'',21.9,'eastar4','mustang-farm','ratler5.0@gmail.com','jon shaub','77 hogate blvd','salem','NJ','UNITED STATES','08079','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 16:57:54',0,NULL,3,0,1,1,NULL,'mustang-farm\r\\'),(1916,526045468004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','bluemurphy4','esthermnewman@gmail.com','Esther Newman','3701 Calle Joaquin','Calabasas','CA','UNITED STATES','91302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 17:06:21',0,NULL,3,1,1,1,NULL,'bluemurphy4\r\\'),(1917,520290440003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'',14.99,'cnfaner','jah-trading','jahebay@gmail.com','Salstein Steven','6250 NW 35th Ave','Miami','FL','UNITED STATES','33147-7502','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 17:11:57',0,NULL,3,0,1,1,NULL,'jah-trading\r\\'),(1918,525351446004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','agente30302','faalvarez30302@yahoo.com','francis a. alvarez rosario','hc 9 box 2099','ponce','puerto rico','PUERTO RICO','00731-9700','(787) 433-6247','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 17:40:00',0,NULL,3,1,1,1,NULL,'agente30302\r\\'),(1919,695053428011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','hrabcakm_2009','hrabcakm@gmail.com','Miroslav Hrabcak','Cerneho 10','Brno','Bystrc','CZECH REPUBLIC','63500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 17:48:16',0,NULL,3,1,2,1,NULL,'hrabcakm_2009\r、'),(1920,571882984013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','telz_87','tommygirl_2_87@yahoo.com','Shantel Schroeder','36450 Hwy 71','Windom','MN','UNITED STATES','56101','(507) 831-2039','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 18:14:02',0,NULL,3,1,1,1,NULL,'telz_87\r\\'),(1921,772212259012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',16.7,'eastar4','vikasmanda','mandavikas@yahoo.com','Vikas Manda','2024 E 74th pl South Apt 101','Tulsa','OK','UNITED STATES','74136','(918) 902-6249','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 19:22:25',0,NULL,3,1,1,1,NULL,'vikasmanda\r\\'),(1922,695106847011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ksiepel','ksiepel@cleantechnow.com','Keith Siepel','526 Topfield Dr','Cincinnati','OH','UNITED STATES','45255-5043','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 19:26:02',0,NULL,3,1,1,1,NULL,'ksiepel\r\\'),(1923,772223540012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',12.99,'eastar4uk','erezkaplan','erez_kaplan@talktalk.net','erez kaplan','5 Wykeham Road, Merrow','Guildford','Surrey','UNITED KINGDOM','GU12SE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 19:39:08',0,NULL,3,1,3,1,NULL,'erezkaplan\rHSMO017\r英标\rRA117729604CN'),(1924,772236478012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','crealiz-2007','contact@crealiz.com','JONATHAN BOUJO','18 RUE DE LA LIBERTE','BISCHHEIM','Alsace','FRANCE','67800','0626044170','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 20:08:11',0,NULL,3,1,2,1,NULL,'crealiz-2007\r\\'),(1925,772242377012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','plombier48','tourigny.marcel@cgocable.ca','Marcel Tourigny','1095 Rue Cartier','Trois-Rivières','QC','CANADA','G8Z 1L5','(819) 384-8118','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 20:11:13',0,NULL,3,1,2,1,NULL,'plombier48\r\\'),(1926,772242569012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','keitten','keiten@post.cz','Jitka Zinke, vedoucí OKP','Ústřední vojenská nemocnice<br>U Vojenské nemocnice 1200','Prague 6','Czech Republic','CZECH REPUBLIC','169 02','723943234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 20:12:25',0,NULL,3,1,2,1,NULL,'keitten\r\\'),(1927,772246621012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',1,'CASS002',17.4,'eastar4','the.q.family','qfamily@hotmail.co.uk','Jamal Qureashi','28 Victoria Road','Mitcham','Surrey','UNITED KINGDOM','CR4 3JA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 20:17:34',0,NULL,3,1,3,1,NULL,'the.q.family\r再发一个CAB-6060\rCASS002+CASS003\r'),(1928,571933951013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','livinonprayer','favamama@yahoo.com','Sheri Fava','469 Bicentennial Trl','Rock Spring','GA','UNITED STATES','30739-2309','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 20:25:48',0,NULL,3,1,1,1,NULL,'livinonprayer\r\\'),(1929,571934215013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','smiggy69mark','msmith-rufc@hotmail.co.uk','Mark Smith','32 Cambridge Crescent<br>East Dene','Rotherham','South Yorkshire','UNITED KINGDOM','S65 2RB','07720525438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 20:29:26',0,NULL,3,1,2,1,NULL,'smiggy69mark\r\\'),(1930,772300169012,220684633355,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'BAIN002+BAIN002+TOIN002',49.9,'eastar4','bumpa2k1','prodsecman@verizon.net','Keith Nicholas','PO Box 1565<br>10 Lombard St','Warren','MA','UNITED STATES','01083','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 22:22:50',0,NULL,3,1,1,1,NULL,'bumpa2k1\rBAIN002+BAIN001+TOIN002\r\\'),(1931,571974811013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','gso102087','george.ct.so@gmail.com','George So','359 Stockbridge Ave','Atherton','CA','UNITED STATES','94027-6442','(650) 862-6306','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 22:55:15',0,NULL,3,1,1,1,NULL,'gso102087\r\\'),(1932,772312362012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','mranario','m_ranario@hotmail.com','Mark Ranario','1908 N Tucker Dr','Tucson','AZ','UNITED STATES','85716-3031','(832) 443-5585','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 23:02:31',0,NULL,3,1,1,1,NULL,'mranario\r\\'),(1933,772325424012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','seamartech','seamartech@comcast.net','Seamartech Marine Electronics','17 Irene st','New Bedford','MA','UNITED STATES','02745-1109','(508) 995-1563','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 23:50:41',0,NULL,3,1,1,1,NULL,'seamartech\r\\'),(1934,772332162012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','moscovita69','69moscovita@hotmail.es','ADOLFO GONZALEZ ALIAGA','Calle Ponzano Nº 16 Local MBE B148','Zaragoza','Zaragoza','SPAIN','50004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 00:14:51',0,NULL,3,1,2,1,NULL,'moscovita69\r\\'),(1935,571991096013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','bigcedharris24','bigcedharris@bellsouth.net','cedric harris','2100 Tuck Dr','Conyers','GA','UNITED STATES','30012','(404) 551-7650','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 00:19:50',0,NULL,3,1,1,1,NULL,'bigcedharris24\r\\'),(1936,571991726013,230608888246,'Brand new LOGITECH VX NANO USB RECEIVER VX V450 V550',1,'RELO003',16.9,'eastar4','tremblayphilippe','tremblay518@hotmail.com','Philippe Tremblay','912 Avenue Bouchard App 3','Amos','QC','CANADA','J9T2W2','(819) 727-4122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 00:21:42',0,NULL,3,1,2,1,NULL,'tremblayphilippe\r\\'),(1937,571992586013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',2,'HSPL005',27,'eastar4','sbeivides','beividesb@yahoo.com','Benjamin Beivides','11907 Lesser St','Norwalk','CA','UNITED STATES','90650-4052','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 00:25:45',0,NULL,3,1,1,1,NULL,'sbeivides\r\\'),(1938,772347023012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','rana009','rana009@yahoo.com','sabir ali rana','77 Delawana Dr<br>App#  508','Hamilton','ON','CANADA','L8E1G5','(905) 297-8949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 01:09:59',0,NULL,3,1,2,1,NULL,'rana009\r\\'),(1939,572000983013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','m7508','malberts@pol.net','Monica Wood','12612 NE 187th St<br>Apt 2402','Bothell','WA','UNITED STATES','98011-9341','(414) 326-0605','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 01:10:36',0,NULL,3,1,1,1,NULL,'m7508\r\\'),(1940,772237432012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.05,'eastar4','jdr_wiredrat','jdr@wiredrat.net','John Robertson','123 Rock Bridge Rd','Batesville','AR','UNITED STATES','72501-7676','(870) 613-8615','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 02:12:09',0,NULL,3,1,1,1,NULL,'jdr_wiredrat\rMX20T\r\\'),(1941,572029788013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',4,'HSJA002',86,'eastar4','barrychickenman','shakey_ghost@yahoo.com','Barry Parker','24457 Mary N Smith, rd','Accomac','VA','UNITED STATES','23301','(757) 710-0737','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 03:42:49',0,NULL,3,1,1,1,NULL,'barrychickenman\r\\'),(1942,0,230609261115,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',13,'eastar4','suddu','sudershang@hotmail.com','SUDERSHAN GUPTA','119 zanca turn','yorktown','va','UNITED STATES','23693-2449','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 04:21:35',0,NULL,3,1,1,1,NULL,'suddu\r\\'),(1943,772395632012,220689444211,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61 Z60',1,'WWSI002',37.45,'eastar4','saccin76','habbaji@gmail.com','Tae-Kwang, Youn','BITEK SYSTEM INC. Rm.719 Doosan Venture Digm, 126-1<br>Pyengchon-dong','Anyang-si','Gyeonggi-do','KOREA,REPUBLIC OF','431-070','82-10-9289-5389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 04:26:07',0,NULL,3,1,3,1,NULL,'saccin76\rWWSI002\rRA117729241CN'),(1944,695273841011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','pppthe_first','douphol@free.fr','SCHBATH pierre','21 avenue Georges','Colombes','Île-de-France','FRANCE','92700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 04:40:21',0,NULL,3,1,3,1,NULL,'pppthe_first\rRCLO006\rRA117729167CN'),(1945,572044807013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','paralaz','2sw@list.ru','Vladimir Scherbakov','Ushakova 4-14','Volgograd','','RUSSIAN FEDERATION','400017','+79064068605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 05:31:37',0,NULL,3,1,3,1,NULL,'paralaz\rOTRA002\rRA117729224CN'),(1946,520458953003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','ryanbastian','ryan.bastian@hotmail.com','Ryan Bastian','Jl. Kopo Jaya No. 17','Bandung','Jawa Barat','INDONESIA','40224','62816611285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 05:33:50',0,NULL,3,1,3,1,NULL,'ryanbastian\rBAZA001\rRA117729255CN'),(1947,772412634012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','roulis222','yiannakis222@hotmail.com','John Dialektakis','Unit 815 / 10 Brodie Spark Drive','Wolli Creek','New South Wales','AUSTRALIA','2205','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 05:59:58',0,NULL,3,1,3,1,NULL,'roulis222\rHSSE006\r澳标\rRA117729215CN\r'),(1948,572049628013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',3,'CACN004',50.64,'eastar4','via4in1via4in1','killa_bee@mail.ru','Sergey Slobodenyuk','Kronshtadtskiy bulvar<br>House 23 Building 1 Flat 47','Moscow','','RUSSIAN FEDERATION','125493','+79647637482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 06:10:26',0,NULL,3,1,3,1,NULL,'via4in1via4in1\rCACN004\rRA117729547CN'),(1949,572047653013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','j_siebenga','jason@bigsteelbox.com','Jason Siebenga','1670 Dilworth Dr','Kelowna','BC','CANADA','V1Y 7V3','(250) 212-8000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 05:53:55',0,NULL,3,1,3,1,NULL,'j_siebenga\rMOSA002\rRA117729555CN'),(1950,772416949012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','deeznutz2377','deeznutz@internode.on.net','Brad Kyaw','28 Heatherdale Street','Amaroo','Australian Capital Territory','AUSTRALIA','2914','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 06:25:54',0,NULL,3,1,3,1,NULL,'deeznutz2377\rOTGR001+OTGR002\rRA117729309CN'),(1951,772430671012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','nozdk01','nozdk1999@yahoo.co.jp','Daisuke Nozawa','5-30-16 S-202 Megurohoncho<br>Meguro-ku','Tokyo','Tokyo','JAPAN','152-0002','+81 3 5876 5090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:28:42',0,NULL,3,1,2,1,NULL,'nozdk01\r\\'),(1952,772444052012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','bebert90','hubert_maisonneuve@hotmail.com','maisonneuve hubert','19 rue des francs bourgeois','Strasbourg','','FRANCE','67000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 08:28:40',0,NULL,3,1,2,1,NULL,'bebert90\r\\'),(1953,572069827013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','nesthaegchen','s.jeanrichard@googlemail.com','Samuel Jeanrichard','Schweriner Ring 18<br>3. Etage','Berlin, Wartenberg','','GERMANY','13059','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 08:33:40',0,NULL,3,1,2,1,NULL,'nesthaegchen\r\\'),(1954,772208722012,220504387390,'2.1 Acer Timeline 4810 5810 Bluetooth Module EDR+ cable',1,'BTAC2101',12.8,'eastar4','crazy_rock','crazy_rock274@hotmail.com','mehmet KAYACIK','yildirim beyazit mh. ozbilen sk. kartas apt. b1 blok no:1','KUTAHYA','MERKEZ','TURKEY','43020','5556635744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 09:41:55',0,NULL,3,0,2,1,NULL,'crazy_rock\racer 4pin1.25 3cm \\'),(1955,572096306013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','flashy69','myglock17@gmail.com','MARIOS MICHAIL','GRIGORIOU KOUSIDOU 7','ZOGRAFOU','ATHENS, GREECE','GREECE','15773','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 11:13:12',0,NULL,3,1,3,1,NULL,'flashy69\rMOSA002\rRA117729272CN'),(1956,572096327013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',33.76,'eastar4','balage001','speed.limit@freemail.hu','Tözser Balazs','Etele ter 3. fszt. 2.','Budapest','','HUNGARY','1115','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 11:17:17',0,NULL,3,1,3,1,NULL,'balage001\rCACN004\rRA117729391CN'),(1957,772488747012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','truck2807','mcautos@hotmail.com','michael clarke','31 Sheelin Park','Derry','Londonderry','UNITED KINGDOM','bt480pd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 11:24:05',0,NULL,3,1,3,1,NULL,'truck2807\rHSPL011\r英标\rRA117729330CN'),(1958,526263892004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','vovaharitonov','flurry.ebay@gmail.com','Volodymyr Kharytonov','Kravchuka Street 19, Appartment 103','Lutsk','Volyn','UKRAINE','43026','+380936114444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 11:25:36',0,NULL,3,1,3,1,NULL,'vovaharitonov\r送螺丝 \rWWSI005\rRA117728453CN\r'),(1959,695364471011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','stoni1999','m-kaufmann@web.de','Michael Kaufmann','Schulberg 3','Unterwürschnitz','','GERMANY','08626','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 11:53:30',0,NULL,3,1,2,1,NULL,'stoni1999\\'),(1960,526270816004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','karind2008','danek@iprimus.com.au','Karin Danek','Unit 5, 53 Biscayne Way','Jandakot','Western Australia','AUSTRALIA','6164','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 11:58:30',0,NULL,3,1,3,1,NULL,'karind2008\rBALO007\rRA117729343CN'),(1961,695368265011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',3,'TRMX002',25.65,'eastar4','ivsindustrialsurplus','dolesuk@ivsincorporated.com','John Morris','35572 Veronica St','LIVONIA','MI','UNITED STATES','48150-1204','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 12:02:43',0,NULL,3,0,1,1,NULL,'ivsindustrialsurplus\r\\'),(1962,526271998004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','shaharbv','shaharbv@walla.co.il','Shahar Ben-Varon','Savion 21','Petah-Tikva','','ISRAEL','49542','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 12:08:47',0,NULL,3,1,3,1,NULL,'shaharbv\rHSPL001\rRA117729357CN'),(1963,526279639004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'cnfaner','bobbertobobberto','bobberto@libero.it','roberto carracciuolo','strada torino 90 fornaci','beinasco','TO','ITALY','10092','3358495202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 12:42:50',0,NULL,3,1,3,1,NULL,'bobbertobobberto\rANYA001\rRA117728100CN'),(1964,572122404013,230498933879,'2.1 Acer Aspire AS 4740  Bluetooth Module EDR + cable',1,'BTAC2123',12.8,'eastar4','goetzahr','hermannsoares@gmail.com','Aldir','Rua do Álamo, Quadra 30, Lote 47<br>Bairro Goiânia 2','Goiânia','Goiás','BRAZIL','74663040','55(62)3205-6465','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:22:47',0,NULL,3,1,2,1,NULL,'goetzahr\racer 8pin1.00 10cm\\'),(1965,772533526012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','trekeeboy2','trekeeboy@comcast.net','Spencer Burke','8300 W 31st Street<br>Apt 304','Minneapolis','MN','UNITED STATES','55426','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 13:44:58',0,NULL,3,1,1,1,NULL,'trekeeboy2\r\\'),(1966,572127313013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','invaderoz','serendipity_dragon@hotmail.com','Ashli Neese','Unit 1<br>90 Grey Street','St Kilda','Victoria','AUSTRALIA','3182','610405060743','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:48:16',0,NULL,3,1,2,1,NULL,'invaderoz\\'),(1967,695400971011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','neoplaz','alan@hyde.net.au','Alan Hyde','Unit 21, 1029 Manly Road','Tingalpa','Queensland','AUSTRALIA','4173','0418879461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:59:55',0,NULL,3,1,2,1,NULL,'neoplaz\rRELO002\\'),(1968,772545369012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','bekawillms','bekawillms@yahoo.com','Rebekah Williams','3 Winland Ct','Gillette','WY','UNITED STATES','82718-6941','(307) 299-7366','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:18:57',0,NULL,3,1,1,1,NULL,'bekawillms\r\\'),(1969,0,320685158781,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','beaztyb','beaztybee@aol.com','JACOB DESJARDINS','4143 BAIN PKWY','BLASDELL','NY','UNITED STATES','14219','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:21:43',0,NULL,8,1,17,1,NULL,'beaztyb'),(1970,526303481004,140429366892,'2.1 HP Compaq Presario V2000 V2100 bluetooth module ',1,'BTHP2109',13.99,'cnfaner','nakiz2010','nakiz@globomail.com','leo zikan ferri','rua joao pessoa n74 centro','itatiaia','rio de janeiro','BRAZIL','27580-000','02499992832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 14:39:12',0,NULL,3,1,3,1,NULL,'nakiz2010\rHP 8pin 1.25 3cm \rRA117729365CN'),(1971,0,220769182825,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',8.99,'eastar4','philaz','phil_ellsworth@yahoo.com','Phil Ellsworth','11745 Mobile St','Commerce City','CO','UNITED STATES','80022-6218','(602) 361-3374','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:40:58',0,NULL,3,1,1,1,NULL,'philaz\r\\'),(1972,695418757011,320441946712,'2.1 HP NW8240 NW8440 Bluetooth Module EDR + cable',1,'BTHP2101',12.8,'eastar4','45bluesky135','acewolf69@gmail.com','Yongdon Shin','Dorim1dong 137-17 3rd floor<br>Youngdeungpogu','Seoul','','KOREA,REPUBLIC OF','150081','01063807446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 14:50:44',0,NULL,3,1,2,1,NULL,'45bluesky135\rHP 8pin 1.0 3cm\\'),(1973,526306666004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','turquoise-web','turquoise.web@gmail.com','GURSOY HAFIZOGLU','HURRIYET MAH. 276 SOK. NO:7/3<br>GAZIOSMANPASA','ISTANBUL','IST','TURKEY','34240','(212) 537 6390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 14:52:37',0,NULL,3,1,3,1,NULL,'turquoise-web\rHSNO022 银色的\r欧标\rRA117729269CN'),(1974,695424045011,320394929398,'Acer Aspire 5720 5720G  Bluetooth Module 2.0+cable',1,'BTAC2022',12.5,'eastar4','azbrizer2010','alexander.zbrizer@numonyx.com','Zbrizer Alexander','Eli Cohen 10/9','Holon','','ISRAEL','58370','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 15:02:14',0,NULL,3,0,2,1,NULL,'azbrizer2010\racer 8pin1.00 15cm\\'),(1975,0,230609028105,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',13.49,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 15:17:23',0,NULL,3,1,1,1,NULL,'4278dennis\r\\'),(1976,695434127011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','ghartz2009','georgehartzoulakis@hotmail.com','george hartzoulakis','ioanninon 23<br>ilion','athens','','GREECE','13123','00302102636880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 15:31:19',0,NULL,3,1,3,1,NULL,'ghartz2009\rRCLO006\rRA117729405CN'),(1977,772581731012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','sniper_iv','lpanzini@rogers.com','Lui Panzini','7 Giltspur Drive','North York','ON','CANADA','M3L 1M4','(416) 744-8707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 15:55:16',0,NULL,3,1,2,1,NULL,'sniper_iv\\'),(1978,772593735012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','blackcountach','functionalbiceps@aol.com','Tory Simmons','44 N Rural St','Indianapolis','IN','UNITED STATES','46201-3208','(317) 717-9864','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 16:34:27',0,NULL,3,1,1,1,NULL,'blackcountach\r\\'),(1979,572172336013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','nous.dim','petrovdim@gmail.com','Leo Steinberg (c/o D.Petrov)','119 Mackenzie St','Brooklyn','NY','UNITED STATES','11235-2303','(718) 496-0075','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 16:36:53',0,NULL,3,1,1,1,NULL,'nous.dim\r\\'),(1980,772616337012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','cad1225','ted@nwbuzz.net','Ted Isaac','17201 N Meadowview Ct','Nine Mile Falls','WA','UNITED STATES','99026-9333','(360) 910-9119','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 17:15:37',0,NULL,3,1,1,1,NULL,'cad1225\r\\'),(1981,526344975004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','digimoney','karlheinzmeese@web.de','Karl-Heinz Meese','Weikenweg 61','Paderborn','','GERMANY','33106','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 17:22:22',0,NULL,3,1,3,1,NULL,'digimoney\r欧标\rHSPL010\rRA117728039CN'),(1982,572196172013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','jmmc9000','joaniemc@me.com','Joan McCutcheon','4910 Joni Way','Richmond','TX','UNITED STATES','77407-7921','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 17:52:15',0,NULL,3,1,1,1,NULL,'jmmc9000\r\\'),(1983,660317741001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','516gene','gene@kenclaire.com','Kenclaire Electric','714 Old Country Rd','Westbury','NY','UNITED STATES','11590-4504','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'516gene  \r改的地址\rLK043485068CN\r\\\r'),(1984,772654078012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','khehra4400','doordie@live.ca','GURINDERPAL KHEHRA','52 BLAZINGSTAR DR','BRAMPTON','ON','CANADA','L6R3E7','(905) 782-4400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 18:27:06',0,NULL,3,1,2,1,NULL,'khehra4400\\'),(1985,772655216012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',99,'eastar4','bumark','compras@bct.com.ar','BCT SAR','6993 NW 82nd Ave<br>Ste 28','Miami','FL','UNITED STATES','33166-2782','(305) 648-8404','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 18:30:31',0,NULL,3,1,1,1,NULL,'bumark\r新地址\r6993nw 82Ave. Suite 28 Miami Florida, zip 33166, USA. Name: BCT BUMARK - Sar Express (JUAN), 305 468 8404 \r\\'),(1986,695512780011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','soldatii','gadyoo@yahoo.com','grigorescu alexandru daniel','str.soldat lazar florea nr1 bl 8c ap43','bucharest','bucharest','ROMANIA','7000','0040767118822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 18:35:02',0,NULL,3,1,2,1,NULL,'soldatii\r欧标\\'),(1987,772662031012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','orion1-2008','apintech@aol.com','stan byrd','4525 N Road 68<br>Ste F','Pasco','WA','UNITED STATES','99301-9595','(509) 628-7613','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 18:41:15',0,NULL,3,1,1,1,NULL,'orion1-2008\r\\'),(1988,572223601013,230608888246,'Brand new LOGITECH VX NANO USB RECEIVER VX V450 V550',1,'RELO003',16.9,'eastar4','bolo99999','bolo9999@wanadoo.fr','Christian GREZES','43 rue Henri Tariel','Issy les Moulineaux','Île-de-France','FRANCE','92130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 19:06:01',0,NULL,3,1,2,1,NULL,'bolo99999\r新优联红边的\\'),(1989,519112304003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','puritanstuff','nigel_beaumont@yahoo.com','LaDonna Beaumont','2040 E Mountain Vista Dr','Coeur D Alene','ID','UNITED STATES','83815','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 19:13:32',0,NULL,3,1,1,1,NULL,'puritanstuff\r\\'),(1990,695544240011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',2,'HSNO019',89.98,'eastar4','metropol0_1','mehti_yazici@yahoo.de','Mehti yazici','Karl-marx-str.175 a','Berlin','','GERMANY','12043','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 19:35:30',0,NULL,3,1,3,1,NULL,'metropol0_1\r欧标   HSNO019\rRA117728042CN'),(1991,695547247011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','sportsfz','bestpeople1@earthlink.net','vito  desantis','1187 richmond ave','staten island','NY','UNITED STATES','10314-7428','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 19:47:01',0,NULL,3,1,1,1,NULL,'sportsfz\r\\'),(1992,660367342001,110672308283,'New 3M Particulate Respirator with valve 9332 N99 FFP3',1,'OT3M001',13.99,'buysia','eshipsides','liz@thompsonpatentlaw.com','Elizabeth Shipsides','4205 Lancaster Ln N<br>Ste 104','Plymouth','MN','UNITED STATES','55441-1702','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 19:50:39',0,NULL,3,1,1,1,NULL,'eshipsides\r\\LK039789315CN'),(1993,695552418011,320441946742,'2.1 HP NX7300 NX7400 Bluetooth Module EDR + cable',1,'BTHP2101',12.8,'eastar4','liudmil13','lcolov@abv.bg','Liudmil Tsolov','JK 3, bl 13, vh-G, ap-65','Kozloduj','Vratsa','BULGARIA','3320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 19:50:52',0,NULL,3,1,2,1,NULL,'liudmil13\rHP 8pin 1.0 3cm \\'),(1994,772703127012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','gwar2230','gwward61@yahoo.com','Glenn Ward','4229 Parkside Dr','Orlando','FL','UNITED STATES','32812','(407) 857-7985','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 19:58:55',0,NULL,3,1,1,1,NULL,'gwar2230\r\\'),(1995,695555694011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',43.9,'eastar4','weissernir','wiesser_nir@yahoo.com','Nir Weisser','Tarad 1/b','Ramat Gan','','ISRAEL','52503','+972549363040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:01:58',0,NULL,3,1,3,1,NULL,'weissernir\rHSPL009\rRA117729326CN'),(1996,695560262011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','sorgaebi','ecoplace@hotmail.com','Changhee Lee','810A Reid Rd','Saskatoon','SK','CANADA','S7N 3C2','(306) 978-2942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:05:59',0,NULL,3,1,3,1,NULL,'sorgaebi\rUDAP001\rRA117728011CN'),(1997,660380043001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','tpkusa','tpkusa@aol.com','TOSHIO AKIMOTO','340 E 2nd St<br>Ste 307','LOS ANGELES','CA','UNITED STATES','90012-4249','(213) 626-0603','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 20:17:37',0,NULL,3,1,1,1,NULL,'tpkusa\r\\LK039787929CN '),(1998,695574486011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','inspiration1977','carlos.roka@gmail.com','Carlos de los reyes  Roka Bopabo','c/ anzuelo nº11 local 9-b','tias','Canarias','SPAIN','35510','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:35:27',0,NULL,3,1,2,1,NULL,'inspiration1977\r欧标\\'),(1999,572253438013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','bibil0_0','bibib1@free.fr','franck barthelemy','49 avenue joliot curie<br>appt 45, 1er etage','nanterre','Ile-de-France','FRANCE','92000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:37:17',0,NULL,3,1,3,1,NULL,'bibil0_0\rMOSA001\rRA117729286CN'),(2000,695581668011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','dugalex','ebay@dugalex.com.au','Aleksandar Dugalic','797A The Horsley Drive','Smithfield','New South Wales','AUSTRALIA','2164','0423765047','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:52:13',0,NULL,3,1,2,1,NULL,'dugalex\\'),(2001,695593404011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','rafaeljfriasjr','rafaeldejesusfriasjr@yahoo.com','Rafael D. Frias Jr','44107 Paget Ter','Ashburn','VA','UNITED STATES','20147-3847','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 21:21:41',0,NULL,3,1,1,1,NULL,'rafaeljfriasjr\r\\'),(2002,526428624004,140516104473,'Logitech Charging Cradle L-LG7 for Harmony 880 890 pro',1,'CRLO002',9.99,'cnfaner','radar224','mconos@gmail.com','Marinus Onos','224 Sunterra Ridge Place','Cochrane','AB','CANADA','T4C 1W9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 21:44:51',0,NULL,3,1,3,1,NULL,'radar224\rCRLO002\rRA117729312CN'),(2003,0,230609028229,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','dapoch','dapoluch@hotmail.com','Anthony Poluch','25 Timber Ridge rd','morgantown','PA','UNITED STATES','19543','(484) 288-8310','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 22:00:02',0,NULL,3,1,1,1,NULL,'dapoch\r\\'),(2004,772771102012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',10.69,'eastar4','digitalsaraiva','saraivadigital@terra.com.br','Evandro Ricardo Saraiva','Rua, Augusto Duó 2138<br>Vila América','Votuporanga','São Paulo','BRAZIL','15502-107','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 22:29:25',0,NULL,3,1,2,1,NULL,'digitalsaraiva\\'),(2005,772773412012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','lrdsouza','lance-d@windowslive.com','Lance D Souza','2010 Peach Orchard Dr<br>Apt 34','Falls Church','VA','UNITED STATES','22043-2038','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 22:37:37',0,NULL,3,1,1,1,NULL,'lrdsouza\r\\'),(2006,772776124012,220449147548,'Samsung R18 R20 R25 Bluetooth Module 2.0 EDR+cable',1,'BTSA2003',12.5,'eastar4','the_fifer','ww51ky49rh@talktalk.net','Willam Wilson','51, Greenbank drive,','Cowdenbeath','Fife','UNITED KINGDOM','KY4-9RH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 22:46:46',0,NULL,3,1,2,1,NULL,'the_fifer\\'),(2007,772780002012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',27.99,'eastar4uk','ratnesh4u','anchor2ratnesh@yahoo.co.in','ratnesh kumar tripathi','Flat -6/11,<br>240,core A, Wallace street','Glasgow','Glasgow (City of)','UNITED KINGDOM','G5 8AU','07411252528','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 23:00:21',0,NULL,3,1,3,1,NULL,'ratnesh4u\r英标  HSNO019\rRA117728056CN\r'),(2008,695628346011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jb2direcway','smjack@comcast.net','John Bailey','5965 Oak Valley Ct','Santa Maria','CA','UNITED STATES','93455-6006','(805) 934-4422','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 23:17:08',0,NULL,3,1,1,1,NULL,'jb2direcway\r\\'),(2009,772791200012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','drhadlock','drhadlock@magiclink.com','David Hadlock','496 Shoup Ave W<br>Ste C','Twin Falls','ID','UNITED STATES','83301-5043','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 23:39:46',0,NULL,3,1,1,1,NULL,'drhadlock\r\\'),(2010,572301912013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','noirmarginal','richardcoutu@videotron.ca','richard coutu','49 des fromagers','st-basile le grand','QC','CANADA','j3n1y6','(450) 723-0532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 23:43:44',0,NULL,3,1,2,1,NULL,'noirmarginal\\'),(2011,520705693003,130458644539,'New GENUINE NOKIA HS-3W BLUETOOTH HEADSET track#',1,'HSNO021',14.9,'cnfaner','rrbdxb','hibz21@hotmail.com','Raheel Rana','21 - 22 Boutique Villas<br>Dubai Media City','Dubai','Dubai - UAE','UNITED ARAB EMIRATES','500585','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 00:22:42',0,NULL,3,1,3,1,NULL,'rrbdxb\rHSNO021\rRA117728025CN'),(2012,772806239012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','ranemoney1','buckjones1011@aol.com','BRIAN PEARSON','868 n 50th st','philadelphia','PA','UNITED STATES','19139','(267) 312-3041','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 00:41:19',0,NULL,3,1,1,1,NULL,'ranemoney1\r\\'),(2013,572317150013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','mimosamom','cassie.koz@gmail.com','Candy Koslowsky','21 Pontiac Dr','Medford','NJ','UNITED STATES','08055-8146','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 01:01:00',0,NULL,3,1,1,1,NULL,'mimosamom\r\\'),(2014,772813918012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','im_top','project.top@gmail.com','Mr. Tridti Taechavorawongsa','67/45 Soi 35 Latphrao Rd.<br>Jankasem','Jatujak','Bangkok','THAILAND','10900','(668)1567-6470','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 01:03:41',0,NULL,3,1,2,1,NULL,'im_top\\'),(2015,695665576011,320631786282,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',15.5,'eastar4','soulful_scentsations','kylegibbons@hotmail.com','Kyle Gibbons','24 GORDON DR.','WOODBRIDGE','ON','CANADA','L4L 1R5','(647) 393-8380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 01:45:37',0,NULL,3,1,2,1,NULL,'soulful_scentsations\\'),(2016,695681556011,320520042459,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'WLHP002',18.99,'eastar4','nslax5','nslax5@yahoo.com','Khristopher Tolbert','7101 Runnymede Trl','Fredericksburg','VA','UNITED STATES','22407-7486','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 02:50:07',0,NULL,3,1,1,1,NULL,'nslax5\r\\'),(2017,772849388012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','resendewilson','wresende@rocketmail.com','wilson resende','Rua Silveira Martins 164<br>apto. 103','Rio de Janeiro','RJ','BRAZIL','22221000','+55-21-9281-0592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 03:11:40',0,NULL,3,1,3,1,NULL,'resendewilson\r\rOTCR001\r\rRA117728935CN'),(2018,520740281003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','medikosakosala','dkctennakoon@gmail.com','Kosala Tennkoon','NO95, Katupilamukalana,Kirimetiyana/west,Lunuwl','Lunuwila','','SRI LANKA','PX  61150','+940718068794','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 03:40:58',0,NULL,3,1,3,1,NULL,'medikosakosala\rHSNO008\rRA117729388CN'),(2019,772856297012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','beaztyb','beaztybee@aol.com','JACOB DESJARDINS','4143 BAIN PKWY','BLASDELL','NY','UNITED STATES','14219','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 03:42:08',0,NULL,3,1,1,1,NULL,'beaztyb\r一共买了两个\r\\'),(2020,772828408012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','t3chnoeagle','akreagle@gmail.com','Austin Russell','1979 Port Trinity Cir','Newport Beach','CA','UNITED STATES','92660-7125','(949) 759-0742','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 04:59:06',0,NULL,3,1,1,1,NULL,'t3chnoeagle\\'),(2021,695713324011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','hernitam','henryt@gazillo.com','Henry Tam','19/11 Rose Street','Chippendale','New South Wales','AUSTRALIA','2008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 05:41:30',0,NULL,3,1,2,1,NULL,'hernitam\\'),(2022,0,230609028207,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','mayfly39','mayfly39@yahoo.co.kr','Woonghan Kim','264-437 SAMICK TOWN22 EMUN2DONG DONGDAEMUN','SEOUL','','KOREA,REPUBLIC OF','130-082','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-15 05:45:54',0,NULL,3,1,2,1,NULL,'mayfly39\\'),(2023,572364780013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','seichkin','t256ao@mail.ru','Eliseev Sergey','Bataiskiy proezd 13-240','Moscow','Moscow','RUSSIAN FEDERATION','109651','(499)3560586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 05:47:54',0,NULL,3,1,3,1,NULL,'seichkin\rOTRA002\rRA117728970CN\r'),(2024,695718708011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',3,'UDAP001',113.97,'eastar4','creaty4','danny444@hanmail.net','Yeonsu Lee','805 Leavenworth St<br>Apt 910','San Francisco','CA','UNITED STATES','94109-6128','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 06:12:02',0,NULL,3,1,1,1,NULL,'creaty4\\'),(2025,520759601003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','fausto1230_4','giacrafax@libero.it','Fausto Rafanelli','Via Elsa Morante, 27','Agliana','PT','ITALY','51031','0574-751251','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-15 06:22:56',0,NULL,3,1,3,1,NULL,'fausto1230_4\rOTJE001  申报10美金\rRA117728997CN\r'),(2026,695745345011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',4,'ANCN001',19.6,'eastar4','magnus.magus','magus@magus.org.ua','Oleksandr Chykysh','Grabyanki 5/31','Lviv','Lviv','UKRAINE','79053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 08:52:48',0,NULL,3,1,2,1,NULL,'magnus.magus\\\r'),(2027,772926060012,220763389232,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',22.5,'eastar4uk','magnusafzelius','magnus.afzelius@gmail.com','Magnus Afzelius','Utflyktsvägen 27','Bromma','','SWEDEN','16841','08-6183022','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 09:35:52',0,NULL,3,1,3,1,NULL,'magnusafzelius\rWWSI005+ANCN001\rRA022493072CN'),(2028,520786520003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','d94pam','peraxel@gmail.com','Per-Axel Mansson','Rolsberga 127','Löberöd','','SWEDEN','24033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:45:51',0,NULL,3,1,3,1,NULL,'d94pam\rMOSA002\rRA117728820CN\r\\'),(2029,572307199013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','fabricefuhrer','fabricefuhrer@hotmail.com','Fabrice Alain Fuhrer','Rua Rio Grande n°50 apto 71<br>Vila Mariana','São Paulo','SP','BRAZIL','04018-000','(011) 8482-2299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 10:02:56',0,NULL,3,1,2,1,NULL,'fabricefuhrer\r\\'),(2030,572409042013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','pudovkinsex','mpud@mail.ru','Maxim Pudovkin','Sibirskay 11A, 15<br>Sibirskay 11a, 15','Surgut','Tuymen region','RUSSIAN FEDERATION','628403','+79222536707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 10:50:24',0,NULL,3,1,3,1,NULL,'pudovkinsex\rMOSA002\rRA117728776CN\r\\'),(2031,695769939011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',2,'UDAP001',75.98,'eastar4','shaaka777','kennethuga@gmail.com','Kenneth Shaaka','Plot 2 Nasser Lane<br>P.O. Box 11743','Kampala','Kampala','UGANDA','11743','+256793111777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 10:53:10',0,NULL,3,1,3,1,NULL,'shaaka777\rUDAP001\rRA022493537CN'),(2032,695780371011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.8,'eastar4','jimakoc88','dtrakas88@hotmail.com','Dimitrios Trakas','Skoufa 71','Volos','','GREECE','38334','6945488658','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 11:17:25',0,NULL,3,1,2,1,NULL,'jimakoc88\rHP 8pin 1.25 25cm '),(2033,772960780012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',50.3,'eastar4','andyvolp','andyvolp@hotmail.com','Andy Volp','P O Box 19292<br>Courtenay Place, Te Aro','Wellington','Wellington','NEW ZEALAND','6149','0212547912','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 11:40:26',0,NULL,8,1,17,0,NULL,'andyvolp'),(2034,695788383011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','andyvolp','andyvolp@hotmail.com','Andy Volp','P O Box 19292<br>Courtenay Place, Te Aro','Wellington','Wellington','NEW ZEALAND','6149','0212547912','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 11:46:39',0,NULL,3,0,3,1,NULL,'andyvolp\r再发一个New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer\rWLIN012+ANTY001*3\r\rRA022493660CN\r\\'),(2035,695792946011,320570842137,'NIB new PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL003',17.5,'eastar4','pb8champ','pb8champ@twcny.rr.com','Hider El-Hage II','PO Box 622','Fulton','NY','UNITED STATES','13069','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 12:02:32',0,NULL,3,1,1,1,NULL,'pb8champ\r、'),(2036,526569310004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','natavor','natavor@mail.ru','Nataly Voronova','Molodogvardeiskaya str. 8-29','Moscow','','RUSSIAN FEDERATION','121467','(925)822-7850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 12:49:16',0,NULL,3,1,3,1,NULL,'natavor\rWLAT008\rRA117728762CN\r\r\\'),(2037,572454720013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','sirsalomon','wolfgang.westermann@yahoo.ca','Wolfgang Westermann','Markt 3','Recke','','GERMANY','49509','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 14:21:22',0,NULL,3,1,2,1,NULL,'sirsalomon\r\\'),(2038,692924329011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','koytroy','ergatikeskoytroy@hotmail.com','koutrouvelis vasilis','agiou Ioannou 4A','PAFOS','CYPRUS','CYPRUS','8021','0035796661780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 14:28:13',0,NULL,8,0,17,0,NULL,'koytroy'),(2039,695838964011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','koytroy','ergatikeskoytroy@hotmail.com','koutrouvelis vasilis','agiou Ioannou 4A','PAFOS','CYPRUS','CYPRUS','8021','0035796661780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 14:31:11',0,NULL,3,1,3,1,NULL,'koytroy\rHSNO004\r一共买了两个\rRA022493109CN'),(2040,695849013011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','weeelman2010','nyborg_93@hotmail.com','Jonathan Nyborg','Vedvik','Raudeberg','Sogn og Fjordane','NORWAY','6710','97097937','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 15:00:38',0,NULL,3,1,2,1,NULL,'weeelman2010\r\\'),(2041,569695381013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','mikhail_medvedev','ebay.com@tmp.medvedev.com.ru','Mikhail Medvedev','KYIV-80 abonentska skrynka 73<br>KYIV-80 a/c 73','KIEV','KYIV','UKRAINE','04080','+380636066062','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 15:00:48',0,NULL,3,1,2,1,NULL,'mikhail_medvedev\r\\'),(2042,520856796003,130490976171,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',15.99,'cnfaner','mootoo-eb','piyachaic@gmail.com','Piyachai Chu-Ame','Bangkok Mass Transit System PCL.<br>BTS Bldg. 1000. Phaholyothin Rd.','Chatuchak, Bangkok','Thailand','THAILAND','10900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 15:33:36',0,NULL,3,1,3,1,NULL,'mootoo-eb\rWLAT001\rRA117728855CN\r\\'),(2043,772990002012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','mr.locksmith2007','mr.locksmith@yahoo.com','michael nelson','PO Box 264<br>3 Bullis Way','nassau','NY','UNITED STATES','12123','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 15:35:50',0,NULL,3,1,1,1,NULL,'mr.locksmith2007\r 一共买了三个\r\\'),(2044,695870814011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mred_cali','dedmister@hotmail.com','William Edmister','107 Sycamore Ave','Mill Valley','CA','UNITED STATES','94941-2807','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 16:04:48',0,NULL,5,0,18,0,NULL,'mred_cali\rpaypal 已经退款'),(2045,772858238012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','sun-light108','lequanghai@gmx.de','Giamy Le (Tou Chia Mei)','167 / F7 Dayou Rd','Taoyuan','','TAIWAN','330','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 16:31:41',0,NULL,3,1,2,1,NULL,'sun-light108\r\\'),(2046,695889044011,320679617626,'New Genuine Sony Ericsson HBH-608 Bluetooth headset',1,'HSSE007',19.9,'eastar4uk','andrewg105','andyg105@hotmail.co.uk','Andrew George','105 Trent Road<br>Shaw','Oldham','Lancashire','UNITED KINGDOM','OL2 7QH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-15 16:50:26',0,NULL,3,1,3,1,NULL,'andrewg105\rHSSE007\r英标  \rRA117739093CN\r\\'),(2047,695893860011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ravusaedes','aegely@telusplanet.net','Aaron Egely','2008E 920 9th Ave SW','Calgary','AB','CANADA','T2P 2T9','(403) 284-5503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 17:02:36',0,NULL,3,1,2,1,NULL,'ravusaedes\\'),(2048,695521902011,320679564112,'New Ultimate Ears MetroFi 170vi  Earphones with Voice',1,'HSUE001',13.5,'eastar4uk','mtnmon','melt99@comcast.net','Mel Cooper','14130 Montauk Ln','Fort Myers','FL','UNITED STATES','33919','(239) 466-9463','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 17:03:54',0,NULL,3,1,1,1,NULL,'mtnmon\r\\'),(2049,695898448011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','zlayde','rich@basement.org','Richard Ziade','747 3rd Ave<br>Fl 30','new york','NY','UNITED STATES','10017-2830','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 17:14:15',0,NULL,3,1,1,1,NULL,'zlayde\r\\'),(2050,572514429013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','stefpineault','stef.pineault@gmail.com','stef pineault','541 Legrand','chicoutimi','QC','CANADA','g7j3l9','(418) 817-8244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 17:53:39',0,NULL,3,1,2,1,NULL,'stefpineault\r\\'),(2051,773104525012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','bolocz','bola_orisajinmi@yahoo.co.uk','akinbola orisajinmi','6 hawkins drive','grays','Essex','UNITED KINGDOM','rm16 6gg','01375481007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 17:53:46',0,NULL,3,1,2,1,NULL,'bolocz\r\\'),(2052,773104613012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','ann.geo.bg','ann.geo@abv.bg','Aneliya Gergieva','Kitka 7b','Razgrad','Razgrad','BULGARIA','7200','00359888917196','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 17:56:30',0,NULL,3,0,2,1,NULL,'ann.geo.bg\r欧标\r\\'),(2053,526668512004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.9,'cnfaner','ivstrom','ivastrom@broadpark.no','Ivar Stroem','Tokerudberget 35','Oslo','','NORWAY','0986','+4790677752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 19:13:59',0,NULL,3,1,3,1,NULL,'ivstrom\rMOSA001\rRA022493090CN\r'),(2054,695958806011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','jofryday','davidfry7@hotmail.co.uk','David Fry','93 Hillside Avenue<br>Midsomer Norton','Radstock','Somerset','UNITED KINGDOM','BA3 2LU','01761412532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 19:25:25',0,NULL,3,1,2,1,NULL,'jofryday\r\\'),(2055,695961882011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','jmiller62','jmiller55@carolina.rr.com','Jeff Miller','804 Broad St.','Shelby','NC','UNITED STATES','28152','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 19:32:02',0,NULL,3,1,1,1,NULL,'jmiller62\racer 8pin1.00 8cm\r\\'),(2056,572550305013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','mark.barzak1989','mark.barzak@gmail.com','mark barzak','Vaitzman 22','Yahud','','ISRAEL','56238','+972544931355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 19:38:41',0,NULL,3,1,2,1,NULL,'mark.barzak1989\r\\'),(2057,773165119012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','felixmxr','felixpaulmeixner@gmail.com','Felix Meixner','Brockmanngasse 114<br>1. stock tür 4','Graz','','AUSTRIA','8010','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 19:50:44',0,NULL,3,1,2,1,NULL,'felixmxr\r\\'),(2058,526698256004,140516160152,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',129,'cnfaner','angelucien','distar@wanadoo.fr','Xavier THOMAS','Route de Sofaia','SAINTE-ROSE','','GUADELOUPE','97115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 20:54:55',0,NULL,3,1,3,1,NULL,'angelucien\rRCMA001\rRA022493642CN'),(2059,695999355011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','northbaytow','mikegeiskopf@hotmail.com','milton bell','799 orange dr<br>suie 301','vacaville','CA','UNITED STATES','95687-3103','(707) 301-2378','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 21:01:52',0,NULL,3,1,1,1,NULL,'northbaytow  换成半高5300卡+antenna\r\\'),(2060,520953170003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','scouttrooper2010','ctprva2007@gmail.com','ben fernandez','6 1st st','east windsor','CT','UNITED STATES','06088-9728','(860) 623-0789','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 21:09:47',0,NULL,3,1,1,1,NULL,'scouttrooper2010\r\\'),(2061,526706139004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','creaktion','ebay@creamedial.de','Norbert Bluhm','C.-Hainmüller-Str. 6','Waren (Müritz)','','GERMANY','17192','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 21:26:26',0,NULL,3,1,3,1,NULL,'creaktion\rWWSI005\rRA022493585CN'),(2062,696013939011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','nickd_101','nickg.drew@googlemail.com','Nick Drew','48 Sandhills Crescent','Solihull','West Midlands','UNITED KINGDOM','B91 3UE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 21:39:31',0,NULL,3,1,2,1,NULL,'nickd_101\r\\'),(2063,572590838013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','stereoshopthe','stereo@minot.com','Terry R Kongelf','304 Burdick Expy W','Minot','ND','UNITED STATES','58701-4323','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 21:54:50',0,NULL,3,1,1,1,NULL,'stereoshopthe\r\\'),(2064,696019425011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','rch-phkr','dclair@cwhloans.com','David Clair','5318 Moonlight Way','Parker','CO','UNITED STATES','80134-4535','(407) 448-8484','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 21:56:45',0,NULL,3,1,1,1,NULL,'rch-phkr\r\\'),(2065,572597789013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',2,'OMHJ001',27.98,'eastar4','barahonaju','juanbarahona@gmail.com','Juan Barahona','Fernandez Concha 105','Santiago','Nunoa','CHILE','7750048 ','56-2-7171660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 22:24:30',0,NULL,3,1,2,1,NULL,'barahonaju\r'),(2066,520977653003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','alleksssa','alleks.ssa@gmail.com','Aleksandr Tarachev','Aerodromnaya 125 kv 52','Samara','Samarskaja oblast\'','RUSSIAN FEDERATION','443117','(917) 164-2692','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 22:59:59',0,NULL,3,1,3,1,NULL,'alleksssa\rRELO002\rRA022493024CN\r'),(2067,572629121013,230393146792,'2.1 Acer Aspire 6930 6530 6930G Bluetooth Module+cable',1,'BTAC2113',12.8,'eastar4','sirvic_42','sirvic_42@hotmail.com','Trevor Thompson','16626 6th Ave W<br>Apt B304','Lynnwood','WA','UNITED STATES','98037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 01:11:53',0,NULL,3,1,1,1,NULL,'sirvic_42\racer 5pin1.25 6cm\r\\'),(2068,572626528013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',3,'HSNO022',44.7,'eastar4','denisdeoliveira','denis.oliveira.salvador@hotmail.com','Denis Oliveira','Rua Caieiras, 124<br>Vila São Paulo','Jundiaí','São Paulo','BRAZIL','13203513','+551196556969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 01:21:31',0,NULL,3,1,3,1,NULL,'denisdeoliveira\rHSNO022\rRA022493470CN\r'),(2069,773294412012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',12.5,'eastar4','round2tires','mariano2go@gmail.com','KEVIN MARIANO','3015 Trolley Bridge Cir','QUAKERTOWN','PA','UNITED STATES','18951-1800','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 02:36:34',0,NULL,3,1,1,1,NULL,'round2tires\racer 8pin1.00 15cm\r\\'),(2070,773298817012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','megamulpha','terrencewalters@consultant.com','Terrence Walters','1219-18Ave NW','Calgary','AB','CANADA','T2M 0W3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 03:03:23',0,NULL,3,1,3,1,NULL,'megamulpha\rOTSO002\rRA022493421CN\r'),(2071,572650466013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','cooljayjie','cool_jay@live.cn','Jie Li','82 Washington ST','Long Branch','NJ','UNITED STATES','07740-5941','(732) 216-7540','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 03:20:16',0,NULL,3,1,1,1,NULL,'cooljayjie\r\\'),(2072,772630844012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','pauleo1214','pauleliasson@gmail.com','Paul Eliasson','3925 Beech Ave<br>APT 213','Baltimore','MD','UNITED STATES','21211-2254','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 03:51:56',0,NULL,3,1,1,1,NULL,'pauleo1214\r\\'),(2073,572655666013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','dobbin-1247','eugene.peoples@yahoo.com','eugene peoples','7415 Sandpiper Dr','houston','TX','UNITED STATES','77074-4807','(713) 774-1247','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 03:57:07',0,NULL,3,1,1,1,NULL,'dobbin-1247\r\\'),(2074,572693626013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','sisiniacom1','serokull5@hotmail.com','Marcelino Parrado Lera','C/Jazmin n4 2F','Trobajo del Camino (LEON)','Castilla y León','SPAIN','24010','606730935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 08:29:01',0,NULL,3,1,2,1,NULL,'sisiniacom1\r欧标\r\\'),(2075,696158096011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','thebigmacs','hufriedy@gmail.com','Derek McConnell','1120 N. 14th Street<br>RD Apartment','Lincoln','NE','UNITED STATES','68508','(402) 432-5457','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-16 08:40:09',0,NULL,3,1,1,1,NULL,'thebigmacs\r\\'),(2076,572698726013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','marios_p','mariospast@yahoo.com','Marios Pastellas','5, Agias Irinis str, Aglantzia','Nicosia','CY','CYPRUS','2102','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 08:58:27',0,NULL,3,1,2,1,NULL,'marios_p\\'),(2077,696194465011,320441946859,'2.1 HP TX2500 TX2500z TX2z Bluetooth Module EDR+cable',10,'BTHP2112',128,'eastar4','batman44410','bruce6777@aol.com','Bruce L Wayne','6777 State Route 46','Cortland','OH','UNITED STATES','44410-9668','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 11:02:38',0,NULL,3,1,1,1,NULL,'batman44410\rHP 8pin 0.8 3cm\r\\'),(2078,773449830012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','mgoularts','mgoularts@yahoo.com.br','Marcelo Goulart da Silva','Alameda Campista, 215.<br>Arsenal','São Gonçalo','Rio de Janeiro','BRAZIL','24751-520','+552192921321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 13:04:37',0,NULL,3,1,2,1,NULL,'mgoularts\r\\'),(2079,572739797013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','vicky20jak','vicky20jak@gmail.com','VIVEK GUPTA','SUNRAYS<br>KACHI GHATI, PO TARADEVI','SHIMLA','Himachal Pradesh','INDIA','171001','9418044690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 13:06:53',0,NULL,3,1,2,1,NULL,'vicky20jak\r\\'),(2080,572751684013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','luckybbts','bennitz@juno.com','Bob Bennitz','23 Flaherty Dr','Guelph','ON','CANADA','N1H8K3','(519) 763-0036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 13:25:00',0,NULL,3,1,2,1,NULL,'luckybbts\\'),(2081,773466479012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',2,'BALO005',14.2,'eastar4','saab914','saab914@aol.com','Peter J Ortiz','6928 Fox Haven Pl','Raleigh','NC','UNITED STATES','27616','(919) 647-4016','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 13:48:28',0,NULL,3,1,1,1,NULL,'saab914\\'),(2082,526868692004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','2010taz368','tazgrondin@videotron.ca','bruno grondin','774 frechette','granby','QC','CANADA','j2h2m2','(450) 777-6632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:10:09',0,NULL,3,1,3,1,NULL,'2010taz368\rOMHJ001\rRA022493483CN\r'),(2083,696259403011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','snastos','steve.nastos@gmail.com','Steve Nastos','138 Melrose Ave','Toronto','ON','CANADA','M5M 1Y7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:29:48',0,NULL,3,1,2,1,NULL,'snastos\r\\'),(2084,773487089012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',3,'OTCN004*10',50.37,'eastar4','ba_ronen','ba_ronen@hotmail.com','Ronen Ben-Aaron','1881 Steeles Ave. West Suit #337','Toronto','ON','CANADA','M3H 0A1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:40:57',0,NULL,3,1,3,1,NULL,'ba_ronen\rOTCN004*10\rRA022493523CN'),(2085,572771405013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.8,'eastar4','tundrwd1257','tim@underwoodfamily.org','Tim Underwood','5114 SW 96th St','Augusta','KS','UNITED STATES','67010-7746','(316) 778-0405','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 14:44:34',0,NULL,3,1,1,1,NULL,'tundrwd1257\r\\'),(2086,696270536011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','rebear01','rebear@comcast.net','karen wright','534 east grand blvd','ypsilanti','MI','UNITED STATES','48198','(734) 660-9304','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 14:58:47',0,NULL,3,1,1,1,NULL,'rebear01\r\\'),(2087,0,230609824619,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','redalf20','surfplus920@yahoo.com','ALFREDO S. ISABEL','909 N Frederic St','Burbank','CA','UNITED STATES','91505-2620','(818) 726-0911','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 15:11:01',0,NULL,3,1,1,1,NULL,'redalf20\r\\'),(2088,0,230609824618,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','tbwilsongolf4u','tbwilson@wildblue.net','Bev Wilson','1868 Highway W','Bonnots Mill','MO','UNITED STATES','65016-2408','(573) 897-2606','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-16 16:06:07',0,NULL,3,1,1,1,NULL,'tbwilsongolf4u\r\\'),(2089,696302829011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','jobie4020','joannhunter@fuse.net','Joann Hunter','4020 Haverstraw Dr','Cincinnati','OH','UNITED STATES','45241','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 16:20:16',0,NULL,3,1,1,1,NULL,'jobie4020\r\\'),(2090,773304067012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','csy922','wilson121869@yahoo.com','Wilson Lee','70 Irenemount Crescent','Markham','ON','CANADA','L3S3C4','(416) 618-2093','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 16:38:18',0,NULL,3,1,2,1,NULL,'csy922\r\\'),(2091,696313171011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','astefane','anthony.stefanelli@rogers.com','Anthony Stefanelli','1 Good\'s Lane','Brantford','ON','CANADA','n3v1c7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 16:41:37',0,NULL,3,1,2,1,NULL,'astefane\\'),(2092,572809683013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','th_psarrakos','thpsarrakos@hotmail.com','Thanos Psarrakos','Koridallou st 19','Pireaus','','GREECE','18540','0030210 4110101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 16:50:26',0,NULL,3,1,2,1,NULL,'th_psarrakos\\'),(2093,526915290004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',2,'HSPL011',46,'cnfaner','ilusha101','ilusha23@gmail.com','Eli Berezovsky','Ashuach 6/38','Nazareth Illit','ME','ISRAEL','17094','972547801410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 17:05:17',0,NULL,3,1,3,1,NULL,'ilusha101\rHSPL011\rRA022493069CN\r'),(2094,695598302011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','rfriskes','robfriskes@hotmail.com','rob friskes','grote beerstraat 78','hengelo','','NETHERLANDS','7557 wl','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 17:34:31',0,NULL,3,1,2,1,NULL,'rfriskes\\'),(2095,526930915004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','helidaniel','danielowen@sympatico.ca','daniel owen','71 Roxborough St. West','Toronto','ON','CANADA','M5R1T9','(416) 961-4300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 17:49:38',0,NULL,3,1,3,1,NULL,'helidaniel\rOMHJ001\rRA022493130CN\r'),(2096,521189032003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','vkp','steven@microsystem.hu','Istvan Gyula Viragos Kis','Lencses 5/a','Nagykoros','Pest','HUNGARY','2750','36203696550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 17:51:09',0,NULL,3,1,3,1,NULL,'vkp\rWWSI002+ANCN001\r潘\r'),(2097,572831768013,230608888246,'Brand new LOGITECH VX NANO USB RECEIVER VX V450 V550',1,'RELO003',16.9,'eastar4','kaeigor_nn','kaeigor@ya.ru','IGOR KRAEV','Appartment 91, 29 6-microrayon Street','Nizhniy Novgorod','RU','RUSSIAN FEDERATION','603147','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 18:17:22',0,NULL,3,1,2,1,NULL,'kaeigor_nn\r新优联'),(2098,521193599003,130498755181,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.99,'cnfaner','autaylor73','autaylor@gmail.com','Austin Taylor','10755 Norchester Village Dr.','Houston','TX','UNITED STATES','77070','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-16 18:17:46',0,NULL,3,1,1,1,NULL,'autaylor73\\'),(2099,521198596003,130508877560,'100% Lowepro Mini Trekker AW Photo Camera Bag Backpacks',1,'',64,'cnfaner','jimnatsam','atcah@aol.com','James C Moore','PO Box 1586','Kingston','WA','UNITED STATES','98346-1586','','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-04-16 18:21:21',0,NULL,3,0,3,1,NULL,'jimnatsam\rRA022493157CN'),(2100,696369347011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','federicoengland','fede@englandoptical.com.ar','england Federico','Barrio los Troncos S/N<br>Casilla de correo N° 46','Saladillo','Buenos Aires','ARGENTINA','7260','02344-454832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 18:35:07',0,NULL,3,1,2,1,NULL,'federicoengland\r\\'),(2101,0,220770230159,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',8.99,'eastar4','2289xd','ms_luckyman@hotmail.com','Weimin Chen','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 18:50:16',0,NULL,3,1,1,1,NULL,'2289xd\r\\'),(2102,773618927012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','999.michael','999.michael@gmail.com','Mike Darling','Churchill College','Cambridge','Cambridgeshire','UNITED KINGDOM','CB3 0DS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 19:07:27',0,NULL,3,1,2,1,NULL,'999.michael'),(2103,773623488012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','tonyandshirleyp','tonyandshirleyp@hotmail.co.uk','anthony pepper','marts marsh<br>bulkington road shilton','coventry','West Midlands','UNITED KINGDOM','cv7 9jt','02476610900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 19:13:57',0,NULL,3,1,3,1,NULL,'tonyandshirleyp\rWLDL001\rRA022493126CN'),(2104,696387748011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',3,'WLAP001',44.43,'eastar4','jamesb2077','jboland@netpenny.net','James Boland','2884 134th Ave','Hopkins','MI','UNITED STATES','49328-9748','(616) 893-7316','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 19:18:29',0,NULL,3,1,1,1,NULL,'jamesb2077\r\\'),(2105,773655466012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',12.5,'eastar4','igormeshkoff','diamond__69@mail.ru','Igor Meshkov','Zorge 43a/16','Novoshahtinsk','Rostov-on-Don','RUSSIAN FEDERATION','346900','+7(928)7799161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 20:18:22',0,NULL,3,1,2,1,NULL,'igormeshkoff\racer 5pin1.25 6cm \r\\'),(2106,572891493013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','nuclearfloyd','nuclearfloyd@gmx.de','Florian Manteuffel','Feldkirchener Straße 14b','Ingolstadt','','GERMANY','85055','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 20:41:08',0,NULL,3,1,2,1,NULL,'nuclearfloyd\r\\'),(2107,773685009012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','anthonygroves1623','anthonygroves16@yahoo.com','Danny Cano','12240 Sago Ave','Jacksonville','FL','UNITED STATES','32218-2653','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 21:19:43',0,NULL,3,1,1,1,NULL,'anthonygroves1623\r\\'),(2108,521258959003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','crazystargrl','movetheneedlecreations@yahoo.com','Anna Leehey','819 N Euclid Ave','Oak Park','IL','UNITED STATES','60302-1520','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-16 21:34:50',0,NULL,3,1,1,1,NULL,'crazystargrl\r\\'),(2109,773695870012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','cougarjft08','jeanf3008@hotmail.com','Jean Theriault','4465 de bellechasse app-410','montreal','QC','CANADA','H1T3R8','(514) 729-7334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 21:47:38',0,NULL,3,1,2,1,NULL,'cougarjft08\r\\'),(2110,773696168012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','omicronpie','bremer.family1@btinternet.com','Grant Bremer','The Chase<br>Badger\'s Ridge','Newbury','Berkshire','UNITED KINGDOM','RG20 0LQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 21:49:03',0,NULL,3,1,3,1,NULL,'omicronpie\r英标\rHSSE005\rRA022493316CN\r'),(2111,696458729011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','rumiware','rumiware@gmail.com','Rui Esteves','Rua José Carlos Ary dos Santos nº 45, Bairro Flor do Minho','Caneças','Caneças','PORTUGAL','1685-441','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 21:58:17',0,NULL,3,1,2,1,NULL,'rumiware\\\r'),(2112,696474988011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','321tocsin','post@tocsin.de','Manfred Bock','Frankenstr. 20','Remshalden','','GERMANY','73630','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 22:50:35',0,NULL,3,1,3,1,NULL,'321tocsin\rADAK002+CACN001+CACN003\r再发一个IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy\rRA022493608CN'),(2113,773726782012,220769088294,'NIB Visenta I0 wireless mouse w/ nano USB receiver',1,'MOVI001',21.99,'eastar4','kiboys','zechang_li@hotmail.com','Zechang Li','5905 DIAL WAY','San Jose','CA','UNITED STATES','95129-4710','(408) 391-7666','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 23:19:49',0,NULL,3,1,1,1,NULL,'kiboys\r白色绿底边\r、'),(2114,527027283004,140429368087,'2.1 HP Pavilion DV6400 DV6500 bluetooth module track#',1,'BTHP2110',13.99,'cnfaner','1940rob','cmf@powerup.com.au','Phillip Holst','47 Station Road','Loganlea','Queensland','AUSTRALIA','4131','0738056156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 23:44:52',0,NULL,3,1,3,1,NULL,'1940rob\rBTHP2110\rHP 8pin 1.25 18cm \rRA022493112CN'),(2115,773740236012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','jrenterprise1','jrenterprise1@netzero.net','jack wood jr','50151 Mile End Dr','Shelby Township','MI','UNITED STATES','48317-1148','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 00:07:13',0,NULL,3,1,1,1,NULL,'jrenterprise1\r\\'),(2116,773742389012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.8,'eastar4','ptd0sss','simon_suen@hotmail.com','Simon Suen','7 Rebecca Rd','Newton','MA','UNITED STATES','02465','(617) 332-9545','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 00:13:09',0,NULL,3,1,1,1,NULL,'ptd0sss\rAcer 5pin1.25 3cm \r\\'),(2117,773749179012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','jarm113','kmather@att.net','kim mather','139 bailey woods rd','brooklyn','CT','UNITED STATES','06234-2407','(860) 779-8643','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 00:39:22',0,NULL,3,1,1,1,NULL,'jarm113\r\\'),(2118,572948959013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','bakerbarry143','brry143@aol.com','Barry Lamb','1350 Bonnie Cove Ave','Glendora','CA','UNITED STATES','91740','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 00:46:36',0,NULL,3,1,1,1,NULL,'bakerbarry143\r\\'),(2119,773757678012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','mike_mckenzy','mikemckenzy@gmail.com','Mike McKenzy','3538 E. Kerry Ln.','Phoenix','AZ','UNITED STATES','85050','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 01:09:07',0,NULL,3,1,1,1,NULL,'mike_mckenzy\r\\'),(2120,696515802011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','vinc07011986','vinc07011986@yahoo.fr','Gandoulas Vincent','32 rue bernard ortet','Toulouse','Midi-Pyrénées','FRANCE','31500','0659456073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 01:28:10',0,NULL,3,1,2,1,NULL,'vinc07011986\\'),(2121,572981611013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',2,'RCLO003',277.98,'eastar4','markviolette','mark@d-bug.org','Mark Violette','1565 Verchere St.','Orleans','ON','CANADA','k1c6b8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 03:59:33',0,NULL,3,1,3,1,NULL,'markviolette\rRCLO003\rRA022493174CN\r、'),(2122,773808301012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','reza4200','r_khademy@hotmail.com','reza khademy','668 Rue De Gaspe App.101 code 156','Montreal','QC','CANADA','H3E1H9','(514) 944-8712','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 04:44:12',0,NULL,3,1,2,1,NULL,'reza4200\r\\'),(2123,696559819011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tazsoft','fmatte@gmail.com','Frédéric Matte','585 Charest Est, suite 900','Québec','QC','CANADA','G1K3J2','(418) 529-9697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 04:59:07',0,NULL,3,1,2,1,NULL,'tazsoft\r\\'),(2124,696561718011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','bogiemon','djgoding@gmail.com','David J. Goding','23 Cherrywood Dr','Palos Park','IL','UNITED STATES','60464-1576','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 05:08:15',0,NULL,3,1,1,1,NULL,'bogiemon\r\\'),(2125,773817578012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','abuamuslim','yusufaina@yahoo.com','Yusuf Aina','Yanbu Industrial College, P. O. Box 30436,','Yanbu','','SAUDI ARABIA','21477','+966508266121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 05:40:06',0,NULL,3,1,2,1,NULL,'abuamuslim\r\\'),(2126,773848929012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','07oscar07','jpoppy@tpg.com.au','Joseph Poppelock','30 BISDEE STREET','CORAL COVE','Queensland','AUSTRALIA','4670','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 07:45:54',0,NULL,3,1,3,1,NULL,'07oscar07\rOTGR001+OTGR002\rRA022493038CN\r'),(2127,527103634004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','abdfarae2009','abdfarae@hotmail.com','abdulla salih mohd','al-madra<br>gsm 92955775','Samail','oman','OMAN','219/620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 07:50:26',0,NULL,3,1,3,1,NULL,'abdfarae2009\rWWSI005\rRA022493055CN'),(2128,773860345012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','jurica1976','jurica.stojkovic1@zg.t-com.hr','Jurica Stojkovic','Skolska 6','Novoselec','','CROATIA','10315','0912385194','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:22:21',0,NULL,3,1,2,1,NULL,'jurica1976\r欧标\r\\'),(2129,696602670011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','yech1927','ykurtz@hotmail.com','Yechiel Kurtz','13 Givat Downes St.','Haifa','','ISRAEL','34345','(972) 544-3088 ext.: 86','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:32:48',0,NULL,3,1,2,1,NULL,'yech1927'),(2130,573036941013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','nadezhda1960','nadezhda1900@gmail.com','Ilja Kozevnikov','Urban str.101 (Vorderhs Etage 2)','Berlin','','GERMANY','10967','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 09:22:57',0,NULL,3,1,2,1,NULL,'nadezhda1960\rIlja Kozevnikov\rUrban str.101 (Vorderhs Etage 2)\r10967 Berlin\rDeutschland\rmob.tel. +49 17694636480\r\\\r\r\r'),(2131,773893428012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','uwe_guth','uwe.guth@t-online.de','Uwe Guth','MSC Vertriebs GmbH<br>Zeppelinstrasse 1a','Neufahrn','','GERMANY','85375','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 09:47:54',0,NULL,3,1,3,1,NULL,'uwe_guth\rHSSH002\rRA022493015CN\r'),(2132,773900482012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','kathschofield','kath.schofield@ntlworld.com','Kath Schofield','38 Westlea Crescent,Yeadon','Leeds','West Yorkshire','UNITED KINGDOM','LS197EE','01132192621','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 10:04:07',0,NULL,3,0,3,1,NULL,'kathschofield\rRA117728881CN\r\\'),(2133,696645066011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jasonadaniels','jason.daniels@hotmail.com','Jason Daniels','PO Box 7388','Southport Park','Queensland','AUSTRALIA','4215','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'jasonadaniels'),(2134,773912065012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','hyperbytesaustralia','hyperbytesaustralia@gmail.com','John Kostakis','12 Forrester Street','Kingsgrove','New South Wales','AUSTRALIA','2208','0293708401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 10:36:51',0,NULL,3,1,2,1,NULL,'hyperbytesaustralia\r\\'),(2135,773941514012,220704730539,'New in Box Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL004',15.5,'eastar4uk','suedave1066','davesue@chercott.com','MR D CAMBLE','UNIT 3<br>JEFFERSON WAY','THAME','Oxfordshire','UNITED KINGDOM','OX9 3SZ','01844217192','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 11:43:11',0,NULL,3,1,3,1,NULL,'suedave1066\rHSPL004  英标\rMR D CAMBLE\r5 brookside\rthame Oxon ox9 3de\rUnited Kingdom\r01844217192\rRA117728949CN'),(2136,696693870011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.8,'eastar4','atcnaked','fred.gotpub@gmail.com','Frédéric   Gautier','40, rue des Alouettes','Cournon','Auvergne','FRANCE','63800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 12:21:09',0,NULL,3,1,2,1,NULL,'atcnaked\rHP 8pin 1.25 18cm \r\\'),(2137,773965439012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',50.3,'eastar4','tauruz.abc','x-and@yandex.ru','Alexander Stepanov','Smel\'chak, 8, 71','Zheleznodorozhny','Moscow region','RUSSIAN FEDERATION','143982','79035764716','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 12:36:57',0,NULL,3,1,3,1,NULL,'tauruz.abc\rWLIN012\r\rRA117728229CN\r\\'),(2138,696711031011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','sold1976a11','soldatenkoass11@rambler.ru','ANDREI SALDATSENKA','rechitskoe shosse str. 63/1/35','gomel','','BELARUS','246012','80232431224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 13:03:31',0,NULL,3,1,2,1,NULL,'sold1976a11\r欧标\r\\'),(2139,696730108011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','fx-tools2009','alius.baranauskas@gmail.com','Alius Baranauskas','Mads Klokkersveg 6c','Fjerdingby','Akershus','NORWAY','2008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 13:49:46',0,NULL,3,1,2,1,NULL,'fx-tools2009'),(2140,573113227013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','rsacal-kurokuma','osamu_t@rc4.so-net.ne.jp','OSAMU TAKENOSHITA','2-15-1-402<br>ENGYO','FUJISAWA-SHI','Kanagawa','JAPAN','252-0805','(0466)47-6974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 13:50:09',0,NULL,3,1,3,1,NULL,'rsacal-kurokuma\rWWOT001+ANCN001\rRA117728952CN\r\\'),(2141,774006666012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','mr.locksmith2007','mr.locksmith@yahoo.com','michael nelson','PO Box 264<br>3 Bullis Way','nassau','NY','UNITED STATES','12123','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 14:06:00',0,NULL,8,0,17,0,NULL,'mr.locksmith2007'),(2142,573126821013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',37.98,'eastar4','tcone_de','f.emden@yahoo.de','Friedrich Emden','Voigtstr. 41','Berlin','','GERMANY','10247','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 14:30:32',0,NULL,3,1,3,1,NULL,'tcone_de\rWLAP008\rRA117728864CN'),(2143,696740377011,320679575380,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',12.95,'eastar4uk','5solas5','adaly@sierraresearch.com','Allan Daly','Ballygarraun South','Athenry','Galway','IRELAND','default','091875780','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 14:41:27',0,NULL,3,1,3,1,NULL,'5solas5\rWLAP001\rRA117728816CN\r\\'),(2144,521484945003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','edgaras9','baneviciuse@gmail.com','Edgaras Banevicius','Senoliu 6','Vilnius','Vilnius','LITHUANIA','LT-08400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 15:29:21',0,NULL,3,0,3,1,NULL,'edgaras9\rHSNO008\r欧标\rRA117728918CN\r\\\r'),(2145,774053241012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','kden2543','katherine.dennison@sadprt.org','Katherine Dennison','6832 Granero Dr','El Paso','TX','UNITED STATES','79912','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 15:32:02',0,NULL,3,1,1,1,NULL,'kden2543\r\\'),(2146,527251345004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','bwrftrt','rla5@dawgfans.net','Raymond Altman','4158 US Highway 17<br>Southern Biker Gear','Richmond Hill','GA','UNITED STATES','31324-3306','(912) 228-5252','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 16:27:50',0,NULL,3,1,1,1,NULL,'bwrftrt\r\\'),(2147,774085710012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','compasist','compasist@hotmail.com','Deniz TAHTALI','Istanbul Bilgi Iletisim Sistemleri Ticaret ve Sanayi A.S.<br>Istanbul Teknik Universitesi Teknokent Ari 1 Binasi No:6 Maslak','Istanbul','Turkey','TURKEY','34469','+905332696118','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 16:31:44',0,NULL,3,1,3,1,NULL,'compasist\rOTSO002\r\rRA117739102CN\r\\'),(2148,521516382003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','anyquilmes10','gerardoluisrivas@hotmail.com','gerardo luis rivas','timoteo gordillo 290','ciudad de buenos aires','buenos aires','ARGENTINA','1408','46413594','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-17 16:42:07',0,NULL,3,1,3,1,NULL,'anyquilmes10\rOTJE001\rRA117728847CN\r\\\r'),(2149,696854194011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','321tocsin','post@tocsin.de','Manfred Bock','Frankenstr. 20','Remshalden','','GERMANY','73630','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 17:20:26',0,NULL,8,1,17,0,NULL,'321tocsin'),(2150,774144119012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','**enigma**','pknaus@gmail.com','Paul Knaus','708B W Gibson St','Austin','TX','UNITED STATES','78704-2344','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 17:28:53',0,NULL,3,1,1,1,NULL,'**enigma**\r\\'),(2151,573217655013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',37.98,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 17:40:10',0,NULL,8,1,17,0,NULL,'small.mac'),(2152,573228695013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','trendanizer','mail2@sloboda.de','Elvira Lipp','Welterpfad 41','Berlin','','GERMANY','12277','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 17:54:24',0,NULL,3,1,2,1,NULL,'trendanizer\r\\'),(2153,573228470013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','denapalermo7','denapalermo@att.net','Dena Palermo','514 Ripple Creek Dr','Houston','TX','UNITED STATES','77024','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 17:56:10',0,NULL,3,1,1,1,NULL,'denapalermo7\r\\'),(2154,521563535003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','2004ohad','ohadshtr@tau.ac.il','Ohad Shtark','Shoshanat Hacarmel 62','Haifa','','ISRAEL','34322','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 18:00:47',0,NULL,3,1,3,1,NULL,'2004ohad\rOTGR001\rRA022493041CN'),(2155,774196704012,220458920723,'Acer Aspire 3810 3810T  Bluetooth Module 2.0+cable',1,'BTAC2017',12.5,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 18:16:03',0,NULL,3,1,3,1,NULL,'small.mac\racer 8pin1.0 3cm\r再发两个NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp\rBTAC2017+WLAP008\rRA022493599CN'),(2156,774265274012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',2,'BALO008',13.2,'eastar4','ra92253','ralvarez92201@hotmail.com','Raul Alvarez','52535 Avenida Navarro','La Quinta','CA','UNITED STATES','92253-3395','(760) 412-9534','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 19:20:48',0,NULL,3,1,1,1,NULL,'ra92253\\'),(2157,696979213011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','rcritter235','rcritter235@yahoo.com',' regina crittendon','235 Box Rd','darden','TN','UNITED STATES','38328-2810','(731) 845-9862','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 19:28:35',0,NULL,3,1,1,1,NULL,'rcritter235\r\\'),(2158,774282106012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','andrew.svenson','andrewpsvenson@gmail.com','Andrew Svenson','366 Island Green Ln','Inman','SC','UNITED STATES','29349-7097','(864) 216-5226','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 19:38:30',0,NULL,3,1,1,1,NULL,'andrew.svenson\r\\'),(2159,774284933012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','jmcc1104','vjmccabe@verizon.net','James McCabe','417 Carmichael Drive','North Wales','PA','UNITED STATES','19454','(215) 699-5498','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 19:40:49',0,NULL,3,1,1,1,NULL,'jmcc1104\r\\'),(2160,527384944004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',2,'HSNO005',29.5,'cnfaner','jp_rm250','mel_jean16@hotmail.com','jean-pierre houle','223 rue des bouleaux','gatineau','QC','CANADA','J8M2B1','(819) 918-5124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 19:59:08',0,NULL,3,1,3,1,NULL,'jp_rm250\rHSNO005\rRA117728833CN'),(2161,774300674012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','bobhillx','bobhilla@aol.com','Robert Hill','210 West 150th Street<br>Apt 2A','New York','NY','UNITED STATES','10039-2511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 20:00:29',0,NULL,3,1,1,1,NULL,'bobhillx\r\\'),(2162,527388700004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','knite77','b_kirchev@yahoo.com','Bozhidar Kirchev','Jolio Kurie street, bl.89, entr.1,ap.8','Sofia','Sofia district','BULGARIA','1113','+359878799105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 20:07:03',0,NULL,3,0,3,1,NULL,'knite77\rHSPL011\r欧标\rRA117728904CN'),(2163,774319606012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','juds1958','juds58@gmail.com','Judith Shisler','2003 Windcrest Ln','Joliet','IL','UNITED STATES','60431-8795','(815) 272-3900','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 20:32:27',0,NULL,5,0,18,0,NULL,'juds1958\rpayapl 撤款'),(2164,774330495012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','maverickicx','weissre@muohio.edu','Ron Weiss','103 Shotwell St','San Francisco','CA','UNITED STATES','94103-3621','(502) 599-5931','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 20:48:01',0,NULL,3,1,1,1,NULL,'maverickicx\r\\'),(2165,573353512013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','kimberlydawnsexy','kimdawn1970@hotmail.com','kimberly williams','2033 S Main St<br>Lot 27','madisonville','KY','UNITED STATES','42431','(270) 875-9859','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 21:42:45',0,NULL,3,1,1,1,NULL,'kimberlydawnsexy\r\\'),(2166,697091539011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','textbookhuman','slaseret@yahoo.com','Teresa Schlosser','2983 Altamahaw Union Ridge Road','Burlington','NC','UNITED STATES','27217','(919) 636-0305','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 23:11:25',0,NULL,3,1,1,1,NULL,'textbookhuman\r\\'),(2167,774400598012,220748684477,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',2.99,'eastar4uk','tartanworrior','eddieb1@hotmail.co.uk','edward boswell','8 Swisscot Walk<br>Woodhead','Hamilton','Scotland','UNITED KINGDOM','ML3 8DX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 23:21:57',0,NULL,3,1,3,1,NULL,'tartanworrior\rOTCN001\rRA117728895CN\r\\\r'),(2168,774405610012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 23:37:51',0,NULL,3,1,2,1,NULL,'avextra-co-uk\r\\'),(2169,773984596012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','mikey-will-eat-it','sawdustorbust@aol.com','Mike Beesley','3324 W University Ave<br># 152','Gainesville','FL','UNITED STATES','32607','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 23:53:32',0,NULL,3,1,1,1,NULL,'mikey-will-eat-it\r\\'),(2170,774430422012,220713846320,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+carcharger',1,'HSNO005+CCNO001',12.28,'eastar4uk','comeagainsundor','sundor.rujina@yahoo.com','sundor ali','6 pinefield road townhill park','southampton','Hampshire','UNITED KINGDOM','so18 2gd','02380555273','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 00:48:49',0,NULL,3,1,3,1,NULL,'comeagainsundor\rHSNO005+CCNO001\rRA117728878CN'),(2171,573397338013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.8,'eastar4','123elra','massey4070@insightbb.com','Elra Massey','4070 Summer Time Pkwy','Louisville','KY','UNITED STATES','40272-4861','(502) 933-0959','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 00:51:16',0,NULL,3,1,1,1,NULL,'123elra\r\\'),(2172,573405811013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','danilaloginov','loginovdanila@gmail.com','Danila Loginov','ulitsa Yakovleva, dom 35, kvartira 149','Tomsk','Tomskaya oblast','RUSSIAN FEDERATION','634003','9131002029','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 00:56:56',0,NULL,3,1,2,1,NULL,'danilaloginov\racer 4pin1.25 15cm\r\\'),(2173,573407298013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','godotxd97','dah@us.ibm.com','David Hoffman','5136 Bartons Enclave Ln','Raleigh','NC','UNITED STATES','27613-6164','(919) 870-0978','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 01:03:47',0,NULL,3,1,1,1,NULL,'godotxd97\r\r\\'),(2174,573408357013,230393482183,'2.1 HP ZD8000 X6000 NX9600 Bluetooth Module+ cable',1,'BTHP2102',12.8,'eastar4','hoo340340','randallhoo374@msn.com','RANDALL HOO','2207 Apache St','ADELPHI','MD','UNITED STATES','20783-1617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 01:04:36',0,NULL,3,1,1,1,NULL,'hoo340340\rHP 8pin 1.0 3cm 线序反\r\\'),(2175,573411293013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','rollingscott','nealhively@comcast.net','Dr. Neal O. Hively','255 Opal Dr','Chambersburg','PA','UNITED STATES','17202','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-18 01:11:15',0,NULL,3,1,1,1,NULL,'rollingscott\r\\'),(2176,661841229001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','cabda01','danielcabrera_18@hotmail.com','Mario Cabrera','170 Orient st','Worcester','MA','UNITED STATES','01604','(508) 424-4304','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 01:21:05',0,NULL,3,1,1,1,NULL,'cabda01\rLK041370495CN\r\\'),(2177,774444681012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','philloper24euk','already_dead@msn.com','phil loper','PO Box 204<br>307 E. Orchard St.','West Manchester','OH','UNITED STATES','45382-0204','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 01:24:06',0,NULL,3,1,1,1,NULL,'philloper24euk\r\\'),(2178,774454608012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',2,'HSPL010',31.3,'eastar4uk','mamasports','whitleymiles@bellsouth.net','TERRESSIA MILES','90cr5260','BOONEVILLE','MS','UNITED STATES','38829','(662) 728-7136','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 01:50:42',0,NULL,3,1,1,1,NULL,'mamasports\\'),(2179,573428836013,230544190510,'NEW original Motorola H700 Gold DG Bluetooth Headset',1,'HSMO012',17.9,'eastar4','ktrinh0808','kt41387@yahoo.com','Kim Trinh','1840 Lake Dr','Lebanon','PA','UNITED STATES','17046','(717) 813-1042','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 02:14:44',0,NULL,3,1,1,1,NULL,'ktrinh0808\r\\'),(2180,527491256004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',55.99,'cnfaner','kimball719','dudlydewright@hotmail.com','kimball ballard','841 circle rd','palmer lake','CO','UNITED STATES','80133','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 02:19:16',0,NULL,3,1,1,1,NULL,'kimball719\r\\'),(2181,527492742004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'cnfaner','brenni13','brenton.f.wong@gmail.com','Brenton Wong','67 Maritime Tce<br>Birkenhead','North Shore City','Auckland','NEW ZEALAND','0626','6421399304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 02:24:30',0,NULL,3,1,3,1,NULL,'brenni13\rWLDE002\rRA022493086CN'),(2182,573437118013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','mateusz39','mateusz@mts.net','Mateusz Labuda','39 Taunus Dr.','Winnipeg','MB','CANADA','R2G3Y5','(204) 668-8745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 02:47:47',0,NULL,3,1,2,1,NULL,'mateusz39\r\\'),(2183,774475925012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','snorkeljim','snorkeljim@yahoo.com','Jimmy Pho','3612 Lindhaven Dr','Pearland','TX','UNITED STATES','77584','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 02:49:54',0,NULL,3,1,1,1,NULL,'snorkeljim\r\\'),(2184,527503182004,140490658519,'New HuaWei EM660 3G WWAN Mini PCI-E Card CDMA EV-DO Mod',1,'WWHU001',71.9,'cnfaner','minersc','minersc@execulink.com','Corey Miners','1411-3700 Kaneff Crescent','Mississauga','ON','CANADA','L5A4B8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 03:24:22',0,NULL,3,1,3,1,NULL,'minersc\rWWHU001\rRA117728921CN'),(2185,573448810013,230608888246,'Brand new LOGITECH VX NANO USB RECEIVER VX V450 V550',1,'RELO003',16.9,'eastar4','ben251067','elekhakia@gmail.com','dr. benedict itsuokor','15, cherry road','newport pagnell','Buckinghamshire','UNITED KINGDOM','mk16 0ar','02032393316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 03:52:53',0,NULL,3,1,2,1,NULL,'ben251067\r\\'),(2186,774497621012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','waterbolt','randomfire@gmail.com','David Young','408 N ORCUTT DR','MONTEBELLO','CA','UNITED STATES','90640','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 04:18:47',0,NULL,3,1,1,1,NULL,'waterbolt\r\\'),(2187,527511641004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','italiano89rus','lucifer-mk5@yandex.ru','Artem Pypa','Magistralnaya 117/30','Noyabrsk','Tumenskaya obl','RUSSIAN FEDERATION','629803','79824080010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 04:26:29',0,NULL,3,0,3,1,NULL,'italiano89rus\r欧标  HSNO017\rRA022493466CN'),(2188,697190424011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','craptologist','edmund.sepikit@gmail.com','Edmund Sepikit','P.O, Box 21569<br>Luyang','Kota Kinabalu','Sabah','MALAYSIA','88773','0128338475','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 05:02:52',0,NULL,3,1,2,1,NULL,'craptologist\r\\'),(2189,774515365012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ladiva411','ladiva411@msn.com','Latavia Barnes','132 Dupuy Circle','Byram','MS','UNITED STATES','39272-4489','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 05:54:42',0,NULL,3,1,1,1,NULL,'ladiva411\r\\'),(2190,774528712012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',11.9,'eastar4uk','magdalena416','rus416@googlemail.com','Magdalena Czajkowska','48 Saunders road','Uxbridge','Middlesex','UNITED KINGDOM','UB10 0rl','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 06:59:31',0,NULL,3,1,3,1,NULL,'magdalena416\rOTCN004*10\rRA022493510CN'),(2191,774531991012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','blassberg','blassberg@email.com','Charles   Blassberg','19 Best Avenue','Kenilworth','Warwickshire','UNITED KINGDOM','CV82TN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 07:14:51',0,NULL,3,1,3,1,NULL,'blassberg\rOTRA002\rRA022493554CN'),(2192,573486886013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',18,'eastar4','yzsd1','ysatwork@msn.com','Yunsheng Zhao','16552 Manassas St','San Diego','CA','UNITED STATES','92127-4410','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-18 08:28:52',0,NULL,3,1,1,1,NULL,'yzsd1\r\\'),(2193,527549941004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','v.kushnir','vkushnir@gmail.com','Vladimir Kushnir','7-30A<br>WestGate','Aktau','Mangystau','KAZAKHSTAN','130000','+77771933351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 09:20:39',0,NULL,3,1,3,1,NULL,'v.kushnir\rOTCR001\rRA022493571CN'),(2322,574140003013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','globalbuyer','mrinal@hotmail.co.uk','Mrinal Kumar','Jetset Journeys Pvt. Ltd., D-82 Amar Colony (Basement)<br>Lajpat Nagar IV','New Delhi','Delhi','INDIA','110024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:04:10',0,NULL,3,1,2,1,NULL,'globalbuyer\r、'),(2194,774568640012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 09:44:46',0,NULL,3,1,2,1,NULL,'avextra-co-uk\r、'),(2195,774587832012,220747230973,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',18.69,'eastar4uk','mal102010','michael.lloyd@kpmg.ie','Michael Lloyd','KPMG, Stokes Place<br>HARCOURT ST','dublin','Dublin','IRELAND','2','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 10:56:12',0,NULL,3,1,3,1,NULL,'mal102010\rHSUE002\rRA022493355CN\r\\'),(2196,694451851011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',9.99,'eastar4','lslh1975','srilalitha37@gmail.com','LSLH LALITA','PLOT NO.87 LIG<br>MAYURINAGER,MIYAPUR POST','HYDERABAD (Andhra Pradesh)','AP','INDIA','500050','919395139768919391668269','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 10:57:13',0,NULL,3,1,2,1,NULL,'lslh1975\r\\'),(2197,573525990013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.8,'eastar4','camphreluche','franck.flichy@orange.fr','Franck FLICHY','Le Plessis HUDELOR','LOUTEHEL','Bretagne','FRANCE','35330','0685458274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 12:08:22',0,NULL,3,1,2,1,NULL,'camphreluche\r\\'),(2198,774611175012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','guard.69.angel','piglet.7@btinternet.com','Joanna Briggs','7,Emmery close','Broughton','Lincolnshire','UNITED KINGDOM','DN20 0SN','01652658984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 12:19:39',0,NULL,3,1,2,1,NULL,'guard.69.angel\r\\'),(2199,573530777013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','dudeboy66','sime01@videotron.ca','leonce sime','823 de l\'harmonie','laval','QC','CANADA','h7a 3z3','(514) 718-5354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 12:31:36',0,NULL,3,1,3,1,NULL,'dudeboy66\rOTRA002\rRA022493347CN\r\\'),(2200,774631092012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','andlil73','anders@liljeberg.nu','Anders Liljeberg','Sturzen-Beckers gata 5','Helsingborg','SE','SWEDEN','25227','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 13:15:48',0,NULL,3,1,2,1,NULL,'andlil73\rMX20T\r\\'),(2201,773007409012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','paulogentil10','paulogentil@hotmail.com','Paulo Gentil','SQN 216 bl.A apt.223','Brasilia','DF','BRAZIL','70875-010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 13:19:43',0,NULL,3,1,2,1,NULL,'paulogentil10\r\\'),(2202,697320337011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','littletug04','littletug_11@hotmail.com','Jamere wilson','19070 NW 57th Ave<br>Apt 306','Hialeah','FL','UNITED STATES','33015-5085','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 14:07:29',0,NULL,3,1,1,1,NULL,'littletug04\r\\'),(2203,697323092011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','geobra','info@klickyworld.com','Andreas Männer','Romaneistr. 2c','Emmendingen','','GERMANY','79312','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 14:17:32',0,NULL,3,1,2,1,NULL,'geobra\r\\'),(2204,697328440011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRMX002',8.55,'eastar4','edyurco','edyurco@yahoo.com','Edward Yurco','3250 N Hamlin Ave','Chicago','IL','UNITED STATES','60618-5208','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 14:34:35',0,NULL,3,0,1,1,NULL,'edyurco\r\\'),(2205,527611006004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','555linas','lalminas@hotmail.com','Leandras Alminas','Debreceno 34-50','Klaipeda','','LITHUANIA','94147','+37068256018','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 14:48:01',0,NULL,3,1,3,1,NULL,'555linas\rHSNO005\r欧标\rRA022493280CN\r\\'),(2206,573562739013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',2,'RELO002',25.98,'eastar4','emir2828','azeemirza@msn.com','Eli Mirza','41 Middlesex Ave','Edison','NJ','UNITED STATES','08820-3525','(917) 681-0568','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 14:50:51',0,NULL,3,1,1,1,NULL,'emir2828\r\\'),(2207,573579975013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','skaterkater','info@appartement-messe.com','Weisse Flotte','Frings Str. 11a<br>z.H. Herr Gantenberg','Düsseldorf','','GERMANY','40221','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 15:55:27',0,NULL,3,1,2,1,NULL,'skaterkater\r\\'),(2208,774688532012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','maxito24','maksymiukmarek@gmail.com','Marek Maksymiuk','Suwalska 36','Gizycko','','POLAND','11-500','004 874284','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 15:56:32',0,NULL,3,1,2,1,NULL,'maxito24\r\\'),(2209,521886896003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',2,'HSMO016',45.38,'cnfaner','olimasoft','badstorm@gmail.com','Marco Olimpi (OPS Activity)','S.S 13 Pontebbana, 81','Basiliano','Udine','ITALY','33031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:04:16',0,NULL,3,1,3,1,NULL,'olimasoft\rHSMO016\r欧标  黑色\rRA117739014CN\r、'),(2210,697378691011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','woohooben','woohooben@hotmail.com','Ben Hawthorn','3 (3f1) Bernard Terrace','Edinburgh','Midlothian','UNITED KINGDOM','EH8 9NU','07841978736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:53:36',0,NULL,3,1,2,1,NULL,'woohooben\r\\'),(2211,662073208001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','sportingood','oliver@goumas.us','Oliver Goumas','2655 s moore dr<br>Unit c','Lakewood','CO','UNITED STATES','80227-6502','(303) 995-3506','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 16:53:46',0,NULL,3,1,1,1,NULL,'sportingood\rLK041624456CN \r\\'),(2212,573597638013,230608888246,'Brand new LOGITECH VX NANO USB RECEIVER VX V450 V550',1,'RELO003',16.9,'eastar4','adkinson12','nadkinson12@yahoo.com','Nick Adkinson','8000 York Rd<br>Unit 14','Towson','MD','UNITED STATES','21252-0001','(301) 676-2419','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 16:55:33',0,NULL,3,1,1,1,NULL,'adkinson12\r新优联\r\\'),(2213,573599537013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','abdulrahim79','lucky_3abdu@hotmail.com','Abdulrahim alharthi','oman<br>P.O BOX NO:74 , P.CODE:122  MABELLAH,SEEB','seeb','MUSCAT','OMAN','968','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 17:01:56',0,NULL,3,1,2,1,NULL,'abdulrahim79\r\\'),(2214,697393496011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',49.99,'eastar4','fan0416hk','fan0416@me.com','Cheuk Fan Li','Flat 39, 24/F, Block D, Metropole Building<br>North Point','default','','HONG KONG','default','60808403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 17:27:02',0,NULL,3,1,14,1,NULL,'fan0416hk\r010976544300'),(2215,573617867013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',2,'HSPL005',27,'eastar4','marcosadrianodia2008','marcosadrianodias@yahoo.com.br','marcos adriano','R; Scorpius N:1259<br>Jardim Satelite','Sao jose dos Campos','sao Paulo','BRAZIL','12230-570','012 34314819','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 18:03:52',0,NULL,3,1,2,1,NULL,'marcosadrianodia2008\r\\'),(2216,774750215012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',17.2,'eastar4','gegemnpt','jtredez@gmail.com','Coronis (Jérôme Tredez)','Espace Concorde – Bât. B<br>120 impasse JB Say','Perols','Languedoc-Roussillon','FRANCE','34470','0687285784','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 18:05:18',0,NULL,3,1,2,1,NULL,'gegemnpt\r再发一个New Logitech Rechargeable battery L-LB2 1700mAh MX1000\r\\'),(2217,527668547004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','g0lduck','eliteground@yandex.ru','Artem Zabirohin','ul. Kamishovai 32/1/30','Saint Petersburg','','RUSSIAN FEDERATION','197372','89627127928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 18:10:21',0,NULL,3,1,3,1,NULL,'g0lduck\r欧标 HSPL011\rRA022493262CN\r\\'),(2218,521927320003,130490592974,'New WIFLY-CITY IDU-2850UG-U20 plus Wireless USB Adapter',1,'ANWI001',59.9,'cnfaner','stascebanu','stasdinvorniceni@rambler.ru','Stanislav Cebanu','RUA ALVARO GOMES lote 4 8eq','Armaçao de Pera','Armaçao de Pera','PORTUGAL','8365-111','964046753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 18:18:17',0,NULL,3,1,3,1,NULL,'stascebanu\rANWI001\rRA022493293CN\r\\'),(2219,774779961012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','kris13514','spam71@wp.pl','Krzysztof Tucholski','Panewnicka 363/3','40-773 Katowice','śląskie','POLAND','40773','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 18:58:45',0,NULL,3,1,2,1,NULL,'kris13514\r\\'),(2220,520906318003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','remolato','maciremo@alice.it','Massimiliano Remolato','Contrada Ghiotti 18','Montecchio Maggiore','Vicenza','ITALY','36075','3207096189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 19:22:38',0,NULL,3,1,3,1,NULL,'remolato\rHSMO016\rRA022493276CN\r\\'),(2221,573659292013,230412690655,'2.0 New ASUS Bluetooth Module +cable for EEEPC1101HA',1,'BTHU2001',12.5,'eastar4','eviz1989','eric.viseur@gmail.com','Eric Viseur','Avenue Reine Astrid 20/2','Mons','','BELGIUM','7000','0497923680','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 19:34:50',0,NULL,3,1,2,1,NULL,'eviz1989\r华硕10pin 0.8 6cm\r\\'),(2222,774809045012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','mgm_cards','dvcamero.n@gmail.com','david cameron','248 tom hill sr blvd<br>pmb 192','MACON','GA','UNITED STATES','31210-1815','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 19:44:04',0,NULL,3,1,1,1,NULL,'mgm_cards\\'),(2223,773692870012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','drwsalvador','davegeoffrey@hotmail.com','Dave Veenhuizen','Debussystraat 4','Spijkenisse','','NETHERLANDS','3208CH','+31 181-630996','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 20:11:28',0,NULL,3,1,2,1,NULL,'drwsalvador\r\\'),(2224,527720426004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',2,'HSNO005',29.5,'cnfaner','skylaptopstore','skylaptop@yahoo.com','xiaohui wang','151 E Garvey Ave','Monterey Park','CA','UNITED STATES','91755-2905','(626) 626-3942','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 20:33:36',0,NULL,3,1,1,1,NULL,'skylaptopstore\r\\'),(2225,774823757012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','hcktds','tidus199193@hotmail.com','Imanol  Barba Sabariego','Abat Escarré, 20, 2º 1ª','Sabadell','Cataluña','SPAIN','08206','649090877','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 20:36:19',0,NULL,3,1,2,1,NULL,'hcktds\r\\'),(2226,774847302012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.05,'eastar4','cisco_racks','marca_alexander@yahoo.com','Marc Alexander','5980 Folkstone Ln','Orlando','FL','UNITED STATES','32822-9423','(407) 489-4672','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'cisco_racks'),(2227,697514917011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','avro91','z.5389@yahoo.com','Abraham Greenman','11811 Dandelion Ln','Houston','TX','UNITED STATES','77071-2608','(281) 881-4822','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 21:32:04',0,NULL,3,1,1,1,NULL,'avro91\r\\'),(2228,697517042011,320394905464,'Acer Aspire 9410 9411 Bluetooth Module 2.0 EDR+cable',1,'BTAC2008',12.5,'eastar4','estherjj','esthertichelaar@hotmail.com','Esther Tichelaar - van der Pijl','Heerenacker 88','Gorredijk','','NETHERLANDS','8401 VJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 21:39:50',0,NULL,3,1,2,1,NULL,'estherjj\racer 4pin1.25 18cm \r\\'),(2229,774874927012,220681549785,'New Nokia LD-3W Bluetooth GPS Module Battery+Carcharger',1,'OTCR001',19.55,'eastar4uk','butz_klauser','butz666@hotmail.com','Florentin BERROD','67 boulevard Pierre Joannon','SAINT CHAMOND','Rhône-Alpes','FRANCE','42400','0664954296','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 22:03:48',0,NULL,3,0,3,1,NULL,'butz_klauser\rOTCR001\rRA022493302CN\r\\'),(2230,774877110012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',12.5,'eastar4','techandgolf','techtraderonline@gmail.com','Stephen Rice','2521 Mosswood Drive','Carrollton','TX','UNITED STATES','75010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 22:08:13',0,NULL,3,1,1,1,NULL,'techandgolf\r\\'),(2231,573707995013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','mikipro','sales@mikipro.com','Milutin Ilic','3/770 Beach Rd<br>Browns Bay','Auckland','','NEW ZEALAND','0630','021886854','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 22:08:17',0,NULL,3,1,2,1,NULL,'mikipro\r\\'),(2232,774910848012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','johnie89pp','johnie89paypal@gmail.com','Jonathan McDonnell','50 The Priory','Donabate','Co Dublin','IRELAND','0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 23:55:23',0,NULL,3,1,2,1,NULL,'johnie89pp\r\\'),(2233,774919582012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','olive33','tltotzke@gmail.com','Terri Totzke','161 Young Oak Rd','Salt Lake City','UT','UNITED STATES','84108','(435) 659-1131','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 00:25:52',0,NULL,3,1,1,1,NULL,'olive33\r\\'),(2234,697569336011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','louiselarson1826','louiselarson1@gmail.com','Louise Larson','636 Londonberry Ln','Bolingbrook','IL','UNITED STATES','60440-1017','(630) 985-3235','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 00:38:32',0,NULL,3,1,1,1,NULL,'louiselarson1826\r\\'),(2235,573733821013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','italoleite11','italoreboucas@yahoo.com.br','Ítalo Rebouças','Rua João Paulino Barros Leal, Nº: 2470<br>Bairro: São João do Tauape','Fortaleza','Ceará','BRAZIL','60120-060','+558586311350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 00:40:36',0,NULL,3,1,3,1,NULL,'italoleite11\rMOSA001\rRA022493333CN\r\\'),(2236,774925440012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',12.5,'eastar4','levelkro','levelkro@yahoo.ca','Mathieu Légaré','13900 Sherbrooke Est Apt. 25','Montréal','QC','CANADA','h1a 1c4','(514) 642-8748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 00:45:08',0,NULL,3,1,2,1,NULL,'levelkro\racer 6pin1.25 23cm\r、'),(2308,574093716013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','cale_dunbar','caledunbar@gmail.com','Cale Dunbar','150 Saskatchewan Ave.<br>Box 693','Gladstone','MB','CANADA','R0J 0T0','(204) 483-0301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 04:33:06',0,NULL,3,1,2,1,NULL,'cale_dunbar\r、'),(2237,697607796011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','colossus202006','colossus856@hotmail.com','LUIS VARGAS','208 ROSLYN AVE','CARLE PLACE','NY','UNITED STATES','11514-1623','(516) 869-4806','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 03:09:18',0,NULL,3,1,1,1,NULL,'colossus202006\r\\'),(2238,697608156011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','dynastywes','dragod@gmail.com','Jay Chao','5200 Canyon Crest Dr<br>Apt 78','Riverside','CA','UNITED STATES','92507-6311','(909) 972-5937','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 03:12:01',0,NULL,3,1,1,1,NULL,'dynastywes\r\\'),(2239,774970468012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','9985samuel','the_warmonger@hotmail.com','Samuel Kerr','#207-831 Ellery St.','Victoria','BC','CANADA','V9A 4R6','(778) 440-1094','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 03:23:08',0,NULL,3,1,2,1,NULL,'9985samuel\r\\'),(2240,697612129011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','knickers','quentin5@me.com','Keith Nickerson','1043 Ashland St<br>Apt 2','Houston','TX','UNITED STATES','77008','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 03:28:48',0,NULL,3,1,1,1,NULL,'knickers\r\\'),(2241,774985085012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','jburn116','jburn116@hotmail.com','Jared Burney','54 Larbonya Crescent<br>Capalaba','Brisbane','Queensland','AUSTRALIA','4157','0738231971','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 04:32:19',0,NULL,3,1,3,1,NULL,'jburn116\rHSSH002\rRA022493449CN\r\\'),(2242,774986183012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','speedy570-half','rayrosado@comcast.net','Ray Rosado','7590 S Jackson St','Centennial','CO','UNITED STATES','80122-3542','(303) 316-4119','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 04:37:29',0,NULL,3,1,1,1,NULL,'speedy570-half\r\\'),(2243,774988192012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','hungq_pham','joe7pham@gmail.com','Hung Pham/CORNERSTONE PHARMACY LTD.','1,5102 Rundlehorn Drive N.E.','Calgary','AB','CANADA','T1Y1C1','(403) 280-0305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 04:48:16',0,NULL,3,1,2,1,NULL,'hungq_pham\r\\'),(2244,770919666012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','vinny16jet','vinny16jet@yahoo.com','Tim Gagnier','11401 Dr Martin Luther King Jr St N<br>Apt 715','Saint Petersburg','FL','UNITED STATES','33716-2312','(813) 334-3416','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 05:15:49',0,NULL,3,1,1,1,NULL,'vinny16jet\r\\'),(2245,697634884011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','des.maughan','desmond_maughan@hotmail.com','Desmond Maughan','The Compass Centre (M.2.S)<br>London Heathrow Airport','Hounslow','Middlesex','UNITED KINGDOM','TW6 2GW','07967032077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 05:38:07',0,NULL,3,1,2,1,NULL,'des.maughan\r\\'),(2246,697648938011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','okilinuk','jaberroa@telefonica.net','Javier Alonso Berroa','C/ Legia 42 1º A','Bera','Navarra','SPAIN','31780','948630896','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 06:58:03',0,NULL,3,1,2,1,NULL,'okilinuk\r\\'),(2247,527832441004,140515701798,'New GENUINE NOKIA BH-205 BLUETOOTH HEADSET track#',1,'HSNO009',15.5,'cnfaner','gt_szamu','kantaluprd@gmail.com','Gabor Szabo','Gardonyi str 15/1','Maklar','Heves','HUNGARY','3397','+3636203551255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 07:10:16',0,NULL,3,1,3,1,NULL,'gt_szamu\r欧标 \rHSNO009\rRA022493435CN\r\\'),(2248,775023114012,220475280848,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10',1,'BTLE2001',12.5,'eastar4','fratzscher','daniel.fratzscher@gmx.de','Daniel Fratzscher','Schönebecker Weg 50A','Woltersdorf','','GERMANY','15569','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 07:51:01',0,NULL,3,1,2,1,NULL,'fratzscher\r、'),(2249,775024992012,220681549785,'New Nokia LD-3W Bluetooth GPS Module Battery+Carcharger',1,'OTCR001',19.55,'eastar4uk','495283486','ddc443@telenet.be','Dirk De Croes','Royal Museum for Central Africa<br>Leuvensesteenweg 13','Tervuren','','BELGIUM','3080','027695244','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 07:54:58',0,NULL,3,1,3,1,NULL,'495283486\rOTCR001\rRA022493228CN\r\\'),(2250,775034122012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',29.99,'eastar4uk','algirdas_suris','algirdassurgautas@gmail.com','Algirdas Surgautas','Navarsoniu km.<br>Panevezio sen.','Panevezio raj.','LT','LITHUANIA','38365','0037061221808','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 08:35:17',0,NULL,3,1,3,1,NULL,'algirdas_suris\rHSNO019+CCNO001\rRA022493231CN\r\\'),(2251,775054362012,220455480428,'HP NC4400 TC4200 TC4400 Bluetooth Module EDR 2.0 +cable',1,'BTHP2007',12.5,'eastar4','itishwang','djhwanghdj@naver.com','Hwang Dojung','10-16 Pil-dong 3-ga, Jung-gu','seoul','','KOREA,REPUBLIC OF','100-273','82-10-4721-5302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 09:59:59',0,NULL,3,1,2,1,NULL,'itishwang\rHP 8pin 1.0 23cm '),(2252,775077008012,220566625683,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',2,'OTIN002',140,'eastar4','qingyuau','sunflower.qingyu@gmail.com','Qing Yu','40/129B Park Road','Rydalmere','New South Wales','AUSTRALIA','2116','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:28:09',0,NULL,3,1,3,1,NULL,'qingyuau\rOTIN002\rRA022493673CN\r\\'),(2253,573845296013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','nekromanths','nekromanths@yahoo.gr','george anastasopoylos','MHTROPOLEOS 134','EGIO','AIGIO','GREECE','25100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:37:35',0,NULL,3,1,2,1,NULL,'nekromanths\r欧标\r\\'),(2254,697713289011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','netdl016','vh_nguyen@bigpond.com','Van Nguyen','17 Drake street','Panania','New South Wales','AUSTRALIA','2213','61407007381','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:42:59',0,NULL,3,1,2,1,NULL,'netdl016\r\\'),(2255,697714246011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','spaark','v9bahl@gmail.com','Vikram Bahl','2nd Floor, MERLIN HOUSE<br>BELMONT TERRACE','London','Middlesex','UNITED KINGDOM','W4 5UG','07525711976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:45:53',0,NULL,3,1,2,1,NULL,'spaark'),(2256,522132349003,130490915279,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'cnfaner','dancekilkenny','benoghre@hotmail.com','Benjamin Oghre','57B Exning Road','London','London','UNITED KINGDOM','E16 4NE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:59:24',0,NULL,3,1,3,1,NULL,'dancekilkenny\rCACN003\rRA022493775CN\r\\'),(2257,775099515012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','getdoc','gwyntull@hotmail.com','Gwyn Tull','26 Roman Road','Northallerton','North Yorks','UNITED KINGDOM','DL7 9SW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 12:46:00',0,NULL,3,1,3,1,NULL,'getdoc\rOTCN003\rRA022493903CN\r\\'),(2258,775112935012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','hennawee','kjtownsend@q.com','Kristie Townsend','170 Joes Way','Bozeman','MT','UNITED STATES','59718-9140','(406) 587-0584','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 13:29:00',0,NULL,3,1,1,1,NULL,'hennawee\r\\'),(2259,775120237012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','jeffncsu2002','jeffwatson@hammerpatent.com','Jeff Watson','4684 Dabney Vigor Dr','Charlotte','NC','UNITED STATES','28209-2838','(704) 222-1184','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 13:53:57',0,NULL,3,1,1,1,NULL,'jeffncsu2002\r\\'),(2260,775124800012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','yago_project','gerd@justmueller.com','Gerd Müller','Kossuth lajos U 143','Dunabogdany','','HUNGARY','2023','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 14:08:24',0,NULL,3,1,2,1,NULL,'yago_project\r\\'),(2261,697745919011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',3,'RELO002',38.97,'eastar4','posevik','posevik@yandex.ru','Sergey Popov','Igralnaya str. 10, apt. 31','Moscow','','RUSSIAN FEDERATION','107258','(965)416-6006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 14:33:30',0,NULL,3,1,3,1,NULL,'posevik\rRELO002\rRA022493832CN\r\\'),(2262,775135694012,220743499505,'NEW Genuine Motorola S9 Bluetooth Stereo Headset',1,'HSMO002',31,'eastar4uk','crayonyes','rusmin.wijaya@gmail.com','Rusmin Wijaya','Perum Kosambi Baru Jl. Janur Kuning II FEX 8 No. 7<br>RT.07/15 Duri Kosambi, Cengkareng','Jakarta Barat','DKI Jakarta','INDONESIA','11750','(62)817-805822','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 14:41:55',0,NULL,3,1,3,1,NULL,'crayonyes\rHSMO002\r红色的   挑个好点的\rRA022493687CN\r\\'),(2263,522166728003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',19.9,'cnfaner','ebrucia74','emanuele@specialimpianti.it','Bruciaferri Emanuele','Via delle Campanelle n.24','Casal Borsetti','RA','ITALY','48123','0544445394','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 14:52:34',0,NULL,3,0,3,1,NULL,'ebrucia74\rHSNO016\r欧标\rRA022493801CN\r、'),(2264,697769760011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',43.9,'eastar4','mb_6297','mb_629@hotmail.com','Mary Susong','77 state route 145','Corydon','KY','UNITED STATES','42406-9200','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 15:01:01',0,NULL,3,1,1,1,NULL,'mb_6297\r\\'),(2265,697770945011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','b-w-matt','info@bwmphoto.com','Brian Matthews','100 Dunbar Road','Hartlepool','Cleveland','UNITED KINGDOM','TS25 5DX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 15:07:44',0,NULL,3,1,2,1,NULL,'b-w-matt\r\\'),(2266,0,220771754733,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','sinhasunil465','sinha.sunil465@gmail.com','sunil sinha','450th CA BN<br>Buld 13, Camp Gibson','APO','AE','AA','09356','0798696601','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 15:22:26',0,NULL,3,1,1,1,NULL,'sinhasunil465\r\\'),(2267,0,230610979551,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',15.55,'eastar4','ru_battleship','tonywadsworth1@gmail.com','Ann Wadsworth','211 N Kent St','Winchester','VA','UNITED STATES','22601','(540) 667-5131','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 15:23:39',0,NULL,3,1,1,1,NULL,'ru_battleship\r\\'),(2268,0,230610978950,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',8.99,'eastar4','sammydad','pv49erfan@yahoo.com','Darin Nishimura','29610 Stonecrest Rd','Rancho Palos Verdes','CA','UNITED STATES','90275-5714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 15:36:58',0,NULL,3,1,1,1,NULL,'sammydad\r\\'),(2269,0,220771754732,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',26.99,'eastar4','iluvts','galleonbrian@juno.com','Mark Talbot','384 Howe Ave<br>Unit 3A','Shelton','CT','UNITED STATES','06484-3167','(203) 924-6760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 15:41:14',0,NULL,3,1,1,1,NULL,'iluvts\r\\'),(2270,0,220771754085,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','ckfenterprises','ckfmd@comcast.net','Curtis K Fisher','3261 CYPRESS MARSH DR','FORT MYERS','FL','UNITED STATES','33905-6251','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-19 16:08:50',0,NULL,3,1,1,1,NULL,'ckfenterprises\r\\'),(2271,697802047011,320444514309,'UNLOCKED Option GTM382 PCI-E 7.2Mbps Modem 3G + antenna',1,'WWOP003+ANCN001',47.95,'eastar4','corsariodance','corsariodance@yahoo.com.ar','Maximiliano Garcia','Ameghino 550','Buenos Aires','Vicente Lopez','ARGENTINA','1603','541147091074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 16:32:09',0,NULL,3,1,3,1,NULL,'corsariodance\rWWOP003+ANCN001\rRA022493846CN\r\\'),(2272,775198501012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','khamaamayama','drakenragendrag@gmail.com','Alexandr Doroshin','14 Filevsky bulvar  App.114','Moscow','Moscow','RUSSIAN FEDERATION','121601','+79269404748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 18:03:54',0,NULL,3,1,2,1,NULL,'khamaamayama'),(2273,573948761013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','sunshinexeclipse1010011010','sunshinexeclipse@hotmail.com','Kenny Ballou','2041 S Cobalt Point Way<br>POWER Engineers Inc.','Meridian','ID','UNITED STATES','83642-4443','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 18:30:55',0,NULL,3,1,1,1,NULL,'sunshinexeclipse1010011010\r\\'),(2274,697865416011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',3,'RELO002',38.97,'eastar4','gtopinka','topinka@shaw.ca','Greg Topinka','45 Lafleur Drive','St. Albert','AB','CANADA','T8N 7N1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 18:56:54',0,NULL,3,1,3,1,NULL,'gtopinka\rRELO002\rRA022493850CN\r\\'),(2275,697876174011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','rayrodriguez1976','kriko@aol.com','Raymond  Rodriguez','7201 NW 36th St','Miami','FL','UNITED STATES','33166-6702','(305) 593-0585','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 19:19:00',0,NULL,3,1,1,1,NULL,'rayrodriguez1976\r\\'),(2276,573962753013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','rob_janae','rthomas@weber.k12.ut.us','Robert Thomas','4438 S 1630 W','Roy','UT','UNITED STATES','84067-3010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 19:09:09',0,NULL,3,1,1,1,NULL,'rob_janae\r\\'),(2277,697883679011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','nieto2007','umpireandrew@hotmail.com','Andrew Nieto','312 Avenue G','Grandview','WA','UNITED STATES','98930-1246','(509) 882-2952','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 19:32:42',0,NULL,3,1,1,1,NULL,'nieto2007\r\\'),(2278,697887062011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','rnbworld','rnb69@yandex.ru','Anton Ilzheev','Novo-Sadovaya<br>house 33 ap. 109','Samara','Samarskay','RUSSIAN FEDERATION','443110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 19:39:27',0,NULL,3,1,3,1,NULL,'rnbworld\rUDAP001\rRA022493761CN\r\\'),(2279,573974869013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','edwardphantom','edwardphantom@oi.com.br','Eduardo Fernandes Larrubia','Street one, home 310 conjunto campinho, campo grande<br>Rua 1 casa 310 conjunto campinho, Campo grande','Rio de Janeiro','Rio de janeiro','BRAZIL','23067-160','+5521 3407-4026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 19:42:59',0,NULL,3,1,2,1,NULL,'edwardphantom'),(2280,697894339011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','ardalon11','ardal.okok@gmail.com','mohammadhassan foroughbakhshfasaei','nagytemplom utca 34 b410','budapest','pest','HUNGARY','1082','0036302018230','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 19:54:55',0,NULL,3,1,3,1,NULL,'ardalon11\rUDAP001\rRA022493829CN\r\\'),(2281,697904469011,320394908928,'Acer Aspire 7730 7730G 7730Z Bluetooth Module 2.0+cable',1,'BTAC2011',12.5,'eastar4','lienesilovaliene','jurok3@inbox.lv','liene silova','progresa iela 4-32','Riga','','LATVIA','lv-1067','29649881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 20:17:28',0,NULL,3,1,2,1,NULL,'lienesilovaliene\racer 5pin1.25 4cm \r\\'),(2282,775293817012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',3,'HSPL010',71.7,'eastar4','paquette450','andrepaquette60@videotron.ca','André Paquette','322 Clifton','Otterburn Park','QC','CANADA','J3H 1X3','(450) 467-7288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 20:24:43',0,NULL,3,1,3,1,NULL,'paquette450\rHSPL010\rRA022493789CN\r\\'),(2283,522268319003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','milan28maggio2003','niceforo75@gmail.com','Nicola Niceforo','via orti ovest 4/1','chioggia','VE','ITALY','30015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 20:35:16',0,NULL,5,0,18,1,NULL,'milan28maggio2003\rRA117739059CN\r、客户嫌慢  已退款'),(2284,697920237011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','longmouse011','longmouse@naver.com','Hansuk Seo','605 W LANIKAULA ST<br>HALE KANILEHUA Rm #202','Hilo','HI','UNITED STATES','96720','808 238 9703','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 20:49:19',0,NULL,3,1,1,1,NULL,'longmouse011\r\\'),(2285,522279592003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','amityes2010','amit.yes@gmail.com','Amit Yeshurun','Echad Ha\'am 18','Akko','','ISRAEL','24706','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 21:10:42',0,NULL,3,1,3,1,NULL,'amityes2010\rHSMO011\rRA022493815CN\r\\'),(2286,574013358013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','ntech12','nickh747@gmail.com','Nicholas Hong','955 Easton Rd<br>Apt G77','Warrington','PA','UNITED STATES','18976','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 21:40:51',0,NULL,3,1,1,1,NULL,'ntech12\r\\'),(2287,775335143012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',2,'HSNO006',59.7,'eastar4','tilchi','claudia.tilch@gmx.de','Claudia Tilch','Veielbrunnenweg 58','Stuttgart','','GERMANY','70372','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 21:55:35',0,NULL,3,1,3,1,NULL,'tilchi\r欧标\r再发两个New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W\rHSNO006+HSNO022\rRA022493792CN\r、'),(2288,522293177003,130490194854,'Genuine Logitech Harmony 880 Universal Remote Control',1,'RCLO002',75.99,'cnfaner','jamesmeeks21','jamesmeeks21@yahoo.com','James Meeks','1009 Sunset Dr','Macon','MO','UNITED STATES','63552-1066','(660) 651-2016','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 22:05:35',0,NULL,3,1,1,1,NULL,'jamesmeeks21\r\\'),(2289,574021564013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','lloydr4437','lloyd2you@sc.rr.com','Lloyd Rivers','6816 Valleybrook Rd','Columbia','SC','UNITED STATES','29206-1057','(803) 738-2653','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 22:13:20',0,NULL,3,1,1,1,NULL,'lloydr4437 '),(2290,697961484011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',2,'HSJA002',29.8,'eastar4uk','462370','flackandsonltd@hotmail.co.uk','adam flack','56 FORTUNA CLOSE','STEVENAGE','Hertfordshire','UNITED KINGDOM','SG1 5TD','01438214721','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 22:44:24',0,NULL,3,1,3,1,NULL,'462370\rHSJA002\r英标\rRA022493713CN\r\\'),(2291,522306748003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','greatstuff4sale2u','yesmayhem@hotmail.com','alecia hill','207 Brighton Ave','east orange','NJ','UNITED STATES','07017','(973) 870-1171','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 23:14:35',0,NULL,3,1,1,1,NULL,'greatstuff4sale2u\r\\'),(2292,697985976011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','evaldas777','ed7777@gmail.com','Shalini Nagaraj','2 CRANBERRY CLOSE','LONDON','London','UNITED KINGDOM','UB5 5PS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 00:15:17',0,NULL,3,1,2,1,NULL,'evaldas777\r英标'),(2293,528062665004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','fay54321','kiran.mir@live.lagcc.cuny.edu','Faiza Mir','30 Horizon Hill Rd','Newington','CT','UNITED STATES','06111-5115','(860) 518-7504','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 00:34:14',0,NULL,3,0,1,1,NULL,'fay54321\r\\'),(2294,697991541011,320552968178,'New Motorola HS810 Bluetooth Wireless Headset HS-810',2,'HSMO017',41.98,'eastar4','abbynormal2','abbynormal79@yahoo.com','Abby Cline','1191 Old Stage Rd','Decorah','IA','UNITED STATES','52101','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 00:45:36',0,NULL,3,1,1,1,NULL,'abbynormal2\r\\'),(2295,775386642012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','reefvan','reefvan@hotmail.com','L.A Van Vlaardingen','7031 des Glaieuls','Saint Hubert','QC','CANADA','J3Y8R9','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 00:46:55',0,NULL,3,0,2,1,NULL,'reefvan\r\\'),(2296,574055742013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','nala290586','c-crites@hotmail.com','Christine L Crites','PO BOX 731','Bushell Park','SK','CANADA','S0H 0N0','(306) 631-2759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 01:03:41',0,NULL,3,1,2,1,NULL,'nala290586'),(2297,574059864013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','pennyjbrown66','prwoodard70@aol.com','Penny Woodard','6300 Brownsville Rd','Lithia Springs','GA','UNITED STATES','30122-1001','(678) 472-6071','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 01:26:02',0,NULL,3,1,1,1,NULL,'pennyjbrown66\\'),(2298,698010710011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jawn_619','jawn619@gmail.com','John Chen','559 Carlton Ave','Bethlehem','PA','UNITED STATES','18015-2945','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 01:50:49',0,NULL,3,1,1,1,NULL,'jawn_619\r\\'),(2299,698014625011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','codywilson36','annwilson@frontiernet.net','Mike Wilson','Po box 399','McArthur','CA','UNITED STATES','96056-0399','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 02:06:12',0,NULL,3,1,1,1,NULL,'codywilson36\r\\'),(2300,574072797013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','oakbending52','jwking4@yahoo.com','j king','23508 Bending Oak Ct','murrieta','CA','UNITED STATES','92562-3304','(951) 304-2037','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 02:23:38',0,NULL,3,1,1,1,NULL,'oakbending52\r\\'),(2301,522341707003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','ericsewnsew','eheikell@msn.com','Mary Rathbun','11405 E Stoughton Rd','Valleyford','WA','UNITED STATES','99036-8536','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 02:28:55',0,NULL,3,1,1,1,NULL,'ericsewnsew\r\\'),(2302,775418942012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','victor57889','vicrxs@hotmail.com','Victor Xavier da Silveira','Rua Benjamin Constant, 26 bloco 13/303','Niterói','Rio de Janeiro','BRAZIL','24110002','552182360965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 02:40:07',0,NULL,3,1,3,1,NULL,'victor57889\r美标 \rMOMI001\rRA117739045CN\r\\'),(2303,775420365012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','davebee100','dkb100@hotmail.co.uk','DAVE BARRETT','53/10 MOO 7, SOI THEPNIMIT, NONGPLALAI','BANGLAMUNG','CHONBURI','THAILAND','20150','006638170816','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 02:44:28',0,NULL,3,1,3,1,NULL,'davebee100\rOTRA002\rRA117739028CN\r、'),(2304,698025807011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','andriy.t','andriy_bmw@yahoo.com','Andriy Tytarenko','28 Riverwood Prky. Apt.# 703','Toronto','ON','CANADA','M8Y 4E2','(416) 357-5054','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 02:53:49',0,NULL,3,1,2,1,NULL,'andriy.t'),(2305,0,220771754086,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','hotrod5071','af30@sbcglobal.net','Melvin Jenkins','7518 Kleberg','San Antonio','TX','UNITED STATES','78250','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 03:22:25',0,NULL,3,1,1,1,NULL,'hotrod5071\r\\'),(2306,528096132004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','krazzyoutlaw69','krazzyoutlaw@hotmail.com','Duane Jackson','18240 N 400 W','Wheatfield','IN','UNITED STATES','46392-8941','(219) 996-7569','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 03:37:25',0,NULL,3,1,1,1,NULL,'krazzyoutlaw69\r\\'),(2307,698040782011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','mobiles_and_extras','dthompson@mobileextras.com.au','Yaqum Pty. Ltd.','P.O. Box 1057','Osborne Park','Western Australia','AUSTRALIA','6917','0892424511','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 04:07:15',0,NULL,3,1,2,1,NULL,'mobiles_and_extras\r澳标'),(2309,775450508012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','capriscanmalaysia','marco.muehlemann@gmail.com','Marco Muehlemann','Stoppani Malaysia Sdn. Bhd.<br>Plot 12 & 13, Phase 4, FIZ Hilir Sg. Keluang 3','Bayan Lepas','Penang','MALAYSIA','11900','0123101105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 05:06:01',0,NULL,3,1,3,1,NULL,'capriscanmalaysia\rMOMI001\r美标\rRA117739969CN\r、'),(2310,528107685004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','ka6zzl','mtosch@verizon.net','Mike Tosch','1089 Waverly Heights Dr','Thousand Oaks','CA','UNITED STATES','91360-5052','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 05:11:46',0,NULL,3,1,1,1,NULL,'ka6zzl\r、'),(2311,698061216011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','t3r3e3y','terlegy@gmail.com','Trey Gomes','8340 Wickham Rd','Springfield','VA','UNITED STATES','22152-1739','(804) 266-5419','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 06:02:50',0,NULL,3,1,1,1,NULL,'t3r3e3y\\'),(2312,574104205013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',6,'HSPL001',70.8,'eastar4','lamplady327','elainefhayes327@yahoo.com','Jymmie Siebert','2250 N. Rock Rd<br>Suite # 118-186','Wichita','KS','UNITED STATES','67226-2331','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 06:10:41',0,NULL,3,1,1,1,NULL,'lamplady327\r、'),(2313,522374497003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','octow1983','octow83@hotmail.com','octavio blanco','1333 s briar cir','mesa','AZ','UNITED STATES','85204-6144','(480) 248-0041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 06:27:44',0,NULL,3,1,1,1,NULL,'octow1983\r、'),(2314,573033321013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','der.fisch','arctanh@gmail.com','Zimmermann Hannes','Trottenstrasse 73','Zürich','','SWITZERLAND','8037','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 06:53:12',0,NULL,3,1,2,1,NULL,'der.fisch\r、'),(2315,775471175012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','skatpul','nicottscole@gmail.com','Scott Poole','610-1483 Lamey\'s Mill Road<br>(Buzzer 175 or leave at office)','Vancouver','BC','CANADA','V6H 3Y7','(604) 732-0302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 06:54:03',0,NULL,3,1,2,1,NULL,'skatpul\r\\'),(2316,775469274012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','mantoh','vhm1206@zoho.com','Henky Mantophani','VIPAC Engineers<br>2 Sirius Road','Lane Cove','New South Wales','AUSTRALIA','2066','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 06:57:05',0,NULL,3,1,2,1,NULL,'mantoh\r澳标  \r\\'),(2317,697776376011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',2,'HSJA002',29.8,'eastar4uk','kippschein','uwe.brehm@gmx.de','Uwe Brehm','Brehm\'s Containerservice<br>Siedlung 3','Liebenwalde','','GERMANY','16559','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 07:16:46',0,NULL,3,1,3,1,NULL,'kippschein\r欧标 \rHSJA002\rRA117739972CN\r、'),(2318,775482383012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','drcharleslee','charleslee2006@fastmail.fm','Charles Lee','527 Stuyvesant Ave<br>Fl 1','Lyndhurst','NJ','UNITED STATES','07071-2627','(201) 765-0552','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 07:44:26',0,NULL,3,1,1,1,NULL,'drcharleslee\r、'),(2319,698090599011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','trentnewton','trent@truclean.com.au','Trent Newton','Unit 2, 659 Boundary Road','Richlands','Queensland','AUSTRALIA','4077','61733755415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 08:33:38',0,NULL,3,1,2,1,NULL,'trentnewton\r、'),(2320,528135378004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','u4studio','stasufo@gmail.com','Prokhodtsev Stanislav','pr. Molodezhniy 9-329','Kemerovo','Kemerovo','RUSSIAN FEDERATION','650070','+79236104422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 08:44:49',0,NULL,3,1,3,1,NULL,'u4studio\rOTRA002\r\rRA117716407CN\r\\'),(2321,574128358013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',21.9,'eastar4','n2odnb','n2odnb@hot.ee','Vadim Knut','Ilmatsalu 8-8','Tartu','Tartumaa','ESTONIA','50408','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 08:50:42',0,NULL,3,1,2,1,NULL,'n2odnb\r、'),(2323,574139799013,230608895412,'New bulk GENUINE NOKIA BH-700 BLUETOOTH HEADSET BH 700',1,'HSNO028',18.48,'eastar4','tundrurat','deepgaze@mail.ru','Rustem Zakirov','Lenina<br>Dom 28, Kv. 32','Pervomayskiy','Kirovskaya oblast','RUSSIAN FEDERATION','613648','+79127098749','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:05:27',0,NULL,3,1,2,1,NULL,'tundrurat\r欧标\r、'),(2324,528154079004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','hong1983','wai_hongwong@hotmail.com','Wai  Wong','Statistics House,<br>The Boulevard, Harbour Quays','Wellington','','NEW ZEALAND','6140','006444782162','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:49:33',0,NULL,3,1,3,1,NULL,'hong1983\rBALO007\rRA117728189CN\r\\'),(2325,775526564012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','pawansher2002','pawansher2002@gmail.com','PAWAN SEHRAWAT','Voltas Ltd, (UPBG)<br>Plot no 2 to 5, sector -8, SIDCUL - Pantnagar','Rudrapur','UL','INDIA','263153','919760695285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:50:41',0,NULL,3,1,2,1,NULL,'pawansher2002\r\\'),(2326,775527913012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','helenamayo','helenaredwalsh@yahoo.com','Helena Walsh','7 Tower View','Ballinrobe','Mayo','IRELAND','0','0861034748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:55:40',0,NULL,3,1,2,1,NULL,'helenamayo\r英标\r、'),(2327,574151761013,230510752651,'NEW GENUINE NOKIA BH-209 BLUETOOTH HEADSET BH 209',1,'HSNO011',19.99,'eastar4','braxos21-2009','braxos21@hotmail.com','Charitakis Stavros','L. Dimokratias 153','Pireus','Perama','GREECE','18863','6947093593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 11:15:21',0,NULL,3,1,2,1,NULL,'braxos21-2009\r欧标\r\\'),(2328,775552002012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.05,'eastar4','usasig1','usasig@hotmail.com','Sinan Asig','400 E 85th St<br>Apt 9K','New York','NY','UNITED STATES','10028-6319','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 12:22:39',0,NULL,3,1,1,1,NULL,'usasig1\rMX20T\r、'),(2329,775552278012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','iam732','cute732@daum.net','Jeon, Cheol-sang','3F Computer Information Division,<br>Eunpyeong-gu Office, 84, Nokbeon-dong,','Eunpyeong-gu,','Seoul','KOREA,REPUBLIC OF','122-702','010-2361-7325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 12:24:28',0,NULL,3,1,2,1,NULL,'iam732\r\\'),(2330,662497762001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','hczabala625','hczabala@gmail.com','HONG-CHAU ZABALA','6715 Vinevale Ave','BELL','CA','UNITED STATES','90201-2642','(714) 943-6978','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 12:29:19',0,NULL,3,1,1,1,NULL,'hczabala625\rLK042164711CN\r、'),(2331,698154259011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','markrowantree','markrowantree@hotmail.com','mark rowantree','139 bellahouston drive<br>mosspark','glasgow','scotland','UNITED KINGDOM','g52 1hl','01418838207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 12:51:37',0,NULL,3,1,2,1,NULL,'markrowantree\r、'),(2332,698153720011,320520042459,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'WLHP002',18.99,'eastar4','lokydm','dsmolyakow@gmail.com','Dmitriy Smolyakow','Revytsky st. 17b, appartment 26','Kiev','','UKRAINE','02091','380674474576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 12:53:51',0,NULL,3,1,2,1,NULL,'lokydm\r\\'),(2333,698153617011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',3,'CASS001',26.1,'eastar4','szhu0618','sam.junzhu@gmail.com','Jun Zhu','123 George Street','Scoresby','Victoria','AUSTRALIA','3179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 13:00:18',0,NULL,3,1,2,1,NULL,'szhu0618\r、'),(2334,696505741011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tunnelinghorror','msweetser87@hotmail.com','Michael sweetser','3814 Calibre Bend Ln<br>Apt 1412','winter park','FL','UNITED STATES','32792-8674','(402) 613-7821 ext.: 4026137821','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 13:04:56',0,NULL,3,1,1,1,NULL,'tunnelinghorror\r、'),(2335,574182900013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',35.94,'eastar4','scobako','junior4430@gmail.com','Alexandr Danilov','Zakrevskogo street, 35A, Apt (kvart) 134','Kiev','UA','UKRAINE','02217','+ 38 050 440 30 02','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 13:52:28',0,NULL,3,1,3,1,NULL,'scobako\rWLAT001+WLIN010\r再发一个New Intel 5300 AGN Wireless Network Mini PCI-E Card\rRA117728175CN\r、'),(2336,698177942011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','shualf','shaulfl@gmail.com','shaul fellah','haroe 275','ramat gan','Israel','ISRAEL','52292','036782899','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 14:14:47',0,NULL,3,1,2,1,NULL,'shualf\r、'),(2337,775587058012,220448688645,'Acer Aspire 4730 4930 Bluetooth Module EDR 2.0+cable',1,'BTAC2019',12.5,'eastar4','lexnem1','lex_nem@mailbolt.com','Alexei Nemov','Alpiyskiy pereulok 19 kor 1 kv 56','Saint-Petersburg','','RUSSIAN FEDERATION','192239','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 14:17:22',0,NULL,3,1,2,1,NULL,'lexnem1\racer 8pin1.00 6cm\r\\'),(2338,574191080013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',21.9,'eastar4','203samiriss23','samiriss29@hotmail.com','samira bouderka','17 Fairfield Ave<br>Apt 31','norwalk','CT','UNITED STATES','06854-2156','(203) 551-0003','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-20 14:26:09',0,NULL,3,1,1,1,NULL,'203samiriss23\r、'),(2339,698187276011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','jjgncmg','jeff@jeffnclaudette.com','Jeffrey J. Gerdjunis','440 Michigan St','Ronkonkoma','NY','UNITED STATES','11779','(516) 408-2020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 14:46:49',0,NULL,3,1,1,1,NULL,'jjgncmg\r、'),(2340,574200308013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','alain930','alain.rioux@live.ca','Alain Rioux','945 des Cimes','Ste-Adele','QC','CANADA','J8B1M7','(450) 229-2410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 15:06:04',0,NULL,3,1,2,1,NULL,'alain930\r、'),(2341,574201057013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','63_sergio','pokelon3@hotmail.com','Sergio Flores V','Juan Jose Baz # 168 Colonia Chapultepec Oriente<br>Esquina Anastacio Cerezero','Morelia','Michoacánl','MEXICO','58260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 15:09:28',0,NULL,3,1,2,1,NULL,'63_sergio\r、'),(2342,698202479011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',1,'CASS003',8.7,'eastar4','earweed','irvinearweed@hotmail.com','William Ware','9850 Kalae St','Diamondhead','MS','UNITED STATES','39525-4425','(205) 237-4782','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-20 15:32:35',0,NULL,3,1,1,1,NULL,'earweed\r、'),(2343,0,230611726958,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',15.05,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 15:43:10',0,NULL,3,1,1,1,NULL,'4278dennis\r、'),(2344,775625129012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',2,'MOLO002',77.8,'eastar4','kebekbutcher','mykeldumasdemers@hotmail.com','Mykel Dumas Demers','57 des Quatre-Vents','Asbestos','QC','CANADA','J1T 4N6','(819) 879-5643','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 16:05:48',0,NULL,3,1,3,1,NULL,'kebekbutcher\rMOLO002\rRA117728351CN\r\\'),(2345,698222778011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','rbar2385','r.barnett01@rogers.com','Robert Barnett','155 Arundel Ave','Toronto','ON','CANADA','M4K 3A7','(416) 423-1515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 16:29:18',0,NULL,3,1,2,1,NULL,'rbar2385\racer 8pin1.00 8cm \r\\'),(2346,522468214003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','iggypla','plaig@musc.edu','Ignacio Pla','1216 Walleye Cor','Charleston','SC','UNITED STATES','29414-9129','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 16:51:35',0,NULL,3,1,1,1,NULL,'iggypla\r、'),(2347,775644296012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',29.99,'eastar4uk','kanareika_artem','avtor_fr@mail.ru','Artem Skripalschikov','yl. S.Lazo, d. 15, kv. 85','Orenburg','Orenburg region','RUSSIAN FEDERATION','460044','+79225306773','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 16:57:19',0,NULL,3,1,3,1,NULL,'kanareika_artem\rHSNO019+CCNO001\rRA022493727CN\r\\'),(2348,775672786012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',11.99,'eastar4','8518steven','howatssw@yahoo.com','Steven Howatson','224- 95 Highfield Park Drive','Dartmouth','NS','CANADA','B3A4V1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:56:04',0,NULL,3,1,2,1,NULL,'8518steven\r\\'),(2349,698257686011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','loizos88','harusloizos@gmail.com','Loizos Charous','gravias 31 aradippou<br>kapellos court 002','Larnaka','','CYPRUS','7102','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:56:54',0,NULL,3,1,2,1,NULL,'loizos88\r\\'),(2350,775673713012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',4,'HSPL011',92,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:58:10',0,NULL,3,1,3,1,NULL,'solopo2009\rHSPL011  \r只发耳机和USB cable不给adapter\rRA117728161CN\r\\'),(2351,775676488012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','dnsnetworks','shawn.ebbs@dnsnetworks.ca','Shawn Ebbs','1122 Wellington St West','Ottawa','ON','CANADA','K1Y2Y7','(819) 664-8895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 18:01:02',0,NULL,3,1,3,1,NULL,'dnsnetworks\rHSSH002\rRA117728250CN\r'),(2352,574259259013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','elestor','nestor.zuleta.l@gmail.com','Nestor Zuleta Lopez','Blas Segundo Tellez  0246<br>Villa Carlos Condell','Tocopilla','Tocopilla / Provincia Tocopilla / II Region','CHILE','1340000 ','055-819402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 18:27:13',0,NULL,8,1,17,1,NULL,'elestor'),(2353,522515068003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',2,'HSSE004',43.8,'cnfaner','elestor','nestor.zuleta.l@gmail.com','Nestor Zuleta Lopez','Blas Segundo Tellez  0246<br>Villa Carlos Condell','Tocopilla','Tocopilla / Provincia Tocopilla / II Region','CHILE','1340000 ','055-819402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 18:28:25',0,NULL,3,1,3,1,NULL,'elestor\rHSSE004\r再发一个New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W\r潘'),(2354,698283958011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',43.9,'eastar4','jonnytii','jon.taylor@jba.aero','Jonathan Taylor','2119 Woodstream Dr','Kingwood','TX','UNITED STATES','77339-3332','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 18:51:07',0,NULL,3,1,1,1,NULL,'jonnytii\r、'),(2355,698288419011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','bule777','linda.tamplin@googlemail.com','Linda   Tamplin','High Carston, Ochiltree','Cumnock','East Ayrshire','UNITED KINGDOM','KA18 2RY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 19:00:01',0,NULL,3,1,3,1,NULL,'bule777\rRA117728232CN\r\\'),(2356,522533981003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','johnniejldjr98','jldjr98@yahoo.com','JOHNNIE DAVIS','7837 Carrie St','DETROIT','MI','UNITED STATES','48211-1701','(313) 778-9961','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 19:27:45',0,NULL,3,1,1,1,NULL,'johnniejldjr98\r、'),(2357,698319881011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.8,'eastar4','andre-cz','andrecz@seznam.cz','Bohumil Polák','M. Malého 164','Hradec Králové','Czech republic','CZECH REPUBLIC','503 01','+420602110593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 20:05:00',0,NULL,3,1,2,1,NULL,'andre-cz\rHP 8pin 1.25 18cm \r\\'),(2358,698326550011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTRA002',75.99,'eastar4','biasicabral','biasicabral@gmail.com','Marcelo Biasi Cabral','SHN Quadra 02 Bloco H, S/N - AP 1701<br>Setor Hoteleiro Norte','Brasilia','Distrito Federal','BRAZIL','70702-905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 20:23:03',0,NULL,3,1,3,1,NULL,'biasicabral\rOTRA002\rRA117716322CN\r\\'),(2359,574307062013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','freezed23','pys2314@naver.com','Young Soo Park','Buyeong 6 Danji Apt., Hwasun-eup<br>603-906','Hwasun-gun','Jeollanam-do','KOREA,REPUBLIC OF','519-756','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 20:42:12',0,NULL,3,1,2,1,NULL,'freezed23\r\\'),(2360,775762438012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','rwoo6629','randy@graass.com','Randall Woodum','8926 Pitner','Houston','TX','UNITED STATES','77080','(713) 554-3755','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 20:48:25',0,NULL,3,1,1,1,' ','rwoo6629\r、'),(2361,698348358011,320402069233,'HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR 2.0+cable',1,'BTHP2007',12.5,'eastar4','techconsignments','es.mpyre@gmail.com','TechConsignments','23502 Earlmist Dr','Spring','TX','UNITED STATES','77373-6251','(561) 541-8028','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 21:12:39',0,NULL,3,1,1,1,NULL,'techconsignments\rHP 8pin 1.0 23cm \r、'),(2362,0,320687956849,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','brandon0404','brandonknox4@yahoo.com','Brandon D. Knox','9008 Topperwind Ct','Fort Worth','TX','UNITED STATES','76134-5501','(817) 703-8468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 21:47:09',0,NULL,3,1,1,1,NULL,'brandon0404\r、'),(2363,775787525012,220663959909,'New Intel 512ANX 5150 HMW Half Mini PCI-E WIFI Card',1,'WLIN004',31.98,'eastar4','soulovey','tsv83@mail.ru','Vasili Tsoukanov','Prospekt Vernadskogo, 89-199','Moscow','','RUSSIAN FEDERATION','119526','+7-910-4003142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 21:54:01',0,NULL,3,1,3,1,NULL,'soulovey\rWLIN004\rRA117728348CN\r\\'),(2364,698364032011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','bergkamp2','bergkamp1414@hotmail.com','Je Hyun Park','550 S Camino Seco<br>Apt 2206','Tucson','AZ','UNITED STATES','85710-4061','(520) 334-9243','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 21:59:45',0,NULL,3,1,1,1,NULL,'bergkamp2\r、'),(2365,775795590012,220713846376,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+carcharger',1,'HSNO016+CCNO001',13.9,'eastar4uk','mmaounn','info@autostern.at','Mohammed Aoun','Erzherzog-Karlstrasse 33-3-21','Wien, AUSTRIA','','AUSTRIA','1220','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 22:17:28',0,NULL,3,1,2,1,NULL,'mmaounn\r、'),(2366,775808848012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','rgie1851','giese@versacall.com','Robert Giese','14031 Recuerdo Dr.','Del Mar','CA','UNITED STATES','92014','(858) 677-6766 ext.: 100','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 22:59:22',0,NULL,3,1,1,1,NULL,'rgie1851\r、'),(2367,698385164011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','hoangtrunghieu','hoang8@marshall.edu','Hieu Hoang','209 19TH ST<br>Apt 2','huntington','WV','UNITED STATES','25703-1144','(304) 972-1987','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 23:11:35',0,NULL,3,1,1,1,NULL,'hoangtrunghieu\r、'),(2368,574346910013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',9.8,'eastar4','vasupplies','vasupplies@hotmail.com','Rolando Barbosa','5300 NW 33rd Ave<br>Ste 218','Fort Lauderdale','FL','UNITED STATES','33309-6356','(954) 485-3900','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 23:31:17',0,NULL,3,1,1,1,NULL,'vasupplies\r、'),(2369,574347344013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',3,'HSPL005',40.5,'eastar4','kirolos_emad2003','kirolos_emad2003@yahoo.com','emad ghobiral','1960 srobertson blvd #4','los angeles','CA','UNITED STATES','90034','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 23:33:32',0,NULL,3,1,1,1,NULL,'kirolos_emad2003\r、'),(2370,698405156011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',18.9,'eastar4','atillat2007','atitaskan@aol.com','Atilla Taskan','20 Beachside court','Victoria Point','Queensland','AUSTRALIA','4165','0732078617','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 00:33:29',0,NULL,3,1,2,1,NULL,'atillat2007\r澳标\\'),(2371,775837085012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','andesigns','anhayes27@gmail.com','Mulberry Cottage/Ashley Hayes','46 main st','Nashville','IN','UNITED STATES','47448','(812) 325-3824','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 00:46:51',0,NULL,3,1,1,1,NULL,'andesigns\r、'),(2372,528351341004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',3,'HSPL010',74.97,'cnfaner','scarlettsewing','scarlettsm0m@aol.com','Dana Hallock','537 Silver Canyon Way','Brea','CA','UNITED STATES','92821','(714) 671-2067','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 00:50:34',0,NULL,3,1,1,1,NULL,'scarlettsewing\r、'),(2373,698419288011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','2131morgan','mdminor@sympatico.ca','Morgan Minor','229 Sugarloaf Street','Port Colborne','ON','CANADA','L3K 2N9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 01:29:54',0,NULL,3,1,2,1,NULL,'2131morgan\r\\'),(2374,574376101013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','ibgoodok','ibgoodok@yahoo.com','John Dicks','1018 Huggins Bottom Rd','Guys','TN','UNITED STATES','38339','(731) 645-0907','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 02:09:44',0,NULL,3,1,1,1,NULL,'ibgoodok\rHP 8pin 1.0 23cm \r、'),(2375,663058265001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','princarl4','tprince68028@yahoo.com','Tricia Prince','10701 S 210th St','Gretna','NE','UNITED STATES','68028-3956','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 02:30:12',0,NULL,3,1,1,1,NULL,'princarl4\rLK042164075CN \r、'),(2376,775867998012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','vangofar','kadams1015@hotmail.com','KENNETH ADAMS','1027 Mabry Mill Rd','HOUSTON','TX','UNITED STATES','77062','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 02:30:55',0,NULL,3,1,1,1,NULL,'vangofar\r、'),(2377,698442241011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','m3t4lh34d_6','kyleswentowsky@hotmail.com','Kyle Swentowsky','8231 Phasis Ct','Elverta','CA','UNITED STATES','95626-9697','(916) 991-1888','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ','m3t4lh34d_6'),(2378,573718729013,230576095186,'Logitech MX518 MX 518 Gaming Optical USB Mouse 90% new',1,'MOLO003',32.9,'eastar4','eatsumcheese','amaznw@gmail.com','Nathan Waxman','4142 Verona Rd','South Euclid','OH','UNITED STATES','44121-3110','(216) 688-6568','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 03:25:40',0,NULL,3,1,1,1,NULL,'eatsumcheese\r、'),(2379,574394806013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','meka80hood','shood1980@yahoo.com','Shameka Hood','2242 Avalon Trce','Winder','GA','UNITED STATES','30680-7810','(678) 963-2747','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 03:51:51',0,NULL,3,1,1,1,NULL,'meka80hood\r、'),(2380,574396469013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','arendsii','yanyanw@gmail.com','Yan Yan Wang','2335 Branner Dr','Menlo Park','CA','UNITED STATES','94025','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 03:56:26',0,NULL,3,1,1,1,NULL,'arendsii\r、'),(2381,574322869013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','robbie5354','robert.may1984@yahoo.com.au','Robert Mayne','20 Langley Street','Warrnambool','Victoria','AUSTRALIA','3280','0355005254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 03:58:32',0,NULL,3,1,2,1,NULL,'robbie5354\r\\'),(2382,775889108012,220759964705,'Logitech MX1000 Mouse special bluetooth  version',1,'MOLO005',59.9,'eastar4','jackrbmac','jdmcdowell@verizon.net','John McDowell','28504 Robinview Ln','Rancho Palos Verdes','CA','UNITED STATES','90275-5043','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 04:05:22',0,NULL,3,1,1,1,NULL,'jackrbmac\r蓝牙版的\r、'),(2383,528386264004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','akvara','akvara@gmail.com','Andrius Kvaraciejus','Paribio 28-37','Vilnius','','LITHUANIA','LT08103','(370) 685 55031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 04:27:59',0,NULL,3,1,3,1,NULL,'akvara\r欧标  \rHSNO005\rRA117728303CN\r\\'),(2384,698458964011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','maxzx123','maxzx@bk.ru','Maxim Mukhin','1-st Kommunisticheckaya, 37-47','Domodedovo','','RUSSIAN FEDERATION','142000','+79263740458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 04:36:38',0,NULL,3,1,2,1,NULL,'maxzx123\r、'),(2385,775657769012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',12.5,'eastar4','avedana01','olsan@gmx.de','Olaf Sandelmann','Richard-Münch-Str. 7','Berlin','','GERMANY','13591','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 06:06:27',0,NULL,3,1,2,1,NULL,'avedana01\racer 4pin1.25 8cm\r、'),(2386,574417712013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','visionmax333','corey@baudinette.com','Corey Baudinette','2/297 Wellington St','Collingwood','Victoria','AUSTRALIA','3066','0412345246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 06:45:36',0,NULL,3,1,3,1,NULL,'visionmax333\rMOSA002\rRA022493744CN\r、'),(2387,775919470012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',4,'OTSO002',303.6,'eastar4','banaszysko','piotr@progress.com.pl','Piotr Banach','Al. Mickiewicza 27','Kraków','małopolskie','POLAND','31120','662 035272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 06:49:44',0,NULL,3,1,12,1,NULL,'banaszysko\r潘\\'),(2388,698488976011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','ablindman','kirbymaster6@gmail.com','George Turba','601 W 10th St<br>202 Mcanerney Hall','Rolla','MO','UNITED STATES','65401-2966','(815) 630-0173','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 07:31:33',0,NULL,3,1,1,1,NULL,'ablindman\r、'),(2389,574429564013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',2,'MOSA001',143.6,'eastar4','quellenfeuer','quellenfeuer@gmx.de','Stephan Boes','Passauer Str. 48','Wegscheid','','GERMANY','94110','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 08:11:37',0,NULL,3,1,3,1,NULL,'quellenfeuer\rMOSA001\r\rRA117716543CN\r\\'),(2390,698516540011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','arnisg123','arnis@specialsolutions.lv','Arnis Glaznieks','Volguntes 38-2','Riga','Vidzeme','LATVIA','LV1046','+37126517859','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 09:46:26',0,NULL,3,1,2,1,NULL,'arnisg123\r、'),(2391,775963068012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','grlgf','graham_langford@btinternet.com','Graham Langford','69 Grove Rd','Harpenden','Hertfordshire','UNITED KINGDOM','AL5 1EN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 10:10:35',0,NULL,3,1,3,1,NULL,'grlgf\rOTRA002\rRA117716398CN\r\\'),(2392,574449301013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','miker1804','michael.rogovin@gmail.com','Michael Rogovin','5 Ha’Solelim Street','Tel Aviv','','ISRAEL','67897','052-6402514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 10:25:19',0,NULL,3,1,2,1,NULL,'miker1804\r\\'),(2393,775968300012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',3,'WLDL001',17.25,'eastar4uk','philo69us','philwells@screaming.net','philip wells','11 south rise<br>north walsham','norwich','Norfolk','UNITED KINGDOM','nr280ee','01692409877','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 10:34:10',0,NULL,3,1,3,1,NULL,'philo69us\rWLDL001\rRA117716438CN\r\\'),(2394,698530088011,320645703558,'New DELL D630 D830 BCM4321 WiFi Mini PCI-E Card+antenna',1,'WLDE001+ANTY001',20,'eastar4','dodgly','ebay@lyledodge.com','Lyle E. Dodge','1000 SE Everett Mall Way<br>Suite 301','Everett','WA','UNITED STATES','98208-2814','(425) 355-7223 ext.: 119','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-21 10:47:05',0,NULL,3,1,1,1,NULL,'dodgly\r\\'),(2395,528435131004,140427917560,'2.1 Acer Aspire 7738G bluetooth module we offer track#',1,'BTAC2104',13.99,'cnfaner','magdavlad1987','magdavlad@yahoo.gr','Magdalini Vladeni','Papadiamanti 3','Thessaloniki','Thessaloniki','GREECE','55133','6973640704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 10:52:12',0,NULL,3,1,3,1,NULL,'magdavlad1987\rBTAC2104\racer 4pin1.25 6cm\rRA117716441CN\r\\'),(2396,698533418011,320679610517,'New GENUINE NOKIA BH-106 BLUETOOTH HEADSET',2,'HSNO004',26.7,'eastar4uk','sotnats2682','snatsios@yahoo.gr','sotiris natsios','kuprou 64 A','Preveza','Preveza','GREECE','48100','2682046209','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 10:59:57',0,NULL,3,1,3,1,NULL,'sotnats2682\rHSNO004\r欧标\rRA117716490CN\r\\'),(2397,775980986012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','curtb','curtbebay@embarqmail.com','Curt Boyles','1231 Whitewood Way','Clermont','FL','UNITED STATES','34714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 11:24:39',0,NULL,3,1,1,1,NULL,'curtb\r\\'),(2398,528442432004,140516076074,'Logitech MX518 MX 518 Gaming Optical USB Mouse track#',1,'MOLO003',32.9,'cnfaner','manal0_0','regnarga001@hotmail.com','AlainGranger','950 Samoisette','St-Jean sur Richelieu','QC','CANADA','J3B2J4','(450) 348-4403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 11:41:45',0,NULL,3,1,3,1,NULL,'manal0_0\rMOLO003\rRA117716375CN\r\\'),(2399,775986248012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','cozpyro','colinnolan1975@hotmail.com','Colin Nolan','12 Lower Hatch Street','Dublin 2','Dublin','IRELAND','D2','0872705866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 11:43:45',0,NULL,3,1,3,1,NULL,'cozpyro\rHSSH002\rRA117716455CN\r\\'),(2400,528443560004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','andrey1771','auto4u2005@yahoo.com','Andrey Prokhorov','1707 Scotchbrook Dr<br># A','Philadelphia','PA','UNITED STATES','19115-4286','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 11:47:19',0,NULL,3,1,1,1,NULL,'andrey1771\r\\'),(2401,574465655013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','claus_74','claus.herholz@gmx.de','Claus Herholz','G-v-Mevissen-Str. 108','Siegen','','GERMANY','57072','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 11:58:44',0,NULL,3,1,2,1,NULL,'claus_74\r\\'),(2402,774847302012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.05,'eastar4','cisco_racks','marca_alexander@yahoo.com','Marc Alexander','5980 Folkstone Ln','Orlando','FL','UNITED STATES','32822-9423','(407) 489-4672','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 13:28:52',0,NULL,3,1,1,1,NULL,'cisco_racks\r\\'),(2403,776018808012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','jakeyboi19942010','jakey-boi1994@live.co.uk','Jake king','2 Hathaway court<br>rainham','Gillingham','Kent','UNITED KINGDOM','me8 0es','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 13:40:21',0,NULL,3,1,3,1,NULL,'jakeyboi19942010\rWLDL001\rRA117716367CN\r\\'),(2404,0,230611726649,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','tylerssmile','lara20226@gmail.com','Lara M Ocasio','2695 Cedar Ct','OCEANSIDE','NY','UNITED STATES','11572','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-21 13:57:50',0,NULL,3,1,1,1,NULL,'tylerssmile\r\\'),(2405,776029593012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','booooster2009','h.kl@live.com','hafez alam','8 hilbre walk','reading','Berkshire','UNITED KINGDOM','rg2 0gd','07966675244','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 14:14:29',0,NULL,3,1,3,1,NULL,'booooster2009\r英标\rHSPL011\rRA117716384CN\r\\'),(2406,698587638011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','karhotom','karhotom@gmail.com','Kar Ho Tom','4075 rue Laubia','Brossard','QC','CANADA','J4Y 0H3','(514) 884-3088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 14:26:20',0,NULL,3,1,2,1,NULL,'karhotom\r\\'),(2407,574500437013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','jplasater','jklasater@centurytel.net','John Lasater','22707 W Spring Harbor Rd','Siloam Springs','AR','UNITED STATES','72761','(479) 549-7271','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 14:53:59',0,NULL,3,1,1,1,NULL,'jplasater\r\\'),(2408,698603377011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',43.9,'eastar4','mario_murillo2002','mario_murillo2002@yahoo.com','mario murillo','625 w market st','salinas','CA','UNITED STATES','93901','(831) 229-5621','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 15:17:49',0,NULL,3,1,1,1,NULL,'mario_murillo2002\r\\'),(2409,698606546011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',24.59,'eastar4uk','valbuena_62','myaudi@hotmail.fr','Antoine Rault','25 rue des Haguettes<br>Raventhun','Ambleteuse','Nord-Pas-de-Calais','FRANCE','62164','03.21.32.60.04','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 15:29:50',0,NULL,3,1,3,1,NULL,'valbuena_62\rUDAP001\rRA117716424CN\r\\'),(2410,698610069011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','gmaragoudlfc','gmaragoud@gmail.com','George Maragoudakis','K.Gerakari 8','Rethymno','Creta','GREECE','74100','283-107-2962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 15:38:43',0,NULL,3,1,2,1,NULL,'gmaragoudlfc\r、'),(2411,574469827013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.99,'eastar4','vstaran','vtipok89@gmail.com','Victor Staranchuk','ul. Vishneva 135 kv. 123','Khmelnytsky','','UKRAINE','29025','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 15:53:10',0,NULL,3,1,2,1,NULL,'vstaran\r\\'),(2412,0,320687522885,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',10.99,'eastar4','lilfelacamacho440','davidcamachojr61@gmail.com','david camacho','7810 ackley rd','cleveland','OH','UNITED STATES','44129-4910','(216) 324-7218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 16:10:40',0,NULL,3,1,1,1,NULL,'lilfelacamacho440\r\\'),(2413,776098633012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','jozsef1957','787779@gmail.com','Jozsef Banhidi','Szent Korona utca 198','Budapest','','HUNGARY','1162','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 17:28:50',0,NULL,3,1,2,1,NULL,'jozsef1957\r\\'),(2414,698661367011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','agent_leprechaun','rom.velasquez@gmail.com','Romulo Velasquez','220 Keele St.','Toronto','ON','CANADA','M6P 2K2','(647) 205-5508','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 18:01:14',0,NULL,3,1,2,1,NULL,'agent_leprechaun\r\\'),(2415,528529848004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',2,'HSPL011',46,'cnfaner','gd_n','gd_n2@yahoo.com','Georgi Nalbantov','Slavianska 85','Plovdiv','Plovdiv','BULGARIA','4000','+359878440198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 18:31:21',0,NULL,3,1,3,1,NULL,'gd_n\rHSPL011\r欧标\rRA117716472CN\r\\'),(2416,528536059004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','bodewallace','wallacejose@gmail.com','Wallace Santos','Rua Quirino nº 830, Condominio Vila Oriente, Bloco 13, Ap.102<br>Bairro: Inacio Barbosa - Atras do Rei dos Colchoes','Aracaju','Sergipe','BRAZIL','49040-700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 18:52:32',0,NULL,3,1,3,1,NULL,'bodewallace\rHSNO022\rRA117716415CN\r\\'),(2417,0,230611726304,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',17.89,'eastar4','richengel','richengel@snet.net','Richard L. Engelhardt','770 Saybrook Rd','Middletown','CT','UNITED STATES','06457','(860) 343-6644','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 19:13:42',0,NULL,3,1,1,1,NULL,'richengel\r再发一个 8V AC Adapter Charger Power Supply Logitech Harmony 880 \r\\\r '),(2418,574580228013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','hgfazel','hfazel@hotmail.com','Hesham Fazel','11 Whalers Cove','Winnipeg','MB','CANADA','R3T 5H1','(204) 509-9917','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 19:37:43',0,NULL,3,1,2,1,NULL,'hgfazel\r\\'),(2419,574588984013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','cjones985charles','safetyfrist20@yahoo.com','charles jones','3001 Essex Ave','La Place','LA','UNITED STATES','70068-2244','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 20:07:54',0,NULL,3,1,1,1,NULL,'cjones985charles\r、'),(2420,698724962011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','julien245','jgandoulas@gmail.com','julien gandoulas','11, Grande rue St Michel, apt. 42','Toulouse','Midi-Pyrénées','FRANCE','31400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 20:31:02',0,NULL,3,1,2,1,NULL,'julien245\r\\'),(2421,574601442013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','kriszta0806','korosi.dudas@gmail.com','Krisztina Kőrösi Dudás','Hiúz utca 5 1/6.','Szeged','','HUNGARY','6725','+36209346445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 20:48:44',0,NULL,3,1,2,1,NULL,'kriszta0806\r\\'),(2422,574615403013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','el_dib','lechac@free.fr','CHALABI Habib','19 place du Salin','Toulouse','Midi-Pyrénées','FRANCE','31000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 21:42:31',0,NULL,3,1,2,1,NULL,'el_dib\r\\'),(2423,574619527013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',29.8,'eastar4','rokbosina2010','rokbosina@yahoo.com','rok bosina','veliki obrež 2b<br>8257','dobova','dobova','SLOVENIA','8257','0038640500008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 22:02:08',0,NULL,3,1,2,1,NULL,'rokbosina2010\r一共买了两个\r欧标\r\\'),(2424,776218537012,220759518349,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12,'eastar4uk','mr.ht','hmeehan2@comcast.net','Harold Meehan','106 Harvest Hills Dr','North Bennington','VT','UNITED STATES','05257','(802) 442-6350','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 22:27:08',0,NULL,3,1,1,1,NULL,'mr.ht\r\\'),(2425,776241664012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',14.9,'eastar4uk','cdibenga','chris@dibenga.com','Chris di Benga','XL Windows<br>9 Dunlop Road','Hadleigh Rd Ind Estate','Ipswich','UNITED KINGDOM','IP2 0UG','01473253595','NoPaymentFailure','CheckoutIncomplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117718941CN\r\\ ','cdibenga\rOTHP003'),(2426,0,220772223307,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','derekefarmer11','derekefarmer@gmail.com','Derek Farmer','2485 Chestnut St','Hanford','CA','UNITED STATES','93230-1212','(559) 917-3581','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 00:36:47',0,NULL,3,1,1,1,NULL,'derekefarmer11\r\\'),(2427,776264287012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','sff1559x','vicang1987@hotmail.com','Christopher Phang Jun Rong','Blk 423 Choa Chu Kang Ave 4 #07-244','default','','SINGAPORE','680423','+65 91814836','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 00:50:22',0,NULL,3,1,11,1,NULL,'sff1559x\rHSPL011\r英标\r\\'),(2428,776267284012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',104,'eastar4','thongngom','thongngom2001@yahoo.com','Udom Thongngom','6/15 Deering ST','Westminster','Western Australia','AUSTRALIA','6061','0417931410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 01:00:55',0,NULL,3,1,3,1,NULL,'thongngom\rOTIN005\rRA117716469CN\r\\'),(2429,528621784004,140516092415,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'cnfaner','jimi403','jmartens70@shaw.ca','Jim Martens','331 Falshire Drive N.E.','Calgary','AB','CANADA','T3J 1T8','(403) 827-4528','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 01:24:02',0,NULL,3,1,3,1,NULL,'jimi403\rBALO001\rRA117716509CN\r\\'),(2430,776275667012,220769590609,'New Atheros AR9287 Wireless PCI-E Half Card+antenna',2,'WLAT007+ANTY001',33.9,'eastar4','mixrgb','prinipio@hanmail.net','Park Gyeong-Hwan','304Ho 101Dong Daerim 1Danji Apt.<br>Yangji-ri Onam-eup','Namyangju-si','Gyeonggi-do','KOREA,REPUBLIC OF','472-940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 01:31:34',0,NULL,3,1,3,1,NULL,'mixrgb\r+011-9038-1171\rWLAT007+ANTY001\rRA117716486CN\r\\'),(2431,776277304012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','cspencer_2k5','cspencer@slingshot.co.nz','Cassandra Spencer','16 Camp Road<br>Mt Wellington','Auckland','','NEW ZEALAND','1006','6492767808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 01:36:25',0,NULL,3,1,2,1,NULL,'cspencer_2k5\r\\'),(2432,663410217001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','entertainmentpls','entertainmentpls@comcast.net','chris fuller','17840 146th Ave NE','woodinville','WA','UNITED STATES','98072-6228','(206) 227-3918','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 01:42:11',0,NULL,3,1,1,1,NULL,'entertainmentpls\rLK042393056CN\r\\'),(2433,698587138011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','care20061','pirelli2006@yandex.ru','Pavel Gushchin','bakalinskaya 66 str. app. 65','Ufa','Bashkortostan','RUSSIAN FEDERATION','450022','89196020001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 02:13:57',0,NULL,3,1,2,1,NULL,'care20061\r\\'),(2434,776296042012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',12.5,'eastar4','marlers2010','raikou2222000@yahoo.com','Justin Marler','12 1/2 Harper St','The Plains','OH','UNITED STATES','45780-1042','(573) 330-3138','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 02:47:48',0,NULL,3,1,1,1,NULL,'marlers2010\racer 6pin1.25 23cm\r\\'),(2435,528631148004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','martin9061','lmhastings@sbcglobal.net','Martin Piekos','8222 W Oakton St','Niles','IL','UNITED STATES','60714-2723','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 03:40:54',0,NULL,3,1,1,1,NULL,'martin9061\r、'),(2436,698847458011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','michelleschembri','mattschembri@gmail.com','Matthew Schembri','403 peel st nth','black hill','Victoria','AUSTRALIA','3350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 04:30:14',0,NULL,3,1,2,1,NULL,'michelleschembri\r、'),(2437,574697009013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','theninja2000','dave.millican@gmail.com','David Millican','Anixter Components, Unit A Nimrod Way<br>East Dorset Trade Park','Wimborne','Dorset','UNITED KINGDOM','BH21 7HY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 05:02:06',0,NULL,3,1,2,1,NULL,'theninja2000\r\\'),(2438,776338335012,220502334252,'2.1 HP ProBook 4510S 4515S 4710S Bluetooth Module cable',1,'BTHP2104',12.8,'eastar4','ma63niek','ma63niek@poczta.onet.pl','Arkadiusz Borodeńko','Okólna 35/42','Konin','wielkopolskie','POLAND','62510','601 966960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 06:21:01',0,NULL,3,1,2,1,NULL,'ma63niek\rHP 8pin 1.0 18cm 4线连 \r、'),(2439,776339764012,220705174904,'New Genuine Motorola H555 Bluetooth Wireless Headset',1,'HSMO008',8.99,'eastar4uk','grigorakiandroniki','niki.grigor@gmail.com','Androniki Grigoraki','Karaiskaki 46<br>N Alikarnasos','Heraklion','Crete','GREECE','71601','+30.6974398406','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 06:27:58',0,NULL,3,1,2,1,NULL,'grigorakiandroniki\r欧标\r、'),(2440,776346444012,220748684477,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',2.99,'eastar4uk','jgcarpenter7oq1','jgcarpenter@comcast.net','DEBORAH CARPENTER','1171 Lions Dr','BURNS HARBOR','IN','UNITED STATES','46304','(219) 787-1040 ext.: 129','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 07:04:32',0,NULL,3,1,1,1,NULL,'jgcarpenter7oq1\r、'),(2441,776346218012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','fk100','frank.kretz@web.de','Frank Kretz','Im Etzel 21','Bexbach','','GERMANY','66450','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 07:08:10',0,NULL,3,1,2,1,NULL,'fk100\r欧标\r、'),(2442,698882806011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ramon314','ramon314@skynet.be','Raphaël Montulet','Rue des Alliés n° 1','Grâce-Hollogne','','BELGIUM','4460','0487110665','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 07:48:52',0,NULL,3,1,2,1,NULL,'ramon314\r\\'),(2443,698902165011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',2,'HSUE003',56.98,'eastar4','cobusvwielligh','cobi_vw@hotmail.com','Cobus von Wielligh','20 Protea Street','Paarl','Western Cape','SOUTH AFRICA','7646','0218723036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 09:16:47',0,NULL,3,1,3,1,' RA117716530CN\r','cobusvwielligh\rHSUE003'),(2444,698906659011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.9,'eastar4uk','jollylands','jholland@telecomconsult.net','John Holland','Ericsson Main building<br>Clonskeagh','Dublin','Dublin','IRELAND','D18','0868331908','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 09:29:56',0,NULL,3,1,3,1,' RA117718062CN\r','jollylands\rWLAP002'),(2445,574735622013,230495606381,'New in box NOKIA HS-11W BLUETOOTH HEADSET HS 11W',1,'HSNO024',17.7,'eastar4','mustafa_veysalov_1986','mustafa_veysalov@yahoo.com','Mustafa Veysalov','city Khirdalan, home 9, flat 33, district 27<br>Azerbaijan','Baku','Azerbaijan','AZERBAIJAN','0100','0123422035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 09:34:28',0,NULL,3,1,2,1,NULL,'mustafa_veysalov_1986\r\\'),(2446,698953761011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',23.9,'eastar4','john2_k','kimidis@hol.gr','john kimidis','mitropolitou nikolaou 13','Chalkida','προεπιλογή','GREECE','34100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 12:35:03',0,NULL,3,1,2,1,' ','john2_k   是大个大remote 新产品\r\\'),(2447,776441717012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','avianamerican','talkylot@hotmail.com','Rebecca Wells','14 Shammall Court, Greenwith','Adelaide','South Australia','AUSTRALIA','5125','0882898894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 13:04:32',0,NULL,3,1,2,1,NULL,'avianamerican\r\\\r'),(2448,698967724011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','albserfid','alsefi@bigfoot.com','Alberto SERRADILLA FIDALGO','Av.Camino de Santiago 7, B, 4, D','Madrid','Madrid','SPAIN','28050','607750488','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 13:24:20',0,NULL,3,1,3,1,' RA117718102CN\r','albserfid\rUDAP001'),(2449,776457613012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',4,'HSPL010',95.6,'eastar4','prettydog37072','larrywreese@bellsouth.net','Larry Reese','540 Utley Dr','Goodlettsville','TN','UNITED STATES','37072','(615) 859-8846','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 13:52:52',0,NULL,3,1,1,1,NULL,'prettydog37072\r、'),(2450,776031275012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',2,'HSMO018',23.98,'eastar4','yoonking08','aceykc08@gmail.com','YK Choong','217-D, Jalan Kenanga 3/31,<br>Taman Kenanga Sek 3,','Melaka','Melaka','MALAYSIA','75200','0126802918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 14:35:29',0,NULL,3,1,2,1,NULL,'yoonking08\r\\'),(2451,698986724011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTRA002',75.99,'eastar4','nielsenalmeida','nielsenalmeida@gmail.com','Nielsen Almeida','Rua Dr. Fernando Bustamant, 289 - Centro','Açu','RN','BRAZIL','59650-000','+55 (84) 8116-1616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 14:38:08',0,NULL,3,0,3,1,' RA117718031CN\r','nielsenalmeida\rOTSO001'),(2452,776478356012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',6,'TRMX003',50.1,'eastar4','kulisra','gunpai@multisys.co.th','Attn:Gunpai Chiramanaphan','MultiSys Computer and Network Co.,Ltd.<br>13 Soi Soonvijai 14, Newpetchburi Road, Bangkapi, Huaykwang,','Bangkok','','THAILAND','10320','662 318 1390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 14:55:16',0,NULL,3,1,3,1,' RA117718204CN\r','kulisra\rTRMX003\rMX20T'),(2453,574829710013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',6,'OMHJ001',83.94,'eastar4','krlhrtmn1','karilou58@yahoo.com','Kari Hartman','719 E Pearl St','Lanark','IL','UNITED STATES','61046-1330','(815) 493-2827','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-22 16:48:40',0,NULL,3,1,1,1,NULL,'krlhrtmn1\r、'),(2454,574831837013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','philipp845','philipp_erber@yahoo.de','Philipp Erber','Mollardgasse /16 Zi.301','Wien','','AUSTRIA','1060','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:56:43',0,NULL,3,1,2,1,NULL,'philipp845\r\\'),(2455,699066384011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','plasticheaven','plastic@s180100082.websitehome.co.uk','Chris Hampele','80 Frances Road','Windsor','Berkshire','UNITED KINGDOM','SL4 3AJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 18:03:56',0,NULL,3,1,2,1,' ','plasticheaven\r\\'),(2456,0,230612114645,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','valerier2009','kanyinglin@yahoo.com','Bobby Carter','1255 Pennsylvania Ave<br>Apt 14E','Brooklyn','NY','UNITED STATES','11239-1101','(917) 499-6735','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 18:57:56',0,NULL,3,1,1,1,NULL,'valerier2009\r、'),(2457,0,320688404833,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','chargersbasketball3','chargersbasketball7@yahoo.com','brian teiell','2006 crazy horse','stillwater','OK','UNITED STATES','74075-6159','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 19:52:57',0,NULL,3,1,1,1,NULL,'chargersbasketball3\r、'),(2458,776620492012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',14.9,'eastar4uk','itbracknell','simon@sodit.net','Simon Simpson','20 Staveley Grove','Keighley','West Yorkshire','UNITED KINGDOM','BD227DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-22 20:22:20',0,NULL,3,1,3,1,' RA117718028CN\r','itbracknell\rOTHP003'),(2459,528849451004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','misiom1','misioallegro@gmail.com','Michał Mroczkowski','Dobrowolskiego 1c/12','Gdańsk','pomorskie','POLAND','80287','696 449750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 21:14:24',0,NULL,3,0,3,1,'RA117718425CN\r ','misiom1\r把8781改换成\r8780\rBTAC2104+WWSI004\r再发一个2.1 Acer Aspire 7738G bluetooth module acer 4pin1.25 6cm\r'),(2460,528850566004,140427917560,'2.1 Acer Aspire 7738G bluetooth module we offer track#',1,'BTAC2104',13.99,'cnfaner','misiom1','misioallegro@gmail.com','Michał Mroczkowski','Dobrowolskiego 1c/12','Gdańsk','pomorskie','POLAND','80287','696 449750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 21:18:55',0,NULL,8,1,17,0,NULL,'misiom1'),(2461,776660203012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.8,'eastar4','digo_pe','pedrosa.rodrigo@gmail.com','RODRIGO PEDROSA','RUA OUREM N.227 BL.C AP.604','RECIFE','PERNAMBUCO','BRAZIL','50761340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 22:12:31',0,NULL,3,1,2,1,NULL,'digo_pe\rAcer 5pin1.25 3cm\r\\'),(2462,776660098012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','fearshogun','sharpprecision@hotmail.com','Francis Bernard Kwegyir-Afful','16 Marden House<br>Bodney Road','Hackney','London','UNITED KINGDOM','E8 1AZ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 22:14:58',0,NULL,3,1,2,1,NULL,'fearshogun\r英标\r\\'),(2463,574941319013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','itso1970','itso@t-2.net','Hristo Grancharov','Naselje J. Kerencica 30','Murska Sobota','','SLOVENIA','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 23:36:41',0,NULL,3,1,2,1,NULL,'itso1970\r\\'),(2464,574942969013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','aura222222','aura222222@naver.com','Hunjoo Lee (tel 010-3056-6560)','Hansol Central Park 2 CHA 1706 HO<br>Gwanyang-dong ,Dongan-gu,','Anyang-si,','Gyeonggi-do, South Korea (Republic of Korea)','KOREA,REPUBLIC OF','431-060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 23:45:22',0,NULL,3,1,2,1,NULL,'aura222222\r\\'),(2465,523145000003,130466041700,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',48.98,'cnfaner','vinodmadadi','vinodmadadi@yahoo.com','Vinod R. Madadi','31 Weller Pl','Holmdel','NJ','UNITED STATES','07733-3119','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 23:52:55',0,NULL,3,1,1,1,NULL,'vinodmadadi\r、'),(2466,776718338012,220529927797,'Logitech Harmony Remote USB Cable 670 680 628 xbox 360',1,'CALO001',3.87,'eastar4','b1indsquirre1','mbosveld@yahoo.com','Michael D Bosveld','11041 Harrison Ave S','Bloomington','MN','UNITED STATES','55437','(952) 884-0982','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 01:56:37',0,NULL,3,1,1,1,NULL,'b1indsquirre1\r、'),(2467,776728616012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','marlheykdt','marlheygsi@yahoo.com.br','marlhey barros','rua graciano neves ,99(ap.901)<br>Centro','vitoria','Espirito Santo','BRAZIL','29015-330','55 27 99916166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 02:33:24',0,NULL,3,1,2,1,NULL,'marlheykdt\r\\'),(2468,574974762013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','nemunasmano','zitas@clear.net','Zita Sabaliauskiene','2317 Beverly Way','Las Vegas','NV','UNITED STATES','89104-2763','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 02:50:22',0,NULL,3,1,1,1,NULL,'nemunasmano\rHP 8pin 1.0 23cm\r、'),(2469,523175123003,130490963329,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'cnfaner','alex_dav','surgutalex@gmail.com','Dmitrieva Marianna','per. Nahimova 14/1 - 55','Tomsk','','RUSSIAN FEDERATION','634012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 03:12:59',0,NULL,3,1,3,1,' RA117718093CN\r','alex_dav\rWLIN010'),(2470,574988097013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','sung.kim.73','shk773@hotmail.com','Sung Kim','8 Essex St','Lexington','MA','UNITED STATES','02421','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 04:26:48',0,NULL,3,1,1,1,NULL,'sung.kim.73\r、'),(2471,523186417003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','dr_lliam','lliam.bicsak@gmail.com','LLiam J.T. Bicsak','1090 25th St<br>Apt 1','Des Moines','IA','UNITED STATES','50311-4274','(440) 714-2862','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-04-23 04:45:41',0,NULL,3,1,1,1,NULL,'dr_lliam\r、'),(2472,776763955012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',2,'BALO001',16.98,'eastar4','titus123ka','titus-ka1@t-online.de','Dietmar Sieg','Kleinabenberg A11','Abenberg','','GERMANY','91183','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 05:38:06',0,NULL,3,1,2,1,NULL,'titus123ka\r\\'),(2473,699258890011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTRA002',75.99,'eastar4','mikenmary1955','magar@bigpond.net.au','Michael Agar','2 palpera Terrace','Greensborough','Victoria','AUSTRALIA','3088','0394345811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 05:38:39',0,NULL,3,0,3,1,' RA117718080CN\r','mikenmary1955\rOTSO001'),(2474,776782882012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','itaymedstud84','itay.aspis@gmail.com','Itay Aspis','24 Alexandroni st.','Ramat Gan','','ISRAEL','52225','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 07:17:25',0,NULL,3,1,3,1,' RA117718116CN\r','itaymedstud84\rHSSH002'),(2475,699285145011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','nilak_bg','nilak@agencyprintsoft.com','Kalin Kalinkov','51, Oborishte str.','Sofia','Bulgaria / Sofia-grad','BULGARIA','1504','359878682049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 07:59:51',0,NULL,3,1,2,1,NULL,'nilak_bg\r\\'),(2476,699311613011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','hoppy100hp','hoppy@clysbarton.freeserve.co.uk','Mike Hopwood','13 Clysbarton Court','stockport','Cheshire','UNITED KINGDOM','SK73NP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 09:58:28',0,NULL,3,1,2,1,NULL,'hoppy100hp\r\\'),(2477,699313226011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTRA002',75.99,'eastar4','alexander.webster','alexander.webster@gmail.com','Alex Webster','c/o SMEC<br>Level 1, 154 Melbourne St','South Brisbane','Queensland','AUSTRALIA','4101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 10:05:23',0,NULL,3,0,3,1,' RA117716565CN\r','alexander.webster\rOTSO001\r'),(2478,575035571013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'eastar4','sqas4','anze.tomic@gmail.com','Anze Tomic','trnovski pristan 10','Ljubljana','','SLOVENIA','1000','+38641334205','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 10:13:59',0,NULL,3,1,2,1,NULL,'sqas4\r\\'),(2479,699333241011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tschemex','stefan.tschemernig@gmx.net','Stefan Tschemernig','Rot-Kreuzstrasse 4','Sankt Veit an der Glan','','AUSTRIA','9300','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 11:29:22',0,NULL,3,1,2,1,NULL,'tschemex\r\\'),(2480,575052477013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','miki--1987','mikolasl@seznam.cz','Mikolas Lebeda','Ckalovova 879/11','Ostrava','Czech Republic','CZECH REPUBLIC','70800','+420775087967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 11:54:55',0,NULL,3,1,2,1,NULL,'miki--1987\r银色的 欧标\r\\'),(2481,663913376001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','hamiltj16','a-and-j-hamilton@hotmail.com','Janet Hamilton','17 Larner St.','St. John\'s','NL','CANADA','A1A 5S9','(709) 754-3345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 12:55:31',0,NULL,3,1,3,1,' RA117716574CN\r','hamiltj16\rOTSO001'),(2482,575074287013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','co.2.fire','sparky.co1@me.com','Brian Dispenza','1046 Jedburg Rd','Summerville','SC','UNITED STATES','29483-6908','(843) 817-8547','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 13:40:07',0,NULL,3,1,1,1,NULL,'co.2.fire\r、'),(2483,699375209011,320394905605,'Acer Travelmate 5620 7510 Bluetooth Module2.0 EDR+cable',1,'BTAC2008',12.5,'eastar4','kerekes.robert','djrobbyy@gmail.com','Robert Kerekes','Dózsa György út 17.','Nagyecsed','','HUNGARY','4355','+36709784373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:00:09',0,NULL,3,1,2,1,NULL,'kerekes.robert\racer 4pin1.25 18cm\r\\'),(2484,776896748012,220448689432,'Acer Aspire 4730Z 4930Z Bluetooth Module EDR 2.0+cable',1,'BTAC2019',12.5,'eastar4','dacmarques','dacmarques@gmail.com','Daniel  Marques','Rua Nazaret, 43<br>Santa Lucia','Belo Horizonte','Minas Gerais','BRAZIL','30360-720','553132861885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:22:07',0,NULL,3,1,2,1,NULL,'dacmarques\racer 8pin1.00 6cm \r\\'),(2485,529014040004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'cnfaner','redline_555','great_dog@mail.ru','Petr Senichkin','Sudoremontnikov 52/2','Tuapse','Krasnodarskiy kray','RUSSIAN FEDERATION','352803','+79183711503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:57:44',0,NULL,3,1,3,1,' RA117739204CN\r','redline_555\rANYA001'),(2486,699398538011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',12.8,'eastar4','raponchito','jc.naranjo@terra.es','Jair Naranjo','C/ Leon y Castillo, 128 - Local Comercial','Las Palmas de Gran Canaria','Las Palmas','SPAIN','35004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 15:11:47',0,NULL,3,1,2,1,NULL,'raponchito\racer 8pin1.00 15cm\\\r'),(2487,776927761012,220759518727,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',24.9,'eastar4uk','jakeruthers','jake_ruthers@live.co.uk','Jake Rutherford','Flat 10 Room 3 Eden Hall<br>11 Victoria Street','Preston','Lancashire','UNITED KINGDOM','PR1 7QS','01617948533','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-23 15:44:35',0,NULL,3,1,3,1,' RA117716512CN\r','jakeruthers\rMOLO002'),(2488,699428486011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','will8050','will8050@aol.com','William Sanders','905 taylor ave','Bellevue','KY','UNITED STATES','41073-1671','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 16:34:47',0,NULL,3,1,1,1,NULL,'will8050\r、'),(2489,699459696011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','golf_f00l','jknight304@charter.net','Jack M Knight','304 Kaplan Ct','Simpsonville','SC','UNITED STATES','29681-1969','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 17:55:08',0,NULL,3,1,1,1,NULL,'golf_f00l\r、'),(2490,575156269013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','aris_balagas','abalagas@gmail.com','Aris Balagas','12 Kanari st','Maroussi','Athens','GREECE','15126','+30 6937 275765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 18:40:28',0,NULL,3,1,2,1,NULL,'aris_balagas\r欧标\r\\'),(2491,664040631001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','u2desire','fordfanatics@mindspring.com','Daniel Bond','1882 Everglade Ave','Clovis','CA','UNITED STATES','93619-2852','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 19:10:29',0,NULL,3,1,1,1,NULL,'u2desire\rLK043125453CN \r、\r'),(2492,777028723012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','shmuelyaniv23','shmuelyaniv@gmail.com','Yaniv Shmuel','Shraga refaeli 12/44','Petach tikva','Israel','ISRAEL','49064','972-50-9060224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 19:38:09',0,NULL,3,1,3,1,' RA117716645CN\r','shmuelyaniv23\rOTGR001+OTGR002\r'),(2493,777053316012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',1,'CASS002',8.7,'eastar4','santfox','yinongwu2007@gmail.com','Yinong Wu','3414 Redpath circle','Mississauga','ON','CANADA','L5N 8R7','(647) 403-8826','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,'、 ','santfox\rCAB-SS-2660'),(2494,777053174012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','esdrascavalcanti','esdrascavalcanti@hotmail.com','Esdras Cavalcanti','Rua da Graça, n°120, bairro Graça, SSA-BA Brasil','Salvador','Bahia-Brazil','BRAZIL','40150060','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 20:31:43',0,NULL,3,1,3,1,' RA117716526CN\r','esdrascavalcanti\rOTRA002'),(2495,699524996011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','uninik','nik.slabkovsky@mail.ru','Nikita Slabkovsky','Tuleneva st., 31-1-25','Moscow','Moscow','RUSSIAN FEDERATION','117465','(903)7277782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 20:38:05',0,NULL,3,1,2,1,NULL,'uninik\r\\'),(2496,777064876012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.49,'eastar4uk','xiehaiwei868819','xiehaiwei86881995@hotmail.com','haiwei xie','39 searles close,parkgate road<br>battersea','London','London','UNITED KINGDOM','SW11 4RG','07598799528','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-23 21:02:01',0,NULL,3,1,3,1,' RA117716628CN\r','xiehaiwei868819\rRELO002'),(2497,699549922011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','the_zw3rg','plbeck@t-online.de','Alexander Beck','Schulweg 4','Eberbach','','GERMANY','69412','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 21:42:14',0,NULL,3,1,2,1,NULL,'the_zw3rg\r\\'),(2498,777091149012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','calebhewitt','calebohewitt@gmail.com','Caleb Hewitt','3405 Monaghan St','Dublin','CA','UNITED STATES','94568-4569','(951) 236-4784','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 22:14:27',0,NULL,3,1,1,1,NULL,'calebhewitt\r、'),(2499,575224687013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',6,'CASS001',52.2,'eastar4','red_dragon_uk','adam.lee2@virgin.net','Adam Lee','Flat 20 Athena Court<br>Spicewood','Fareham','Hampshire','UNITED KINGDOM','po155ds','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 22:59:33',0,NULL,3,1,3,1,' RA117716631CN\r','red_dragon_uk\rCASS001'),(2500,575233587013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','kepferle','diana@kepferle.com','Diana Kepferle','5421 Woodstock St','Shawnee','KS','UNITED STATES','66218','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-23 23:50:30',0,NULL,3,1,1,1,NULL,'kepferle\r、'),(2501,575234245013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','julianocorleta','jcorleta@gmail.com','Juliano Marquardt Corleta','Av. Mato Grosso, 1215 (Delegacia de Polícia Federal)<br>centro','Naviraí','Mato Grosso do Sul','BRAZIL','79950-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 23:53:09',0,NULL,3,1,2,1,NULL,'julianocorleta\rHP 8pin 1.0 23cm \r\\'),(2502,529145866004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',32.9,'cnfaner','clerget-2009','hstleger@aliceadsl.fr','HENRI DE ST LEGER','88 RUE ARMAND SILVESTRE<br>BOITE 177','COURBEVOIE','Île-de-France','FRANCE','92400','01.47.89.28.79.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 00:04:31',0,NULL,3,1,3,1,' RA117718120CN\r','clerget-2009\rHSNO003\r欧标'),(2503,575236974013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','coupebolt','s.fradette@globetrotter.net','Sylvain Fradette','22 rue Fradette<br>optional','St-Damien','QC','CANADA','G0R 2Y0','(418) 789-0097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 00:09:25',0,NULL,3,1,3,1,' RA117739513CN\r','coupebolt\rRCLO003'),(2504,575239571013,230393481897,'2.1 HP NC6220 NC6230 Bluetooth Module EDR +cable',1,'BTHP2105',12.8,'eastar4','vlad0057','ttttt29@yandex.ru','Vladislav Sysoev','Myasnickaya ulitca, dom26 (GlavPochtamt)','Moscow','Moscow','RUSSIAN FEDERATION','101000','+7-926-199-27-93','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 00:21:34',0,NULL,3,1,2,1,NULL,'vlad0057\rHP 8pin 1.0 20cm \r\\'),(2505,575251699013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','rangefinder2008','panuraj1983@gmail.com','Panurach Jirawanich','17 Prachanivej 2, Soi Samakki 58/12,<br>Samakki Rd., Tah Sai,','Muang','Nonthaburi','THAILAND','11000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 01:30:24',0,NULL,3,1,2,1,NULL,'rangefinder2008\r\\'),(2506,575247072013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','dcwholesale','admin@dcwholesale.co.nz','DCWHOLESALE','PO BOX 40','KAIAPOI','','NEW ZEALAND','7644','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 01:57:13',0,NULL,3,1,2,1,NULL,'dcwholesale\r\\'),(2507,699618251011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','888petia','gintariuska@yahoo.com','kestutis petraitis','1233 Wyndham Ct<br>Apt 105','palatine','IL','UNITED STATES','60074-7921','(224) 595-9925','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 02:15:24',0,NULL,3,1,1,1,NULL,'888petia\r、'),(2508,777154950012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','dogrock246','trocky2001@aol.com','Elizabeth Thomas','4250 Suitland Rd<br>Apt 101','Suitland','MD','UNITED STATES','20746-2057','(301) 420-5429','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 02:19:58',0,NULL,3,1,1,1,NULL,'dogrock246\r、'),(2509,0,320688647118,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.25,'eastar4','edwinsingh78664','edwinsingh@gmail.com','Edwin Singh','610 Greenhill Dr. Apt. 9201','Round Rock','TX','UNITED STATES','78665','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 02:34:18',0,NULL,3,1,1,1,NULL,'edwinsingh78664'),(2510,777161000012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','salvanica_8385','lanica040507@hotmail.com','Annes Arana','13230 Delaney Rd','Woodbridge','VA','UNITED STATES','22193','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 02:40:05',0,NULL,3,1,1,1,NULL,'salvanica_8385\r、'),(2511,0,220772713200,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',15,'eastar4','jerald29168','jerald29168@yahoo.com','jerald Tindal','84 James Haskell Rd','wedgefield','SC','UNITED STATES','29168-9769','(803) 494-4133','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 03:03:42',0,NULL,3,1,1,1,NULL,'jerald29168\r、'),(2512,699631076011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','zaipasta','xail_alucard@hotmail.com','Yi-Fan Chu','1616 Melrose Park Ct<br>Apt 1713','Urbana','IL','UNITED STATES','61801-0830','217 974 0266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 03:17:01',0,NULL,3,1,1,1,NULL,'zaipasta\r、'),(2513,529176002004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','razz2u2','hami9357@zoominternet.net','Todd Hamilton','143 N Hills Dr','Rising Sun','MD','UNITED STATES','21911-1670','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 03:18:16',0,NULL,3,1,1,1,NULL,'razz2u2\r、'),(2514,575273511013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','swatchdog76','knicholls@mac.com','Kevin Nicholls','969 PANORAMA DR','MILFORD','MI','UNITED STATES','48381','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 03:36:14',0,NULL,3,1,1,1,NULL,'swatchdog76\r、'),(2515,699634555011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',49.99,'eastar4','steinynyc','jms3494@aol.com','Richard Steinberg','350 E 79th St','New York','NY','UNITED STATES','10075-9202','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 03:36:37',0,NULL,3,1,1,1,NULL,'steinynyc\r、'),(2516,773715623012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','raleymic3','raleymic@msu.edu','June Raley','2355 Rolling Meadow Dr NE','Belmont','MI','UNITED STATES','49306-9322','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 03:51:22',0,NULL,3,1,1,1,NULL,'raleymic3\r、'),(2517,777177544012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',11.99,'eastar4','sillyppl','sillyppl76@hotmail.com','Austin Sharp','PO Box 502<br>103 West South St.','Anna','OH','UNITED STATES','45302-0502','(937) 394-8217','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 04:06:30',0,NULL,3,1,1,1,NULL,'sillyppl\r、'),(2518,575279709013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','elecgeon','mradulsahani@msn.com','Harsh Sahani','129 Upper Humber Dr','Etobicoke','ON','CANADA','M9W 7B7','(416) 913-3312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 04:20:43',0,NULL,3,1,2,1,NULL,'elecgeon\r\\'),(2519,699646779011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.8,'eastar4','coreripper','queenmetroid@gmail.com','Seth Barrial','22715 Gierson Ave','Wildomar','CA','UNITED STATES','92595','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 04:45:44',0,NULL,3,1,1,1,NULL,'coreripper\rHP 8pin 1.25 25cm \r、'),(2520,664193138001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','ronnietoys','rnj1@aol.com','Ronald Joseph','116 Stagecoach Cir','Milford','CT','UNITED STATES','06460','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 05:52:16',0,NULL,3,1,1,1,NULL,'ronnietoys\rLK043124909CN \r、'),(2521,699666847011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','j***gol','jgolangco@gmail.com','Jeffrey Golangco','155 Spinks Canyon Rd','Bradbury','CA','UNITED STATES','91008-1244','(626) 203-3042','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 06:42:05',0,NULL,3,1,1,1,NULL,'j***gol\r、'),(2522,777209738012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','tongzhengxin','thegopackstore@gmail.com','Zhengxin Tong','2816 Avent Ferry Rd<br>Apt 301','Raleigh','NC','UNITED STATES','27606-3126','(919) 760-0277','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 06:52:54',0,NULL,3,1,1,1,NULL,'tongzhengxin\r、'),(2523,699670395011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','m0iseenkoav','moiseenkoav@gmail.com','Aleksey Moiseenko','Sankt-Petersburg, Kronshtadt<br>st.Urija Inge, 8/12, fl.22','Kronshtadt','Sankt-Petersburg','RUSSIAN FEDERATION','197760','(812)915-1529','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 07:00:33',0,NULL,3,1,2,1,NULL,'m0iseenkoav\r\\'),(2524,777213067012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','womancareer17','sederhanabeauty@gmail.com','Darmiana Pulungan (MIA)','AKBAR FINANCIAL CHECK UP<br>GEDUNG DARMA BAKTI WANITA LT. 2, JALAN SENOPATI NO. 74','JAKARTA SELATAN','DKI JAKARTA','INDONESIA','12110','628567014857','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 07:36:21',0,NULL,3,1,3,1,' RA117716659CN\r','womancareer17\rOTSO002'),(2525,528928918004,140482243074,'New  NOKIA BH-202 BLUETOOTH HEADSET offer track#',1,'HSNO006',14.95,'cnfaner','dugarmitul2000','dugarmitul@gmail.com','Mitul Dugar','Dugar Building 1st Floor<br>M.I. Road','Jaipur','RJ','INDIA','302001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 08:19:19',0,NULL,3,1,3,1,' RA117716588CN\r','dugarmitul2000\rHSNO006\r'),(2526,575320366013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','the7111401','2oilrg@gmail.com','Boris Braoude','str. Abba Hillel Silver, 27/13','Haifa','','ISRAEL','32693','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 09:02:32',0,NULL,3,1,2,1,NULL,'the7111401\r\\'),(2527,777285468012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','2398u_bon','chalita.phanmuang@hotmail.com','Chalita Mortensen','Birkevaenge 46','Hanstholm','','DENMARK','7730','23981319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 11:09:13',0,NULL,3,1,2,1,NULL,'2398u_bon\r\\'),(2528,699738531011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',16.75,'eastar4','delababa','godeshan@gmail.com','Deshan Perera','NO 25 Cypress Garden<br>Weragama Road','Wadduwa','Westen','SRI LANKA','12500','+94777352650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 11:17:33',0,NULL,3,1,2,1,NULL,'delababa\r\\'),(2529,575355040013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','miketrigger29','arikov29@meta.ua','Arikov Roman Filippovich','Bereznyakovskaya 20 fl.98','KIEV','','UKRAINE','02152','+380975604149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 11:48:35',0,NULL,3,1,2,1,NULL,'miketrigger29\r\\'),(2530,777359635012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','talmihail','aronov_d@mail.ru','Daniel Aronov','kohen eli 24/28','Bat yam','','ISRAEL','59644','0507631952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 14:35:06',0,NULL,3,1,2,1,NULL,'talmihail\r\\'),(2531,575396904013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','avasanji','adilvasanji@gmail.com','Adil Vasanji','4343 115 Street','Edmonton','AB','CANADA','T6J 1P5','(780) 233-2308','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 14:35:14',0,NULL,3,1,2,1,NULL,'avasanji\r银色的\r\\'),(2532,777362733012,220726309168,'New in box Logitech H530 USB Headset ear-cup 981-000195',1,'HSLO002',46.5,'eastar4','kirill77rez','kirilrez@mail.tau.ac.il','Kirill Reznikovski','Elazar David 9/4 ST.','Raanana','Raanana','ISRAEL','Israel','972-546886814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 14:45:09',0,NULL,3,1,3,1,' RA117718045CN\r','kirill77rez\rHSLO002'),(2533,529297504004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','dkylove1004','inzone@nate.com','Ki-Young Dong','Korea University, 5-1, Anam-dong, Seongbuk-Gu, Seoul, 136-713<br>Republic of Korea, Innovation Hall, Room 701(EEE)','Seoul','','KOREA,REPUBLIC OF','136-713','01088989567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 14:56:43',0,NULL,3,1,3,1,' RA117716614CN\r','dkylove1004\rWWSI005'),(2534,777380061012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',5.98,'eastar4uk','ncsageil','ncsamel@hotmail.com','Neil Skiffington','P.O. Box 5085<br>Sth Melbourne','Melbourne','Victoria','AUSTRALIA','3205','0449105088','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 15:21:49',0,NULL,3,1,2,1,NULL,'ncsageil\r\\'),(2535,529308554004,140516805344,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'cnfaner','ebfi99','maurih@gmail.com','Mauri Hamalainen','Luotsikatu 3 A 2','HELSINKI','Fi','FINLAND','00160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 15:29:48',0,NULL,3,1,3,1,' RA117716591CN\r','ebfi99\rCACN001'),(2536,699831226011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',75.99,'eastar4','franciscojos3222','perezfj@movistar.es','Francisco José Pérez Hernández','plaza Antonio Martinez Nº7, Alumbres Cartagena','Murcia','Murcia','SPAIN','30351','968552220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 15:36:19',0,NULL,3,1,3,1,'RA117716605CN\r ','franciscojos3222\rOTSO001\r'),(2537,777399498012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','marasboss','sztaba29@interia.pl','Marek Sztabinski','70 Elder Road','Bisley Woking','Surrey','UNITED KINGDOM','gu24 9sa','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-24 16:00:48',0,NULL,3,1,3,1,' ','marasboss\r英标\rHSNO006\r潘\r'),(2538,777404974012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','shorl2','shorl2@yahoo.com','Sharon Hardman','29 Church Meadows<br>Sholden','Deal','Kent','UNITED KINGDOM','CT14 9QZ','01304362708','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-24 16:11:20',0,NULL,3,1,3,1,'RA117718147CN\r ','shorl2\rOTCN002'),(2539,777414250012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','simo007_berkani','moha_power@hotmail.com','Simo Ayadi','Grondherenstraat 115','Rotterdam','Zuid-Holland','NETHERLANDS','3087CK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 16:29:07',0,NULL,3,1,2,1,NULL,'simo007_berkani\r\\'),(2540,777415561012,220763388903,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',21.5,'eastar4uk','benzaibenoit','benhur@megaquebec.net','benoit poitras','309 route 269','quebec','QC','CANADA','g0s2p0','(418) 888-1205','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 16:34:00',0,NULL,3,1,3,1,' RA117718014CN\r','benzaibenoit\rWLAP009'),(2541,699860182011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',1,'WLAT006',17.4,'eastar4','pauluz66','meneer.rietbroek@gmail.com','Paul Rietbroek','Lisztstraat 109','\'S-GRAVENHAGE','','NETHERLANDS','2551TC','+31645766898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 16:34:27',0,NULL,3,1,2,1,NULL,'pauluz66\r\\'),(2542,699867732011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','raven1234crow','raven123crow@bellsouth.net','okechukwu anyanwu','9848 buncome rd','jacksonville','FL','UNITED STATES','32246-4714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 16:49:14',0,NULL,3,1,1,1,NULL,'raven1234crow\r、'),(2543,777442556012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','raghavendra1','kr_p@yahoo.com','raghavendra P krishnamurthy','1402 E Braymore Cir','Naperville','IL','UNITED STATES','60564','(630) 236-0768','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 17:16:02',0,NULL,3,1,1,1,NULL,'raghavendra1\r、'),(2544,664406700001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','garry5125','garrytower@hotmail.com','Garry Tower','177 Weldon Street','Moncton','NB','CANADA','E1C 5W5','(506) 204-5755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 17:21:41',0,NULL,3,1,3,1,' RA117718076CN\r','garry5125\rOTSO001'),(2545,777453087012,220578466424,'NEW GENUINE NOKIA BH-102 BLUETOOTH HEADSET BH 102',1,'HSNO001',19.99,'eastar4','manilana','thozip@web.de','Vilma Zipser','Trockenkamp 11','Winsen/ Luhe','','GERMANY','21423','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 17:32:14',0,NULL,3,1,2,1,NULL,'manilana\r欧标\r\\\r'),(2546,777465212012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',29.99,'eastar4uk','baccaratdupont','cashcity@sfr.fr','Christophe RAIMBAULT','21, rue d\'Amsterdam','PARIS','Ile-de-France','FRANCE','75008','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 17:49:14',0,NULL,3,1,3,1,' RA117718235CN\r','baccaratdupont'),(2547,575469205013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','edpsychdoc','zionscamp@hotmail.com','Mark White','2930 N 840 E','Provo','UT','UNITED STATES','84604','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-24 17:55:10',0,NULL,3,1,1,1,NULL,'edpsychdoc\r、'),(2548,664501360001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','sena505','elitegs18@yahoo.com','Michelle Sena','831 W Manana Blvd','Clovis','NM','UNITED STATES','88101','(505) 762-4293','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 20:03:06',0,NULL,3,1,1,1,NULL,'sena505\rLK043123320CN\r、'),(2549,700003370011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','soude1164','soudez@hotmail.fr','ELBAKKALI ABDELAZIZ','45 STROMBEEKLINDE','GRIMBERGEN','','BELGIUM','1853','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 20:30:22',0,NULL,3,1,2,1,NULL,'soude1164\r\\'),(2550,523697319003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','auggust_70','yury.tsyganov@emerson.com','Yury Tsyganov','Tsurupy str. 12-3-48','Moscow','','RUSSIAN FEDERATION','117418','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 20:45:12',0,NULL,3,1,3,1,' RA117718155CN\r','auggust_70\rOTGR001'),(2551,777588010012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',3,'MOLO002',116.7,'eastar4','psj59','psj59@hotmail.com','sung Joon Park','245 BAY STREET','OTTAWA','ON','CANADA','K1R 5Z4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 20:54:43',0,NULL,3,1,3,1,' RA117718195CN\r','psj59\rMOLO002'),(2552,700019994011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','kerccolaro','michel.cachia@sfr.fr','Michel Cachia','la valeriane apt 2','val thorens','Rhône-Alpes','FRANCE','73440','+33668916865','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 21:08:01',0,NULL,3,1,2,1,NULL,'kerccolaro\r\\'),(2553,0,230611943742,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',1.4,'eastar4','davecarter3','carterdavid@verizon.net','David J Carter','7974 Castle Hedge Dell','Glen Burnie','MD','UNITED STATES','21061','(410) 760-0307','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 22:06:07',0,NULL,3,1,1,1,NULL,'davecarter3\r一共买了两条\r、'),(2554,777622933012,220456476892,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'eastar4','razal999','zazix@2xsnet.nl','L.I. Klaassens','Diakenhuisweg 83','Haarlem','','NETHERLANDS','2033AP','(023) 5405529','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 22:19:24',0,NULL,3,1,2,1,NULL,'razal999\r\\'),(2555,529459073004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'cnfaner','vinicius.sperandio','vmsperandio@yahoo.com.br','Vinicius Martinelli Sperandio','Rua Aluysio Simões, 730 Casa 02<br>Ilha de Monte Belo','Vitória','Espirito Santo','BRAZIL','29053-264','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 22:41:58',0,NULL,3,1,3,1,'RA117739195CN\r ','vinicius.sperandio\rANYA001'),(2556,777633526012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','savages9r','aaronjsavage@yahoo.com','Aaron Frederick','3208 New England St','Rapid City','SD','UNITED STATES','57703-4727','(605) 390-1552','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 22:48:24',0,NULL,3,1,1,1,NULL,'savages9r\r、'),(2557,575490653013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','sillygrapes86','agordon813@gmail.com','Carrie Gordon','1221 Meadowridge Trl','goshen','KY','UNITED STATES','40026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 23:00:45',0,NULL,3,1,1,1,NULL,'sillygrapes86\r、'),(2558,777633544012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','aoa110','yakovlevbogdan@yandex.ru','Bogdan Yakovlev','Nagatinkaya naberezhnaya<br>dom 54 kv. 643','Moscow','Moscow','RUSSIAN FEDERATION','115407','+7 9165878707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 23:07:46',0,NULL,3,1,2,1,NULL,'aoa110\r\\'),(2559,777640164012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','mario972s','mmcmagnum@hotmail.com','mario martin casado','calle peñarredonda 2 (correos)','aranjuez','Madrid','SPAIN','28300','678787421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 23:07:53',0,NULL,3,1,2,1,NULL,'mario972s\r\\'),(2560,700066653011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',18.9,'eastar4','tarynfrank','blfrank@gmail.com','Brian Frank','13090 Pierce Rd','Saratoga','CA','UNITED STATES','95070','(408) 666-0518','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-24 23:27:05',0,NULL,3,1,1,1,NULL,'tarynfrank\r、'),(2561,529469339004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','sobersusie','pofqal1@sbcglobal.net','Susan Sauer','1544 Hickory Road','Woodstock','IL','UNITED STATES','60098','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 23:30:15',0,NULL,3,1,1,1,NULL,'sobersusie\r、'),(2562,700081157011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','barrmaley','barrmaley@gmail.com','Artem Solovyov','7/2 Tankernaya str.','Odessa','Odessa region','UKRAINE','65010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 00:16:18',0,NULL,3,1,2,1,NULL,'barrmaley\r\\'),(2563,575620813013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','nanrspm1970','nanrspm@hotmail.com','Sergeant Tanan Rangseeprom','592 Charoennakorn 14<br>Khlongtonsai Khlongsan','Bangkok','Thailand','THAILAND','10600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 01:24:01',0,NULL,3,1,2,1,NULL,'nanrspm1970\r\\\r\r\r'),(2564,777694536012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','dcol2803','d.colebank@yahoo.com','david colebank','2517 walbrook dr','louisville','KY','UNITED STATES','40222','(502) 426-4664','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 01:40:18',0,NULL,3,1,1,1,NULL,'dcol2803\r、'),(2565,575628379013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',2,'RCLO003',277.98,'eastar4','sawoodturner','gurley@swbell.net','Randall Gurley','400 S 14th ST<br>Apt 1018','Saint Louis','MO','UNITED STATES','63103-2720','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 01:52:41',0,NULL,3,1,12,1,' 2182315494 \r','sawoodturner\r\\'),(2566,777701994012,220546791970,'Yagi 16dBi 2.4 GHz 802.11b/g Wifi Antenna RP-SMA',2,'ANYA001',28.9,'eastar4','jakeofarabia','opp11@yahoo.com','tony Jimenez','8069 Garvey Ave<br>box 42 Trlr #45','Rosemead','CA','UNITED STATES','91770-2466','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 02:03:27',0,NULL,3,1,3,1,' RA117739527CN\r','jakeofarabia'),(2567,777704860012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',11.99,'eastar4','drew306','alsdiner306@charter.net','ANDREW GUZMAN','2620 RAINBOW DR','PLOVER','WI','UNITED STATES','54467','(715) 347-4225','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 02:10:51',0,NULL,3,1,1,1,NULL,'drew306\r、'),(2568,777745083012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','ttommy.ufo','ufo.nyva4x4@gmail.com','Tomas Nikitinas','Naumiescio 5','Kaunas','','LITHUANIA','46342','(0370)68972642','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 05:02:50',0,NULL,3,1,2,1,NULL,'ttommy.ufo\r欧标\r\\'),(2569,529532977004,140516109270,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',12.99,'cnfaner','mrminas10','theonlybiggreek@hotmail.com','minas grigoratos','box 985','DAWSON','YT','CANADA','Y0B 1G0','(867) 993-5868','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 05:03:05',0,NULL,3,1,3,1,' RA117718164CN\r','mrminas10\rRELE001'),(2570,777757234012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jhap_panis','jhap101@yahoo.com','Jeremy Philip Arceo','26 Bundagul','Mabalacat','Pampanga','PHILIPPINES','2010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 06:19:51',0,NULL,3,1,2,1,' ','jhap_panis\r\\'),(2571,700169533011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',11.99,'eastar4uk','steedboy','lukesteed@aol.com','LUKE STEED','SMITH INT. SDN BHD KG SG KELING<br>LORONG SK 32,SK 32,SK0786 JLN RANCHA RANCHA','WP LABUAN','MALAYSIA','MALAYSIA','87000','0198250696','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 08:24:45',0,NULL,3,1,3,1,' RA117739460CN\r','steedboy\rOMHJ001\r'),(2572,700209689011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','andrsjkb','jakobimon@aol.com','Andreas Jakobi','Industriestrasse 51','Stolberg','','GERMANY','52224','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 09:20:50',0,NULL,3,1,2,1,NULL,'andrsjkb\r\\'),(2573,529571843004,140516092374,'Logitech harmony Li-ion Rechargeable Battery 950mAh',2,'BALO008',13.2,'cnfaner','akrachai123','akrachai@truemail.co.th','AKRACHAI HENG','148 TROK ISSRANUPHAP JA-LEARN-KRUNG RD.SUMPUNTAWONG','BANGKOK','','THAILAND','10100','0016626230091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 09:39:40',0,NULL,3,1,3,1,' RA117718283CN\r','akrachai123\rBALO008'),(2574,575709446013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',9,'CASS003',78.3,'eastar4','crsutton31','crsutton_personal@yahoo.co.uk','Christopher Sutton','26 Claymoor Close','Mansfield','Nottinghamshire','UNITED KINGDOM','NG18 5RS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 10:20:56',0,NULL,3,1,3,1,' RA117718411CN\r','crsutton31\rCASS003'),(2575,776733178012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','computer615','ryanbirk@gmail.com','Ryan Birk','10101 Pendula Dr','Indianapolis','IN','UNITED STATES','46236-7365','(317) 650-3310 ext.: 0','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'computer615'),(2576,777831937012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','phil14570','p.musgrove1@ntlworld.com','Philip musgrove','14 Poachers Way','Northampton','Northamptonshire','UNITED KINGDOM','NN28AY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 10:56:52',0,NULL,3,1,3,1,' RA117718270CN\r','phil14570\r英标   HSNO006'),(2577,575726794013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',5,'WLIN010',104.75,'eastar4','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 12:19:45',0,NULL,3,1,3,1,' RA117718266CN\r','saiajin77\rWLIN010'),(2578,777858039012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','wilogen','willrogers1995@hotmail.co.uk','William Rogers','26<br>Castle Street','Hereford','Herefordshire','UNITED KINGDOM','HR1 4LB','01432350521','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 13:17:23',0,NULL,3,1,3,1,' RA117718354CN\r','wilogen\rWLDL001'),(2579,0,230613185024,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','bmorebullet','jstones08@verizon.net','jared stones','2415 E Hoffman St','BALTIMORE','MD','UNITED STATES','21213-3634','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 13:17:23',0,NULL,3,1,1,1,NULL,'bmorebullet\r\\'),(2580,0,320690016510,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',10.5,'eastar4','cake207','cmarek207@hotmail.com','Carol Marek','301 Linden St W','Frederic','WI','UNITED STATES','54837-8931','(715) 327-5550','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-25 13:18:45',0,NULL,3,1,1,1,NULL,'cake207\r\\'),(2581,700287821011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',11.99,'eastar4uk','garc4991','gwyn.arch@ukgateway.net','Gwyn Arch','15 Grove Rd<br>Sonning Common','Reading','Berkshire','UNITED KINGDOM','RG4 9RH','01189723474','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 13:53:12',0,NULL,3,1,3,1,' RA117718345CN\r','garc4991\rOMHJ001'),(2582,777889174012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ratchetjawes','dhunt@newwavecomm.net','Debbie Hunt','501 E Karen St','Rector','AR','UNITED STATES','72461-1435','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:02:33',0,NULL,3,1,1,1,' \\','ratchetjawes'),(2583,0,320688646214,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',9.09,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:16:27',0,NULL,5,0,18,0,NULL,'blue8sky'),(2584,0,220772970829,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',16.27,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:16:26',0,NULL,3,0,1,1,NULL,'blue8sky\r发两个3G天线\rANCN001\rLK043472815CN\r\\'),(2585,0,230611941726,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',17.64,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:16:34',0,NULL,5,0,18,0,NULL,'blue8sky'),(2586,777898597012,220704730634,'New Plantronics Explorer220 BLUETOOTH HEADSET+carcharge',1,'HSPL001+CCPL001',11.2,'eastar4uk','2005dickman','shyboi2@btinternet.com','Henry Dickman','18 William Morris Terrace<br>Shotton Colliery','Durham','Durham','UNITED KINGDOM','DH6 2PL','07771813201','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 14:22:53',0,NULL,3,1,3,1,' RA117718221CN\r','2005dickman\rHSPL001+CCPL001'),(2587,700301831011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','eby01821','vermontloghome@yahoo.com','Tom Rezucha, C/O Raybeam, Inc','175 Great Rd<br>Ste 110','Bedford','MA','UNITED STATES','01730','(978) 618-5854','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:36:15',0,NULL,3,1,4,1,'YW864488970CN ','eby01821'),(2588,0,320690016094,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',28.5,'eastar4','gildroyracing','zcamaro@zoominternet.net','Shawn Gildroy','1349 Mount Pleasant Road','Mount Pleasant','PA','UNITED STATES','15666','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:37:57',0,NULL,3,1,1,1,NULL,'gildroyracing\r\\'),(2589,575797531013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',37.2,'eastar4','kia_22','ilkkakautto@gmail.com','Ilkka  Kautto','Kärkikuja 2 C 76','Tampere','Tampere','FINLAND','33720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 16:28:38',0,NULL,3,1,3,1,' RA117716185CN\r','kia_22\rWWSI004+ANCN001'),(2590,575797721013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','mathurageethan2010','mathurageethan@gmail.com','Mathurageethan Mounasamy','395/11B1, Banadaranayaka Mw','Anuradhapura','','SRI LANKA','00094','+94772071091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 16:41:23',0,NULL,8,1,17,0,NULL,'mathurageethan2010'),(2591,700352995011,320552968178,'New Motorola HS810 Bluetooth Wireless Headset HS-810',1,'HSMO017',20.99,'eastar4','lance8022','bgbfbg@comcast.net','Lance Lewis','2588 Hawthorne Rd','Ann Arbor','MI','UNITED STATES','48104-4032','(734) 995-1726','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 16:47:57',0,NULL,3,1,1,1,'\\ ','lance8022'),(2592,777960129012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','isuru.senadheera','freestyler830@yahoo.com','Isuru Senadheera','77, Senani, Madurawala<br>Anguruwathota','Anguruwathota','Western','SRI LANKA','12320','+94777562095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 16:48:26',0,NULL,3,1,2,1,NULL,'isuru.senadheera\r\\'),(2593,0,220774817164,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',28,'eastar4','urmeannate','tran.nate@gmail.com','Nathan Tran','2302 falling leaf ave','rosemead','CA','UNITED STATES','91770','(626) 512-9465','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 16:50:13',0,NULL,3,1,1,1,NULL,'urmeannate\r\\'),(2594,777966859012,220681549785,'New Nokia LD-3W Bluetooth GPS Module Battery+Carcharger',1,'OTCR001',19.55,'eastar4uk','rainbow.7064','rainbow.70@mail.ru','oleg vlasov','histadrut 41-16','ashqelon','','ISRAEL','78251','+10 972 504204743','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 17:01:25',0,NULL,3,1,3,1,' RA117718297CN\r','rainbow.7064\rOTCR001'),(2595,575812600013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','zkalwar2000','zahid_kalwar2000@yahoo.com','Zahid Kalwar','2nd Floor, 70 Grace Church Street<br>London','London','London','UNITED KINGDOM','EC3V 0XL','02079654452','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 17:15:41',0,NULL,3,1,2,1,NULL,'zkalwar2000\r\\'),(2596,575811503013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','neil042','neilhart@comcast.net','Neil Everhart','43775 Nansa Ct','Fremont','CA','UNITED STATES','94539','(510) 579-1593','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 17:22:22',0,NULL,3,1,1,1,NULL,'neil042\r\\'),(2597,575842024013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','snax_007','mrsnax07@yahoo.com','Harry Bond','831 Snohan Rd','ayden','NC','UNITED STATES','28513-9792','(252) 717-7614','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 18:28:47',0,NULL,3,1,1,1,NULL,'snax_007\r\\'),(2598,700428697011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','20bef','cassiman.joeri@pandora.be','Joeri Cassiman','Borgeleien 48','Geel','','BELGIUM','2440','0486262191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 19:11:49',0,NULL,3,1,2,1,NULL,'20bef\r\\'),(2599,0,230613185379,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 19:23:04',0,NULL,3,1,1,1,NULL,'4278dennis\r\\'),(2600,575865590013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','mathurageethan2010','mathurageethan@gmail.com','Mathurageethan Mounasamy','395/11B1, Banadaranayaka Mw','Anuradhapura','','SRI LANKA','00094','+94772071091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 19:26:17',0,NULL,3,1,2,1,NULL,'mathurageethan2010\r再发一个New GENUINE NOKIA HS-4W BLUETOOTH\r银色的\r\\'),(2601,700434871011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','krskst','krastyo@stanchev.info','Krastyo Stanchev','ul. Probuda 57','Bourgas','Bourgas','BULGARIA','8000','+359885132299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 19:28:07',0,NULL,3,1,2,1,NULL,'krskst\r\\'),(2602,575889809013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',2,'RELE001',18.9,'eastar4','technologyoutlet','sales@balancelogic.com','Bill Campbell','3995 Hanson Rd','White Plains','MD','UNITED STATES','20695','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 20:27:51',0,NULL,3,1,1,1,NULL,'technologyoutlet\r\\'),(2603,700469143011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',2,'UDAP001',49.18,'eastar4uk','rhaleuk','mr.rich@gmail.com','Richard Hale','81 White Hill','Kinver','Staffordshire','UNITED KINGDOM','DY76AR','07535440440','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 20:28:42',0,NULL,3,1,3,1,' RA117718306CN\r','rhaleuk\rUDAP001'),(2604,700480236011,320497200017,'New Apple AR9280 AR5BXB92 Mini PCI-E AGN 300M+2 antenna',1,'WLAP008+ANAP001',20.99,'eastar4','terryinwales','terry@pantypwll.co.uk','Terry O\'Brien','Pant y Pwll','KIDWELLY','Carmarthenshire','UNITED KINGDOM','SA17 5LW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 20:48:53',0,NULL,3,0,2,1,NULL,'terryinwales\r\\'),(2605,575893954013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','cano278','escamill_patricia@sbcglobal.net','patricia cano','2525 San Gabriel Blvd','Rosemead','CA','UNITED STATES','91770','(626) 374-0291','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 20:50:13',0,NULL,3,1,1,1,' \\\r','cano278'),(2606,529756051004,140428315663,'2.1 Acer Aspire Timeline 1810TZ bluetooth module track#',1,'BTAC2111',13.99,'cnfaner','mih75','p.florin@alice.it','Florin Petru Pop','Caduti del lavoro 8','Coccaglio','BS','ITALY','25030','3475931791','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 21:00:50',0,NULL,3,1,3,1,' RA117718218CN\r','mih75\rAcer 5pin1.25 3cm\r'),(2607,778114788012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','okeeffet92','okeeffet@verizon.net','Tom O\'Keeffe','1019 S Hollow Dr','Southlake','TX','UNITED STATES','76092-8831','(214) 529-0885','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 21:30:43',0,NULL,3,1,1,1,'\\ ','okeeffet92\r美标'),(2608,700504579011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','titty101','little_tit@hotmail.com','kyle tytler','23708-54a AVE.','Langley','BC','CANADA','v2z2p2','(604) 534-6369','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 21:52:18',0,NULL,3,1,2,1,NULL,'titty101\r\\'),(2609,778143797012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','brickpig3','thebrickpig@bellsouth.net','David Pfeiffer','1216 W Woodlawn Ave','Louisville','KY','UNITED STATES','40215-2357','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 22:52:59',0,NULL,3,1,1,1,NULL,'brickpig3\r\\'),(2610,575931177013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','jab_joe','si12volt1@cox.net','Alfred Gray','130 Avenida De La Grulla<br>Apt A','San Clemente','CA','UNITED STATES','92672-9110','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 23:02:57',0,NULL,3,1,1,1,NULL,'jab_joe\r\\'),(2611,575944287013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','rhtran','rick_tran@hotmail.com','Rick Tran','8225 Lampson Ave','Garden Grove','CA','UNITED STATES','92841-3115','(714) 590-1473','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 00:07:12',0,NULL,3,1,1,1,NULL,'rhtran\r\\'),(2612,778202541012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','rocket3k','sfausch@hotmail.com','Stefan C. Fausch','509A S Al Davis Rd','New Orleans','LA','UNITED STATES','70123-7300','(504) 460-4200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 02:11:30',0,NULL,3,1,1,1,NULL,'rocket3k\r美标\r\\'),(2613,575967365013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','rodrigo30031980','rigo032@hotmail.com','Abarca Lara Rodrigo','Jacaranda 834','Valparaiso','Casablanca','CHILE','2480505','0560322743368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 02:21:59',0,NULL,3,1,2,1,NULL,'rodrigo30031980\r、'),(2614,575975446013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','xxdestiny','annie.ta.tran@gmail.com','Annie Tran','68 Westforest Trail','Kitchener','ON','CANADA','n2n3a8','(519) 496-7380','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'xxdestiny'),(2615,778213981012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','labossarte','labossarte@verizon.net','Larry Bossarte','118 E Stuart Ave','Lake Wales','FL','UNITED STATES','33853-4128','(863) 679-1850','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 02:50:31',0,NULL,3,1,1,1,NULL,'labossarte\r\\'),(2616,700593235011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','fuffiopl','fufflon@yahoo.com','Manfred Brueggemeier','19177 W Harbour Village Dr','Northville','MI','UNITED STATES','48167-3145','(248) 982-2732','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 03:23:19',0,NULL,3,1,1,1,NULL,'fuffiopl\r\\'),(2617,0,320690460140,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',10,'eastar4','dncfaeri','debnarasaki@comcast.net','deb narasaki','250 Parkside Dr','palo alto','CA','UNITED STATES','94306','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-26 03:57:09',0,NULL,3,1,1,1,NULL,'dncfaeri\r、'),(2618,778235037012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','victorgraur','victorgraur@hotmail.com','Victor Graur','13030 122nd PL','South Ozone Park','NY','UNITED STATES','11420-2710','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 04:24:36',0,NULL,3,1,1,1,NULL,'victorgraur\r、'),(2619,700605717011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',3,'RELO002',38.97,'eastar4','aa_speedy11','huot.max@gmail.com','Maxime Huot','127 Pueblo cr.','Whitehorse','YT','CANADA','y1a 6v3','(867) 667-6667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 04:27:24',0,NULL,3,1,3,1,NULL,'aa_speedy11\rRELO002\rRA117718399CN'),(2620,700618237011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','dijerydo100','michael_clamp@hotmail.com','Michael Clamp','18 Bedford Avenue','Wyton on the Hill','Cambridgeshire','UNITED KINGDOM','PE28 2HJ','01480700523','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 05:43:32',0,NULL,3,1,3,1,'RA117741808CN','dijerydo100\rMOAP001\r'),(2621,529191436004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','digitaljockey','mhenriquealmeida@gmail.com','Marcelo Almeida','Rua Barao Do Triunfo,1282 apt. 61','Sao Paulo','SP','BRAZIL','04602-005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 06:08:29',0,NULL,3,1,3,1,NULL,'digitaljockey\rHSMO007\rRA117718371CN\r'),(2622,778255274012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','richievee','richard.vivian@tesco.net','R.Vivian','9 Osbert Road','Witham','Essex','UNITED KINGDOM','CM8 1PE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 06:13:48',0,NULL,3,0,3,1,NULL,'richievee\rOTRA002\rRA117718385CN\r、'),(2623,576009537013,230402659419,'Genuine Cisco PVDM-256K-12 VoiceFax DSP Module PVDM-256',1,'OTIN003',75,'eastar4','angelgarciaguillen','agarciaguillen@hotmail.com','angel garcia guillen','C/Barcelona nº1 LOCAL','Zaragoza','Aragón','SPAIN','50017','600491623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 06:27:51',0,NULL,3,1,3,1,NULL,'angelgarciaguillen\rOTIN003\rRA117718310CN'),(2624,700646872011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','mattereza','mattereza44@mail.ru','Maxim Kadomtsev','Korolenko 8 /post box 133','Moscow','','RUSSIAN FEDERATION','107014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 08:18:31',0,NULL,3,1,3,1,'RA117718955CN\r\\ ','mattereza\rUDAP001\r'),(2625,576036077013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','frsm11','franxi_7@hotmail.com','Fco Rafael Sabariego Menjibar','Pasaje Pintor Ramirez n 3','Córdoba','Andalucía Ceuta y Melilla','SPAIN','14006','605038849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 09:32:52',0,NULL,3,1,2,1,NULL,'frsm11\r欧标'),(2626,700663148011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ordor2k','or_dor@hotmail.com','or dor','Zablodovitch 5','Petach Tiqva','Kiryat Alon','ISRAEL','49389','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 09:33:19',0,NULL,3,1,2,1,NULL,'ordor2k'),(2627,700675667011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','thierry170764','tcostes@wanadoo.fr','Thierry COSTES','22, rue de Perpeigneux, SAULCHERY','CHARLY','Picardie','FRANCE','02310','0323700341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 10:26:45',0,NULL,3,1,2,1,NULL,'thierry170764\r\\'),(2628,778317856012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','maki_na','maki_na@telefonica.net','Bienvenido Frutos','Mestre Tonet nº 30 4º 3ª','lleida','Cataluña','SPAIN','25003','973267197','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 10:51:08',0,NULL,3,1,2,1,NULL,'maki_na\r\\'),(2629,576055629013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','lukitishna','knyazz@inbox.ru','EVGENY SMIRNOV','Rossiysky Prospekt, 14-282','Saint Petersburg','','RUSSIAN FEDERATION','193231','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 11:22:39',0,NULL,3,1,2,1,NULL,'lukitishna\r\\'),(2630,700697619011,320552968178,'New Motorola HS810 Bluetooth Wireless Headset HS-810',1,'HSMO017',20.99,'eastar4','petunia1953','cmtophat@msn.com','Crystal Miller','424 Swope Ave','Colorado Springs','CO','UNITED STATES','80909','(719) 661-1918','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 11:52:40',0,NULL,3,1,1,1,NULL,'petunia1953\r\\'),(2631,700725353011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','magie1992','francois2007@globetrotter.net','Francois   Pelletier','29-7e rue ouest','Ste-Anne-des-Monts','QC','CANADA','G4V2K4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 13:29:31',0,NULL,3,1,2,1,NULL,'magie1992\r\\'),(2632,576086025013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','mikshir','denisbot@rambler.ru','Dzianis Mikrukou','Internationalnaya str. 43 18','Bobrujsk','Mogilevskaya obl','BELARUS','213819','+375-29-3248340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 13:49:47',0,NULL,3,1,2,1,NULL,'mikshir\r欧标\r\\'),(2633,700731836011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','gilphnx','gilphnx@hotmail.com','Gilfredo Adames','1020 Plover Ave','Miami Springs','FL','UNITED STATES','33166-4349','(305) 772-7622','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 13:50:19',0,NULL,3,1,1,1,NULL,'gilphnx\r\\'),(2634,576089131013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','meanmange','magnus@gata.se','Magnus Lindén','Spångatan 27 E','Malmö','-','SWEDEN','21153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 14:00:35',0,NULL,3,1,2,1,NULL,'meanmange\r\\'),(2635,700530063011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','bcshutterbug','autosmith@lakecable.ca','Tim Smith','PO Box 296','Sorrento','BC','CANADA','V0E 2W0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 14:01:40',0,NULL,3,1,2,1,NULL,'bcshutterbug\r\\'),(2636,778379368012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 14:11:21',0,NULL,8,1,17,0,NULL,'avextra-co-uk'),(2637,778381164012,220759518116,'Genuine Logitech Harmony LED 525 Remote Control',1,'RCLO005',43,'eastar4uk','hugogypsy','torview@btopenworld.com','Clare Hugo','Corgee Farm,','Bodmin','Cornwall','UNITED KINGDOM','PL305DS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 14:17:00',0,NULL,3,1,3,1,' RA117718972CN\r\\','hugogypsy\rRCLO005'),(2638,700740021011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','rodrces','crodriguez@its-laredo.com','Cesar Rodriguez','10612 Cabo Wabo','Laredo','TX','UNITED STATES','78045-6558','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 14:19:10',0,NULL,3,1,4,1,' YW864488874CN\r、','rodrces'),(2639,576094552013,230495606381,'New in box NOKIA HS-11W BLUETOOTH HEADSET HS 11W',1,'HSNO024',17.7,'eastar4','thulakshan','terrothulakshan@yahoo.com','Vettivelu Thulakshan','49/8, 4th lane , Anuradhapura road,','Puttalam','North western','SRI LANKA','61300','0094770767807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 14:25:39',0,NULL,3,1,2,1,NULL,'thulakshan\r\\'),(2640,698442241011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','m3t4lh34d_6','kyleswentowsky@hotmail.com','Kyle Swentowsky','8231 Phasis Ct','Elverta','CA','UNITED STATES','95626-9697','(916) 991-1888','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 14:25:58',0,NULL,3,1,1,1,NULL,'m3t4lh34d_6\r新地址\rKyle Swentowsky\rSan Nicolas Hall, Room 6340\rSanta Barbara, CA 93106\r\\\r\r'),(2641,778385270012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',11.99,'eastar4','jgollner','jgollner@bea.net','John M. Gollner','5887 Glenridge Dr NE<br>Ste 130','Atlanta','GA','UNITED STATES','30328-6191','(404) 256-9640','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 14:28:57',0,NULL,3,1,1,1,NULL,'jgollner\r\\'),(2642,778391021012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','candies69','drtongue96@yahoo.com','Jim Chabai','1011 Dudley Avenue','Winnipeg','MB','CANADA','R3M 1R4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 14:46:02',0,NULL,3,1,2,1,NULL,'candies69\r\\'),(2643,0,320690461122,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',10.99,'eastar4','apontmi','mikea331@optonline.net','mike aponte','138 Kings Hwy','warwick','NY','UNITED STATES','10990-3115','(914) 582-9282','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 14:52:13',0,NULL,3,1,1,1,NULL,'apontmi\r\\'),(2644,777317178012,220581067419,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10-2',1,'BTLE2002',12.5,'eastar4','nanes64','nanes64@comcast.net','Nestor Rosario','101 NW 187th Ave','Pembroke Pines','FL','UNITED STATES','33029','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 14:56:42',0,NULL,3,1,1,1,' ','nanes64\r8pin 1.0 8cm 五线连接'),(2645,778403699012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','cole9nyc','nycole@gmail.com','C Nicole Phipps','860 Dekalb Ave<br>Apt 5','Brooklyn','NY','UNITED STATES','11221-2496','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 15:20:38',0,NULL,3,1,1,1,NULL,'cole9nyc\r\\'),(2646,699098578011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','wsf08262s','waltersflores@yahoo.com','walter flores','po box 2418','Jenkintown','PA','UNITED STATES','19046-8418','(215) 459-5520','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 15:42:47',0,NULL,3,1,1,1,NULL,'wsf08262s\r\\'),(2647,700770491011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.8,'eastar4','michael.ketchel','kaboomi2@yahoo.com','Michael Ketchel','800 Martinsburg Rd','Mount Vernon','OH','UNITED STATES','43050-9509','(740) 392-8707','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 15:49:39',0,NULL,3,1,1,1,NULL,'michael.ketchel\rHP 8pin 1.25 25cm \r\\'),(2648,778420520012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',12.99,'eastar4uk','accessories2you','ebay@accessories2you.net','Sohail Hayat','21 Moss Street','Paisley','Renfrewshire','UNITED KINGDOM','PA1 1BE','08700278330','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 16:01:37',0,NULL,3,1,3,1,' RA117718442CN\r\\','accessories2you\rHSMO017\r英标'),(2649,778430669012,220713846397,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET',1,'HSNO017',13.29,'eastar4uk','suzanne_72','suzannewolny@hotmail.co.uk','Suzanne Wolny','5 Ford Crescent','Thornton','Fife','UNITED KINGDOM','KY1 4EB','01592572205','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 16:26:22',0,NULL,3,1,3,1,' RA117718439CN\r\\','suzanne_72\rHSNO017\r英标'),(2650,700786803011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','ketenik','kete@freemail.gr','Nikolaos Ketetzidis','Karaoli Dimitriou 45','Drama','','GREECE','66100','00306946993356','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 16:32:15',0,NULL,3,1,2,1,NULL,'ketenik\r欧标\r\\'),(2651,700787165011,320557629748,'New Motorola H3 Bluetooth Wireless Headset H 3',1,'HSMO003',14.75,'eastar4','robertrabuf1','rjasr55@sbcglobal.net','ROBERT ANDERSON','6029 W 64TH STREET','CHICAGO','IL','UNITED STATES','60638','(773) 331-2687','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 16:35:35',0,NULL,3,1,1,1,NULL,'robertrabuf1\r\\'),(2652,700788747011,320631786282,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',15.5,'eastar4','goodnewsnutrition','sunshine496@bellsouth.net','Patrica Nasci','496 Fleming St','Sebastian','FL','UNITED STATES','32958-4212','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 16:37:21',0,NULL,3,1,1,1,NULL,'goodnewsnutrition\r\\'),(2653,700789167011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','maxjazz123','chrithanner@gmx.at','Christian Thanner','Garnisonstraße 15<br>Zimmer 73B','Linz','','AUSTRIA','4020','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 16:38:10',0,NULL,3,1,2,1,NULL,'maxjazz123\r\\'),(2654,576132081013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','evilknight911','cmwong999@gmail.com','NG KIN CHI','ROOM 2302, CHEUNG SHUN HOUSE<br>CHEUNG WAH ESTATE, FANLING','default','','HONG KONG','default','96304037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 16:45:04',0,NULL,3,1,2,1,NULL,'evilknight911\r\\'),(2655,778456678012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',14.9,'eastar4uk','zjonesz','zjonesz@lyse.net','Bjørn Vidar Jones','Tuånå 20','Jørpeland','Rogaland','NORWAY','4100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 17:26:20',0,NULL,3,1,2,1,NULL,'zjonesz\r\r\\'),(2656,778417476012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',2,'WLAT007',29.9,'eastar4','micha964','michael.wahl@t-online.de','Michael Wahl','Augustenstr.4','Stuttgart','','GERMANY','70178','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 17:32:38',0,NULL,3,1,2,1,NULL,'micha964\r\\'),(2657,529981365004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','2010nsxv10','k20honda08@hotmail.com','Albert Kando','104 sugarcane ave','brampton','ON','CANADA','l6r0g5','(647) 801-4449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 17:36:19',0,NULL,8,1,17,0,NULL,'2010nsxv10'),(2658,529983857004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','2010nsxv10','k20honda08@hotmail.com','Albert Kando','104 sugarcane ave','brampton','ON','CANADA','l6r0g5','(647) 801-4449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 17:44:41',0,NULL,3,1,3,1,' RA117718986CN','2010nsxv10\rHSSA001\r一共买了两个'),(2659,700586519011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','nshtx561','nshtx@hotmail.com','luis espinoza','4525 21st St SW','lehigh acres','FL','UNITED STATES','33973','(561) 452-1332','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 17:44:59',0,NULL,3,1,1,1,NULL,'nshtx561\r\\'),(2660,576167851013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','jayceline_quek','jayceline.quek@gmail.com','Quek Jayceline','Blk 267 Tampines street 21 #08-33','Singapore','','SINGAPORE','520267','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 18:28:28',0,NULL,3,1,11,1,NULL,'jayceline_quek\rHSPL001'),(2661,778514335012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','s.pancho.90023','mrfrank2402@yahoo.com','francisco gallegos','2743 Guirado St','Los Angeles','CA','UNITED STATES','90023-1434','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 19:12:57',0,NULL,3,1,1,1,NULL,'s.pancho.90023\r\\'),(2662,530023377004,140516805344,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'cnfaner','semi_kimo','semikimo@gmail.com','samyon shayayev','bar yehuda 54','bat yam','','ISRAEL','59576','+972-544-311231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 19:39:37',0,NULL,3,1,3,1,'RA117718969CN\r\\ ','semi_kimo\rCACN001\r'),(2663,700875363011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','janesht','janesht@yandex.ru','Yaroslav Shturman','ul.Schapova<br>12-41','Yaroslavl','','RUSSIAN FEDERATION','150054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 19:40:58',0,NULL,3,1,2,1,'\\ ','janesht'),(2664,778537984012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.49,'eastar4uk','mtekiela','mtekiela@hotmail.com','Mike Tekiela','130 Stephens Road','London','London','UNITED KINGDOM','E15 3JL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 19:54:32',0,NULL,3,1,3,1,'RA117718456CN\r\\] ','mtekiela\rRELO002'),(2665,700882519011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',158.99,'eastar4','kaosbandit','adamsowens@gmail.com','Adam Owens','361 Castleton Cir','Boiling Springs','SC','UNITED STATES','29316','(864) 266-1965','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 19:55:06',0,NULL,3,1,1,1,NULL,'kaosbandit'),(2666,576203259013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','ruppel2854','kisel@gmx.net','Alexander Ruppel','Zur Sonnenhöhe 103','Iserlohn','','GERMANY','58636','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:01:21',0,NULL,3,1,2,1,NULL,'ruppel2854\r\\'),(2667,700885163011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','fredohdez','fredo@origen.com.mx','fredo hernandez balmaceda','Jojutla 93-3<br>Tlalpan centro','México','Distrito Federal','MEXICO','14000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:01:25',0,NULL,3,1,2,1,NULL,'fredohdez\r\\'),(2668,778550533012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:18:01',0,NULL,3,1,3,1,'RA117718924CN\r\\ ','avextra-co-uk\r一共买了4件\rOTCN004*10'),(2669,576210405013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','giannimiguel','g.miguel5@gmail.com','miguel gautier','la caudierie, route de lengronne','cerences','Basse-Normandie','FRANCE','50510','0659721041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:20:31',0,NULL,3,0,2,1,NULL,'giannimiguel\r欧标\r\\'),(2670,665362404001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','saulzamora1979','saulzamora1951@yahoo.com','saul zamora','4340 Ming Ave<br>Ste A','bakersfield','CA','UNITED STATES','93309-4885','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 20:42:38',0,NULL,3,1,1,1,NULL,'saulzamora1979\r\\'),(2671,700918447011,320679564112,'New Ultimate Ears MetroFi 170vi  Earphones with Voice',1,'HSUE001',13.5,'eastar4uk','giorgos3347','vlachos_g@hotmail.com','giorgos vlachos','stratoula<br>1','athens','nkosmos','GREECE','11744','210 9332374','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 21:13:37',0,NULL,3,1,2,1,NULL,'giorgos3347\r\\'),(2672,576232071013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','shoval1971','shovaal@hotmail.com','Shoval  Shimon','Haalonim 5','Beer yaakov','Israel','ISRAEL','70300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 21:28:13',0,NULL,3,1,2,1,NULL,'shoval1971\r\\'),(2673,576215740013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',11.99,'eastar4','12313alfred','autoaltima@hotmail.com','mohamed karout','12313<br>Alfred','Montreal','QC','CANADA','H1G5C8','(514) 835-9235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 21:51:29',0,NULL,3,1,2,1,NULL,'12313alfred\r\\'),(2674,576243070013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','maristel02','kristelraider@yahoo.com','marian  webster','3426 Merkner Dr','glen allen','VA','UNITED STATES','23060-3206','(804) 868-8666','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'maristel02'),(2675,778599081012,220448689432,'Acer Aspire 4730Z 4930Z Bluetooth Module EDR 2.0+cable',1,'BTAC2019',12.5,'eastar4','burn1234567','burn2@comcast.net','Dragan Dimitrijevic','26710 w orchard ave','antioch','IL','UNITED STATES','60002-9133','(847) 589-0578','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 22:10:08',0,NULL,3,1,1,1,NULL,'burn1234567\racer 8pin1.00 6cm \r\\'),(2676,576246798013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',158.99,'eastar4','bigshanon','bigshanon@gmail.com','Shanon Newson','po box 119','rye','Victoria','AUSTRALIA','3941','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 22:27:18',0,NULL,3,1,3,1,'RA117714030CN\r\\ ','bigshanon\rRCLO003'),(2677,778613233012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','nomel28','gangamartial@aol.com','Martial GANGA','210 ufton court<br>Canberra Drive','Northolt Middesex','Middlesex','UNITED KINGDOM','UB5 6JQ','07933934488','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 22:55:00',0,NULL,3,1,2,1,NULL,'nomel28\r\\'),(2678,0,230613619088,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','lriasnady','lriasnady1@wmconnect.com','RANDALL FOSTER','1875 Highway 907','MONTEREY','LA','UNITED STATES','71354','(318) 421-0106','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 22:57:29',0,NULL,3,1,1,1,NULL,'lriasnady\r\\'),(2679,778637524012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','marioenr','mario@marsyl.ca','Mario Faucher','563 des pins','Ste-Brigide d\'iberville','QC','CANADA','j0j 1x0','(450) 577-1869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 00:20:09',0,NULL,3,1,3,1,'RA117718368CN\r\\ ','marioenr\rHSSH002\r'),(2680,576272467013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','bdgold','asubhan175@yahoo.com','Abdus Subhan','C/ Carretes 34, 01º 01ª','Barcelona','Cataluña','SPAIN','08001','634273405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 00:34:39',0,NULL,3,1,2,1,NULL,'bdgold\r\\'),(2681,0,230613618490,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','dncfaeri','debnarasaki@comcast.net','deb narasaki','250 Parkside Dr','palo alto','CA','UNITED STATES','94306','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-27 00:35:36',0,NULL,3,1,1,1,NULL,'dncfaeri\r\\'),(2682,576288936013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','zensun-half','psunjar@yahoo.com','Peter Susnjar','7871 112A st','Delta','BC','CANADA','v4c4y4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 01:51:45',0,NULL,3,1,2,1,NULL,'zensun-half\r\\'),(2683,778679273012,220759911881,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',41.99,'eastar4','jtargosz1','jk@targosz.com','Jacek Targosz','12250 Milly Dr','doylestown','OH','UNITED STATES','44230-9328','(330) 606-8902','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 02:48:36',0,NULL,3,1,1,1,NULL,'jtargosz1\\'),(2684,778681037012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','ansel128','pauler@aei.ca','Bruno Bourgeois','2521 Chapleau','Montreal','QC','CANADA','H2K 3H5','(514) 521-8433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 02:53:22',0,NULL,3,1,2,1,NULL,'ansel128\r\\'),(2685,778683919012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','greathammadur','hammadurb@gmail.com','Hammadur Bhandari','18009 Cozumel Isle Dr','Tampa','FL','UNITED STATES','33647-3374','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 03:04:22',0,NULL,3,1,1,1,NULL,'greathammadur\r\\'),(2686,774991163012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','goldhair78','goldhair8@hotmail.com','Phong Nguyen Ha','Körsbärsvägen 6','Hässleholm','Skåne','SWEDEN','28140','+46732020188','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 04:03:16',0,NULL,3,0,2,1,NULL,'goldhair78'),(2687,778719175012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',3,'HSMO011',38.97,'eastar4','jtor7278','torresilla@hotmail.com','jose torres','3131 W Wapato Dr<br>Unit 61','moses lake','WA','UNITED STATES','98837-2955','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 06:04:01',0,NULL,3,1,1,1,' ','jtor7278'),(2688,778720869012,220747230960,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',10.5,'eastar4uk','kelvintse','kelvint2@hotmail.co.uk','Kelvin Tse','The Palace<br>The Close','Lichfield','Staffordshire','UNITED KINGDOM','WS13 7LH','07917110289','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 06:12:09',0,NULL,3,1,3,1,'RA117719006CN\r\\ ','kelvintse\rHSUE004'),(2689,701049653011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',4,'OTCN002',15.96,'eastar4','reggie.ferguson','jeremy@biasboating.co','Jeremy Hill','304 Manns rd','West Gosford','New South Wales','AUSTRALIA','2250','0243236273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 06:19:11',0,NULL,3,1,2,1,NULL,'reggie.ferguson'),(2690,524422780003,130490590870,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',83,'cnfaner','rizabozaci','rizabozaci@gmail.com','riza bozaci','Serap Cad. Köroglu sok. Kursunlu Apt.<br>no:3 Daire:5 Adatepe','ISTANBUL','','TURKEY','34843','+905333898789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 08:32:20',0,NULL,3,1,3,1,' RA117718495CN','rizabozaci\rTRTT002*10\r把发票放在包装盒里'),(2691,778751386012,220704730766,'New Plantronics Voyager 855 Bluetooth Headset+carcharge',1,'HSPL009+CCPL001',25,'eastar4uk','suharoid','ilyin.viktor@gmail.com','Viktor Ilyin','4-1 Gzhatskaya Str. App. 39','Moscow','RU','RUSSIAN FEDERATION','121471','(7903)5684444','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 08:38:56',0,NULL,3,1,3,1,'RA117718558CN ','suharoid\r\rHSPL009+CCPL001'),(2692,574063673013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',61.8,'eastar4','itishwang','djhwanghdj@naver.com','Hwang Dojung','10-16 Pil-dong 3-ga, Jung-gu','seoul','','KOREA,REPUBLIC OF','100-273','82-10-4721-5302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 08:48:21',0,NULL,3,1,3,1,' RA117718544CN','itishwang\rWWSI005'),(2693,576353316013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','aleksanderpap','a.poteev@gmail.com','Alexander Poteev','Rokossovsky aveniu 145-426','Minsk','','BELARUS','220085','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 09:05:22',0,NULL,3,1,2,1,NULL,'aleksanderpap'),(2694,778761657012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','sanson16','csac@misco.es','Carlos Sánchez Escudero','C/ de la Granja nº 20','Daganzo de Arriba','Madrid','SPAIN','28814','656595686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 09:17:48',0,NULL,3,1,2,1,NULL,'sanson16'),(2695,701098530011,320441575447,'2.1 Acer Aspire 7730 7730G 7730Z Bluetooth Module+cable',1,'BTAC2112',12.8,'eastar4','conodi','info@conodi.com','Conodi limited','Willibaldstrasse 27','München','','GERMANY','80689','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 10:13:06',0,NULL,3,1,2,1,' 、','conodi\racer 5pin1.25 4cm'),(2696,701111147011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mrcavad','premier5565@gmx.fr','Cavad Mamedov','Balabala Mecidov 56','Baku','','AZERBAIJAN','az1009','0707455565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 11:10:23',0,NULL,3,1,2,1,'、 ','mrcavad'),(2697,778793852012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',21.9,'eastar4','kheder1234','m.khodr@live.com.au','moe khodr','29 glengyle st','melbourne','Victoria','AUSTRALIA','3058','0422406253','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'kheder1234'),(2698,701122558011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','martunia0407','martusiek0407@o2.pl','Marta Bednarczyk','109 Gladstone st','west bromwich','West Midlands','UNITED KINGDOM','b71 1et','07597711266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 11:45:02',0,NULL,5,0,18,0,NULL,'martunia0407\r客户想撤单'),(2699,701136856011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','tecking_singapore','tecking_mail@yahoo.co.uk','Low Teck Ing','Block 234 Bukit Batok East Ave 5<br>#04-115','default','','SINGAPORE','650234','82820852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 12:36:34',0,NULL,3,1,11,1,NULL,'tecking_singapore\rADAK002'),(2700,776453581012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','ayannami','paulamontenegrodias@gmail.com','Paula Montenegro Dias','AVENIDA PREFEITO DULCIDIO CARDOSO<br>2920, AP 1601, BARRA DA TIJUCA','Rio de Janeiro','RJ','BRAZIL','22631-052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 13:36:48',0,NULL,3,1,3,1,' RA117718513CN','ayannami\rOTSO002'),(2701,778844082012,220759518239,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',27.99,'eastar4uk','jc.auctioneer','johnchen.yc@gmail.com','John Chen','25 Brickworks Drive','Brunswick','Victoria','AUSTRALIA','3056','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 14:03:53',0,NULL,3,1,3,1,'RA117718487CN ','jc.auctioneer\rCMLO001'),(2702,701164985011,320684990784,'New Sony Ericsson HBH-DS200 Stereo Bluetooth  Headset',1,'HSSE009',39.85,'eastar4','discreetred7','heather.ustick@gmail.com','Heather Ustick','Unit 34/11 Fawkner Street','Braddon','Australian Capital Territory','AUSTRALIA','2612','0262759247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 14:14:24',0,NULL,3,1,3,1,' RA117718601CN','discreetred7\rHSSE009\r澳标'),(2703,576416693013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','444xc','j46w2005@aol.com','jimmy wright','102 Noble Ave NE<br>Apt B','roanoke','VA','UNITED STATES','24012-4733','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 14:33:50',0,NULL,3,1,1,1,NULL,'444xc\r\\'),(2704,701173913011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','raswalker','ebay@theoldjas.com','Petar Oldja III','2518 Madison St','Paducah','KY','UNITED STATES','42001','(732) 947-4122','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 14:39:29',0,NULL,3,1,1,1,NULL,'raswalker\r\\'),(2705,701178589011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mannimondeo','meyer-remlingen@t-online.de','Manfred Meyer','Dorfstraße 4','Klein Biewende','','GERMANY','38319','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 14:54:51',0,NULL,3,1,2,1,'、 ','mannimondeo'),(2706,701179158011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','1926chelsea','martin4fran@hotmail.com','martin green','2 rockfort est','wallingford','oxon','UNITED KINGDOM','ox10 9da','01491836282','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 14:55:30',0,NULL,3,1,3,1,'RA117718535CN ','1926chelsea\rMOAP001'),(2707,0,320690016092,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',2.9,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-27 14:57:56',0,NULL,5,0,18,0,NULL,'blue8sky'),(2708,0,220774366874,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',22.3,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 14:57:59',0,NULL,5,0,18,0,NULL,'blue8sky'),(2709,0,230613185007,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',12.9,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 14:58:06',0,NULL,5,0,18,0,NULL,'blue8sky'),(2710,701188162011,320465511535,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',3.87,'eastar4','verabatgirl','verabatgirl@telia.com','Veronica Carlsson','Brittgården 123','Tibro','','SWEDEN','54337','+46706944026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 15:21:16',0,NULL,3,1,2,1,' 、','verabatgirl'),(2711,778877249012,220572910849,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET HS 12W',1,'HSNO025',59.9,'eastar4','transformersandgsmphones','labbek@gmail.com','Overseas Electronics','2457 W Devon Ave','Chicago','IL','UNITED STATES','60659-1914','(773) 274-3764','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 15:27:34',0,NULL,3,1,1,1,NULL,'transformersandgsmphones\r\\'),(2712,530256696004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','matute682','crespo_matias@hotmail.com','Matias Crespo','Aldo della rosa<br>5779','Villa Bosch','Buenos Aires','ARGENTINA','1682','+5491151101641','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 16:32:59',0,NULL,3,1,3,1,' RA117718527CN','matute682\rHSMO007'),(2713,576452245013,230412694830,'2.0 Bluetooth Module cable DELL mini10 10v 1010 1011',1,'BTDE2002',12.5,'eastar4','bazwebb','barry@essexboy.us','Barry Webb','285 Turkey Ridge Rd','Charlottesville','VA','UNITED STATES','22903','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 16:40:58',0,NULL,3,1,1,1,NULL,'bazwebb\r\\'),(2714,701223587011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.8,'eastar4','bekir.ushcs','bekir.tuncer@ushcs.net','Bekir TUNÇER','4343 Shallowford Rd<br>Ste H4B','Marietta','GA','UNITED STATES','30062-5008','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 16:54:01',0,NULL,3,1,1,1,NULL,'bekir.ushcs\racer 4pin1.25 6cm \r\\'),(2715,778925306012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.8,'eastar4','lucianosobue','lucianosobue@gmail.com','Luciano Sobue','Av. Americo Dezorgi, 455<br>Jd. Bela Vista','Barrinha','São Paulo','BRAZIL','14860-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 17:22:28',0,NULL,3,1,2,1,'、 ','lucianosobue\rAcer 5pin1.25 3cm '),(2716,701252870011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','istencsaszar','ezittaz@vipmail.hu','Peter Stefkovics','Ludvigh u. 34.','Bekescsaba','','HUNGARY','5600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 18:00:08',0,NULL,3,1,2,1,'\\ ','istencsaszar\r'),(2717,576478722013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','crossxc','crosscountryci@gmail.com','Mikal Applewhite','1201 Wheeler St S','Tacoma','WA','UNITED STATES','98444-3843','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 18:03:54',0,NULL,3,1,1,1,NULL,'crossxc\r\\'),(2718,576480021013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','cesargoza','cesargoza@yahoo.com','Cesar Gonzalez','Alangasi Calle Juan Montalvo 431 y Abdón Calderon<br>Valle de los Chillos','Quito','Pichincha','ECUADOR','EC170151','593 97322242','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 18:07:04',0,NULL,3,1,2,1,' 、','cesargoza'),(2719,778950272012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','madiazs','mads.mads@gmail.com','MAURICIO ALFONSO DIAZ SUAREZ','AVENIDA CONSISTORIAL 2320-33<br>PEÑALOLÉN','SANTIAGO','METROPOLITANA','CHILE','794-1137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 18:16:58',0,NULL,3,1,2,1,' 、','madiazs'),(2720,701265163011,320402069233,'HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR 2.0+cable',1,'BTHP2007',12.5,'eastar4','mfocker87','kaneymarta@hotmail.com','marta de juan romero','calle corral de cantos n 6 1-c','puente de vallecas','Madrid','SPAIN','28053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 18:24:26',0,NULL,3,1,2,1,' 、','mfocker87\rHP 8pin 1.0 23cm'),(2721,576485211013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','ecle7855','eduardo.clerigues@gmail.com','Eduardo Clerigues Martínez','Avda. Dr. J.J. Dominez 18 - 46','Valencia','Valencia','SPAIN','46011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 18:24:34',0,NULL,3,1,2,1,'、 ','ecle7855'),(2722,778962389012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','fac_clayton','clayton.luis@gmail.com','Clayton Luis Rodrigues','Rua Oswaldo Andrelli Silva, 41<br>Bloco B AP 24 Vila União, Campinas','Brazil','São Paulo','BRAZIL','13060774','55 19 81132048','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 18:37:23',0,NULL,3,1,3,1,'RA117718500CN ','fac_clayton\rOTRA002'),(2723,701275457011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.8,'eastar4','evolv4ever','rnadal@hotmail.com','ray nadal','611 e blair st','west chicago','IL','UNITED STATES','60185','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 18:45:23',0,NULL,3,1,1,1,NULL,'evolv4ever\r\\'),(2724,701299923011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','positionx','robert@viascript.ca','Robert Brunet','257 Lepage','Dorval','QC','CANADA','H9S 3E7','(514) 631-1911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 19:33:24',0,NULL,3,1,2,1,'、 ','positionx'),(2725,779009242012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','fjr_07','fjr_gaviao@hotmail.com','Fernando Jose Ribeiro','Rua Embu-Guaçu  13-C<br>Vila Menck','Osasco','São Paulo','BRAZIL','06270250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 20:02:43',0,NULL,3,1,2,1,'、 ','fjr_07'),(2726,701331278011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',50,'TRMX002',427.5,'eastar4','usedrouters','purchasing@cablesandkits.com','AtlanTech Resellers, Inc.','4555 Atwater Ct<br>Ste A','Buford','GA','UNITED STATES','30518-3498','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 20:42:37',0,NULL,3,0,4,1,'YW866011382CN ','usedrouters\r'),(2727,530347871004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','lilas0425','christine.huot@hotmail.com','Christine Huot','3135 Stornoway Circle','Oakville','ON','CANADA','L6M5H9','(647) 267-2028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:30:50',0,NULL,3,1,3,1,' RA117718473CN','lilas0425\rHSPL011'),(2728,701358647011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','jaems8282','james8282@hanmail.net','JUNGBYUNG PARK','Block A, Flat 034, Room D, Piccadilly Point,<br>23 Berry Street,','Manchester','Greater Manchester','UNITED KINGDOM','M1 2AD','07749412439','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:47:48',0,NULL,3,1,3,1,'RA117718561CN ','jaems8282\rUDAP001'),(2729,701360056011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','ruvvo','fareastern@gmail.com','YAN BOKALDER','Gamarnika street, 12-B, 30','Vladivostok','Primorsky Kray','RUSSIAN FEDERATION','690033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:51:39',0,NULL,3,1,3,1,'RA117718460CN ','ruvvo\rRCLO006\r'),(2730,576561989013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','bmeyer1888','bmeyer1888@msn.com','DIVE BAR','3035 White Bear Ave N<br>Ste 12','maplewood','MN','UNITED STATES','55109-1321','(612) 701-9896','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 22:09:49',0,NULL,3,1,1,1,NULL,'bmeyer1888\r\\'),(2731,530358377004,140428313198,'2.1 Acer Travelmate 5520 bluetooth module offer track#',1,'BTAC2109',13.99,'cnfaner','snarf264','franshjj264@aol.com','Frans Beuvink','1194 Ute Pass','San Angelo','TX','UNITED STATES','76901','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 22:17:02',0,NULL,3,1,1,1,NULL,'snarf264\racer 4pin1.25 20cm\r\\'),(2732,701370955011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','kromulis4hys','kromulis@optonline.net','Kevin Facal','5 Oak Haven Pl','East Northport','NY','UNITED STATES','11731-6516','(631) 486-8700','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 22:24:36',0,NULL,3,1,1,1,NULL,'kromulis4hys\r\\'),(2733,779092497012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','lorddc','gazza89@gmail.com','gary glover jr','10 palmstead road','sunderland','Tyne and Wear','UNITED KINGDOM','sr48ew','07961602267','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 23:38:06',0,NULL,3,1,3,1,' RA117718575CN','lorddc\rOTCN003\r'),(2734,665820127001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','melons37','stnow@charter.net','Stephen Nowaskie','4817 N Camp Arthur Rd','Bruceville','IN','UNITED STATES','47516','(812) 882-0402','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 00:10:53',0,NULL,3,1,1,1,NULL,'melons37\rLK044033648CN \r\\'),(2735,530379972004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','segmentor','segmentor@terra.es','SAMUEL RAMOS ORIHUELA','C/ ITALIA, 21 - 2ºPISO','LAS PALMAS','Canarias','SPAIN','35006','928241484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 00:18:19',0,NULL,3,1,3,1,'RA117718589CN ','segmentor\rWLAT008\r'),(2736,575639598013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','syou1306','lookout21@optonline.net','Susan Young','21 Lookout Dr','Ledgewood','NJ','UNITED STATES','07852','(973) 445-0263','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 00:20:12',0,NULL,3,1,1,1,NULL,'syou1306\r\\'),(2737,701438609011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',24.9,'eastar4','utru6083','chepa56@hotmail.com','URIEL TRUJILLO','93 PRINCETON AVE','DOVER','NJ','UNITED STATES','07801-2528','(973) 343-7808','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 02:59:58',0,NULL,3,1,1,1,NULL,'utru6083\r\\'),(2738,665865643001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','panelsky2011kothwala','panelsky2011@gmail.com','KOTHWALA HERATH','453, VILLA REGINA<br>HEERASSAGALA','KANDY','CENTRAL','SRI LANKA','24000','0094716859686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 03:39:37',0,NULL,3,1,3,1,' RA117718748CN','panelsky2011kothwala\rOTSO001'),(2739,779169763012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','crystalccl','maria@crystalclean.com','Con Schultz','223 - 12 St B N','Lethbridge','AB','CANADA','T1H 2K8','(403) 381-0015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 04:36:38',0,NULL,3,1,2,1,'、 ','crystalccl'),(2740,530421479004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','kykla','y.kagan@yahoo.com','Yelena Kagan','9810 Juniper Hill Rd','Rockville','MD','UNITED STATES','20850','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 04:38:54',0,NULL,3,1,1,1,NULL,'kykla'),(2741,701474827011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','driver342933','brent.dunn@gmail.com','Brent Dunn','1177 Rockingham, Unit #3','Ottawa','ON','CANADA','K1H 8A6','(613) 907-1198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 06:09:39',0,NULL,3,1,2,1,'、 ','driver342933'),(2742,576670415013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','k3n610','kengio@gmail.com','Suppaseth Charoenkarnka','9/56 Vista Park Prachachuen<br>Samakkee Road, Bangtalad','Pakkred','Nonthaburi','THAILAND','11120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:05:59',0,NULL,3,1,2,1,NULL,'k3n610'),(2743,779224633012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','10roneno12','roneno12@bezeqint.net','ronen oren','lebar zaav  15','natanya','','ISRAEL','42524','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:10:07',0,NULL,3,1,2,1,NULL,'10roneno12'),(2744,779230547012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',17.73,'eastar4','hardl0ck','hardlock@bk.ru','Yuriy Filippenko','Pobeda 87, 113','Zaporozhje','ZP','UKRAINE','69000','+380676147252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:36:30',0,NULL,3,1,2,1,NULL,'hardl0ck\r再发一个NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET \r欧标'),(2745,576677701013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','drumsrme','rick.retiredtech@gmail.com','Rick Berthiaume','595 iowa ave e','Saint Paul','MN','UNITED STATES','55130-3026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 09:51:32',0,NULL,3,1,1,1,'、 ','drumsrme'),(2746,576682177013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',10,'WLAP008',189.9,'eastar4','michel_egorov','maket888@gmail.com','DMITRIY POPOV','ul. Spartakovskaya, dom 19 korp. 2, kv. 25<br>ул.Спартаковская, дом 19 корп. 2, кв. 25','Moscow','RUSSIA','RUSSIAN FEDERATION','105066','+79057183878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:17:09',0,NULL,3,1,3,1,'RA117718853CN\r\\ ','michel_egorov\rWLAP008'),(2747,701527131011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','hozudogru','hozudogru@gmail.com','Hasim Ozudogru','GAZI UNIVERSITESI<br>ENDUSTRIYEL SANATLAR EGITIM FAKULTESI Bahçelievler Mah.','ANKARA','GOLBASI','TURKEY','06830','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:21:42',0,NULL,3,1,2,1,NULL,'hozudogru\r欧标'),(2748,530467617004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','milanocarvalho','milanogc@gmail.com','Aurélio Carvalho','R. Gonçalves Ledo, 660. Apto. 502<br>Centro','Fortaleza','CE','BRAZIL','60110260','+558597192263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:33:20',0,NULL,3,1,3,1,'RA117718840CN\r\\ ','milanocarvalho\rOTRA002\r'),(2749,701532031011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','filet-crochet-designs','info@filet-crochet-designs.com','TATYANA  KARAMAGIAS','3, Viktor Hugo Str.','Thessaloniki','','GREECE','546 25','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:43:38',0,NULL,3,1,2,1,NULL,'filet-crochet-designs\r欧标\r\\'),(2750,574637924013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','vaggoz','vaggozpay@gmail.com','Evangelos Kalaitzakis','Apeiranthou 4','Galatsi','Athens','GREECE','11147','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:43:39',0,NULL,3,1,3,1,'RA117718782CN\r\\ ','vaggoz\rMOSA002'),(2751,524727840003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',16.75,'cnfaner','king3995','onlocation2005@sbcglobal.net','Carlos King','652 Albrook Dr','ALLEN','TX','UNITED STATES','75002-4701','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 10:44:51',0,NULL,3,1,1,1,'、 ','king3995'),(2752,779248798012,220713846397,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET',1,'HSNO017',13.29,'eastar4uk','visvaldas2010','letkauskasvisvaldas4@gmail.com','Visvaldas Letkauskas','Vapsvu 24<br>Karsakiskio sen. Naujiku k.','Panevezio raj.','Panevezio raj','LITHUANIA','38464','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 10:46:48',0,NULL,3,1,2,1,'\\ ','visvaldas2010\r欧标\r'),(2753,701340224011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',14.99,'eastar4','ps8jn','ps7jn@hotmail.com','Joaquim das Virgens Neto','Rua Goias 312-sul<br>Ilhotas','Teresina','Piaui','BRAZIL','64001-620','(86) 94339839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 11:43:02',0,NULL,3,1,2,1,'\\ ','ps8jn\r'),(2754,576699292013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','samuelgideon','samuelgid@gmail.com','gideon samuel','sokolov 126<br>frishman 2','holon','Israel','ISRAEL','58351','0548190169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 11:50:31',0,NULL,3,1,2,1,'\\ ','samuelgideon'),(2755,779278839012,220713846368,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET',1,'HSNO016',11.9,'eastar4uk','jerryjose_90','mangalathjerry@yahoo.com','jerry anto','3<br>Eynsford st','carindale','Queensland','AUSTRALIA','4152','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 12:35:32',0,NULL,5,0,18,1,NULL,'jerryjose_90\r\r已经退款'),(2756,530492930004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','cnay0','hiddent@swbell.net','Charlie Nay','542 N Main St','Duncanville','TX','UNITED STATES','75116-3655','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 12:51:39',0,NULL,3,1,1,1,'、 ','cnay0'),(2757,779284522012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','ibaie1990','noe.mage@gmail.com','Noé Mage c/o Manigley','14 route du crépis','Ballaison','Rhône-Alpes','FRANCE','74140','0041787147316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 12:52:46',0,NULL,3,1,2,1,'\\ ','ibaie1990'),(2758,779276600012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','yakkon39rus','yakkon@yandex.ru','Konstantin Yakunin','pt.Leninsky 94-14','Kaliningrad','Kaliningradskaya obl','RUSSIAN FEDERATION','236039','89114810481','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:02:18',0,NULL,3,1,2,1,'\\ ','yakkon39rus'),(2759,576714634013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',37.2,'eastar4','mmenti','mame@bug.ch','Marco Menti','Bergstrasse 20','Stäfa','','SWITZERLAND','8712','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:07:07',0,NULL,3,1,3,1,'RA117718836CN\r\\ ','mmenti\rWWSI004+ANCN001'),(2760,576720331013,230393147201,'2.1 Acer TM 2400 3210 3220 3230 Bluetooth Module +cable',1,'BTAC2122',12.8,'eastar4','treadmill537','john.gibson47@ntlworld.com','John Gibson','6 Glaramara Close<br>Brownsover','Rugby','Warwickshire','UNITED KINGDOM','CV21 1JE','07724850498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:32:31',0,NULL,3,1,2,1,'\\ ','treadmill537\racer 8pin1.00 8cm '),(2761,701578912011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','smint1986','ruslanass@gmail.com','Ruslanas Sobolevas','Alsėdžių 1-31','Kaunas','','LITHUANIA','LT-44456','+37065130390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:33:21',0,NULL,3,1,2,1,'\\ ','smint1986'),(2762,776733178012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','computer615','ryanbirk@gmail.com','Ryan Birk','10101 Pendula Dr','Indianapolis','IN','UNITED STATES','46236-7365','(317) 650-3310 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 13:36:49',0,NULL,3,1,1,1,'、 ','computer615'),(2763,779307056012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',4,'HSSH002',143.96,'eastar4','arkangel-hz3','foued@arkan.fr','foued moukid','24 allee de penthievre','livry gargan','Ile-de-France','FRANCE','93190','0682045368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 14:12:08',0,NULL,3,1,3,1,'RA117718819CN\r\\ ','arkangel-hz3\rHSSH002'),(2764,701591600011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','robantsto','robstorino@yahoo.com','Robert Storino','19121 Allison Square','West Windsor','NJ','UNITED STATES','08550','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 14:19:58',0,NULL,3,1,1,1,'、 ','robantsto'),(2765,779316296012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','tournataka0646','vriens.jurre@gmail.com','Jurre Vriens','Gerard Walschaplaan 48','Roosendaal','','NETHERLANDS','4707CS','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'tournataka0646'),(2766,701549092011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',2,'CACN003',27,'eastar4','321tocsin','post@tocsin.de','Manfred Bock','Frankenstr. 20','Remshalden','','GERMANY','73630','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 14:41:34',0,NULL,3,1,2,1,'\\ ','321tocsin'),(2767,701613657011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',10,'HSPL009',439,'eastar4','gogo-buyers','buyers@gogotech.com','Nathaniel Long','34 34th St<br>Ste 3','Brooklyn','NY','UNITED STATES','11232-2020','(212) 386-7193 ext.: 119','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 15:27:39',0,NULL,3,1,4,1,'YW866011371CN ','gogo-buyers\r'),(2768,779338152012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','maksym1378','max1378@ukr.net','Shaposhnykov Maksym','14 Ozernaya str.  App 16','Kiev','','UKRAINE','04209','0679023440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 15:36:30',0,NULL,3,1,2,1,'\\ ','maksym1378'),(2769,576753800013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','hawg_rider_2112','johnb5403@gmail.com','John Bayer','214-84 Oakville Ave.','London','ON','CANADA','N5V 2S5','(519) 455-6376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 15:51:17',0,NULL,3,1,3,1,'RA117718751CN ','hawg_rider_2112\rMOLO004\r华硕版的'),(2770,779353367012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',1,'ANYA002',19.5,'eastar4','chooter50','chooter3@msn.com','ed Harris ATTN RuthMartin','1502 S Mildred St<br>Apt 204','Tacoma','WA','UNITED STATES','98465-1609','(253) 327-3871','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 16:16:54',0,NULL,3,1,11,1,' RA117714366CN','chooter50\rANYA002');
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (2771,779395388012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',2,'HSSE003',43.8,'eastar4','skylightindustries','saveholm@telia.com','Patrik  Säveholm','Forsbrovägen 4','Arbrå','none','SWEDEN','82010','070-2333167','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 17:53:36',0,NULL,3,1,3,1,'RA117718907CN\r ','skylightindustries\rHSSE003\r欧标\r\\'),(2772,701672737011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','midnight1337','iambadkarma0@aim.com','Adam Batchelor','PO Box 553','Midland City','AL','UNITED STATES','36350-0553','(334) 797-4807','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 17:58:28',0,NULL,3,1,1,1,'、 ','midnight1337'),(2773,779408965012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','zaferzarar226','zaferzarar@gmail.com','ZAFER YAPICIOGLU','mumtaz apt.no:4<br>ismet inonu bulvari','GAZIMAGUSA','KIBRIS','TURKEY','MERSIN 10','00905338700018','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 18:21:27',0,NULL,3,1,2,1,NULL,'zaferzarar226\r欧标\r\\'),(2774,701689345011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',17.4,'eastar4','adonis.bunn','adonis.bunn@gmail.com','adonis bunn','825, José Tomasi','Curitiba','Paraná','BRAZIL','82015-630','55 41 33726746','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 18:34:53',0,NULL,3,1,3,1,'RA117718822CN\r\\ ','adonis.bunn\r再发两个CAB-2626\rCASS003+CASS001'),(2775,779418454012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','tornadord','tornado1@mail.ru','Roman Dmitrievich','Tarhova st. 14b - 5','Saratov','Saratov','RUSSIAN FEDERATION','410064','+79033805555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 18:41:04',0,NULL,3,1,2,1,'\\ ','tornadord\r欧标'),(2776,576823040013,230512575271,'Genuine Logitech Harmony LED 515 Remote Control',1,'RCLO004',60,'eastar4','trainergs1','cbrauning@goodwillakron.org','Chris Brauning','109 Karns Dr','Dover','OH','UNITED STATES','44622-9428','(330) 343-0612','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 19:27:10',0,NULL,3,1,1,1,' ','trainergs1'),(2777,779453561012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',2,'HSSE003',43.8,'eastar4','shtimpee','shtimpee@yahoo.com.au','CIA Services Att Steve','PO Box 49','Seville','Victoria','AUSTRALIA','3139','61411334344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 19:46:04',0,NULL,3,1,3,1,'RA117718805CN\r\\ ','shtimpee\rHSSE003\r澳标'),(2778,779455205012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','bobybravo','bobybravo@abv.bg','Boris Vasilev','Mednikarska 21','Veliko Tarnovo','Veliko Tarnovo','BULGARIA','5000','00359885223621','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 19:48:47',0,NULL,3,1,2,1,'\\ ','bobybravo'),(2779,576837067013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','goldengemini1981','goldengemini81@gmail.com','Jun Hoe Chow','18 Leschen Way','Darlington','Western Australia','AUSTRALIA','6070','0434410020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:09:46',0,NULL,3,1,2,1,'\\ ','goldengemini1981'),(2780,701738784011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','virtualsudip','f66459092@gmail.com','Manoj Rami (C/o Sabre Machinery Pvt. Ltd.)','B 21 Neelamber Apts., Near Bank Of Baroda<br>HL College -  Xaviers Corner, Navrangpura,','Ahmedabad','GJ','INDIA','380009','66059550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:18:01',0,NULL,3,1,3,1,' RA117718646CN','virtualsudip\rEXLO001'),(2781,576845484013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',17.4,'eastar4','adonis.bunn','adonis.bunn@gmail.com','adonis bunn','825, José Tomasi','Curitiba','Paraná','BRAZIL','82015-630','55 41 33726746','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:33:46',0,NULL,8,1,17,0,NULL,'adonis.bunn'),(2782,576848594013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','jdboily','jdboily@gmail.com','Jean-Daniel Boily','123 laurie','Les coteaux','QC','CANADA','j7x0a3','(514) 467-5407','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:43:18',0,NULL,3,1,3,1,'RA117718765CN\r\\ ','jdboily\rOTRA002'),(2783,701763936011,320684990784,'New Sony Ericsson HBH-DS200 Stereo Bluetooth  Headset',1,'HSSE009',39.85,'eastar4','niton_007','niton007@hotmail.com','nazrul islam chowdhury','stora sällskapets vag 24','stockholm','Skärholmen','SWEDEN','12731','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 21:17:47',0,NULL,3,1,3,1,'RA117718632CN ','niton_007\rHSSE009\r'),(2784,779513105012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','msspencer-dassau','sonia.spencer10@yahoo.com','Sonia Spencer','4437 Mullens Ford Rd<br>Apt L','Charlotte','NC','UNITED STATES','28226-4015','(704) 277-6291','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 21:59:34',0,NULL,3,1,1,1,'、 ','msspencer-dassau'),(2785,701777340011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','jayjaee2000','jason.saunders@comcast.net','Jason Saunders','700 E Prosperity Ave<br>APT 29','Tulare','CA','UNITED STATES','93274','(559) 302-7558','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 22:01:20',0,NULL,3,1,1,1,'、 ','jayjaee2000'),(2786,779514791012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','rudykedem','rudy@rudy.org.il','Nemrod Kedem','3/3 Ha\'Imahot St.<br>POB 514','Nes-Ziona','','ISRAEL','74025','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 22:03:08',0,NULL,3,1,2,1,'\\ ','rudykedem\r欧标'),(2787,779524840012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','gaz_mac','garymccreadie@supanet.com','Gary Mccreadie','Focus 31, East Wing<br>Ground Floor, Mark Road','HEMEL HEMPSTEAD','Hertfordshire','UNITED KINGDOM','HP2 7BW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-28 22:33:49',0,NULL,3,1,3,1,'RA117718779CN\r\\ ','gaz_mac\rOTRA002\r'),(2788,701797907011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','hags978','hagshollow1@gmail.com','David Haggarty','7341  9th  line<br>RR #3','Thornton','ON','CANADA','L0L2N0','(705) 424-1497','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 23:08:57',0,NULL,3,1,2,1,'\\ ','hags978'),(2789,779545072012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','gunzo90','gunzo.90@videotron.ca','frederic kleinbaum','1632 des bouvreuils','terrebonne','QC','CANADA','j7m1x3','(514) 867-1002','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 23:43:28',0,NULL,3,1,2,1,'\\ ','gunzo90'),(2790,701814240011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','arec4328','amyrechner@live.com','amy rechner','2418 ravens crest dr','plainsboro','NJ','UNITED STATES','08536-2457','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 00:11:09',0,NULL,3,1,1,1,'、 ','arec4328'),(2791,576900452013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','funkrew','funkrewdotcom@yahoo.com','Patrick Lee','Barco, Inc.<br>11101 Trade Center Drive','Rancho Cordova','CA','UNITED STATES','95670','(916) 281-8114','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 00:19:30',0,NULL,3,1,1,1,'、 ','funkrew'),(2792,779558196012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','grune7','grune@localnetplus.com','Kevin Grubb','5715 Highfreeland Rd','Chandlersville','OH','UNITED STATES','43727','(740) 638-4740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 00:36:54',0,NULL,3,1,1,1,'、 ','grune7'),(2793,701823947011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','dovewing2000','shunwu@mindspring.com','Shunwing Wu','6138 San Vicente Blvd','Los Angeles','CA','UNITED STATES','90048','(323) 936-4709','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 00:50:04',0,NULL,3,1,1,1,NULL,'dovewing2000'),(2794,701824361011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mamarracho19','oscarzapata69@gmail.com','Oscar Zapata','27455 S Dixie Hwy','Homestead','FL','UNITED STATES','33032','(305) 336-3967','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 00:51:46',0,NULL,3,1,1,1,NULL,'mamarracho19'),(2795,576925899013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',92.7,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 02:22:21',0,NULL,3,1,3,1,'RA117718796CN\r\\ ','update_marcelo\rWWSI005'),(2796,666240416001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','don-halley','dehalley@ca.rr.com','Donald Halley','402 E Clarion Dr','Carson','CA','UNITED STATES','90745-1317','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 02:47:28',0,NULL,3,1,1,1,'、 ','don-halley'),(2797,701856586011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',18.9,'eastar4','h.guzella','h.guzella@gmail.com','Henrique Guzella','Av. Queiros Filho 442<br>Pq. Industriário','Santo André','São Paulo','BRAZIL','09110-260','(55 11) 75140010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 03:03:06',0,NULL,3,1,2,1,'\\ ','h.guzella\r欧标'),(2798,779601947012,220716842449,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','apatten','allanpatten@hotmail.com','Allan Patten','A. Harvey<br>60 Water St','St. John\'s','NL','CANADA','A1C 5V6','(709) 687-4493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 03:03:56',0,NULL,3,1,2,1,'\\ ','apatten'),(2799,701859652011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','saab914','saab914@aol.com','Peter J Ortiz','6928 Fox Haven Pl','Raleigh','NC','UNITED STATES','27616','(919) 647-4016','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-29 03:16:47',0,NULL,3,1,1,1,'、 ','saab914'),(2800,701866484011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','king_of_misc','c.g.beadles@gmail.com','cory beadles','208 N 24th Ave','Hattiesburg','MS','UNITED STATES','39401-5938','(601) 341-9170','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 03:50:29',0,NULL,3,1,1,1,'\\ ','king_of_misc'),(2801,576953714013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','fjelltun','e.aure@hotmail.com','Eivind Aure','Klungrebakken','Skodje','Skodje','NORWAY','6260','90094036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 05:24:34',0,NULL,3,1,2,1,' \\','fjelltun'),(2802,701885205011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','victorasieduyoung','victor.asieduyoung51@gmail.com','Victor Asiedu-Young','71 Nightstar Drive','Richmond Hill','ON','CANADA','L4C 8H5','(647) 701-5952','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'victorasieduyoung'),(2803,701894695011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.9,'eastar4','kevinlouie','kevinlouie@hotmail.com','Kevin Louie','215 Park Row<br>Apt. 6E','New York','NY','UNITED STATES','10038','(917) 836-1810','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 06:35:21',0,NULL,3,1,1,1,'\\ ','kevinlouie'),(2804,779646594012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',2,'OTGR001+OTGR002',79.8,'eastar4','deeznutz2377','deeznutz@internode.on.net','Brad Kyaw','28 Heatherdale Street','Amaroo','Australian Capital Territory','AUSTRALIA','2614','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 06:52:52',0,NULL,3,1,3,1,' RA117718650CN','deeznutz2377\rOTGR001+OTGR002\r'),(2805,576985752013,230545855021,'2.1 Acer TM 3000 3020 /AS5760 Bluetooth Module+cable',1,'BTAC2126',12.8,'eastar4','kw9_greece','kw9@mail.ru','Yuri Nikolaidis','Papafeofilou 9','KILKIS','KILKIS','GREECE','61100','030 6972961100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 09:15:56',0,NULL,3,1,2,1,NULL,'kw9_greece\racer 8pin1.25 10cm'),(2806,574373343013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','poshk2009','poshkevin@gmail.com','POSH Poon','21b<br>yelverton st','st peters','New South Wales','AUSTRALIA','2044','0403743886','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 10:01:16',0,NULL,3,1,2,1,NULL,'poshk2009\r澳标'),(2807,701942529011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','richb0','richard.boulding@ntlworld.com','Richard boulding','18, Baldocks lane','Melton Mowbray','Leicestershire','UNITED KINGDOM','LE131EN','07773559487','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 10:29:27',0,NULL,3,1,2,1,'\\ ','richb0'),(2808,530751957004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','jsnider1970','jsnider1970@yahoo.com','Joe Snider','2267 Ravenwood Trl','Marietta','GA','UNITED STATES','30066','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-29 10:58:08',0,NULL,3,1,1,1,'\\ ','jsnider1970'),(2809,779689458012,220713846354,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET+carcharger',1,'HSNO006+CCNO001',11.49,'eastar4uk','joaosimas','joaosousasimas@hotmail.com','João Simas','Rua Dos Canos Verdes N.º 10<br>Angra do Heroismo','Angra do Heroismo','açores','PORTUGAL','9700-040','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 10:59:08',0,NULL,3,1,2,1,' \\','joaosimas'),(2810,779702417012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',3,'OTCN004*10',50.37,'eastar4','jaras_cro','josiparas@gmail.com','Josip Aras','Obala palih omladinaca 11','Šibenik','Croatia','CROATIA','22000','+38598816414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 10:59:34',0,NULL,3,1,3,1,'RA117732095CN\r ','jaras_cro\rOTCN004*10\r'),(2811,576430039013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','thing2397','siewthing2397@hotmail.com','soh siew thing','10E, Jalan Muar','Segamat','Johor','MALAYSIA','85000','0167172566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 11:48:02',0,NULL,3,1,2,1,'\\ ','thing2397'),(2812,701964695011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','j5robert','j5robert@alumni.uwaterloo.ca','Jon Robertson','223 High Park Ave<br>bsmt','Toronto','ON','CANADA','M6P2S5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 12:00:49',0,NULL,3,1,2,1,'\\ ','j5robert'),(2813,701967983011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','zetlaw','zetlawi@bezeqint.net','Idan Zetlawi','Bialik 121/2','Beer-sheva','','ISRAEL','84308','972544910895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 12:14:18',0,NULL,3,1,2,1,'\\ ','zetlaw'),(2814,779732551012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','route66_oldie','holjoh1@yahoo.com','John Holman','PO Box 445','kingman','AZ','UNITED STATES','86402-0445','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 12:49:35',0,NULL,3,1,1,1,NULL,'route66_oldie\\'),(2815,701977092011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tobiasherzog12121212','tobias@herzog.hk','Patrick Herzog','1/F U-C Court<br>25 Stanley Market Road','default','','HONG KONG','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 12:50:34',0,NULL,3,1,2,1,'\\ ','tobiasherzog12121212'),(2816,576243070013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','maristel02','kristelraider@yahoo.com','marian  webster','3426 Merkner Dr','glen allen','VA','UNITED STATES','23060-3206','(804) 868-8666','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 14:10:07',0,NULL,3,1,1,1,'\\ ','maristel02'),(2817,702006571011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',1,'CASS003',8.7,'eastar4','froggyluv1981','melissa.cottew@gmail.com','Melissa Cottew','4721 Avery St','Columbus','GA','UNITED STATES','31907','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-29 14:27:18',0,NULL,3,1,1,1,'\\ ','froggyluv1981'),(2818,779772497012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',11.9,'eastar4uk','4klx','a.allen@orange.net','Alexander Allen','16 Crowhurst Road,<br>Borough Green','Sevenoaks','Kent','UNITED KINGDOM','TN15 8SJ','07974665202','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-29 14:52:36',0,NULL,3,1,3,1,'RA117732016CN\r ','4klx\rOTCN004*10'),(2819,779779166012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','cracksloth','michaelmoore@fastmail.fm','michael moore','2411 Antler Point Dr','Henderson','NV','UNITED STATES','89074-6257','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 15:14:20',0,NULL,3,1,1,1,'\\ ','cracksloth'),(2820,666414373001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','pr0pet','rcrrob@hotmail.com','Rob Hepburn','33 Vereyken Cres','Petawawa','ON','CANADA','k8h 3m3','(613) 440-1784 ext.: 1','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 16:10:44',0,NULL,3,1,3,1,'RA117732055CN\r ','pr0pet\rOTSO001'),(2821,702048958011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','73mark1','marklang8@hotmail.co.uk','Mark Lang','C/O Mullions Hotel<br>51 High Street','STREET','Somerset','UNITED KINGDOM','BA16 0EF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-29 16:40:02',0,NULL,3,1,3,1,'RA117732104CN\r ','73mark1\rMOAP001'),(2822,779815711012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','heatherann25','autoknow@rogers.com','Heather A. Gouchie','3538 Route 106','Salisbury West','NB','CANADA','E4J 3J2','(506) 372-5492','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 16:50:29',0,NULL,3,1,2,1,'\\ ','heatherann25'),(2823,577084111013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','soos.viktor','soos.vitya@gmail.com','Soós Viktor','Csengeri utca 13/A','Isaszeg','','HUNGARY','2117','+36-30-491-5076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 17:15:05',0,NULL,8,1,2,1,NULL,'soos.viktor'),(2824,702066384011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','rafaelws','rafaelws@globo.com','Rafael Wilson','Rua Cisplatina 660 apt12','Sao Paulo','SP','BRAZIL','04211040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 17:25:06',0,NULL,3,1,2,1,'\\ ','rafaelws'),(2825,577092037013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','sereshe','seresheorg@gmail.com','Sereshe Kariyawasam','No : 70/1A, Colombo Road, Rathanapitiya,<br>Boralesgamuwa.','Boralesgamuwa - Colombo','Western Province - Colombo','SRI LANKA','10290','0094-777-591-561','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 17:30:57',0,NULL,3,1,2,1,'\\ ','sereshe  送欧标头\r'),(2826,779832184012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','arenosetella','sonmezserdar@gmail.com','serdar sönmez','balikesir üniversitesi fen edebiyat fakültesi<br>biyoloji bölümü','balıkesir','balıkesir','TURKEY','10145','+905303447184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 17:31:48',0,NULL,3,1,3,1,'RA117732020CN\r ','arenosetella\rOTSO002'),(2827,779854623012,220704209256,'NEW PLANTRONICS EXPLORER 340 headset E340 w/charger',1,'HSPL007',18.9,'eastar4','lriska1','iralspb@yandex.ru','Irina Lushnikova','Irinovskij pr., 31/48, kv. 178','Saint-Petersburg','','RUSSIAN FEDERATION','195279','+79052657323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 18:19:05',0,NULL,3,1,2,1,'\\ ','lriska1\r欧标'),(2828,577107927013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','matt2005matt','mathol2005@hotmail.com','Matt McGarrah','599 Madison 1516','Huntsville','AR','UNITED STATES','72740-7088','(479) 325-0808','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 18:25:06',0,NULL,3,1,1,1,'\\ ','matt2005matt'),(2829,525125997003,130458358302,'New GENUINE  NOKIA BH-203 BLUETOOTH HEADSET track#',1,'HSNO007',14.99,'cnfaner','tycho72','thorsten-sommer@versanet.de','Thorsten Sommer','Senftenberger Ring 83','Berlin','','GERMANY','13435','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 19:44:17',0,NULL,3,1,3,1,'RA117732064CN\r ','tycho72\rHSNO007\r欧标'),(2830,778852118012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',27.8,'eastar4uk','v-yellow','vardikos@yellowroom.gr','Nektarios Vardikos','Aristotelous 10','Thessaloniki','Greece','GREECE','54623','+30 2310947271','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 20:23:50',0,NULL,3,1,3,1,'RA117732550CN\r ','v-yellow\rHSSE005+HSSE003\r欧标\r再发一个NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset\r'),(2831,779932138012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','iort8587','rplufkil2011@hotmail.com','Ivonne Ortiz','5220 Reed Dr','The Colony','TX','UNITED STATES','75056','(469) 384-5472','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 21:11:46',0,NULL,3,1,1,1,NULL,'iort8587\\'),(2832,779939044012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',4,'BALO008',26.4,'eastar4','sethos.x','sethosx@t-online.de','Matthias Quester','Buckower Damm 255a','Berlin','','GERMANY','12349','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 21:32:09',0,NULL,3,1,2,1,'\\ ','sethos.x'),(2833,779964478012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',2,'ANYA002',39,'eastar4','knetphils','ebay@deanwestbury.com','Dean Westbury','Sitio Centro<br>Barangay Dulangan','Puerto Galera','Oriental Mindoro','PHILIPPINES','5203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 22:52:11',0,NULL,3,1,3,1,'RA117715021CN ','knetphils\rANYA002\r'),(2834,779967080012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','mrbricolage123456','a.lejal@ficam.com','Alexandre LEJAL','14 rue du clos de la montespan','saint jean de la ruelle','Centre','FRANCE','45140','02.38.45.77.73','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 23:00:43',0,NULL,3,1,2,1,'\\ ','mrbricolage123456'),(2835,702193082011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',11.99,'eastar4uk','ragnarjonny','s.ragnar@yahoo.no','Ragnar Sundsås','Bleikenveien 173','Brandbu','','NORWAY','2760','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 23:11:29',0,NULL,3,1,2,1,'\\ ','ragnarjonny'),(2836,577190787013,230576095186,'Logitech MX518 MX 518 Gaming Optical USB Mouse 90% new',1,'MOLO003',32.9,'eastar4','dragoniade','dragoniade0@gmail.com','Philippe Busque','5-81 Louise','Longueuil','QC','CANADA','J4J 2T1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 23:47:15',0,NULL,3,1,3,1,'RA117733011CN\r ','dragoniade\rMOLO003'),(2837,702202750011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','tomersh','tomer@shiri.info','Tomer Shiri','Sufit 1','Lehavim','','ISRAEL','85338','+97286518833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 23:54:24',0,NULL,3,1,2,1,'\\ ','tomersh'),(2838,779984497012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','txsr','ramos_thiago@hotmail.com','Thiago Xible Salles Ramos','Avenida Dante Micheline, numero 1545, apartamento 501, Mata da Praia','Vitória','Espírito Santo','BRAZIL','29066-430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 00:10:49',0,NULL,3,1,2,1,'\\ ','txsr'),(2839,702206535011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','leonardodiaz','ljosediaz.r@gmail.com','Leonardo Diaz','7 / 85-87 Wyrallah Road','East Lismore','New South Wales','AUSTRALIA','2480','0401076908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 00:22:29',0,NULL,3,1,2,1,'\\ ','leonardodiaz'),(2840,577203215013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',92.7,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 01:03:14',0,NULL,3,1,3,1,' RA117732444CN','update_marcelo\rWWSI005\\'),(2841,780020530012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','skinnyjeep','bfreyman@gmail.com','Brett Freyman','po box 132','Fairfield','PA','UNITED STATES','17320-0132','(717) 504-3506','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 02:40:55',0,NULL,3,1,1,1,NULL,'skinnyjeep\\'),(2842,780020674012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','tigge811','tigge811@gmail.com','victor chong','5301 McFarren Blvd','Mississauga','ON','CANADA','L5M 6C2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 02:45:31',0,NULL,3,1,2,1,'\\ ','tigge811'),(2843,577232111013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',5,'HSPL005',67.5,'eastar4','quydautu','quydautu.vn@gmail.com','AAAHR blue','510 Parrott St<br>Ste 2','San Jose','CA','UNITED STATES','95112-4117','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 04:06:42',0,NULL,3,1,1,1,'\\ ','quydautu'),(2844,577237374013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',26.1,'eastar4','luizcahue','luizcahue@gmail.com','Luiz Cahue','Rua Cajuru nº140<br>Casacadura','Rio de Janeiro','RIO DE JANEIRO','BRAZIL','21311040','55 21 9119-7255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 04:50:36',0,NULL,3,1,2,1,'\\ ','luizcahue'),(2845,780047445012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','huttnutt42','huttnutt42@aol.com','Johnie Hudson','19701 Freeland St','Detroit','MI','UNITED STATES','48235-1512','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 05:07:56',0,NULL,3,1,1,1,NULL,'huttnutt42\\'),(2846,780049813012,220711639863,'New Logitech Rechargeable battery 890 880 950mA+charger',1,'BALO001+BAIN002',14.99,'eastar4','107okp','djrowell@bigpond.net.au','Dudley  R Rowell','18 Cosette Street','Bracken Ridge','Queensland','AUSTRALIA','4017','0732617161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 05:14:44',0,NULL,3,1,2,1,'\\ ','107okp'),(2847,702266398011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','illdevilinc','illdevilinc@gmail.com','Justin Ledoux','1761 Boxwood ave.','san leandro','CA','UNITED STATES','94579','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 05:25:35',0,NULL,3,1,1,1,'\\ ','illdevilinc'),(2848,780058457012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','jkranjc1968','s52jk@lea.hamradio.si','JOZE KRANJC','Dorfarje 45','Zabnica','','SLOVENIA','SI-4209','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 06:05:06',0,NULL,3,1,2,1,'\\ ','jkranjc1968'),(2849,577271961013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','dinoefthimios','mikey.revival@yahoo.com','efthimios katsonis','el.venizelou 29-ilion<br>ilion','athens','athens','GREECE','13121','00306972259333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 09:08:23',0,NULL,3,1,2,1,'\\ ','dinoefthimios\r欧标'),(2850,577274310013,230412690731,'2.0 New ASUS Bluetooth Module+cable A8/Z99/F8/N80/U5/U6',1,'BTHU2001',12.5,'eastar4','beikeland','beikeland@gmail.com','Bjørn Eikeland','Strømgaten 18','Bergen','','NORWAY','5008','004793439020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 09:21:18',0,NULL,3,1,2,1,'\\ ','beikeland\r华硕10pin 0.8 6cm '),(2851,780109257012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',23.8,'eastar4uk','bebo500','sales@bsl-cctv.com','Hugh  Boyne','269 Boundary Road','Walthamstow','London','UNITED KINGDOM','E178NE','02085098000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 09:51:19',0,NULL,3,1,3,1,' RA117733100CN\r','bebo500\rOTCN004*10'),(2852,780124979012,220763389064,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',26,'eastar4uk','nonye.atueyi','atueyi_emma@yahoo.com','Emmanuel Atueyi','73 Hinchley Wood Grove','BRAMPTON','ON','CANADA','L6V4B1','(905) 452-9184','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-30 10:52:52',0,NULL,3,1,3,1,'RA117733025CN\r ','nonye.atueyi\rWWSI002+ANCN001'),(2853,779369274012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',5,'HSSE005',69.5,'eastar4uk','bogunovic46','zulee46@yahoo.com','Milos Djuric','Balkanska 12','Belgrade','Serbia','SERBIA','11000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-30 10:54:27',0,NULL,3,1,3,1,' RA117718915CN','bogunovic46\rHSSE005\r欧标'),(2854,702336203011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','lorna.sawyers','lorna.sawyers@yahoo.com','Lorna Sawyers','19 Coopers Road, Handsworth Wood','Brmingham','West Midlands','UNITED KINGDOM','B20 2JS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 10:59:13',0,NULL,3,1,3,1,'RA117732081CN\r ','lorna.sawyers\rMOAP001'),(2855,702349734011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','nonamenlsubs','noname.nlsubs@gmail.com','Johnny Berben','Hubert Goffinstraat 1','Genk','','BELGIUM','3600','0486376726','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 11:51:45',0,NULL,3,1,2,1,'\\ ','nonamenlsubs\r欧标'),(2856,577308280013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',10,'CASS003',104.1,'eastar4','dam11gh','damien.lozach@free.fr','Damien LOZAC\'H','6 rue de la Fonderie','Trémuson','Bretagne','FRANCE','22440','06 85 62 01 72','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 12:27:36',0,NULL,3,1,4,1,'YW866010822CN ','dam11gh\rCASS003+TRTS001\r再发两个 AT-210TS '),(2857,780155865012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',12.8,'eastar4','proedrosdk','chlisnick@hotmail.com','nick chlis','chora andros','andros','kuklades','GREECE','84500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 12:34:44',0,NULL,3,1,2,1,'\\ ','proedrosdk\racer 5pin1.25 15cm'),(2858,780160469012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','jwoodyard07','angel16221@nycap.rr.com','Jessica Woodyard','430 Route 146<br>Lot 162','Clifton Park','NY','UNITED STATES','12065','(518) 383-8212','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 12:49:08',0,NULL,3,1,1,1,'\\ ','jwoodyard07'),(2859,525298060003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',2,'OTJE001',31.8,'cnfaner','anyquilmes10','gerardoluisrivas@hotmail.com','gerardo luis rivas','timoteo gordillo 290','ciudad de buenos aires','buenos aires','ARGENTINA','1408','46413594','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-30 13:23:55',0,NULL,3,1,3,1,'RA117718694CN\r ','anyquilmes10\rOTJE001'),(2860,780190133012,220726309168,'New in box Logitech H530 USB Headset ear-cup 981-000195',1,'HSLO002',46.5,'eastar4','jpportier4122','jppor@bluewin.ch','Jean Pierre Portier','Chemin des Bois 101','Veyrier','','SWITZERLAND','1255','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 14:18:30',0,NULL,3,1,3,1,'RA117732529CN\r ','jpportier4122\rHSLO002'),(2861,577334613013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',71.97,'eastar4','theburkey','theburkey@cox.net','Jarret Burkey','400 SW 8th Ave<br>Hill\'s Pet Nutrition, Inc','Topeka','KS','UNITED STATES','66603-3925','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 14:24:31',0,NULL,3,1,1,1,NULL,'theburkey\\'),(2862,702420381011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','at22987','ebay@erber.biz','Marcus Erber','Embelgasse 39/27','Wien','','AUSTRIA','1050','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 15:39:10',0,NULL,3,1,3,1,'RA117732475CN\r ','at22987\rEXLO001'),(2863,702429405011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','akatamaxitoss','sschizas@msn.com','savvas schizas','kyriakou kakouli<br>4 geri','nicosia','00357','CYPRUS','2200','99531293','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 16:04:40',0,NULL,3,1,2,1,'\\ ','akatamaxitoss\r英标\r银色的'),(2864,577361035013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','kei-1','jackiesfridge@hotmail.com','Brett Hiorns','3094 Cty Hwy X','Stevens Point','WI','UNITED STATES','54482','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 16:06:31',0,NULL,3,1,1,1,NULL,'kei-1\\'),(2865,702257405011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','computer_parts_direct_2_u','gossbn@msn.com','Brad Goss','2045 Hickory Ln','Oak Harbor','WA','UNITED STATES','98277-3408','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 16:48:00',0,NULL,3,1,1,1,'\\ ','computer_parts_direct_2_u'),(2866,780259059012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','ebjim99','gmjim99@gmail.com','Dimitris Koumoutsos','SP. LAMPROU 44<br>PIRAEUS - KALLIPOLI','PIRAEUS','','GREECE','185 38','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 17:10:41',0,NULL,3,1,2,1,'\\ ','ebjim99'),(2867,531096821004,140523331018,'New Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',65,'cnfaner','realsqueezy','sven@speedproject.de','Sven Ritter','Otto-Lilienthal-Strasse 11b','Varel','','GERMANY','26316','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 17:18:34',0,NULL,3,1,3,1,'RA117731276CN\r ','realsqueezy\rMOLO001'),(2868,577389139013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','liljabj','alvena_jones@yahoo.com','Alvena Jones','2105 Ridge Park Dr','Little Rock','AR','UNITED STATES','72204-3548','(501) 416-0000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 17:41:04',0,NULL,3,1,1,1,'\\ ','liljabj'),(2869,702474613011,320394929398,'Acer Aspire 5720 5720G  Bluetooth Module 2.0+cable',5,'BTAC2022',62.5,'eastar4','azelzo','korpassyz@gmail.com','Ferenc Vajda','Kiss József utca 102.','Kerepes','Pest','HUNGARY','2145','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 17:58:46',0,NULL,3,1,3,1,' RA117732489CN','azelzo\racer 8pin1.00 15cm \rBTAC2022\\'),(2870,780290323012,220726309168,'New in box Logitech H530 USB Headset ear-cup 981-000195',1,'HSLO002',46.5,'eastar4','mse65$','mscorpe@gmail.com','Ehud Cohen','Sheftel 12','Rishon le zion','israel','ISRAEL','75234','0545-847277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 18:17:24',0,NULL,3,1,3,1,'RA117732532CN\r ','mse65$\rHSLO002'),(2871,577409053013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',37.98,'eastar4','vic_f','victor@vipnetworks.com','Victor Feng','43532 OCASO CORTE','FREMONT','CA','UNITED STATES','94539','(510) 226-7572','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 18:45:38',0,NULL,3,1,1,1,'\\ ','vic_f'),(2872,700438082011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',24.59,'eastar4uk','nickscottjones','nicksj93@me.com','Nick Scott-Jones','19 Greenfield Avenue<br>Kippax','Leeds','West Yorkshire','UNITED KINGDOM','LS25 7PS','07926547564','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 18:55:18',0,NULL,3,1,3,1,NULL,'nickscottjones\rUDAP001潘\\'),(2873,780309833012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','kf_2002_kf','karsten@bank24.net','Karsten Fillmer','1145 Spanish Lace Ln','Vero Beach','FL','UNITED STATES','32963-2351','(772) 231-1173','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-30 18:57:11',0,NULL,3,1,1,1,NULL,'kf_2002_kf\\'),(2874,702501866011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','kruzz-74','andy_phuakh@yahoo.co.uk','Andy Phua','5 Solok Sulam 2,<br>Taman Maznah','Klang','Selangor','MALAYSIA','41000','012-6616664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 18:59:40',0,NULL,3,0,2,1,'\\ ','kruzz-74'),(2875,702533204011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005',67.99,'eastar4','leopolregpor','leopolreg@ono.com','Leopoldo Regidor Portero','Urb. Verdeluz, Nº 22 ,1º C<br>Huelva','Huelva','Andalucía Ceuta y Melilla','SPAIN','21005','654141788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 20:15:24',0,NULL,3,0,3,1,'RA117731302CN\r ','leopolregpor\rGLSG001'),(2876,577442007013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','dudushka','demia-75@hotmail.com','Petimat Demilhanova','Sjøvollvegen 8','selbu','selbu','NORWAY','7580','004793676928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 20:28:42',0,NULL,3,1,3,1,NULL,'dudushka\rHSNO019\r欧标潘\\'),(2877,780406327012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','nickz_de','robert.zednik@web.de','Robert Zednik','Am Fuchsbau 7A','Pfungstadt','','GERMANY','64319','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 22:59:53',0,NULL,3,1,2,1,'\\ ','nickz_de'),(2878,702603961011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',3,'MOSA005',203.97,'eastar4','srrman','thebibbsmail@comcast.net','Alan Bibb','51 Saint Roberts Dr','Stafford','VA','UNITED STATES','22556-3632','(540) 659-6638','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 00:05:00',0,NULL,3,0,1,1,'\\ ','srrman\rGLSG001'),(2879,577500087013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','leodwd','leodwd@yahoo.com','donald doyle','po box 1204','Klamath Falls','OR','UNITED STATES','97601','(503) 750-1881','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 01:01:44',0,NULL,3,1,1,1,'\\ ','leodwd'),(2880,780339694012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',2,'BALO005',14.2,'eastar4','valauch','lauchjr2@aol.com','Lauch Bennett','912 Patrick Dr','West Palm Beach','FL','UNITED STATES','33406-4438','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 01:18:50',0,NULL,3,1,1,1,'\\ ','valauch'),(2881,702556146011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','billyjpatton','billyjpattonesq@verizon.net','Bill Patton Esq.','1428 N 2nd St<br>1st Floor','Harrisburg','PA','UNITED STATES','17102-2635','(717) 230-9310','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 01:19:00',0,NULL,3,1,1,1,NULL,'billyjpatton\\'),(2882,780460564012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','armzzz','armzzz@hotmail.com','Wasan Sinswang','53/317 Maungthongthani  Tiwanon Rd.<br>Bangpood','Pakkred','Nonthaburi','THAILAND','11120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 02:26:08',0,NULL,3,1,3,1,' RA117732206CN','armzzz\rOTRA002\r\\'),(2883,780468068012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',1,'BALO005',7.1,'eastar4','sylbar84','sylbar84@videotron.ca','Nicolas Sylvestre','2150 des intendants app 1','quebec','QC','CANADA','g1j2k3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 02:56:09',0,NULL,3,1,2,1,'\\ ','sylbar84'),(2884,702644462011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','newtemps','wiredtorch@hotmail.com','Jonathan Ridley','6240 Westdale Dr','Grand Blanc','MI','UNITED STATES','48439-8509','(810) 624-4051','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 03:03:20',0,NULL,3,1,1,1,'\\ ','newtemps'),(2885,780470230012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',2,'HSMO007',23.8,'eastar4','divedeep100','smeadowsjr@live.com','steve meadows jr','1215 fennimore st','fairmont','WV','UNITED STATES','26554','(304) 692-5828','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 03:06:38',0,NULL,3,1,1,1,'\\ ','divedeep100'),(2886,780472156012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','like2buy-like2sell','acer1@aol.com','Marcos Peixoto','1090 E River Pkwy','Santa Clara','CA','UNITED STATES','95054-4188','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 03:14:01',0,NULL,3,1,1,1,'\\ ','like2buy-like2sell'),(2887,531237387004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','zohar_yd','zohar_yd@bezeqint.net','Zohar Yehuda','P.O. Box 1268','Kfar Saba','','ISRAEL','44111','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 04:44:51',0,NULL,3,1,3,1,' RA117732118CN','zohar_yd\rOMHJ001\\'),(2888,666954616001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','kurdtcobain316','philghazal@shaw.ca','Phil Ghazal','12071 21st Ave SW','Edmonton','AB','CANADA','T6W 0C7','(780) 757-0737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 04:57:29',0,NULL,3,1,3,1,' RA117732501CN','kurdtcobain316\rOTSO001\\\r'),(2889,780522726012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','esile_audio','ebay@esile.de','iStereo, Hr. Christian Blechinger','Pöllatstr. 14','München','','GERMANY','81539','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 07:30:41',0,NULL,3,1,3,1,' RA117732360CN','esile_audio\rHSSH002\r\\'),(2890,780379415012,220684633355,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'BAIN001+BAIN002+TOIN002',49.9,'eastar4','3rmila707','whereami707@gmail.com','Mark  Callejo','1156 Legend Cir','VALLEJO','CA','UNITED STATES','94591-8688','(707) 334-7397','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 09:02:46',0,NULL,3,1,1,1,'\\ ','3rmila707'),(2891,780558200012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','richardhiggins79','richardhiggins79@aol.com','Richard  Higgins','810 Oriole Cv','lafayette','CO','UNITED STATES','80026-2122','(303) 604-4486','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 09:31:15',0,NULL,3,1,1,1,'\\ ','richardhiggins79'),(2892,780587860012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',12.5,'eastar4','rzaev','ruslan.rzaev@hotmail.com','Руслан Рзаев','ул. Труда дом 10 кв 15','Калуга','','RUSSIAN FEDERATION','248030','79208759292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 10:54:59',0,NULL,3,1,2,1,'\\ ','rzaev\racer 6pin1.25 23cm '),(2893,780324201012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','davidcapaguti','davidcapaguti@yahoo.es','DAVID CAPARROS GUTIERREZ','C / RECIFE 11, 4ºD','CARTAGENA','MURCIA','SPAIN','30394','655543645','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 11:17:59',0,NULL,3,1,3,1,'RA117718629CN\r ','davidcapaguti\rOTRA002'),(2894,577612908013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','ecofino','ecofino@terra.es','Eduardo Cofiño Jorrín','C/ Puerto Príncipe, 16, 1º C','Barcelona','Cataluña','SPAIN','08027','610488404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 11:57:58',0,NULL,3,1,2,1,'\\ ','ecofino\racer 4pin1.25 15cm '),(2895,780611464012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','pilot_a1','pilot_a@mail.ru','Aleksey Malyshev','Marshala Vasilevskogo 17, apt. 136 Moscow, RUSSIA','Moscow','','RUSSIAN FEDERATION','123182','89637231932','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 12:01:18',0,NULL,3,1,2,1,'\\ ','pilot_a1'),(2896,702785160011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','eumicro','eugenlange@online.de','Eugen Lange','Otto-Suhr-Str.15','Oldenburg','','GERMANY','26131','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 12:25:00',0,NULL,5,0,18,0,NULL,'eumicro\r撤单 款已经退了'),(2897,780649187012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','funkymunki','monkey_magic692003@yahoo.co.uk','matthew rowe','1 cole close<br>cotford st. luke','taunton','somerset','UNITED KINGDOM','ta4 1nz','01823430905','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-01 13:38:37',0,NULL,3,1,3,1,'RA117718685CN\r ','funkymunki\rOTRA002'),(2898,577647965013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',19.9,'eastar4','palkan','brestmail@gmail.com','Natal\'ja Nikolaeva','ul.Oktjabrskoj Revoljucii, dom.17,kv.7','Brest','','BELARUS','224011','+375297912945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:00:36',0,NULL,3,1,2,1,'\\ ','palkan\r欧标'),(2899,577652497013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','kroro100','r.kronenwetter@t-online.de','Robert Kronenwetter','Forstenrieder Allee 203','München','','GERMANY','81476','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:09:14',0,NULL,3,1,2,1,'\\ ','kroro100\r欧标'),(2900,780656387012,220704730389,'New GENUINE Plantronics Explorer 340 BLUETOOTH HEADSET',1,'HSPL007',14.9,'eastar4uk','igor_kremin','other@flint.lutsk.ua','Igor Kremin','Senatora<br>15a','Luts\'k','Volyn','UKRAINE','43000','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-05-01 14:13:28',0,NULL,3,1,2,1,'\\ ','igor_kremin\r欧标'),(2901,780669982012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',11.99,'eastar4','skytt2000','cyho930@gmail.com','Chin Yan Ho','No. 26, Jalan Sungai Congkak 32/44<br>Bukit Rimau','Shah Alam','Selangor','MALAYSIA','40460','0122831343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:35:13',0,NULL,3,1,2,1,'\\ ','skytt2000'),(2902,780671938012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','tohon301','creapon301@yahoo.co.jp','Hiroshi Sasaki','6-7-8-301, HigashiKasai<br>Edogawa-Ku','Edogawa-Ku','Tokyo','JAPAN','134-0084','03-5605-0282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:37:46',0,NULL,3,1,2,1,NULL,'tohon301\\'),(2903,780683025012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','rocky75000','supersteel45@yahoo.com','kenneth payton','914 Assembly Rd','Jeffersonville','IN','UNITED STATES','47130-5743','(812) 989-6508','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 14:55:10',0,NULL,3,1,1,1,'\\ ','rocky75000'),(2904,702868812011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','emiel.h','emielch@gmail.com','Emiel Harmsen','Hoofdstraat 39','ZENDEREN','','NETHERLANDS','7625PA','0742660237','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 15:49:40',0,NULL,3,1,2,1,'\\ ','emiel.h'),(2905,780719228012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','arnie-75','spindelndreher@googlemail.com','Alexander Spindelndreher','Wolthuser Dorfstr. 5','Emden','','GERMANY','26725','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 16:05:49',0,NULL,3,1,2,1,'\\ ','arnie-75'),(2906,576390158013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','unaimg91','unimg@hotmail.com','Unai Márquez González','Mare de deu del port 385, 8o 12','Barcelona','Cataluña','SPAIN','08038','609526097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 16:16:50',0,NULL,3,1,2,1,'\\ ','unaimg91'),(2907,577701554013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','drgee514','david.richard@videotron.qc.ca','David Richard','1617 Sicard','Montréal','QC','CANADA','H1V 2X7','(514) 232-7548','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 16:30:41',0,NULL,3,1,2,1,'\\ ','drgee514'),(2908,667217388001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','fishbone8910','claudiafisher7@hotmail.com','Jason Fisher','2001 41st St N','saint petersburg','FL','UNITED STATES','33713-4735','(727) 327-9384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 16:32:16',0,NULL,3,1,1,1,NULL,'fishbone8910\rLK045265569CN\\'),(2909,780737237012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','deckpi','deckpi@hotmail.com','Roderick Pena','35270 Lucia St','Fremont','CA','UNITED STATES','94536-5474','(510) 859-5532','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 16:35:30',0,NULL,3,1,1,1,NULL,'deckpi\\'),(2910,577715257013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',11.99,'eastar4','aprilandjada','aprilandjada@yahoo.com','Jada Suttle','9013 Villanova Dr','Shreveport','LA','UNITED STATES','71118-2437','(318) 426-4388','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 17:01:05',0,NULL,3,1,1,1,' \\','aprilandjada'),(2911,780753919012,220761694645,'New Logitech IO Digital Notebook for IO/ IO2 pen',1,'NTLO001',17.35,'eastar4','frech2003','dougfrech@hotmail.com','Doug Frech','78 Lake St','Sault Ste. Marie','ON','CANADA','p6a4a7','(705) 541-9847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 17:02:11',0,NULL,3,1,2,1,'\\ ','frech2003'),(2912,702912757011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','automattic716','matt20606@aol.com','Matthew Weiskopff','7649 Fallswood Way','Lorton','VA','UNITED STATES','22079-1730','(716) 604-4586','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 17:06:37',0,NULL,3,1,1,1,'\\ ','automattic716'),(2913,702916995011,320613191693,'NEW Motorola H700 Gold DG Bluetooth Headset+car charger',1,'HSMO012+CCMO001',19.9,'eastar4','lion-arm','liongev@yahoo.com','Gevorg Ayvazyan','Jrvezh, Mayak bld.8 apt.21','Yerevan','Yerevan','ARMENIA','0089','+374 77 504455','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 17:12:12',0,NULL,3,0,2,1,'\\ ','lion-arm  客户改发花洒一个\r'),(2914,702946866011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',2,'UDAP001',49.18,'eastar4uk','realitynick','jsynick@gmail.com','Nicholas Arnold','4 Clement Court<br>Ann Street, St Helier','Jersey, Channel Islands','Channel Islands','UNITED KINGDOM','JE2 4AS','07797813841','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-01 17:50:51',0,NULL,3,1,3,1,'RA117718677CN\r ','realitynick\rUDAP001'),(2915,577767678013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','crb_rr','lesniak@rochester.rr.com','Mark Lesniak','90 Mickens Bnd','West Henrietta','NY','UNITED STATES','14586-9561','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 18:34:20',0,NULL,3,1,1,1,'\\ ','crb_rr'),(2916,702997362011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','trialgun','lkesten@bhpklaw.com','Leonard Kesten','14 Elm St','Wellesley','MA','UNITED STATES','02481-3107','(781) 237-0904','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 18:56:37',0,NULL,3,1,1,1,NULL,'trialgun\\'),(2917,577782564013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','mykmyk86','soul@ukr.net','Mykola Gladchenko','Symerenko st,<br>22b, 13','Kyiv','UA','UKRAINE','03134','(380) 936-7697 ext.: 02','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 19:02:34',0,NULL,3,1,2,1,'\\ ','mykmyk86'),(2918,702997324011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','nightstalkeraj','andrewgjones86@googlemail.com','Andrew Jones','19 Pether Avenue','Brackley','Northamptonshire','UNITED KINGDOM','NN13 6NJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-01 19:10:11',0,NULL,3,1,3,1,'RA117732078CN\r ','nightstalkeraj\rMOAP001\r'),(2919,780881721012,220713846504,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET',3,'HSNO025',107.7,'eastar4uk','rynke08','vicky.mancini@mail.dk','vicky mancini','rich. granholms alle 16','kastrup','','DENMARK','2770','(0045) 61914112','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 19:37:43',0,NULL,3,1,3,1,'RA117732461CN\r ','rynke08\rHSNO025\r欧标\r'),(2920,703035822011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005',67.99,'eastar4','mrnine324','dodgeman324@yahoo.com','Brandon Turley','4966 Hawk Meadow Dr','Colorado Springs','CO','UNITED STATES','80916-5719','(918) 949-1608','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 19:48:57',0,NULL,3,0,1,1,'\\ ','mrnine324\rGLSG001'),(2921,667359482001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','k0135','simon.desbiens.1@videotron.ca','Simon Desbiens','286, rue Lafontaine','Rivière-du-Loup','QC','CANADA','G5R 3A8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:04:26',0,NULL,3,1,3,1,'RA117718615CN\r ','k0135\rOTSO001'),(2922,577818096013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','tinahopper','tinahopper@web.de','Susanne Terheyden','Ronshauser Str. 17','Recklinghausen','','GERMANY','45663','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:18:29',0,NULL,3,1,2,1,NULL,'tinahopper'),(2923,577827132013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','tesha_rae','tesha_rae@hotmail.com','Tesha-Rae Cole','673 Linden Ave','Winnipeg','MB','CANADA','R2K0P1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:31:56',0,NULL,3,1,2,1,'\\ ','tesha_rae'),(2924,577832689013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','eddieo020','eddieandliz@sympatico.ca','Eddie Oliveira','11 Beaverbrook Crescent','Cambridge','ON','CANADA','N1P 1G9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:45:56',0,NULL,3,1,2,1,'\\\r ','eddieo020'),(2925,703046403011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','redmohawk','svenclausen@sbcglobal.net','Sven H Clausen','1553 Palm Ave','Chico','CA','UNITED STATES','95926-2605','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 20:54:35',0,NULL,3,1,1,1,'\\ ','redmohawk'),(2926,703077547011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','rfondon','rubenfondon@hotmail.com','Ruben Fondon Alcalde','C/San Francisco 72','Villaviciosa de Odón','Madrid','SPAIN','28670','672397378','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 21:08:16',0,NULL,3,1,2,1,'\\ ','rfondon'),(2927,703090646011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','valc240','valcatrazz@gmail.com','Brian Vorst','76 Danbury Dr','Springfield','IL','UNITED STATES','62704-5438','(217) 415-9916','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 21:30:44',0,NULL,3,1,1,1,NULL,'valc240\\'),(2928,703103190011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005',67.99,'eastar4','exodiak','exodiak@verizon.net','David Rodriguez','155 East 4th St.<br>Apt 2D','New york','NY','UNITED STATES','10009','(212) 228-5763','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 22:01:29',0,NULL,3,0,1,1,'\\ ','exodiak\rGLSG001'),(2929,577863858013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','bli2007','bli194@hotmail.com','pablo lorenzana alvarez','c/ peña santa, 194 urb. las lomas','valdefresno- león','Castilla y León','SPAIN','24227','626927209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 22:24:22',0,NULL,3,1,2,1,'\\ ','bli2007\r欧标'),(2930,577870500013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','drparasite','dangreenhaus+onlineorders@gmail.com','Dan Greenhaus','1106 Harbor Club Dr','Parlin','NJ','UNITED STATES','08859','(732) 735-3682','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 22:48:22',0,NULL,3,1,1,1,'\\ ','drparasite'),(2931,703125445011,320692106584,'New in box genuine SONY 3D Active Glasses TDG-BR100',4,'OTSO003',416,'eastar4','5.0-mustangs','devinandchristy@sbcglobal.net','Devin Wagner','5873 Echo Bluff Dr','Haltom City','TX','UNITED STATES','76137-5807','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 23:06:14',0,NULL,3,1,6,1,'EE456353954CN','5.0-mustangs\r'),(2932,703147861011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ghostboy814','gorensteinay@aol.com','Alex Gorenstein','191 Tweed Blvd','Nyack','NY','UNITED STATES','10960-4913','(845) 729-9938','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 00:15:43',0,NULL,3,1,1,1,'\\ ','ghostboy814'),(2933,577894442013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','pedricb','briankpedrick@comcast.net','Brian Pedrick','115 Silver Birch rd','Williamstown','NJ','UNITED STATES','08094-2027','','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'\\ ','pedricb\rLK046599152CN '),(2934,703168349011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',1,'TRMX001',8.55,'eastar4','husmun','munir2000@hotmail.com','Pritchard Francis (Hussain Munir)','Level 1, 430 Roberts Road','Subiaco','Western Australia','AUSTRALIA','6008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 01:14:51',0,NULL,3,0,2,1,'\\ ','husmun'),(2935,781046951012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','njtrader01','nrewari@yahoo.com','Naresh Rewari','14 Jamesworthy Ct','Marlboro','NJ','UNITED STATES','07746-2714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 01:40:09',0,NULL,3,1,1,1,NULL,'njtrader01\\'),(2936,577916894013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','pointsan','pointsan@yahoo.com','Bussarin Sinnung','PTT Phenol Co.,Ltd. 555/1 4th Floor Energy Complex Building,<br>Vibhavadi Rangsit Rd., Jatuchak','Bangkok','Bangkok','THAILAND','10900','66891357725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 01:43:02',0,NULL,3,1,2,1,'\\ ','pointsan'),(2937,703185954011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','melissam934','mmorse3@partners.org','Armand chery','42 Royal Crest Dr<br>Apt 7','Nashua','NH','UNITED STATES','03060-6633','(978) 985-7789','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 02:09:38',0,NULL,3,1,1,1,'\\ ','melissam934'),(2938,703200491011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005*2',134.99,'eastar4','nunyone2','douglas.heredia@yahoo.com','Nerime Pervizaj','75 Rockefeller Plz<br>C/O Warner Music Group Fl 12','New York','NY','UNITED STATES','10019-6908','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 02:57:19',0,NULL,3,0,1,1,'\\ ','nunyone2\rGLSG001*2'),(2939,703213936011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','reg_at_capio','reg@capiogroup.com','SEO Web Sales','1 Blackfield Dr<br># 134','Tiburon','CA','UNITED STATES','94920-2053','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 03:54:45',0,NULL,3,1,1,1,'\\ ','reg_at_capio'),(2940,703254222011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',3,'RELO002',38.97,'eastar4','sawty','jimmy.latham@gmail.com','James Latham','6 Mary St<br>Longueville','Sydney','New South Wales','AUSTRALIA','2066','0435776144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 07:35:17',0,NULL,3,1,3,1,'RA117718663CN\r ','sawty\rRELO002'),(2941,703252132011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','don_24_7','don_24_7@hotmail.com','Don Roberts','41 Cathnor Road, Shepherd\'s Bush','London','London','UNITED KINGDOM','W12 9JB','02087620758','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 07:35:33',0,NULL,3,1,3,1,'RA117732047CN\r ','don_24_7\rMOAP001'),(2942,703258398011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','petersruh','w.petersen-s.p.o@t-online.de','Walter Petersen','Zum Leuchtturm 5','St. Peter-Ording','','GERMANY','25826','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 07:53:14',0,NULL,3,1,3,1,' RA117732458CN','petersruh\rWWSI004\\'),(2943,577979685013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','agouder','gouderadrian@yahoo.co.uk','Adrian Gouder','136, Sunshine Flats 2.,<br>Potters Str.,','Birkirkara','Malta (EU - Europe)','MALTA','BKR 1201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 08:04:26',0,NULL,3,1,2,1,'\\ ','agouder\r欧标'),(2944,577984210013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','titanium_ten','vestitor@me.com','chris taylor','Building 29Q<br>Airfeild Camp','Netheravon','Wiltshire','UNITED KINGDOM','SP4 9SF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 08:34:19',0,NULL,3,1,2,1,'\\ ','titanium_ten'),(2945,577986796013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','rodri333','rodri@eureka.es','Rodrigo Marcos','Seneca, 10 - Bjos. 2','Barcelona','Barcelona','SPAIN','08006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 08:46:11',0,NULL,3,1,2,1,'\\ ','rodri333'),(2946,703269692011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','soos.viktor','soos.vitya@gmail.com','Soós Viktor','Csengeri utca 13/A','Isaszeg','','HUNGARY','2117','+36-30-491-5076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 08:53:57',0,NULL,3,1,2,1,NULL,'soos.viktor\\'),(2947,703277740011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','zup2sky2','jhk9@sfu.ca','Jin Kim','16861 85A Ave','SURREY','BC','CANADA','V4N 5A4','(604) 575-7123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 09:14:01',0,NULL,3,1,2,1,'\\ ','zup2sky2'),(2948,781189685012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','tontonchris31180','toff31@gmail.com','Monique Rualta','175 CHEMIN DE GARENNE','mirepoix  sur tarn','31','FRANCE','31340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 10:52:27',0,NULL,3,1,2,1,'\\ ','tontonchris31180'),(2949,781197982012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','rudi-dakota','denisefossey@hotmail.com','Denise Fossey','940 Georgianna St','Hobart','IN','UNITED STATES','46342-4508','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 11:19:29',0,NULL,3,1,1,1,'\\ ','rudi-dakota'),(2950,525952343003,130490976552,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',3,'WLAT006',52.47,'cnfaner','lizika_zlikovski','offroad.lobor@gmail.com','Ivan Hleb','Zagrebačka<br>64','Zlatar','Hrvatsko Zagorje','CROATIA','49250','+385959121267','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 12:19:07',0,NULL,3,1,3,1,'RA117732546CN\r ','lizika_zlikovski\rWLAT006'),(2951,578043340013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','in-shades','bobk@fremontind.com','Bob Krosnowski','14695 Trotters Trl NE','Prior Lake','MN','UNITED STATES','55372-4104','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 13:18:54',0,NULL,3,1,1,1,'\\ ','in-shades'),(2952,703351088011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','shasmani1','steve@hasmanis.net','steve hasmanis','1342 Crown Ridge Dr','Fort Mill','SC','UNITED STATES','29708','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 13:25:34',0,NULL,3,1,1,1,NULL,'shasmani1\\'),(2953,0,220774366905,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',0.43,'eastar4','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-02 13:28:12',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(2954,781251939012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',5,'HSPL010',119.5,'eastar4','uuu-pb','postmaster@ullner.de','Ullner u. Ullner GmbH','zu Hd. H. Bücker<br>Grüner Weg 25','Paderborn','','GERMANY','33098','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 13:57:57',0,NULL,3,1,3,1,'RA117718703CN\r ','uuu-pb\r欧标\rHSPL010'),(2955,525980386003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','guido88au','archieaparicio@iinet.net.au','Archimedes Aparicio','913/3 HERBERT ST','ST LEONARDS','New South Wales','AUSTRALIA','2065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 14:28:36',0,NULL,3,1,3,1,'RA117733039CN\r ','guido88au\rOTGR001'),(2956,531733221004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','behind_the_eyes','enrico.ghirardo@gmail.com','enrico ghirardo','piazza marconi 45','vigonovo','VE','ITALY','30030','0499830060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 15:24:53',0,NULL,3,1,3,1,'RA117732033CN\r ','behind_the_eyes\rWWSI005'),(2957,781292594012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','markcata','mcatalanot@aol.com','Mark Catalanotti','313 N Broadway<br>Apt 2','Redondo Beach','CA','UNITED STATES','90277-2800','(310) 798-0548','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 15:36:30',0,NULL,3,1,1,1,NULL,'markcata\\'),(2958,781318299012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','abbott1999','michael.abbott@inenco.com','Michael Abbott','Inenco Group Ltd<br>Petros House, St Andrews Rd North','Lytham St Annes','Lancashire','UNITED KINGDOM','FY8 2NF','01253785000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 16:31:55',0,NULL,3,1,3,1,'RA117732356CN\r ','abbott1999\r英标\rHSPL014\r'),(2959,526021554003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',19.9,'cnfaner','cecoanny','ebayca@abv.bg','Ani Ganeva','10, Venera Str<br>1st floor ','Gabrovo','Gabrovo','BULGARIA','5300','00359878917249','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 16:55:51',0,NULL,3,1,3,1,' RA117733042CN\r','cecoanny\rHSNO016\r欧标'),(2960,703457698011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',28.49,'eastar4','suwannawech2009','suwannawech@gmail.com','Suwannawech natasha','146/106 Soi Sang U-Thai tip<br>Dindeang','Dindaeng','Bangkok','THAILAND','10400','668 1 7011929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 17:44:55',0,NULL,3,1,2,1,'\\ ','suwannawech2009'),(2961,703465210011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005*2',134.99,'eastar4','senor56','f.villasenor@hotmail.com','Fatima Villasenor','2508 Canyon Dr','Modesto','CA','UNITED STATES','95351-4851','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 17:58:52',0,NULL,3,0,1,1,'\\ ','senor56\rGLSG001*2'),(2962,578136093013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','pmj1979','paulmjob@yahoo.co.uk','Paul Job','Jee Ltd, 2 Abercrombie Court<br>Arnhall Business Park, Prospect Rd','Westhill','Aberdeenshire','UNITED KINGDOM','AB32 6FE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 18:14:43',0,NULL,3,1,3,1,'RA117733056CN\r ','pmj1979\rMOSA002'),(2963,578146786013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','adammoriarty123','mo18_33@yahoo.com','Adam Moriarty','2450 Hamilton St','Oshkosh','WI','UNITED STATES','54901-1544','(608) 751-0839','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 18:38:47',0,NULL,3,1,1,1,NULL,'adammoriarty123\\'),(2964,781392117012,220769590609,'New Atheros AR9287 Wireless PCI-E Half Card+antenna',1,'WLAT007+ANTY001',16.95,'eastar4','metalfirebladesw','metalfireblade@hotmail.com','Sergio Martinez Ciruelos','Avda. Fermina Sevillano 40B','Madrid','Madrid','SPAIN','28022','666341285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 18:39:20',0,NULL,3,1,2,1,NULL,'metalfirebladesw\\'),(2965,703532797011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','greyman46','grahamsfineart@googlemail.com','graham clarke','6<br>humphreys road','wellington','Somerset','UNITED KINGDOM','ta219es','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 19:52:18',0,NULL,3,1,3,1,' RA117732413CN','greyman46\rMOAP001\\'),(2966,531829936004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','jimgoepel','jgoepel@jegconsulting.com','James Goepel','Unisys Corp., Office of the General Counsel<br>801 Lakeview Drive, Suite 100; Mail Stop 2NW','Blue Bell','PA','UNITED STATES','19422','(703) 593-5460','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 19:58:21',0,NULL,3,1,1,1,NULL,'jimgoepel\\'),(2967,703539807011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','petr.drugak','petr.drugak@gmail.com','Peter Drugak','Borochov 12 apartment 16','Netanya','','ISRAEL','42266','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 20:06:48',0,NULL,3,1,2,1,'\\ ','petr.drugak'),(2968,781450303012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','dig453','george.fryer@gmail.com','George D Fryer','13 Park Avenue','Bath','Avon','UNITED KINGDOM','BA24QD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 20:08:55',0,NULL,3,1,3,1,'RA117732342CN\r ','dig453\rHSSH002\r'),(2969,703549691011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005',67.99,'eastar4','elgrancomercial','mhergon@hotmail.com','Marc Hervera Gonzalez','C/ Santa Marcelina 13 B Bajos 1ª','Cerdanyola del Valles','Cataluña/Barcelona','SPAIN','08290','647493793','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 20:24:32',0,NULL,3,0,3,1,'RA117731293CN\r ','elgrancomercial\rGLSG001'),(2970,703569042011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','jfjodoin00','jfjodoin@megaquebec.net','Jean-Francois Jodoin','40, rue Kamouraska','Sainte-Catherine-de-la-Jacques-Cartier','QC','CANADA','G3N 0Y9','(418) 875-4141','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 21:07:04',0,NULL,3,1,2,1,'\\ ','jfjodoin00'),(2971,703576656011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',37.68,'eastar4','jjcriado','jjcriado@telefonica.net','Jose Javier Criado Fernandez','Barrio Castanedo 70-A Chalet 12','Villanueva de Villaescusa','Cantabria','SPAIN','39690','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 21:25:14',0,NULL,3,1,3,1,' RA117732435CN','jjcriado\rBALO007+RELO002\r再发两个优联\\'),(2972,578216095013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','kfan1tp4','kfan@cisco.com','Kyle Fan','6405 Prospect Rd','San Jose','CA','UNITED STATES','95129-3840','(408) 527-2607','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 21:43:24',0,NULL,3,1,1,1,'\\ ','kfan1tp4'),(2973,703585627011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005',67.99,'eastar4','sirhavz','havril.taing@wanadoo.fr','Christophe TAING','cité du petit bois batiment O','Carrieres sur Seine','Île-de-France','FRANCE','78420','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 21:50:40',0,NULL,3,0,3,1,'RA117731262CN\r ','sirhavz\rGLSG001\r'),(2974,781502345012,220759964705,'Logitech MX1000 Mouse special bluetooth  version',1,'MOLO005',59.9,'eastar4','wata.o','watao@yahoo.co.jp','Toshio Watanabe','Yasashido-cyo 1170-45<br>Midori-ku','Chiba-shi','Chiba','JAPAN','267-0062','+81-43-294-2385','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 21:54:13',0,NULL,3,1,3,1,'RA117731280CN\r ','wata.o\r蓝牙版的\rMOLO005'),(2975,781504769012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','schnelllangsam','scottdaniel@arcor.de','Daniel Scott','Am Frauenberg 20A','Bad Hersfeld','','GERMANY','36251','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 22:00:45',0,NULL,3,1,2,1,'\\ ','schnelllangsam'),(2976,703596619011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','jmclark47','jmclark47@gmail.com','Jeffrey M Clark','12435 28 Avenue NW','Edmonton','AB','CANADA','T6J 4G4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 22:25:31',0,NULL,3,1,2,1,'\\ ','jmclark47'),(2977,578235089013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','iwowdaily','djadamson12@hotmail.com','David Adamson','9802 NE 108TH CT','Vancouver','WA','UNITED STATES','98662-3387','(360) 718-2212','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 23:06:41',0,NULL,3,1,1,1,'\\ ','iwowdaily\r华硕限量版'),(2978,578239863013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','edpsychdoc','zionscamp@hotmail.com','Mark White','2930 N 840 E','Provo','UT','UNITED STATES','84604','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-02 23:32:09',0,NULL,3,1,1,1,'\\ ','edpsychdoc'),(2979,778793852012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',21.9,'eastar4','kheder1234','m.khodr@live.com.au','moe khodr','29 glengyle st','melbourne','Victoria','AUSTRALIA','3058','0422406253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 23:38:25',0,NULL,3,1,2,1,'\\ ','kheder1234\r澳标'),(2980,781321450012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','alvaromoroni','alv.moroni@gmail.com','Alvaro Moroni','Avenida Nossa Senhora de Copacabana 379<br>Apartamento 1204','Rio de Janeiro','RJ','BRAZIL','22020-002','(55) 21 8405-8494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 01:05:46',0,NULL,3,1,3,1,' RA117732121CN','alvaromoroni\rOTSO002\\\r'),(2981,703644434011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mezrin','mezrin@hotmail.com','Vadim Mezrin','19 Skyline Dr','West Orange','NJ','UNITED STATES','07052','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 01:27:25',0,NULL,3,1,1,1,'\\ ','mezrin'),(2982,578264378013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','troy.mcguinness','troymcguinness74@gmail.com','Troy McGuinness','11 Lavery Place','Attwood','Victoria','AUSTRALIA','3049','0393093613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 01:36:04',0,NULL,3,1,2,1,'\\ ','troy.mcguinness\rCAB-6060'),(2989,702651504011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','davidkbecker','davidkbecker@yahoo.com','David Becker','856 Church St','San Francisco','CA','UNITED STATES','94114-3031','(415) 401-8048','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 05:17:07',0,NULL,3,1,1,1,'\\ ','davidkbecker'),(2983,703659956011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','transamman1','mikelespike@hotmail.com','Mike Thompson','575 7th Avenue East N','Columbia Falls','MT','UNITED STATES','59912-3212','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 02:23:19',0,NULL,3,1,1,1,'\\ ','transamman1'),(2984,781583409012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','nd4spd42','mrebony38@excite.com','Steven Rorie','5200 Butterfield Dr','Winston Salem','NC','UNITED STATES','27105-3251','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 02:24:07',0,NULL,3,1,1,1,NULL,'nd4spd42\\'),(2985,781587621012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','nikkoandfia','ralpaugh1@hotmail.com','rochelle mendez','123 W Hillcrest Dr','Greenville','SC','UNITED STATES','29609-4617','(828) 301-5698','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 02:39:12',0,NULL,3,1,1,1,NULL,'nikkoandfia\\'),(2986,578284176013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','heeinlee','lhi819@hotmail.com','HeeIn Lee','#5-3175 Baird Road','North Vancouver','BC','CANADA','V7K 2G5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 03:17:12',0,NULL,3,1,2,1,'\\ ','heeinlee'),(2987,703673128011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','repcoservices','rep-co@repairman.com','Ryan Casper','23809 5th Ave W','Bothell','WA','UNITED STATES','98021-8528','(206) 321-7044','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 03:19:40',0,NULL,3,1,1,1,'\\ ','repcoservices'),(2988,781606468012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','brother_dugan','dougrodriguez81@hotmail.com','Douglas Rodriguez','2100 10th St<br>Ste 300','Plano','TX','UNITED STATES','75074-8022','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 04:05:32',0,NULL,3,1,1,1,'\\ ','brother_dugan'),(2990,703697376011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',2,'BTHP2111',25.6,'eastar4','gadzekpo','gadzekpo@yahoo.com','Leonard Gadzekpo','414 N Beadle Dr<br>Apt 4','Carbondale','IL','UNITED STATES','62901','(618) 351-7084','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 05:36:48',0,NULL,3,1,1,1,' ','gadzekpo\rHP 8pin 1.25 25cm \\'),(2991,781625867012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','igvisualizations','bishaug@ieee.org','Brian Ishaug','4817 Funston Gate Ct','Pleasanton','CA','UNITED STATES','94566-4529','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 05:42:41',0,NULL,3,1,1,1,'\\ ','igvisualizations'),(2992,781627689012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','marcandsteve','sunswimpool@yahoo.com','Steven e Ongman','6890 Highway 9','Felton','Ca','UNITED STATES','95018','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 05:51:35',0,NULL,3,1,1,1,' ','marcandsteve\\  bank reversal'),(2993,703704559011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','diesel6s7k','diesel@hitel.net','HAEYONG LEE','JUNG GUM SA 260-2 NAMSAN2DONG JUNG-GU','DAEGU','','KOREA,REPUBLIC OF','700-442','+82-11-501-3407','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 06:24:48',0,NULL,3,1,2,1,'\\ ','diesel6s7k'),(2994,578313858013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','tridoc05','conkst@gmail.com','Cherie Onkst','5206 Dwire Ct','Tampa','FL','UNITED STATES','33647-1016','(813) 978-1614','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 06:59:45',0,NULL,3,1,1,1,'\\ ','tridoc05'),(2995,781645394012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',5.98,'eastar4uk','castefan','stefanclaudiuadrian@hotmail.com','Claudiu Adrian STEFAN','48 Villa Park Gardens','Dublin','Dublin','IRELAND','D7','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-03 07:18:05',0,NULL,3,1,3,1,'RA117732152CN\r ','castefan\rOTCN002'),(2996,578318862013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','alcom05','alcom@club-internet.fr','Alexandre COMBES','Appartement 17, 31 Rue de Cugnaux','TOULOUSE','Midi-Pyrénées','FRANCE','31300','06.89.95.21.30','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 07:36:18',0,NULL,3,1,2,1,'\\ ','alcom05'),(2997,781662610012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','his047','f.pedersen@abdn.ac.uk','Frederik Pedersen','Inches Lodge<br>Inch Road','Newburgh','Aberdeenshire','UNITED KINGDOM','AB41 6BQ','01358789105','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 08:38:17',0,NULL,3,1,3,1,'RA117732585CN\r ','his047\rHSPL014\r英标'),(2998,526231933003,130458644390,'New GENUINE NOKIA BH-300 BLUETOOTH HEADSET track#',1,'HSNO013',15.6,'cnfaner','rwu3','salmor8@yahoo.ca','Buu Ngo','P.O.Box 40154','Ottawa','ON','CANADA','K1V 0W8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 08:59:56',0,NULL,3,1,3,1,'RA117732299CN\r ','rwu3\rHSNO013\r'),(2999,781670866012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','der_frauenversteher2','dkdruck@gmx.de','Druckerei Krause','Langenscheidtstrasse 9A','Berlin','','GERMANY','10827','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 09:08:51',0,NULL,3,1,2,1,'\\ ','der_frauenversteher2'),(3000,578339886013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',4,'CACN004',52,'eastar4','rampelstilskin_88','kommytator@gmail.com','Yuriy Popov','Shilkinskaia 6 - 15','Vladivostok','Primorsky','RUSSIAN FEDERATION','690066','+79502890608','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 09:52:55',0,NULL,3,1,3,1,'RA117732594CN\r ','rampelstilskin_88\rCACN004'),(3001,526245167003,130489883385,'New Sony Ericsson HBH-PV702 BLUETOOTH HEADSET track#',2,'HSSE003',43.8,'cnfaner','gog7811','qudsia1@live.com.au','Qudsia chaudhry','11<br>scotney place','quakers hills','New South Wales','AUSTRALIA','2763','0296269312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 10:28:55',0,NULL,3,1,3,1,'RA117732237CN\r ','gog7811\rHSSE003\r澳标'),(3002,531993589004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','ckyrts','pentepedia@gmail.com','Christos Kyrtsakas','409 Beach Grove Drive','Tecumseh','ON','CANADA','N8N 1K6','(519) 257-9148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 11:05:28',0,NULL,3,1,3,1,'RA117732170CN\r ','ckyrts\rOTGR002'),(3003,524884889003,130493246602,'Logitech harmony Li-ion Rechargeable Battery 930mAh',1,'BALO002',10.5,'cnfaner','gux70','agarzon.licof@afiti.com','Agustin Garzon Cabrerizo','Camilo Jose Cela 22 P3 2C','Las Rozas','Madrid','SPAIN','28230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 11:09:15',0,NULL,3,1,3,1,'RA117732245CN\r ','gux70\rBALO002'),(3004,781701501012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','outsidebroadcast','outsideb@optusnet.com.au','Steve Wakely','12 Parraweena Ave','Baulkham Hills','New South Wales','AUSTRALIA','2153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 11:11:20',0,NULL,3,1,2,1,'\\ ','outsidebroadcast'),(3005,781707948012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','trueduck2000','etn@free.fr','Etienne MERIAUX','81bis route de Clisson','St-SEBASTIEN sur LOIRE','Pays de la Loire','FRANCE','44230','02.28.21.03.46','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 11:29:57',0,NULL,3,1,2,1,'\\ ','trueduck2000\r欧标'),(3006,703783903011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','chtirlipimpon','laurent.gaudron@gmail.com','laurent gaudron','6 rue ronsard','chambourg sur indre','Centre','FRANCE','37310','06.30.51.28.64','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 12:05:49',0,NULL,3,1,3,1,'RA117731347CN\r ','chtirlipimpon\rGLSG001'),(3007,578368066013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','massmike69','masmike1969@msn.com','Michael P Arsenault','2015 Bonisle Cir','Riviera Beach','FL','UNITED STATES','33418','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 12:19:57',0,NULL,3,1,1,1,'\\ ','massmike69'),(3008,578367986013,230393459225,'2.1 New Acer Timeline 3810 3810T Bluetooth Module+cable',1,'BTAC2118',62.5,'eastar4','gregos13','greg.in.forest@gmail.com','Greg Sidorov','Garibaldi 14/1 flat 20','Moscow','Moscow','RUSSIAN FEDERATION','117393','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 12:26:39',0,NULL,3,1,3,1,'RA117733144CN\r ','gregos13\racer 8pin1.0 3cm \r再发两个 3G WWAN antenna\r 一个UNLOCKED ACER HS2300 SIERRA MC8775 WWAN 3G not HP\rBTAC2118+ANCN001+WWSI001\r\r'),(3009,578371696013,230545855042,'Acer TM 3000 3020 /AS5760 Bluetooth Module2.0+cable',1,'BTAC2024',12.5,'eastar4','megerald68','raymond.forghani@gmail.com','Raymond Forghani','Unit 2<br>45 Bangor Street','Guildford','New South Wales','AUSTRALIA','2161','0296322370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 12:38:18',0,NULL,3,1,2,1,'\\ ','megerald68\r\racer 8pin1.25 10cm'),(3010,781755761012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','linckgroup','e1-3snw-n31w-901c@aetm.us','Christian Bailey','85 Bolton St<br>Ligon Discovery','Cambridge','MA','UNITED STATES','02140-3310','(617) 326-7284','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 13:57:16',0,NULL,3,1,1,1,'\\ ','linckgroup\r红边优联'),(3011,578389634013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','marekfia','marek@dropzone.com','Marek Fiala','M.Pujmanove 4','Prostejov','','CZECH REPUBLIC','79811','776203170','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 13:57:35',0,NULL,3,1,3,1,'RA117732563CN\r ','marekfia\rMOSA002'),(3012,668088896001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','bewe720','benoit.weiss@chimbio-ulp.u-strasbg.fr','Benoit weiss','9 rue des Cigognes','Weyersheim','Alsace','FRANCE','67720','0388513641','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 14:17:05',0,NULL,3,1,3,1,'RA117732210CN\r ','bewe720\rOTSO001'),(3013,668089291001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','samitnk9900','samitnk@hotmail.com','Jitesh Khokhani','458 Ebony Tree Ave','Galloway','NJ','UNITED STATES','08205-4478','6096523347','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 14:19:56',0,NULL,3,1,1,1,'\\ LK045714673CN','samitnk9900'),(3014,578400804013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','quinnsrus','quinnsrus@yahoo.com','Anthony Quinn','4410 Highway 16','Elkins','AR','UNITED STATES','72727','(479) 643-2822','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 14:44:41',0,NULL,3,1,1,1,'\\ ','quinnsrus'),(3015,703838184011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',2,'WWSI004',66.4,'eastar4','jmyoon0815','blueguy@blueguy.sarang.net','Jongmin Yoon','WindRiver 5th fl. Sambo Bldg.<br>88 Samsung Dong','Kangnam Gu','Seoul','KOREA,REPUBLIC OF','135090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 15:07:45',0,NULL,3,1,3,1,'RA117732308CN\r ','jmyoon0815\rWWSI004'),(3016,781783547012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','darinh92','darinh@pobox.com','Darin Haugen','9165 Woodhill Ct','Savage','MN','UNITED STATES','55378-3149','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 15:15:32',0,NULL,3,1,1,1,'\\ ','darinh92'),(3017,781784695012,220682003790,'2.1 Acer As 6530G Extensa 5235 Bluetooth Module+cable',1,'BTAC2113',12.8,'eastar4','sisley_111','mariestlouis@9bit.com','Martial Berthod','1435 Goupil','Drummondville','QC','CANADA','J2B5A1','(819) 478-6987','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 15:19:35',0,NULL,3,1,2,1,'\\ ','sisley_111\racer 5pin1.25 6cm   '),(3018,781784711012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','jillybean775','jillnhagan@yahoo.com','Jillian White','9308 Lake Chase Island Way','Tampa','FL','UNITED STATES','33626-1932','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 15:20:21',0,NULL,3,1,1,1,'\\ ','jillybean775\r红边优联'),(3019,777988315012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',2,'HSSE005',27.8,'eastar4uk','arty271048','artybabs@yahoo.co.uk','Arthur Turnbull','53 Bracken Brae, Tulloch','Perth','Perthshire and Kinross','UNITED KINGDOM','PH12SF','01738620446','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 15:20:50',0,NULL,3,1,3,1,'RA117733113CN\r ','arty271048\rHSSE005'),(3020,703842472011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','gah5140','smishara@alumni.upenn.edu','Scott Mishara','7 Jones Street, Apt 16','New York','NY','UNITED STATES','10014','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 15:22:27',0,NULL,3,1,1,1,'\\ ','gah5140'),(3021,703873347011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','harry_harper','yorkproofreading@googlemail.com','Katherine James','35 Selborne Road','Bishop\'s Cleeve','Gloucestershire','UNITED KINGDOM','GL52 8BT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 16:40:11',0,NULL,3,1,3,1,'RA117732166CN\r ','harry_harper\rMOAP001\r'),(3022,781822045012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','bitwaresales','mokuba@gmail.com','Gary Sparkes Jr.','2333 Pennington Rd','Bel Air','MD','UNITED STATES','21015-1203','(443) 617-0710','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 16:51:54',0,NULL,3,1,1,1,'\\ ','bitwaresales'),(3023,578441013013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','corys20','corys34@yahoo.com','Corrin Sotala','710 Tower Hill Dr','Brookfield','WI','UNITED STATES','53045-6740','(414) 322-6012','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-03 17:10:56',0,NULL,3,1,1,1,'\\ ','corys20'),(3024,781646295012,220759518349,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12,'eastar4uk','ywd40','yoni74@gmail.com','yoni Jagel','62<br>Dingle Close','Radcliff','Lancashire','UNITED KINGDOM','M26 1UN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 17:27:02',0,NULL,3,1,3,1,'RA117732651CN ','ywd40\rSCLO001'),(3025,781839466012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','mekawendie','arierae@gmail.com','Alvaro Riera Elena','C/Martin Alonso Pedraz nº 14<br>Bloque 4 - 1ºA','Salamanca','Castilla y León','SPAIN','37007','650137202','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-03 17:27:28',0,NULL,3,1,3,1,'RA117732254CN\r ','mekawendie\rOTRA002'),(3026,703894613011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','azcjhons','joieh@aol.com','Joe A. Honsberger`','13770 W Van Buren St<br>Ste 100','Goodyear','AZ','UNITED STATES','85338-1292','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 17:32:02',0,NULL,3,1,1,1,'\\ ','azcjhons'),(3027,578450378013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',3,'HSJA002',64.5,'eastar4','eugenekotlar','eugenekotlar@optonline.net','Yevgeny Kotlyar','251 W Dekalb Pike<br>Apt A105','King of Prussia','PA','UNITED STATES','19406-2445','(215) 798-0047','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 17:38:08',0,NULL,3,1,1,1,'\\ ','eugenekotlar'),(3028,781841806012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','histla','kurnia2k3@yahoo.com.sg','Mochammad Kurniawan','Puskesmas Sukodadi<br>Jl. P. Sudirman 39 Sukodadi','Lamongan','Jawa timur','INDONESIA','62253','081553000301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 17:40:41',0,NULL,3,1,2,1,'\\ ','histla'),(3029,781869504012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','ziphansen','tripzip@gmail.com','Zip Hansen','15232 SE 272nd St #107<br>Cascade Mobile Villa','Kent','WA','UNITED STATES','98042','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 18:23:38',0,NULL,3,1,1,1,'\\ ','ziphansen\r红边优联'),(3030,703924962011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','luckypapa13','luc.thys1@telenet.be','Luc Thys','Deken J. Van Herckstraat 55','Kontich','','BELGIUM','2550','032890688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 18:32:45',0,NULL,3,1,2,1,'\\ ','luckypapa13'),(3031,781891711012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','sale10sale','elado.neked@gmail.com','Molnar Attila D. EMH-Bp','Gyomroi u. 120.<br>BOSCH','Budapest','Hungary','HUNGARY','1103','36703404853','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 19:03:27',0,NULL,3,1,2,1,'\\ ','sale10sale'),(3032,578512082013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','princemanni','princemanni@gmx.de','Manfred Rutetzki','Am Mehrdrusch 27','Lahntal-Gossfelden','','GERMANY','35094','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 20:26:06',0,NULL,3,1,3,1,'RA117733127CN\r ','princemanni\rMOSA002'),(3033,781940432012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',12.99,'eastar4uk','masood75msn','masood75@msn.com','shaheen ahmed','2 vinters avenue','stevenage','Hertfordshire','UNITED KINGDOM','sg11qs','01438211767','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 20:28:25',0,NULL,3,1,3,1,'RA117732223CN\r ','masood75msn\rHSMO017'),(3034,532146660004,140516157546,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'TOIN002+BAIN002+BAIN001',49.9,'cnfaner','oizzo','mattias@hlo.se','Mattias Österberg','Lillebovägen 8','Saltsjö-Boo','','SWEDEN','13236','0046705090301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 20:38:38',0,NULL,3,0,3,1,'RA117732625CN ','oizzo\rTOIN002+BAIN002+BAIN001'),(3035,578519257013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',3,'HSJA002',64.5,'eastar4','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 20:49:22',0,NULL,3,1,3,1,'RA117732285CN\r ','vjendrisvelimir\r欧标\rHSJA002'),(3036,781960734012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','cotelilllo','joberab@hotmail.com','Jose Antonio Bernal Abad','Juan Ramon Jimenez 55 Puerta 15<br>22577962N','Valencia','Comunidad Valenciana','SPAIN','46026','963258979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 21:09:43',0,NULL,3,1,2,1,'\\ ','cotelilllo'),(3037,578532160013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','dhos1659','deliah@homeschools.org','DELIA HOSU','1304 E WHITE WATER LANE','PALATINE','IL','UNITED STATES','60074','(847) 529-9752','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 21:25:54',0,NULL,3,1,1,1,'\\ ','dhos1659'),(3038,704013318011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','djhughe','ebay@dnahughes.com','David Hughes','10 Cave Creek Ct','Bloomington','IL','UNITED STATES','61704','(309) 661-8129','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 21:43:40',0,NULL,3,1,1,1,'\\ ','djhughe'),(3039,578538488013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','krl0s_86','loscar14686@msn.com','CARLOS RAMOS NOTARIO','POLIGON RUTLLA ALTA NAU Nº 6<br>CALYGAS S.L.','PALAMÓS','Cataluña','SPAIN','17230','620677292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 21:56:14',0,NULL,3,1,3,1,'RA117733135CN\r ','krl0s_86\rMOSA002'),(3040,781991174012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','karaokeaustralia','ebaysales@1stchoicejukeboxes.com','Kayone Karaoke','PO Box 4164','Frankston Heights','Victoria','AUSTRALIA','3199','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 22:25:46',0,NULL,3,1,2,1,'\\ ','karaokeaustralia'),(3041,526432098003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','ofra10','ofra555@gmail.com','OFRA YEMINI','KEREN  HAYESOD  25/37','BAT-YAM','ISRAEL','ISRAEL','59624','0544566435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 22:33:43',0,NULL,3,1,3,1,'RA117732603CN\r ','ofra10\rHSMO011'),(3042,781996504012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',4,'HSMO008',43.8,'eastar4','3447','fagan.otis@yahoo.com','Otis Fagan','2247 Scotland Dr','Dallas','TX','UNITED STATES','75216-6452','(214) 228-3447','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 22:42:23',0,NULL,3,1,1,1,'\\ ','3447'),(3043,704025975011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','jive.talkin.robot','ebay@rockout.org','Adam Arseneau','860 Rymal Rd. E<br>Unit 11','Hamilton','ON','CANADA','L8W2X3','(905) 315-4305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 22:42:50',0,NULL,3,1,2,1,'\\ ','jive.talkin.robot'),(3044,668287333001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','valtkach6','poltava@earthlink.net','Valeriy Tkachenko','555 MAIN ST<br>APT 1407','NEW YORK','NY','UNITED STATES','10044','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 22:43:20',0,NULL,3,1,1,1,' LK045713752CN\r\\','valtkach6\r'),(3045,578552955013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',11.99,'eastar4','kadrely','kadrelyp@gmail.com','yahe','12721 Lynn Rd<br>Lot 30','tampa','FL','UNITED STATES','33624-2863','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 22:57:02',0,NULL,3,1,1,1,'\\ ','kadrely'),(3046,704051877011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',18.9,'eastar4','importacionquito','ivanmarcelo27@hotmail.com','IVAN MARCELO QUINTANILLA','LORENZO ALDANA OE3-19 Y AVENIDA AMERICA','QUITO','PICHINCHA','ECUADOR','59301','3200576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 23:51:24',0,NULL,3,1,2,1,'\\ ','importacionquito'),(3047,531933695004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','chris_gupta','locomotivesteamerheisler@yahoo.com','Christian Gupta','523 Harvard Rd','San Mateo','CA','UNITED STATES','94402','(650) 823-5454','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 23:59:09',0,NULL,3,1,1,1,'\\ ','chris_gupta'),(3048,532193301004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','ecomtelecomunicaciones','ecom@ecomtelecomunicaciones.com','Ecom Telecomunicaciones','C/ San Blas, 14-A','Paterna (Valencia)','Comunidad Valenciana','SPAIN','46980','644500800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 00:14:33',0,NULL,3,1,3,1,'RA117732183CN\r ','ecomtelecomunicaciones\rHSNO017  欧标\r'),(3049,782014758012,220502333507,'2.1 HP DV2000 DV2100 DV2200  Bluetooth Module+ cable',1,'BTHP2103',12.8,'eastar4','texicanian','t_raley3@hotmail.com','Thomas Raley','3722 W Rochelle Rd','Irving','TX','UNITED STATES','75062','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 00:21:31',0,NULL,3,1,1,1,'\\ ','texicanian\rHP 8pin 1.0 12cm '),(3050,578036145013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','vimalpaul2255','vimalpaul2006@yahoo.com','Vimal Paul','L&P Rubber Industries,<br>Rubber Park, Valayanchirangra P.O, Perumbavoor','Ernakulam','Kerala','INDIA','683556','9745929333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 01:16:04',0,NULL,3,1,3,1,'RA117732648CN RA117732577CN','vimalpaul2255\rHSNO019\r欧标\r申报10美金\rRA117732577CN\r\r'),(3051,782044386012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','casitatraveler','lkdavis.co@gmail.com','Lowell K Davis','PO Box 599<br>1341 County Road 85','Tabernash','CO','UNITED STATES','80478','(970) 887-2296','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 01:37:56',0,NULL,3,1,1,1,'\\ ','casitatraveler'),(3052,0,220774366903,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.22,'eastar4','ptechiiiii','pdog70@msn.com','PEDRO RODRIGUEZ','12332 Floral Dr','WHITTIER','CA','UNITED STATES','90601-3021','(562) 699-5303','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 01:54:29',0,NULL,3,1,1,1,'\\ ','ptechiiiii'),(3053,578586358013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','kpgmd','katepgarcia@yahoo.com','kate garcia','4 topaz street, millionaires village, novaliches','quezon city','','PHILIPPINES','1123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 01:55:10',0,NULL,3,1,2,1,'\\ ','kpgmd'),(3054,782049541012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','embexiu','ntpphong@yahoo.com','Phong T Nguyen','12631 Pleasant Pl<br>null','Garden Grove','CA','UNITED STATES','92841-4938','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 01:57:19',0,NULL,3,1,1,1,'\\ ','embexiu\r红边优联'),(3055,782052745012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','annaandythai','thantai2002ca@yahoo.com','van hung thai','2747 rue benjamin - sulte.','montreal','QC','CANADA','h3m1s3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 02:07:49',0,NULL,3,1,2,1,'\\ ','annaandythai'),(3056,704089228011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','pdiddy56','peter22@sbcglobal.net','Pedro De La Cruz','2416 Houston St','Los Angeles','CA','UNITED STATES','90033-2520','(323) 485-0443','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 02:22:22',0,NULL,3,1,1,1,'\\ ','pdiddy56'),(3057,577536202013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','denice202001','denice202001@yahoo.com','TASHONDRA D ROPER','8100 Winterwood Dr','Little Rock','AR','UNITED STATES','72209-7319','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'denice202001'),(3058,704115773011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','joserodriguezcuevas','jarcvs88@gmail.com','JOSE RODRIGUEZ','1131 Leahy RD','MONTEREY','CA','UNITED STATES','93940-7451','(831) 831-5572','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 04:39:10',0,NULL,3,1,1,1,'\\ ','joserodriguezcuevas'),(3059,704116359011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','bomblekz','kuansien@hotmail.com','kuansien chiang','16 Mort Street','shortland','New South Wales','AUSTRALIA','2307','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 04:42:15',0,NULL,3,1,2,1,'\\ ','bomblekz'),(3060,578614730013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','nazauto','nazauto@aol.com','discount tir center c/o nazareth minassian','6817 van nuys blvd','van nuys','ca','UNITED STATES','91405-4626','(818) 421-5517','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 04:48:26',0,NULL,3,1,1,1,'\\ ','nazauto'),(3061,578616459013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','gsmrepair_com','8727303@qip.ru','Vitaliy Alentev','Kusnecova str. 20-245','Saint-Petersburg','RU','RUSSIAN FEDERATION','198332','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 05:03:30',0,NULL,3,1,3,1,'RA117732515CN\r ','gsmrepair_com\rMOSA002\r'),(3062,782098076012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','chilaquil626','subaru2005_1@hotmail.com','agustin hernandez','17036 Broadvale Dr','la puente','CA','UNITED STATES','91744-4251','(626) 333-8893','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 05:42:47',0,NULL,3,1,1,1,'\\ ','chilaquil626'),(3063,578620096013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','tonyw36','tony.wong@au.viewsonic.com','Tony Wong','Unit 4, 44 Dickson Ave','Artarmon','New South Wales','AUSTRALIA','2064','0299066277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 05:32:59',0,NULL,3,1,2,1,'\\ ','tonyw36'),(3064,782107269012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',5,'CMLO001',249.95,'eastar4','risaasen','hjr@ebs-as.no','EBS AS v/Helge Risaasen','Peder Sletners vei 4','Kolbotn','Kolbotn','NORWAY','1415','004795052532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 06:42:37',0,NULL,3,0,4,1,'YW866010866CN ','risaasen'),(3065,782124772012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','dyhr1973','asia_number1@hotmail.com','Daisuke Yuhara','2-19 Gakuonji','Yao','Osaka','JAPAN','581-0853','(50) 1555-2163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 07:52:05',0,NULL,3,1,2,1,'\\ ','dyhr1973'),(3066,703096670011,320679575575,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',32.5,'eastar4uk','ptru1955','pt@city.dk','Peter Truelsen','25 Magdelonevej','Copenhagen','','DENMARK','2400','(045) 29623930','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 07:59:53',0,NULL,3,1,3,1,'RA117732634CN ','ptru1955\rWWOT001\r'),(3067,578645035013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',83.85,'eastar4','rowdy1974','samantha.donovan@gmail.com','Byron Donovan','37 Union Road','Surrey Hills','Victoria','AUSTRALIA','3127','0398363999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 08:37:29',0,NULL,3,1,3,1,'RA117733073CN\r ','rowdy1974\rMOSA003'),(3068,782137330012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','ramazzotti_totti','torsten263@web.de','Torsten Schmitt','Zum Wurmtal 8','Wuerselen','','GERMANY','52146','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 08:47:29',0,NULL,3,1,2,1,'\\ ','ramazzotti_totti'),(3069,704169288011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','elmyh1','chenhsiung@gmail.com','Chen Hsiung Wong','Level 13, Menara Park (Formerly KUB.com), Megan Avenue 2, Blk D<br>No. 12, Jalan Yap Kwan Seng','Kuala Lumpur','Kuala Lumpur','MALAYSIA','50450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 09:15:32',0,NULL,3,1,2,1,'\\ ','elmyh1'),(3070,578655018013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','de39ster','dirt444@gmail.com','Sándor Németh','iskola utca 73','Gomba','','HUNGARY','2217','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 09:41:12',0,NULL,3,1,2,1,'\\ ','de39ster'),(3071,782163670012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',2,'RELO003',23.98,'eastar4','racer560surf','racer560@onlinehome.de','Berthold Rademacher','Reiger Weg 37','Velbert','','GERMANY','42553','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 10:32:47',0,NULL,3,1,2,1,'\\ ','racer560surf\r红边优联'),(3072,782168487012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','mrandmrsgee','pat_dan@bigpond.com','Patrick and Danielle Gaut','90 Russell St','tumut','New South Wales','AUSTRALIA','2720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 10:55:14',0,NULL,3,1,2,1,'、 ','mrandmrsgee\r红边优联\r新地址\r\rPatrick and Danielle Gaut\rconner spicer 1/9 view st \rmarrackville 2720 nsw \rAustralia'),(3073,578670000013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','8kedc54','sterndani@yahoo.com','Dani Stern','PO BOX 3005','Ramat Hasharon','israel','ISRAEL','47130','+972-50-7599993','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 11:04:24',0,NULL,3,1,3,1,'RA117732965CN\r ','8kedc54\rBAZA001'),(3074,782175065012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','skaska1000','skaska100@mail.ru','Natalia Nechaeva','Krasnogo Mayaka st. 4/2','Moscow','Moscow','RUSSIAN FEDERATION','117519','+74953136356','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 11:15:10',0,NULL,3,1,2,1,'\\ ','skaska1000\r欧标'),(3075,577215050013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','thai_vy','joliedinh@gmail.com','Vy  Dinh Thao','C45 Cu Xa Vinh Hoi, Phuong 5, Quan 4','Ho Chi Minh','Ho Chi Minh','VIET NAM','054','(+84) 938206866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 11:16:49',0,NULL,3,1,2,1,'\\ ','thai_vy'),(3076,578672741013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','nfix_dj','master.qmail@gmail.com','Jiri Dejmek','Nadrazni 23','Novy Jicin','','CZECH REPUBLIC','741 01','(420) 774838','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 11:21:44',0,NULL,3,1,2,1,'\\ ','nfix_dj'),(3077,704206996011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','lewis.1012','janehcleveland@yahoo.com','ROGER CLEVELAND','403 S Sycamore St','Palestine','TX','UNITED STATES','75801-3509','(903) 948-9088','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 11:45:26',0,NULL,3,1,1,1,'\\ ','lewis.1012\r带电池'),(3078,578681434013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','axo78','ignacio.diaz.cortes@gmail.com','Ignacio Díaz Cortés','Alcala 44, 4º (Ashurst)','Madrid','Madrid','SPAIN','28014','629013805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 12:02:54',0,NULL,3,1,3,1,'RA117733158CN ','axo78\rOTRA002'),(3079,525602216003,130490202395,'Genuine Logitech Harmony 525 Universal Remote Control',1,'RCLO005',74.99,'cnfaner','shruthi87','shruthi_paradise@yahoo.com','Mangay Samy Vellu','4281 Express Ln<br>Ste L5421','Sarasota','FL','UNITED STATES','34238-2602','941 538 6941','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 12:09:02',0,NULL,3,1,1,1,'\\ ','shruthi87'),(3080,578689970013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','twistedmind1974','mr.twist@gmx.de','Klaus Stürzenbecher','Nappenhorn 19','Barmstedt','','GERMANY','25355','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 12:42:47',0,NULL,3,1,2,1,'\\ ','twistedmind1974'),(3081,578692486013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','zivtsarfati14','digger18@gmail.com','Ziv Tsarfati','Hayarden 27','Moshav Tal Shahar','','ISRAEL','76805','972-54-7655544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 12:57:01',0,NULL,3,1,3,1,'RA117732974CN ','zivtsarfati14\rBAZA001'),(3082,704231240011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','benandtim','baj73@aol.com','Ben Johansen','511 Teakwood Dr','Altamonte Springs','FL','UNITED STATES','32714-7429','(407) 697-5034','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 13:10:32',0,NULL,3,1,4,1,'YW866010855CN ','benandtim'),(3083,704235750011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','ckchoi73','ckchoi73@hotmail.com','Joshua Choi','Suite 5, Level 3,<br>33 Rowe Street','Eastwood','New South Wales','AUSTRALIA','2122','0298584977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 13:24:25',0,NULL,3,1,2,1,'\\ ','ckchoi73'),(3084,704243039011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','rumrumvoo','pictureoftime@hotmail.co.uk','David Thomas','8, Rolls ave, Forest Park est,<br>Penpedairheol','Hengoed','South Wales','UNITED KINGDOM','CF82 8HP','01443833149','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 13:47:41',0,NULL,3,1,3,1,'RA117732912CN\r ','rumrumvoo\rMOAP001'),(3085,659815970001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','rys_store','ryan@rollinjunk.com','3D Mobile creations','933 E Crosstown pkwy','kalamazoo','MI','UNITED STATES','49001-2507','(269) 998-6597','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 14:03:59',0,NULL,5,0,18,0,NULL,'rys_store'),(3086,704258504011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',11.95,'eastar4','guatis','guatis@gmail.com','Benjamín Velasco','Albacete 4420<br>Depto 72','Santiago','Santiago','CHILE','7580287','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 14:35:18',0,NULL,3,1,2,1,'\\ ','guatis'),(3087,704267691011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','poofs','poofsie@yahoo.com','Ronald Serafin','25202 Colgate St','Dearborn Heights','MI','UNITED STATES','48125-1643','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 15:02:02',0,NULL,3,1,1,1,'\\ ','poofs'),(3088,782259563012,220759964705,'Logitech MX1000 Mouse special bluetooth  version',1,'MOLO005',59.9,'eastar4','sashoh','sashoh@gmail.com','Alexander Hristov','Kukush 1 street<br>Mtel M1 Building, Room A103','Sofia','Bulgaria','BULGARIA','1309','+359882204432','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 15:29:13',0,NULL,3,1,3,1,'RA117732872CN ','sashoh\r蓝牙版的\rMOLO005'),(3089,782261807012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','a3vanderberg','emieljansen@hotmail.com','Emiel Jansen','Weideland 10','Den Hoorn','','NETHERLANDS','2635 JP','0151234567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 15:35:25',0,NULL,3,1,3,1,'RA117733008CN\r ','a3vanderberg\rOTCR001'),(3090,578734020013,230606052768,'New Leather Case Built-in Bluetooth Keyboard For iPad',1,'KBAP001',39.8,'eastar4','cgarrett31304','cgarret1@comcast.net','Charles Garrett','31304 Saunders Dr','Tavares','FL','UNITED STATES','32778-4921','(407) 310-4760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 15:49:16',0,NULL,3,1,1,1,'\\ ','cgarrett31304'),(3091,782283167012,220704730539,'New in Box Plantronics Explorer 330 BLUETOOTH HEADSET',2,'HSPL004',31,'eastar4uk','jtrunky','jaynelinfoot@gmx.com','Jayne Linfoot','150 galliard road','edmonton','london','UNITED KINGDOM','n9 7lp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 16:32:38',0,NULL,3,1,3,1,'RA117732930CN\r ','jtrunky\rHSPL004\r英标'),(3092,704302386011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','mike-mm','mihail.pashko@gmail.com','Mihail Pashko','lermontova 207 kv 7','Slavyansk-na-Kubani','Krasnodar','RUSSIAN FEDERATION','353560','918-454-86-67','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 16:36:54',0,NULL,3,1,2,1,'\\ ','mike-mm\r欧标'),(3093,575975446013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','xxdestiny','annie.ta.tran@gmail.com','Annie Tran','68 Westforest Trail','Kitchener','ON','CANADA','n2n3a8','(519) 496-7380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 16:48:43',0,NULL,3,1,3,1,'RA117715106CN ','xxdestiny\rRCLO003'),(3094,782296309012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','salvanica_8385','lanica040507@hotmail.com','Annes Arana','13107 Kumar Ct','Woodbridge','VA','UNITED STATES','22193-5244','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 16:58:10',0,NULL,3,1,1,1,'\\ ','salvanica_8385'),(3095,704318907011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',4,'GLSG001',271.96,'eastar4','blpch','brian.heiser1@verizon.net','Brian M. Heiser','16562 Aquamarine Ct','Chino Hills','CA','UNITED STATES','91709-4644','(909) 597-0639','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 17:19:59',0,NULL,3,1,6,1,'EE520583304CN ','blpch\r带电池'),(3096,704324384011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',29.8,'eastar4','guard.69.angel','piglet.7@btinternet.com','Joanna Briggs','7,Emmery close','Broughton','Lincolnshire','UNITED KINGDOM','DN20 0SN','01652658984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:30:54',0,NULL,3,1,2,1,'\\ ','guard.69.angel'),(3097,578769843013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','cascademaxi12','doofkatze@gmx.de','Maxi  Behn','Kreuzlingerstr.9','Germering','','GERMANY','82110','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:46:23',0,NULL,3,1,2,1,'\\ ','cascademaxi12'),(3098,704331949011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','dolbination','guntrash@gmail.com','Burdila Alexandru','str. Columna 121, ap. 35','Chisinau','','MOLDOVA, REPUBLIC OF','MD 2012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:47:56',0,NULL,3,1,3,1,'RA117733060CN\r ','dolbination\rWLAP009'),(3099,578771272013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','puzzybaer','puzzybaer@gmx.net','Dominik Berger','Theresienstr. 4','Augsburg','','GERMANY','86153','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:49:17',0,NULL,3,1,2,1,'\\\r ','puzzybaer'),(3100,704331082011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','flash15*','tom-spencer4@hotmail.co.uk','Michael Spencer','Resipole House,<br>Gubberford Lane, Garstang','Preston','Lancashire','UNITED KINGDOM','PR3 1PS','01995604147','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 17:49:54',0,NULL,3,1,3,1,'RA117732991CN\r ','flash15*\rMOAP001'),(3101,526639661003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','jeep_ko-bk','jeep_ko@bk.ru','Dzhepko Vitaliy','Komsomolskaya<br>113-24','Rubtsovsk','Altayskiy kray','RUSSIAN FEDERATION','658207','+79133626243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:53:38',0,NULL,3,1,3,1,'RA117733087CN ','jeep_ko-bk\rHSMO018\r欧标'),(3102,578767197013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','andrerosso66','andrerossobr@gmail.com','Andre Schumann Rosso','SQS 104 Bloco D apto 504<br>ASA SUL','Brasilia','DISTRITO FEDERAL','BRAZIL','70343-040','+556138790202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:36:23',0,NULL,3,1,2,1,'\\ ','andrerosso66'),(3103,704330400011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','aynne08','jymmy1000@hotmail.com','tarcisio silva','praca da bandeira quadra 142 lote 14 setor jao','Goiania','Goias','BRAZIL','74674-040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 19:09:03',0,NULL,3,1,3,1,'RA117732869CN ','aynne08\rRCLO006'),(3104,782377782012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','chouette60','martinelaliberte@hotmail.com','martinelaliberte','436, rue bérubé','quebec','QC','CANADA','g1m 1c8','(418) 687-0770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 19:33:11',0,NULL,3,1,2,1,'\\ ','chouette60'),(3105,782382278012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','stkandrdr','steven.keith@comcast.net','Steven Keith','2690 Nevada Ct','Placerville','CA','UNITED STATES','95667-3837','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 19:37:54',0,NULL,3,1,1,1,'\\ ','stkandrdr'),(3106,704410835011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','lepoja11','raimo.aikas@gmail.com','raimo äikäs','päijänteentie 48','vilppula','Oletus','FINLAND','35700','0443137495','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 20:26:43',0,NULL,3,1,2,1,'\\ ','lepoja11\r欧标'),(3107,704420779011,320557739481,'2.0 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2004',12.5,'eastar4','jerki1py8','jerrylking@yahoo.com','Jerry King','916 Crescent Moon Dr','North Las Vegas','NV','UNITED STATES','89031-1493','(702) 639-6653','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 20:46:10',0,NULL,3,1,1,1,'\\ ','jerki1py8\racer 4pin1.25 6cm'),(3108,704425065011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',14.9,'eastar4uk','ashe8741','sheps@talktalk.net','Andrew Shepherd','18 Woollards Lane<br>Great Shelford','Cambridge','Cambridgeshire','UNITED KINGDOM','CB22 5LZ','07860443856','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 20:54:27',0,NULL,3,1,3,1,'RA117732926CN ','ashe8741\rHSJA002\r英标'),(3109,782433019012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','tunney205','shawn.tunney@gmail.com','Shawn Tunney','PO Box 183','Roscoe','PA','UNITED STATES','15477','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 21:15:27',0,NULL,3,1,1,1,'\\ ','tunney205\r红边优联'),(3110,704438720011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',3,'HSJA002',44.7,'eastar4uk','manofbronze55','jerrysavagehd@msn.com','Jerry Savage','5073 Dyer Ln','Taylorsville','UT','UNITED STATES','84118-2913','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 21:34:17',0,NULL,3,1,1,1,'\\ ','manofbronze55'),(3111,578851856013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','buyer.md','redmax@rambler.ru','Maxim Vasik','str. Igor Vieru 14 apt. 96','Chisinau','MD','MOLDOVA, REPUBLIC OF','2075','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 21:38:22',0,NULL,3,1,2,1,'\\ ','buyer.md'),(3112,782443449012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','drunk_f','dr_unk@msn.com','Florian Dranca','24 Bolton Gardens<br>flat 1, c.o. Carlo Casiraghi','London','London','UNITED KINGDOM','SW5 0AQ','2073701717','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 21:40:20',0,NULL,3,1,3,1,'RA117732943CN ','drunk_f\rANCN001'),(3113,578855338013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','navs44','navs21@gmail.com','Navjot Sandhu','25 pringle drive','Barrie','ON','CANADA','L4N0N9','(705) 792-0698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 21:47:42',0,NULL,3,1,2,1,'\\ ','navs44'),(3114,704450162011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','lacey0406','lmc8623@yahoo.com','Lacey Case','944 Sams Rd NW','Brookhaven','MS','UNITED STATES','39601-8696','(601) 757-8937','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 22:06:51',0,NULL,3,1,1,1,'\\ ','lacey0406'),(3115,704453148011,320411515152,'UNLOCKED Option GTM382 PCI-E 7.2Mbps Modem WWAN GTM 382',1,'WWOP003',43.95,'eastar4','scunkaneli','scunkaneli@yahoo.de','Christian Hanke','Leipziger Straße 7','Zeitz OT Zangenberg','','GERMANY','06712','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 22:11:15',0,NULL,3,1,3,1,'RA117732988CN\r ','scunkaneli\rWWOP003'),(3116,578862588013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','pierre0357','pierre.fridel@yahoo.fr','Pierre Fridel','24, rue Paul Simminger','Montigny-les-Metz','Lorraine','FRANCE','57950','06.61.86.97.48','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 22:19:55',0,NULL,3,1,2,1,'\\ ','pierre0357'),(3117,782470385012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','sbarsotti','sbarsotti@hotmail.com','Steve Barsotti','19255 SW 65th Ave<br>Suite 120','Tualatin','OR','UNITED STATES','97062-9712','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 23:04:34',0,NULL,3,1,1,1,'\\ ','sbarsotti'),(3118,782473027012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','cirruslx','gbrown69@gmail.com','Gaetan Brown','2255 du Neptune','Quebec','QC','CANADA','G2E 6A3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 23:10:50',0,NULL,3,1,2,1,'\\ ','cirruslx'),(3119,578877413013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','dwallingham','dwallingham@hotmail.com','David Wallingham','3000 Olivet St.<br>Suite 105','Halifax','NS','CANADA','B3L3Z7','(902) 431-0045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 23:37:52',0,NULL,3,1,2,1,'\\ ','dwallingham'),(3120,782480509012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','kastlekolor','slaterlovesspam@yahoo.com','Greg Stieritz','2266 Hickory Creek Ln','New Richmond','OH','UNITED STATES','45157','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 23:39:26',0,NULL,3,1,1,1,'\\ ','kastlekolor'),(3121,702894119011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','clearwater-designs','ccperla@earthlink.net','Christine C Perla','13156 Seneca Dr','Waynesboro','PA','UNITED STATES','17268-8458','(717) 762-6460','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 23:47:28',0,NULL,3,1,1,1,'\\ ','clearwater-designs'),(3122,782491098012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','kmcflow','kmcflow@pacbell.net','Kevin McCormick','810 Los Vallecitos Blvd<br>Ste 214','San Marcos','CA','UNITED STATES','92069-1451','(760) 471-0300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 00:19:22',0,NULL,3,1,1,1,'\\ ','kmcflow'),(3123,578896270013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','mare1383','smiley401816@yahoo.com','Maryann Maness','4198 Martin Rd','Festus','MO','UNITED STATES','63028-3459','(636) 337-7034','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 01:19:23',0,NULL,3,1,1,1,'\\ ','mare1383'),(3124,704520968011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',83,'eastar4','plcab','plcoptions@bigpond.com.au','PLC Options Pty Ltd','Unit 12<br>37 Shipley Drive','Rutherford','New South Wales','AUSTRALIA','2320','0249337757','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 02:46:01',0,NULL,3,1,3,1,'RA117732957CN ','plcab\rTRTS001*10'),(3125,782547615012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',15.5,'eastar4','lourdes1858','phil.n@mirjmj.com','Phil Stuckey','81 Chapel Road','Moorabbin','Victoria','AUSTRALIA','3189','0419525071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 04:06:26',0,NULL,3,1,2,1,'、 ','lourdes1858\r极动鲨鼠标'),(3126,532524688004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','decha.t','bosslee2010@gmail.com','Decha Tharakulwattana','698/29 Ideomix Phaholyothin, Phaholyothin Road<br>Samsean Nai, Phayathai','Bangkok','','THAILAND','10400','+66843530111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 04:08:35',0,NULL,3,1,3,1,'RA117732841CN ','decha.t\rOTRA002'),(3127,578925307013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','elizabeth841410','elizabeth.buitrago@gmail.com','Elizabeth Buitrago','Rue du village 43','Lutry','','SWITZERLAND','1095','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 04:10:52',0,NULL,3,1,2,1,'\\ ','elizabeth841410'),(3128,704544164011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ginacopycatana','copycatana@gmail.com','Trent Montgomery','5 Delacy Court','Narre Warren South','Victoria','AUSTRALIA','3805','61400998880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 04:48:11',0,NULL,3,1,2,1,'、 ','ginacopycatana'),(3129,704545030011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',19.95,'eastar4','ushakh','yushakov@mail.ru','Yuri Ushakov','Shosse Kosmonavtov 209-43','Perm','Permskiy krai','RUSSIAN FEDERATION','614065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 04:53:31',0,NULL,8,1,17,1,NULL,'ushakh\r无线蓝牙二合一'),(3130,578933423013,230617128655,'New Genuine DENON RC-969 Remote Control RC 969',1,'RCDE001',75.99,'eastar4','niceaudio4less','av4less@aol.com','donald beale','13 Firedrake Terrace','Henderson','NV','UNITED STATES','89074','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 05:14:04',0,NULL,3,1,1,1,'、 ','niceaudio4less'),(3131,578936441013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',79.98,'eastar4','citio','mikhail@arteev.com','Mikhail Arteev','Avenue du Moléson, 21','Fribourg','','SWITZERLAND','1700','0767000333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 05:40:42',0,NULL,3,1,3,1,'RA117732909CN ','citio\rHSNO019'),(3132,782205582012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','gsrerio','csrcs@bis.net.ua','Svjatoslav Gresuk','Zabyzzia I. Franka, 74','Sokal','Lviv region','UKRAINE','80028','380639760702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 06:56:45',0,NULL,3,1,2,1,'、 ','gsrerio'),(3133,578948744013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','ushakh','yushakov@mail.ru','Yuri Ushakov','Shosse Kosmonavtov 209-43','Perm','Permskiy krai','RUSSIAN FEDERATION','614065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:14:01',0,NULL,3,1,3,1,'RA117732855CN ','ushakh\r再发一个Triple Tyco Universal Wireless Laptop Antenna Mini PCI\r一个New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card'),(3134,704570680011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','ushakh','yushakov@mail.ru','Yuri Ushakov','Shosse Kosmonavtov 209-43','Perm','Permskiy krai','RUSSIAN FEDERATION','614065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:16:10',0,NULL,8,0,17,0,NULL,'ushakh'),(3135,704576884011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','bass_hunter69','ab_apple@me.com','Alex BAUD','9 rue Roger Bréchan','Lyon','Rhône-Alpes','FRANCE','69003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:47:50',0,NULL,3,1,3,1,'RA117732838CN ','bass_hunter69\rUDAP001 '),(3136,704463692011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','fixbeau','francois.xavier.beau@gmail.com','François-Xavier Beau','225 W 83rd St<br>Apt 20I','NEW YORK','NY','UNITED STATES','10024-4964','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 07:57:51',0,NULL,3,1,1,1,'\\ ','fixbeau'),(3137,526808676003,130490202395,'Genuine Logitech Harmony 525 Universal Remote Control',1,'RCLO005',74.99,'cnfaner','reinholdmichael','philip_hill@web.de','Philip Hill','Talstraße 45','Ockenfels','','GERMANY','53545','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 08:05:31',0,NULL,3,1,3,1,'RA117732767CN ','reinholdmichael\rRCLO005\r'),(3138,704591326011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','astchanuk','andrewstchan@gmail.com','AST Chan','12A Poplar Road','Herne Hill','London','UNITED KINGDOM','SE24 0BW','02077387804','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 08:54:26',0,NULL,3,1,3,1,'RA117715154CN ','astchanuk\rMOAP001'),(3139,578975922013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','ozimextrading','sales@ozimextrading.com.au','Ngoc Minh','45/4-10 Benedict Ct','HOLROYD','New South Wales','AUSTRALIA','2142','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 10:11:46',0,NULL,3,1,2,1,'、 ','ozimextrading'),(3140,526840686003,130458358024,'New Motorola HS810 Bluetooth Wireless Headset track#',1,'HSMO017',21.99,'cnfaner','isakovboris972','isakovboris@walla.com','boris isakov','P.O.Box 4332','Bait Arie','ID','ISRAEL','71947','972-50-6273355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 11:21:44',0,NULL,3,1,3,1,'RA117715260CN\r ','isakovboris972\rHSMO017'),(3141,782652677012,220459522492,'Acer Aspire 5680 5630 3690  Bluetooth Module 2.0+cable',1,'BTAC2021',12.5,'eastar4','lamdim','lamdimos@yahoo.com','LAMBROS DIMOS','MAIANDROY 12 CHALANDRI','ATHENS','CHALANDRI','GREECE','15233','6972119668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 11:48:14',0,NULL,3,1,2,1,'、 ','lamdim\racer 8pin1.00 8cm'),(3142,704098018011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',22.98,'eastar4','rq!','post2rq@gmail.com','R.A. Quinn','160 Lane Rd','Chester','NH','UNITED STATES','03036','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 11:57:53',0,NULL,3,1,1,1,'\\ ','rq!\r一共买了两个'),(3143,704644570011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','doctor_macintosh','sat@conserve.de','CONSERVE Computer','Im Mediapark 11','Köln','','GERMANY','50670','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 12:22:04',0,NULL,3,1,3,1,'RA117715375CN\r ','doctor_macintosh\rWLAP009'),(3144,782668558012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',2,'RELO003',23.98,'eastar4','oksteine','oksteine@online.no','Ole Kristian Steine','Hvittingfossveien 362a','Holmestrand','','NORWAY','3080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 12:40:54',0,NULL,3,1,2,1,'、 ','oksteine\r红边优联'),(3145,579005907013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','timporium','ttalimon@mail.win.org','Tim Talimonchuk','1879 S Old Highway 94','Saint Charles','MO','UNITED STATES','63303','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 12:46:34',0,NULL,3,1,1,1,'\\ ','timporium\r由于旧的缺货，发一个新的'),(3146,704673243011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','tmfitz2001','tmfitz2001@yahoo.com','Tom Fitzgerald','1827 S Madison St','Denver','CO','UNITED STATES','80210-3629','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 13:57:20',0,NULL,3,1,1,1,'\\ ','tmfitz2001'),(3147,782695037012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','belle_riviere','oung.byun@sciences-po.org','Oung BYUN','1, Rue Maurice Arnoux<br>ENS B515','Montrouge','Ile-de-France','FRANCE','92120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 14:00:38',0,NULL,3,1,2,1,'\\ ','belle_riviere\r红边优联'),(3148,579023322013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','tiga_cat','frankg@vt.edu','Francis  Galligan','2521 Gloucester Dr','Blacksburg','VA','UNITED STATES','24060-8267','(540) 552-6663','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 14:04:42',0,NULL,3,1,1,1,' \\','tiga_cat'),(3149,782697546012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','jbra23163','paulnjohn@talktalk.net','John Atherall','176 Hadlow road','Tonbridge','Kent','UNITED KINGDOM','tn9 1pd','01732350335','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 14:09:06',0,NULL,3,1,3,1,'RA117715389CN\r ','jbra23163\rOTRA002'),(3150,782705781012,220720533789,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',21.5,'eastar4uk','peregrine_took','rpnc_ebay@tiscali.co.uk','Russell Parker','118 Woodfield Drive','Barnet','Herts','UNITED KINGDOM','EN4 8PB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 14:31:58',0,NULL,3,1,3,1,'RA117715361CN\r ','peregrine_took\rSCLO001'),(3151,704234638011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','978tomtom88','mccormick.t.p@gmail.com','Tom McCormick','1 Blue Ridge Rd','Westford','MA','UNITED STATES','01886-1909','(978) 407-6708','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 15:23:30',0,NULL,3,1,1,1,'\\ ','978tomtom88'),(3152,526899895003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','johnnyjean','jgagne@cybernaute.com','Jean Gagne','157, rue Neree','Chicoutimi','QC','CANADA','G7G 4A5','(418) 543-5376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 16:04:05',0,NULL,3,1,3,1,'RA117715392CN\r ','johnnyjean\rOTGR001'),(3153,704715322011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','graffittimonster','winto1990@gmx.net','Andrea Winter','Augustastraße 38','Oranienburg','','GERMANY','16515','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 16:05:44',0,NULL,3,1,2,1,'、 ','graffittimonster'),(3154,704728197011,320679575403,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.5,'eastar4uk','squall25','squalldenis@gmail.com','DENIS SMIRNOV','Garibaldi 10-6-553','Moscow','Moscow','RUSSIAN FEDERATION','117393','7(926)2164450','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-05 16:40:13',0,NULL,3,1,2,1,'、 ','squall25'),(3155,579073928013,230393459225,'2.1 New Acer Timeline 3810 3810T Bluetooth Module+cable',1,'BTAC2118',12.8,'eastar4','misiom1','misioallegro@gmail.com','Michał Mroczkowski','Dobrowolskiego 1c/12','Gdańsk','pomorskie','POLAND','80287','696 449750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 17:22:24',0,NULL,3,1,2,1,'、 ','misiom1\racer 8pin1.0 3cm\r'),(3156,660317741001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','516gene','gene@kenclaire.com','Kenclaire Electric','714 Old Country Rd','Westbury','NY','UNITED STATES','11590-4504','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 18:10:24',0,NULL,5,0,18,0,NULL,'516gene'),(3157,782801021012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','acrouth','alanrouth@gmail.com','Alan C. Routh','82 Fairview Ave','Chatham','NJ','UNITED STATES','07928-1741','(973) 635-0906','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 18:18:00',0,NULL,3,1,1,1,'\\ ','acrouth\r红边优联'),(3158,526952062003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','cafilisador','okokendi@gmail.com','Wellington Kendi Oko','Rua Dona Nina Zanotto, 155<br>Jardim Las Vegas','Santo André','São Paulo','BRAZIL','09182-410','(5511) 9263-4126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 18:59:01',0,NULL,3,1,3,1,'RA117715401CN\r ','cafilisador\rHSMO018'),(3159,782823843012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','lagunacyberguy','stevecanning@cox.net','Steve Canning','5 Carmel Court','Laguna Beach','CA','UNITED STATES','92651','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 18:59:18',0,NULL,3,1,1,1,'\\ ','lagunacyberguy'),(3160,579112818013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','khrisanov','khrisanovdmitrij@gmail.com','Дмитрий Хрисанов','Сурова 24-66','Ульяновск','Ульяновская область','RUSSIAN FEDERATION','432055','+79276330163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 19:13:22',0,NULL,3,1,2,1,'、 ','khrisanov'),(3161,579122437013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','rooms001','reolschool@yahoo.fr','emilie ringoir','16 rue housseroul','nalinnes','','BELGIUM','6120','071215862','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 19:34:14',0,NULL,3,1,2,1,'、 ','rooms001'),(3162,782849410012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',2,'HSPL011',25.96,'eastar4uk','jona8932','jon_askham@yahoo.com','Jon Askham','21 Dower Chase<br>Escrick','York','North Yorkshire','UNITED KINGDOM','YO19 6JF','07779859231','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 19:45:29',0,NULL,3,1,3,1,'RA117715415CN\r ','jona8932\rHSPL011\r英标'),(3163,704823355011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','aleksey1005','alekseygsm@mail.ru','Aleksey Shitov','Nastavnikov 15/2-140','Sankt-Peterburg','ru','RUSSIAN FEDERATION','195298','79119737296','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 20:02:49',0,NULL,3,1,2,1,'、 ','aleksey1005'),(3164,782884378012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','sboer5','sander.boer@casema.nl','sander boer','Laan van Nieuw Oosteinde 362','VOORBURG','','NETHERLANDS','2274GH','070 3839979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 20:53:32',0,NULL,3,1,2,1,'、 ','sboer5'),(3165,579155490013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','havix_end','h_a_v_i_x@yahoo.com','Philip Johnson','182 Mount Marie Ave NW','Canton','OH','UNITED STATES','44708','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'havix_end'),(3166,579156129013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','mickg-man','nospamman@mac.com','Mick Guinn','313 Salida del Sol','Santa Barbara','CA','UNITED STATES','93109-2021','(805) 259-9584','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 21:15:59',0,NULL,8,1,17,0,NULL,'mickg-man'),(3167,579157175013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',4,'MOAP001',87.96,'eastar4','mickg-man','nospamman@mac.com','Mick Guinn','313 Salida del Sol','Santa Barbara','CA','UNITED STATES','93109-2021','(805) 259-9584','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 21:17:40',0,NULL,3,1,1,1,'\\ ','mickg-man\r一共买了5个\r苹果鼠标'),(3168,704865760011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 21:42:54',0,NULL,3,1,3,1,'RA117715335CN\r ','update_marcelo\rWWSI006'),(3169,782910873012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','garym2475','gmorrison_30@yahoo.co.uk','Gary  Morrison','61 Holmhills Drive, Cambuslang','Glasgow','South Lanarkshire','UNITED KINGDOM','G72 8EN','01416417734','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 21:59:48',0,NULL,3,1,3,1,'RA117715503CN\r ','garym2475\r英标\rHSPL010'),(3170,782914168012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','levraimisutsu','misutsu@live.fr','SCP TEISSONNIERE ET ASSOCIES','STEVE CHARTIER<br>5 RUE ST-GERMAIN L\'AUXERROIS','PARIS','Île-de-France','FRANCE','75001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 22:29:44',0,NULL,3,1,3,1,'RA117715344CN\r ','levraimisutsu\rOTSO002'),(3171,704888429011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.76,'eastar4','therntier','therntier@gmail.com','Travis Herntier','7122 105A Street','Edmonton','AB','CANADA','T6E4H9','(780) 633-5939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 23:01:30',0,NULL,3,1,3,1,'RA117715450CN\r ','therntier\rMOSA001\r新地址\rTravis Herntier\r127 Patterson Cres\rBrandon, Manitoba\rR7A 6T7\rCANADA\r'),(3172,782933565012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','justphishing','mrpierre@gmail.com','Mr Anthony Pierre','25 Anerley Grove<br>Anerley','London','London','UNITED KINGDOM','SE19 2HS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 23:14:33',0,NULL,3,1,3,1,'RA117715313CN\r ','justphishing\rHSPL014\r英标'),(3173,579185923013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','arawilbur','shopping.ebay@xenway.com','Alex Wilbur','7 Kelly Farm Way','Burlington','MA','UNITED STATES','01803-5124','(978) 821-8101','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 23:30:52',0,NULL,3,1,1,1,'\\ ','arawilbur'),(3174,579190447013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','scudworm','scudworm@rogers.com','John Giang','18 Dovehaven Court','North York','ON','CANADA','M3N2G6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 23:53:30',0,NULL,3,1,2,1,'\\ ','scudworm'),(3175,782946794012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','roland-d-50','chris.mendoza87@yahoo.com','j carmen mendoza','1986 21st st sw','vero beach','FL','UNITED STATES','32962-7915','(772) 453-0387','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 00:00:31',0,NULL,3,1,1,1,'\\ ','roland-d-50'),(3176,527029337003,130490187857,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'cnfaner','elfreak11','angel_of_evil5@hotmail.com','leclair yoann','26 daigle','sept-iles','QC','CANADA','g4r 4g8','(418) 960-5095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 00:09:15',0,NULL,3,1,3,1,'RA117715429CN\r ','elfreak11\rMOLO002\r'),(3177,579195461013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','lidney_2005','lmaynart@hotmail.com','Lidney Freitas','Rua Ministro João Mendes, 237<br>Casa 02','Santos','São Paulo','BRAZIL','11040-261','55 11 9186 0730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 00:21:41',0,NULL,3,1,2,1,'、 ','lidney_2005'),(3178,579126540013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','dghn22','daniel.ghn@gmail.com','Daniel Hernandez PN 19510','10421 N.W 28th Street D-106<br>P.O.Box Air Internationals','Miami','FL','UNITED STATES','33172','(305) 477-8334','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 00:48:43',0,NULL,3,1,1,1,'\\ ','dghn22\rHP 8pin 1.0 23cm '),(3179,579201490013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','locotics','topforce@hanmail.net','Sungdeok, Hwang','HANYOUNG NUX Inc. 1381-3,<br>Juan-Dong, Nam-gu','Incheon','Incheon','KOREA,REPUBLIC OF','402200','+82-17-319-8233','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 00:56:58',0,NULL,3,1,2,1,'、 ','locotics'),(3180,579205066013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','lucidalvacantanheidebrito','lucidalvacantanheide@gmail.com','MARCOS CARNEIRO','RUA RIACHUELO 2434<br>VERMELHA','TERESINA','PIAUI','BRAZIL','64018060','558632181524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 01:14:27',0,NULL,3,1,3,1,'RA117715358CN\r ','lucidalvacantanheidebrito\rWWOT001+ANCN001'),(3181,579112770013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','eldio727','eladiohp@hotmail.com','Eladio Herrero','727 Mitchell','Mont-Royal','QC','CANADA','H4P 1C9','(514) 737-3856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 01:47:50',0,NULL,3,1,3,1,'RA117715273CN\r ','eldio727\rOTRA002'),(3182,704928049011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','conecty71','danielxhorvath@gmail.com','Daniel Horvath','Apt.No.91 Louisa Bridge<br>Station Road','Leixlip','Kildare','IRELAND','ROI','0877412642','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 01:51:08',0,NULL,3,1,3,1,'RA117715327CN\r ','conecty71\rGLSG001'),(3183,782997610012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','y-vern','mike@oregoncamera.com','Richard W Danler','264 sw madison ave','Corvallis','OR','UNITED STATES','97333-4706','(541) 753-2653','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 03:17:45',0,NULL,3,1,1,1,'\\ ','y-vern'),(3184,579233016013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',26.1,'eastar4','patrykr1','patrykjava@optusnet.com.au','patryk prudzienica','6/10<br>TINDALL AVE','LIVERPOOL','New South Wales','AUSTRALIA','2170','0422838335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 03:59:25',0,NULL,3,1,2,1,'、 ','patrykr1'),(3185,781205976012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',12.5,'eastar4','joaruch2011','joa.ruch@freenet.de','Joachim^ Ruch','Am Sportplatz 14','Neuried','','GERMANY','77743','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 04:16:50',0,NULL,3,1,2,1,'、 ','joaruch2011\r4pin 1.25'),(3186,783015875012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','lksamm','jsmith@4q9.com','Jeff Smith','16611 Se May Valley Rd','Newcastle','WA','UNITED STATES','98059','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 04:52:55',0,NULL,3,1,1,1,'\\ ','lksamm'),(3187,704965429011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',2,'HSMO019',45.98,'eastar4','getnjiggywitit','clearandshiny@hotmail.com','Jonathan M. Kirchner','202 Cherokee Ln','Victoria','TX','UNITED STATES','77901','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 05:05:46',0,NULL,3,1,1,1,'\\ ','getnjiggywitit'),(3188,578671897013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','levbarkan','levik2003@bk.ru','Lev Barkan','196128, Russia, St.-Petersburg, ulitsa Varshavskaya dom 19 korpus 1 kvartira 113','St.-Petersburg','','RUSSIAN FEDERATION','196128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 05:11:54',0,NULL,3,1,2,1,'、 ','levbarkan'),(3189,704974700011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','model466','model46@mac.com','Hoon Song','2316 S. Harbor Blvd. Anaheim, CA 92802','Anaheim','CA','UNITED STATES','92802','(951) 236-4410','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 05:59:21',0,NULL,3,1,1,1,'\\ ','model466'),(3190,783036428012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',6,'OTCR001',155.1,'eastar4','blueiphot','aliet_182@yahoo.co.id','Aliet Sutrisna','Jl Pedongkelan baru gg Timbul 1<br>RT 018/016 no.3 Kapuk Jak-Bar','default','JK','INDONESIA','11720','668174969729','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 06:41:55',0,NULL,3,1,3,1,'RA117732722CN ','blueiphot\rOTCR001'),(3191,783042228012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',2,'MOMI001',119.98,'eastar4','datatony','rw@iqcircle.eu','Udo Wöckner','Häringen 26','Weilheim-Häringen','CO','GERMANY','73235','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 07:08:29',0,NULL,3,1,3,1,'RA117715485CN ','datatony\rMOMI001\r'),(3192,705002534011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.9,'eastar4','activevorx','vorx@mail.ru','Sergey Pochatkov','Shipilovskiy pr-d, 59-2, 65','Moscow','','RUSSIAN FEDERATION','115582','+79260295046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 08:29:02',0,NULL,3,1,3,1,'RA117730307CN\r ','activevorx\rWWSI005+ANCN001'),(3193,579269878013,230412690573,'2.0 New ASUS Bluetooth Module +cable F5/Z53/F3/M51',1,'BTHU2003',12.5,'eastar4','mmikelsama','mmikelsama@hotmail.com','Mariano Miguel','c Santiago 1 4º','Sama de Langreo','Asturias','SPAIN','33900','985676734','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 08:30:08',0,NULL,3,1,2,1,NULL,'mmikelsama\r华硕 10pin 1.0 15cm \\'),(3194,705011320011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','lvn888','bargainedge@gmail.com','Tony Lu','927 s. 10th ave','arcadia','CA','UNITED STATES','91006','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 09:01:00',0,NULL,3,1,1,1,'\\ ','lvn888'),(3195,783069746012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','kev-n-tru','ksdobbie@aol.com','Kevin Dobbie','8 Mablethorpe Close','Redcar','Cleveland','UNITED KINGDOM','TS10 4GW','01642490404','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-06 09:05:28',0,NULL,3,1,3,1,'RA117730545CN\r ','kev-n-tru\rOTCN003\r'),(3196,783065905012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',2,'HSMO008',21.9,'eastar4','laster35soner','sonersaplak@hotmail.com','Serafettin YASA','Erler Mah. Dumlupinar Serpmeleri<br>Kume Evleri Hava Lojmanlari A2/1 Etimesgut','ANKARA','','TURKEY','06790','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 09:07:41',0,NULL,3,1,3,1,'RA117730063CN ','laster35soner\r欧标\rHSMO008'),(3197,705013699011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','6516530','thstahlschmidt@alice-dsl.net','Thomas Stahlschmidt','Struenseestrasse 69','Hamburg','','GERMANY','22767','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 09:11:49',0,NULL,3,1,2,1,NULL,'6516530\\'),(3198,705016395011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',2,'ANYA001',28.9,'eastar4','tudijaidem','tomislav.radovic@gmail.com','Tomislav Radovic','Put Sv. Izidora 80<br>Croatia / Europe','Split','Croatia','CROATIA','21000','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 09:23:20',0,NULL,3,1,3,1,'RA117715962CN ','tudijaidem\rANYA001'),(3199,783077555012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',14.99,'eastar4uk','kenny1003','kenny@killegray.fsnet.co.uk','Kenneth Campbell','17 Lomond Road<br>Bearsden','GLASGOW','East Dunbartonshire','UNITED KINGDOM','G61 1BA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-06 09:38:44',0,NULL,3,1,3,1,'RA117730219CN\r ','kenny1003\rOTGR001'),(3200,705021262011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','1961budgie4','budgie4@bigpond.com.au','Tony Buhagiar','1529 York-Williams Road','Beverley','Western Australia','AUSTRALIA','6304','0417098809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 09:45:42',0,NULL,3,1,2,1,'、 ','1961budgie4'),(3201,532861944004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','pasi5044','pasi.kauppinen@iki.fi','Pasi Kauppinen','Mattilanmäki 4as1','Tampere','','FINLAND','33610','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 11:03:31',0,NULL,3,1,3,1,'RA117730077CN\r ','pasi5044\rOMHJ001'),(3202,577345084013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','spykon','psylom31@hotmail.com','TRISTAN LOMMEZ','1 RUE PIERRE DE RONSARD','BLAGNAC','Midi-Pyrénées','FRANCE','31700','0631822869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 11:31:51',0,NULL,3,1,2,1,NULL,'spykon\rHP 8pin 1.0 23cm '),(3203,579308972013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',48.95,'eastar4','batman3334','alainb33@gmail.com','BENOIT Alain','2811,route de Sommieres.D22<br>la bergerie du petit pont.','MONTPEZAT','Languedoc-Roussillon','FRANCE','30730','0673518755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 12:17:15',0,NULL,3,1,3,1,'RA117730085CN\r ','batman3334\rOTRA002'),(3204,579312470013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',8,'HSNO019',319.92,'eastar4','jape324','jani324@hotmail.com','Jani Hassinen','Kulhontie 133','Joensuu','Kulho','FINLAND','80910','0503235742','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 12:31:44',0,NULL,3,1,4,1,'YW865907513CN ','jape324\r欧标\r'),(3205,783142766012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',3,'BALO005',21.3,'eastar4','xatalan','oliver@lemling.de','Oliver Lemling','Else-Lasker-Schüler-Eck 15','Göttingen','','GERMANY','37085','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 13:25:19',0,NULL,3,1,2,1,NULL,'xatalan\\'),(3206,579332253013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','davedaloia','whynotme_17@hotmail.com','Dave D\'Aloia','560 Fullarton Road','Keilor Park','Victoria','AUSTRALIA','3042','0393367735','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:04:13',0,NULL,3,1,2,1,'\\ ','davedaloia'),(3207,705104610011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','lg_medellin','luis@alphicgroup.com','Luis Medellin','Hacienda de torrecillas 5, Col. bosque de echegaray','Naucalpan de Juarez','Estado de Mexico','MEXICO','53310','5555082593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:44:01',0,NULL,3,1,3,1,'RA117730094CN\r ','lg_medellin\rRCLO006'),(3208,783170600012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',2,'OTGR002',43.8,'eastar4','speedsterporsche','rommel.cruz@tdsb.on.ca','Rommel    Cruz','107 Frankdale Ave','Toronto','ON','CANADA','M4J 4A4','(416) 466-8732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:46:42',0,NULL,3,1,3,1,'RA117730253CN\r ','speedsterporsche\rOTGR002'),(3209,579348227013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',2,'OMHJ001',27.98,'eastar4','woodysca','motowoodys@gmail.com','Woody Sutherland','3526 Voyager Cir','San Diego','CA','UNITED STATES','92130','(858) 603-1860','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-06 15:14:20',0,NULL,3,1,1,1,'\\ ','woodysca'),(3210,705121581011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',33.98,'eastar4','murciamen','murciamen@hotmail.com','Pedro Parra Ibañez','Calle: Luisa Aledo, num 16. bajo C','Murcia','Murcia','SPAIN','30003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 15:39:44',0,NULL,3,1,3,1,'RA117730236CN\r ','murciamen\rWLAT001+ANTY002\r一共买了两个'),(3211,705128911011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','viclil96','victorsheinfeld@gmail.com','Victor Sheinfeld','Tishrei 2/1','Netanya','ID','ISRAEL','42524','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 16:01:47',0,NULL,3,1,2,1,NULL,'viclil96\\'),(3212,705133734011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','ecuadorhomesonline','banking@ecuadorhomesonline.com','David Workman','3607 Lew Wallace St','Frederick','MD','UNITED STATES','21704-7872','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 16:11:07',0,NULL,3,1,1,1,'\\ ','ecuadorhomesonline'),(3213,532932901004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','sisbeav','sisbeav@aol.com','Amanda Beaver','78903 38th Ave','Covert','MI','UNITED STATES','49043-9728','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 16:42:48',0,NULL,3,1,1,1,'\\ ','sisbeav'),(3214,783242500012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','rfbatch','randfb@yahoo.com','Rand F Batchelder','238 Sienna Trl','Venetia','PA','UNITED STATES','15367-1316','(724) 260-0707','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 17:50:04',0,NULL,3,1,1,1,'\\ ','rfbatch'),(3215,705171378011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','fredhound333','shapiro333@gmail.com','Jonathan M. Shapiro','205 W Plaza Dr','Mooresville','NC','UNITED STATES','28117-8063','(704) 663-4994','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 17:51:32',0,NULL,3,1,1,1,'\\ ','fredhound333'),(3216,705177693011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','peter.milnrow','peterandi@gmail.com','Peter Walsh','4 Croft Head Drive<br>Milnrow','Rochdale','Greater Manchester','UNITED KINGDOM','OL16 3UE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 18:03:32',0,NULL,3,1,2,1,NULL,'peter.milnrow\\'),(3217,783271515012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jamesl9369','jcleitzel@verizon.net','James Leitzel','104 N Broad St','Selinsgrove','PA','UNITED STATES','17870','(570) 374-0304','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 18:48:31',0,NULL,3,1,1,1,'\\ ','jamesl9369'),(3218,783275598012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',5,'TRMX003',86.25,'eastar4','kposkpos','kposyniak@gmail.com','Krzysztof Posyniak','Piotrkowska 15/16','Gdansk','pomorskie','POLAND','80180','600 948393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 18:55:47',0,NULL,3,1,3,1,'RA117730372CN\r ','kposkpos\r一共买了5个CAB-6060\r5个MX20T'),(3219,783278831012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','yo2435','yo2435us@yahoo.com','larry cruz','po box 6697','central falls','RI','UNITED STATES','02863-0661','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 19:10:00',0,NULL,3,1,1,1,'\\ ','yo2435'),(3220,705210102011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','alonradzi','alon@radzis.com','Alon Radzi','149 Emek Ayalon Ave.','Shoham','','ISRAEL','60850','(052) 552-2965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 19:18:46',0,NULL,3,1,2,1,'\\ ','alonradzi'),(3221,532981091004,140516157546,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'TOIN002+BAIN002+BAIN001',49.9,'cnfaner','fernandojaburu','jaburu69@hotmail.com','Fernando A M Morais','Rua 10, n.887 Apt.1103 Setor Oeste<br>Ed. Itanhagá Palace','Goiania','GO','BRAZIL','74120-020','(623) 215-9695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 19:29:34',0,NULL,3,0,3,1,'RA117715914CN\r ','fernandojaburu\rTOIN002+BAIN002+BAIN001'),(3222,705220195011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','khalidkhan3432','mr.__khan@hotmail.com','Khalid Khan','15-384 Driftwood Avenue','North York','ON','CANADA','M3N 2P5','(416) 886-6589','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 19:39:08',0,NULL,3,1,2,1,'\\ ','khalidkhan3432'),(3223,783302966012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','guizhang','guizhang@hotmail.com','Gui Zhang (Tim)','6351 Loudon Ave<br>Unit A','Elkridge','MD','UNITED STATES','21075-5636','(410) 330-0796','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 19:52:24',0,NULL,3,1,1,1,'\\ ','guizhang\r红边优联'),(3224,705226373011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','c_hertling','chris@hertling.net','Chris Hertling','810 E 24th Ave','North Kansas City','MO','UNITED STATES','64116-3361','(816) 221-9269','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 19:54:42',0,NULL,3,1,1,1,'\\ ','c_hertling'),(3225,705232717011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',134.99,'eastar4','jbabyadkins2009','jbabyadkins@yahoo.com','Jonathan Adkins','107 Santa Ana Pl','West Columbia','SC','UNITED STATES','29170-3050','(803) 261-2192','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 20:11:40',0,NULL,3,1,1,1,'\\ ','jbabyadkins2009'),(3226,783323523012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','n10aguy','n10aguy@cfl.rr.com','Brian Anderson','720 Armitage Ave','Apopka','FL','UNITED STATES','32703-5434','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 20:43:44',0,NULL,3,1,1,1,'\\ ','n10aguy'),(3227,705250373011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',4,'GLSG001',271.96,'eastar4','mwetty1234','mattwetty@yahoo.com','Matthew Wetty','7 South Rd','Bronxville','NY','UNITED STATES','10708-1920','(914) 337-1790','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 20:49:19',0,NULL,3,1,6,1,'EE442466457CN ','mwetty1234'),(3228,705250907011,320394908928,'Acer Aspire 7730 7730G 7730Z Bluetooth Module 2.0+cable',1,'BTAC2011',12.5,'eastar4','jlmar0123','marche.jeanlouis@orange.fr','Jean-Louis Marche','2 rue Rochet','Breurey Les Faverney','Franche-Comté','FRANCE','70160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 20:50:13',0,NULL,3,1,2,1,'\\ ','jlmar0123\racer 5pin1.25 4cm '),(3229,579461639013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','twistedmind1974','mr.twist@gmx.de','Klaus Stürzenbecher','Nappenhorn 19','Barmstedt','','GERMANY','25355','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 21:38:14',0,NULL,3,1,2,1,NULL,'twistedmind1974\\'),(3230,779316296012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','tournataka0646','vriens.jurre@gmail.com','Jurre Vriens','Gerard Walschaplaan 48','Roosendaal','','NETHERLANDS','4707CS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 22:16:36',0,NULL,3,1,2,1,NULL,'tournataka0646\\'),(3231,783367736012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','homehealthx3','julieharper@centurytel.net','Julie B Harper','161 Gober Rd','Hackleburg','AL','UNITED STATES','35564-4403','(205) 935-8526','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 22:34:03',0,NULL,3,1,1,1,'\\ ','homehealthx3'),(3232,533034719004,140516092374,'Logitech harmony Li-ion Rechargeable Battery 950mAh',1,'BALO008',6.6,'cnfaner','tomspeed62david','tomspeed62@yahoo.com','David Jobes','8023 E Evergreen St','Mesa','AZ','UNITED STATES','85207-4938','(480) 357-6732','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 23:15:43',0,NULL,3,1,1,1,'\\ ','tomspeed62david'),(3233,705298893011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',3,'HSNO017',56.7,'eastar4','darrylwash','dwash@ascendventures.com','Darryl E. Wash','3127 Corinth Avenue','Los Angeles','CA','UNITED STATES','90066','(212) 324-2225','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-06 23:29:21',0,NULL,3,1,1,1,'\\ ','darrylwash'),(3234,533042525004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','07oscar07','jpoppy@tpg.com.au','Joseph Poppelock','30 BISDEE STREET','CORAL COVE','Queensland','AUSTRALIA','4670','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 00:09:56',0,NULL,3,1,3,1,'RA117730046CN ','07oscar07\rOTGR001+OTGR002'),(3235,783392552012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','kiranbiz','kiran.malineni@gmail.com','Kiran Malineni','261 Poplar Ave<br>Apt# R647','Devon','PA','UNITED STATES','19333','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 00:13:03',0,NULL,3,1,1,1,'\\ ','kiranbiz\r红边优联'),(3236,705315631011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','jonaslieser','jonas.lieser@gmail.com','Jonas Lieser','Jernbanegade 6','Kopenhagen','V','DENMARK','1608','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 00:49:34',0,NULL,3,1,2,1,NULL,'jonaslieser\\'),(3237,705320868011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','steven5223063','steven52230@hotmail.com','steven bedard','694 rue hoggar<br>quebec','quebec','QC','CANADA','g1b3e4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 01:14:16',0,NULL,3,1,2,1,NULL,'steven5223063\\'),(3238,525297928003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',2,'OTJE001',31.8,'cnfaner','anyquilmes10','gerardoluisrivas@hotmail.com','gerardo luis rivas','timoteo gordillo 290','ciudad de buenos aires','buenos aires','ARGENTINA','1408','46413594','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-07 01:34:25',0,NULL,3,1,3,1,'RA117730029CN ','anyquilmes10\rOTJE001'),(3239,783415967012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','dariukel','robinetstella@hotmail.com','jimmy doucet','956 # 4 Rue Alexandre','Drummondville','QC','CANADA','j2c6c3','(819) 850-3301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 01:51:00',0,NULL,3,1,2,1,NULL,'dariukel\r红边优联\\'),(3240,783430395012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','greenbeans14','kevie_smithy@yahoo.com','Kevin Smith','815 Smith Hudson Rd','Siler City','NC','UNITED STATES','27344-6988','(919) 663-2271','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 02:53:53',0,NULL,3,1,1,1,'\\ ','greenbeans14'),(3241,705349148011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',39.99,'eastar4','sydney88808','sydney880@gmail.com','Leo (SO23293)','Techoni.Mobile.Phones<br>Suite 214, 160 Castlereagh St','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 03:36:50',0,NULL,3,1,3,1,'RA117730222CN\r ','sydney88808\rHSNO019\r澳标'),(3242,783465687012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','wen-jiezheng','wenjie_zheng@yahoo.com','Wen-Jie Zheng','5123 72nd St','Woodside','NY','UNITED STATES','11377-7619','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 06:06:23',0,NULL,3,1,1,1,'\\ ','wen-jiezheng\r红边优联'),(3243,705391228011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',21.9,'eastar4','golfmester','hartyanyitibor@t-email.hu','Hartyányi Tibor','Dobó utca 12','Cegléd','','HUNGARY','2700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 07:39:07',0,NULL,3,1,2,1,NULL,'golfmester\r欧标\\'),(3244,705394386011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',19.95,'eastar4','jcstodd','jcstodd@yahoo.com','Jeffrey C. Stoddard','3 Tiara Ct','Burlingame','CA','UNITED STATES','94010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 07:52:51',0,NULL,3,1,1,1,'\\ ','jcstodd\r无线蓝牙二合一'),(3245,579560706013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',83.85,'eastar4','loupenz','petersquires@squiresmarine.com','Peter Squires','1259 Kaipara Coast Highway<br>RD4 Warkworth','Auckland','Auckland','NEW ZEALAND','0984','021 2518707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 08:19:47',0,NULL,3,1,3,1,'RA117730050CN\r ','loupenz\rMOSA003'),(3246,783520127012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','bohaben','jbohaben@gmail.com','Juan Carlos Vazquez','c/ Cueva de Santa Ana 14','Cáceres','Extremadura','SPAIN','10005','655450547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 09:52:01',0,NULL,3,1,2,1,NULL,'bohaben\\'),(3247,579577348013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','paul606455','paul.westpennine1@virginmedia.com','Paul Davison','41 Longworth Road, Egerton','Bolton','Lancashire','UNITED KINGDOM','BL79TS','01204594998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 09:53:10',0,NULL,3,1,2,1,' ','paul606455\\'),(3248,579578147013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','klyecptguy','klye.hay@gmail.com','Kyle Hay','5 Muratie Close<br>Richwood','Cape Town','Western Province','SOUTH AFRICA','7441','0845366797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 09:58:21',0,NULL,3,1,2,1,'\\ ','klyecptguy'),(3249,705438638011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','carpe.diem)','jfritsch1@gmx.net','Jens Fritsch','Voigtstr 18','Berlin','','GERMANY','10247','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 10:47:43',0,NULL,3,1,2,1,NULL,'carpe.diem)\\'),(3250,783565131012,220704730634,'New Plantronics Explorer220 BLUETOOTH HEADSET+carcharge',1,'HSPL001+CCPL001',11.2,'eastar4uk','sabynandha123','amit_sharma4350@yahoo.com','Saby Nandha','88-A<br>Roman road','luton','Bedfordshire','UNITED KINGDOM','Lu4 9se','07969128855','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 12:24:24',0,NULL,3,1,3,1,'RA117730267CN\r ','sabynandha123\rHSPL001+CCPL001'),(3251,579608862013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','kockjo','kockjo@gmx.de','Jörg Kock','Op de Wisch 30','Appen','','GERMANY','25482','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 12:26:53',0,NULL,3,1,2,1,'\\ ','kockjo'),(3252,533164712004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',44.98,'cnfaner','brandonpheng','harddrive80gb@hotmail.com','Brandon Phengsavath','2 Tali Karng Close','Rowville','Victoria','AUSTRALIA','3178','0397634109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 13:20:08',0,NULL,3,1,3,1,'RA117730355CN\r ','brandonpheng\rWWOT001'),(3253,705485975011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','sercank06','sercan06@gmail.com','Sercan KILIÇKAYA','Tuzlucayir Mahallesi 592. Sokak Deniz Apt<br>1/5 Mamak','Ankara','TR','TURKEY','06590','+905552349058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 13:23:02',0,NULL,3,1,2,1,'\\ ','sercank06'),(3254,579621397013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',79.98,'eastar4','holaju6','juke_holappa_69@hotmail.com','Jukka-Pekka Holappa','Vartiokatu 14-16 B9<br>96100','Rovaniemi','Rovaniemi','FINLAND','96100','+358405160239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 13:37:47',0,NULL,3,1,3,1,'RA117730275CN\r ','holaju6\rHSNO019'),(3255,577059790013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','lourdeskert','manik247@maltanet.net','Lourdes Kert','46 fidele street','Hamrun','','MALTA','HMR06','+35699251930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 13:39:47',0,NULL,3,1,2,1,NULL,'lourdeskert\r\r欧标\\'),(3256,783592900012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','vlad_sh1971','v_shuvaev@mail.ru','Vladislav Shuvaev','11-ya Parkovaya street 9/35<br>Appartment 184','Moscow','RU','RUSSIAN FEDERATION','105554','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 13:41:26',0,NULL,3,1,2,1,'\\ ','vlad_sh1971\r红边优联'),(3257,705495622011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','burningchromezero','magatsu_08@yahoo.com','Michael Dan','1516 Snyder Ave. Apt. 2F','Philadelphia','PA','UNITED STATES','19145','(215) 559-1122','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 13:51:49',0,NULL,3,1,1,1,'\\ ','burningchromezero'),(3258,783124734012,220778910015,'NIB Samsung SSG-P2100S Starter Kit Two 3D Glasses',1,'GLSG002',158.99,'eastar4','3399771','sandrayan@yandex.ru','VORONIN BORIS','UNUSABAD STREET<br>19-4-9','TASHKENT','UZBEKISTAN','UZBEKISTAN','700114','+998712225805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 14:05:58',0,NULL,3,1,3,1,'RA117715976CN ','3399771\rGLSG002'),(3259,783609596012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','mbracciodieta1213','mbracciodieta@yahoo.com','matt bracciodieta','15 Samantha Dr','coram','NY','UNITED STATES','11727-3068','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 14:20:49',0,NULL,3,1,1,1,'\\ ','mbracciodieta1213'),(3260,783618180012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','the_lord_of_the_laptops','selcukatak@hotmail.com','Selcuk Atak','Yozgat Polis Meslek Yuksek Okulu','Yozgat','','TURKEY','66100','905068937090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 14:42:41',0,NULL,3,1,2,1,NULL,'the_lord_of_the_laptops\\'),(3261,705523390011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','applecatz09','applecatz@hotmail.co.uk','Tristan Figueroa','bs8,  34, Park St<br>Clifton','Bristol','Bristol','UNITED KINGDOM','BS1 5JG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 15:11:21',0,NULL,3,1,3,1,'RA117730015CN\r ','applecatz09\rMOAP001'),(3262,705526708011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',19.95,'eastar4','laurenzos44','petiteau.laurent@wanadoo.fr','LAURENT PETITEAU','35 RUE PASTEUR','LA MONTAGNE','Pays de la Loire','FRANCE','44620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 15:22:15',0,NULL,3,1,2,1,NULL,'laurenzos44\r 无线蓝牙二合一\\'),(3263,783637144012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','caboqueen7','caboqueen7@hotmail.com','Carolyn D Taylor','15910 Palo Seco Dr','Corpus Christi','TX','UNITED STATES','78418-6617','(361) 949-8447','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 15:30:39',0,NULL,3,1,1,1,'\\ ','caboqueen7'),(3264,579661330013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','fibrastick','c_guerra@telefonica.net','JOSE LUIS CARBALLO GUERRA','CL COMARCA RIBERA DEL TAJO 95','MERIDA','BADAJOZ','SPAIN','06800','924371677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 15:55:21',0,NULL,3,1,2,1,NULL,'fibrastick\\'),(3265,579662247013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','axquest','axquest@mac.com','Chanon Sarasuk','454/233, Wat Pai Ngoen Road, Soi Udee<br>Bangkhlo,  Bangkholame','Bangkok','Bangkok','THAILAND','10120','(+66)892118050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 15:58:19',0,NULL,3,1,2,1,NULL,'axquest\\'),(3266,705562077011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',134.99,'eastar4','514-july','july--@hotmail.com','julie lehoux','5000 des frenes','ste-catherine','QC','CANADA','j5C 1L3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 16:56:10',0,NULL,3,1,3,1,'RA117715874CN ','514-july\rGLSG001*2'),(3267,579683692013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','dracoqc','dracoqc@hotmail.com','Jocelyne  Mongeau','2775 ave. Lebrun','Montréal','QC','CANADA','H1L 5E7','(514) 351-8932','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 17:09:08',0,NULL,3,1,3,1,'RA117730032CN\r ','dracoqc\r华硕限量版\rMOLO004'),(3268,705578876011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',11.99,'eastar4uk','noblebest','johan@gedde-dahl.no','Johan Gedde-Dahl','Jongsaasveien 12a','Sandvika','Sandvika','NORWAY','1338','(047) 97138646','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 17:30:58',0,NULL,3,1,2,1,'\\ ','noblebest'),(3269,579693098013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','erigler','eduardorigler@hotmail.com','Eduardo Rigler','Rua do Semeador, 702<br>- Cidade Industrial','Curitiba','Paraná','BRAZIL','81270-050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 17:40:00',0,NULL,3,1,2,1,NULL,'erigler\\'),(3270,783704608012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',25.8,'eastar4','canan1st','kanan1st@gmail.com','Kanan Bayramov','Y.Yasamal-1, ev 4, menzil 189','Baku','Yasamal','AZERBAIJAN','AZ1012','4341084','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 18:01:55',0,NULL,3,1,2,1,NULL,'canan1st\\'),(3271,579700341013,230504995230,'New Motorola H670 Bluetooth Wireless Headset H 670',6,'HSMO010',89.94,'eastar4','paul90266','skolnick@newstrench.com','Paul Skolnick','10573 W Pico Blvd<br># 167','Los Angeles','CA','UNITED STATES','90064-2333','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 18:04:02',0,NULL,3,1,1,1,'\\ ','paul90266'),(3272,783707280012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',28.9,'eastar4uk','niomimonty','mghduk@hotmail.com','MUNIR DHALECH','9 FRANCIS ROAD','LEYTON','London','UNITED KINGDOM','E10 6PN','02085589516','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 18:05:26',0,NULL,3,1,3,1,'RA117715888CN ','niomimonty\rOTGR001+OTGR002'),(3273,533246414004,140481827793,'New Plantronics Voyager 851/855 Bluetooth Headse track#',1,'HSPL009',49.9,'cnfaner','s_bpridgeon','itismehereandnow@hotmail.com','Beronica Pridgeon','1219 Park Hill Drive','Conway','SC','UNITED STATES','29526','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-07 18:29:31',0,NULL,3,1,1,1,'\\ ','s_bpridgeon'),(3274,783740635012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','rjporter','rporter@thinkerworks.com','Ralph Porter','PO Box 616<br>191 East Center Street','Spring City','UT','UNITED STATES','84662-0616','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 19:11:49',0,NULL,3,1,1,1,'\\ ','rjporter'),(3275,783746736012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',14.99,'eastar4uk','doddybonnie','doddymanu@sky.com','robert white','2 sytch house green','wolverhampton','Shropshire','UNITED KINGDOM','wv5 7aj','01746710987','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 19:21:53',0,NULL,3,1,3,1,'RA117715786CN ','doddybonnie\rOTGR001'),(3276,705631813011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','pzipf','peter.zipfelmayer@gmx.com','Peter Zipfelmayer','Mozartgasse 7','Leobersdorf','','AUSTRIA','2544','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 19:26:36',0,NULL,3,1,2,1,'\\ ','pzipf'),(3277,579730393013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','shaggyrogers2','sfrancis31@yahoo.com','scott francis','26 Chillington Ln','mendon','NY','UNITED STATES','14506-9720','(585) 697-4958','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 19:31:32',0,NULL,3,1,1,1,'\\ ','shaggyrogers2'),(3278,705644818011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','danny13xrimer','danny.rimer@gmail.com','Danny Rimer','Olei Hagardom 63/9','Rishon Lezion','','ISRAEL','75235','(009) 725-0672 ext.: 2072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 19:55:37',0,NULL,3,1,2,1,NULL,'danny13xrimer\\'),(3279,783757651012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','psy_soul','azarovua@gmail.com','Anton Azarov','Lesya Kurbasa st. 4. App. 67.','Kiev','UA','UKRAINE','03148','380936844412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 20:02:28',0,NULL,3,1,2,1,NULL,'psy_soul\\'),(3280,783779052012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',2,'HSMO008',21.9,'eastar4','elj77777','murermester.jensen@tdcadsl.dk','Erling Jensen','Johannesdalsvej 13','Lundforlund, Slagelse','','DENMARK','DK4200','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 20:28:31',0,NULL,3,1,2,1,NULL,'elj77777\r欧标\\'),(3281,783780944012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','nancybraun28277','nancy@showcaserealty.net','nancy braun','10418 counts pl','charlotte','NC','UNITED STATES','28277-1743','(704) 488-3109','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 20:45:09',0,NULL,3,1,1,1,'\\ ','nancybraun28277\r红边优联'),(3282,783792991012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','rikki4910','erika.rikki@gmail.com','Rikki Mosley','742 Cobble Hill Drive','ottawa','ON','CANADA','K2J 0C7','(613) 823-1123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 20:59:16',0,NULL,3,1,2,1,NULL,'rikki4910\\'),(3283,783799681012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','wonko_999','r_lowthian@yahoo.co.uk','Robert Lowthian','64 cleeve court<br>glebe','Washington','Tyne and Wear','UNITED KINGDOM','ne38 7qf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 21:14:28',0,NULL,3,1,3,1,'RA117715980CN\r ','wonko_999\rOTCN003'),(3284,579762878013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',3,'HSJA002',64.5,'eastar4','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 21:18:09',0,NULL,3,0,3,1,'RA117715945CN\r ','vjendrisvelimir\rHSJA002\r欧标'),(3285,783807578012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','aznervedoc','wlwdc@azchiro.net','William L. Wesselink, DC','4558 N 1st Ave<br>Ste 110','Tucson','AZ','UNITED STATES','85718-5687','(520) 888-2600','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 21:34:45',0,NULL,3,1,1,1,'\\ ','aznervedoc'),(3286,533306951004,140523331018,'New Logitech MX1000 Wireless Laser Cordless Mouse',2,'MOLO001',130,'cnfaner','freewaymotorcars','brian@freewaymotorcars.com','brian poirrier','2433 Cleveland Ave SW','canton','OH','UNITED STATES','44707-3642','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-07 21:57:47',0,NULL,3,1,4,1,'YW865907443CN ','freewaymotorcars'),(3287,705695194011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 22:05:58',0,NULL,3,1,3,1,'RA117715959CN\r ','update_marcelo\rWWSI006'),(3288,705704731011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','lcthunderbird','lcthunderbirds@yahoo.com','Constantine Gulgas','29694 Westminster Dr','North Olmsted','OH','UNITED STATES','44070-5074','(440) 242-7743','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 22:43:01',0,NULL,3,1,1,1,'\\ ','lcthunderbird'),(3289,579790401013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','littlemcc','nancymccurry@cox.net','Nancy E. McCurry','19047 N 29th Pl','Phoenix','AZ','UNITED STATES','85050-2550','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 23:18:18',0,NULL,3,1,1,1,'\\ ','littlemcc'),(3290,705729928011,320441946828,'2.1 HP TX1000 TX1000z TX1200 Bluetooth Module EDR+cable',2,'BTHP2112',25.6,'eastar4','bikeman30sh','babuji@msn.com','ABRAHAM ABRAHAM','714 Manor CT 1st Floor','Brooklyn','NY','UNITED STATES','11235','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 00:23:45',0,NULL,3,1,1,1,NULL,'bikeman30sh\rHP 8pin 0.8 3cm \\'),(3291,533347314004,140523331018,'New Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',65,'cnfaner','dscoop9977','dscoop9977@aol.com','Dawn C Hertzel','17D Lakeview Ave','Leonia','NJ','UNITED STATES','07605-3119','(201) 944-2361','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-08 01:54:53',0,NULL,3,1,1,1,'\\ ','dscoop9977'),(3292,705753484011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','curtisicampbell','curtisicampbellthe1st@gmail.com','Curtis Campbell','6085 Hazeldean Rd.<br>RBC Bank','Stittsville','ON','CANADA','K2S1B9','(613) 447-6078','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 02:13:00',0,NULL,3,1,3,1,'RA117715928CN\r ','curtisicampbell\rHSPL009'),(3293,705754032011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','dreamchaser225','dreamchaser225@yahoo.com','Raymond Lee','23717 Southpoint Dr','Denham Springs','LA','UNITED STATES','70726','(225) 271-8261','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 02:14:46',0,NULL,3,1,1,1,'\\ ','dreamchaser225'),(3294,533349675004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',1,'HSJA002',21.5,'cnfaner','sigor220972','sigor72@mail.ru','Igor Selyutin','Kutuzova 6/1 kv 49','Pavlodar','','KAZAKHSTAN','140000','87182550675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 02:14:52',0,NULL,3,1,3,1,'RA117715772CN\r ','sigor220972\rHSJA002\r欧标\r'),(3295,783889478012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','spectralcluster','zac.harland@googlemail.com','Zac Harland','12 / 79-81 Balgowlah Road<br>Fairlight','Sydney','New South Wales','AUSTRALIA','2094','61299491906','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 02:28:25',0,NULL,3,1,2,1,' ','spectralcluster\r红边优联\\'),(3296,579823705013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',2,'OTCN001',7.98,'eastar4','n2vjb','n2vjb@frontiernet.net','Kevin Popplewell','53 Squirrels Heath Rd','Fairport','NY','UNITED STATES','14450-9605','(585) 223-7478','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 02:30:31',0,NULL,3,1,1,1,'\\ ','n2vjb'),(3297,783937716012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',1,'OTHP001',39.99,'eastar4','vachfolle','vachfolle@yahoo.com','gauchotte benoit','Résidence les Cyclamens<br>1 rue Voltaire','Champagnole','Franche-Comté','FRANCE','39300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 06:34:25',0,NULL,3,1,3,1,'RA117716000CN\r ','vachfolle\rOTHP001'),(3298,705818222011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',11.99,'eastar4uk','peebee56','pen3333@gmail.com','Penelope Feeney','PO Box 1129','Gibraltar','Gibraltar','GIBRALTAR','no code','+35056001222','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 07:44:36',0,NULL,3,1,2,1,NULL,'peebee56\\'),(3299,705822723011,320666180879,'NIB Genuine Sony Ericsson HBH-DS220 Bluetooth  Headset',1,'HSSE006',67.9,'eastar4','ivonini','igor.ivonin@gmail.com','Igor Ivonin','Parkovaya, 3-65','Yubileyny','Moscow region','RUSSIAN FEDERATION','141092','+79152023669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 08:07:11',0,NULL,3,1,3,1,'RA117715790CN ','ivonini\rHSSE006\r'),(3300,783140489012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','rau020202','wsrau02@mail.ru','Sandra Rau','Am Dorfplatz 43','Halen','','GERMANY','49685','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 08:20:42',0,NULL,3,1,2,1,NULL,'rau020202\r欧标\\'),(3301,579880249013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','rfernan4','ranga_fernando@hotmail.com','Ranga Fernando','1551 N Tustin Ave<br>Suite 200','Santa Ana','CA','UNITED STATES','92705-8693','(714) 598-7125','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 08:38:38',0,NULL,3,1,1,1,'\\ ','rfernan4\rCAB-6060'),(3302,783978888012,220572910849,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET HS 12W',1,'HSNO025',59.9,'eastar4','yaanasip','ferhatildes@hotmail.com','ferhat ildes','uluanak mah. ulucami park sok. ekeler apt. 13/3','default','sivas','TURKEY','58070','05054822739','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 09:45:46',0,NULL,3,1,3,1,'RA117715809CN\r ','yaanasip\r欧标\rHSNO025'),(3303,705864459011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','checkman81','checkman@list.ru','Nesterov Alexander','Batyuninskaya street, 8-21','Moscow','','RUSSIAN FEDERATION','109235','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 10:06:34',0,NULL,3,1,2,1,'\\ ','checkman81'),(3304,705864039011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','the-ment','the_ment@mail.ru','Oleg Mishin','Krasnoarmeyskaya st,dom 22,kv.68','Vladimir','ru','RUSSIAN FEDERATION','600021','(910)775-3059','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 10:20:25',0,NULL,3,1,2,1,NULL,'the-ment\r欧标\\'),(3305,705877456011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','zerostyle_2010','gatol@yahoo.co.jp','Junji Miyazaki','1-15-11<br>Deiki, Kanazawa-ku','Yokohama-shi','Kanagawa','JAPAN','236-0021','045-783-5505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 10:34:03',0,NULL,3,1,3,1,'RA117715931CN\r ','zerostyle_2010\rHSPL009'),(3306,705879463011,320679553967,'New Battery for Genuine INOVA T4 LED Flashlight Torch',1,'BAIN001',6.55,'eastar4uk','stevev1187','svince146@hotmail.com','steve vince','gower waltham road<br>borehan','chelmsford','Essex','UNITED KINGDOM','cm3 3ax','01245469681','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 10:37:49',0,NULL,3,1,3,1,'RA117730284CN\r ','stevev1187\rBAIN001'),(3307,533457978004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','slavicripper','xslavic@gmail.com','Veaceslav Condur','via della fornace 15','Zola Predosa','BO','ITALY','40069','3404820676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 12:05:58',0,NULL,3,0,3,1,'RA117730369CN\r ','slavicripper\r换成半高卡New Intel 5300 HALF Wireless Mini PCI-E Card+3 antenna\r\r'),(3308,705614281011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','kifferm2','kifferc2@yahoo.com','CHRIS BLANKENSHIP','3118 CREEK BANK LN','PEARLAND','TX','UNITED STATES','77581-4675','(713) 291-3106','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 12:08:38',0,NULL,3,1,1,1,'\\ ','kifferm2'),(3309,705926201011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','etamme','etamme@optonline.net','Eric Tamme','255 Huguenot St<br>APT 1016','New Rochelle','NY','UNITED STATES','10801-6396','(203) 479-2949','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 12:36:57',0,NULL,3,1,1,1,'\\ ','etamme'),(3310,705933093011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','rduke72','jjacksonpearce@gmail.com','Jordan Pearce','918 Algregg St','Houston','TX','UNITED STATES','77009-4401','(713) 417-2376','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 12:52:49',0,NULL,3,1,1,1,'\\ ','rduke72'),(3311,784084324012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','manic_and_depressive','bgawert@gmail.com','Benjamin Gawert','Warton Aerodrome<br>QinetiQ/Bldg W271','Warton, Preston','Lancashire','UNITED KINGDOM','PR4 1AX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 13:05:24',0,NULL,3,1,3,1,'RA117730298CN\r ','manic_and_depressive\rOTCN002'),(3312,784112486012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',2,'HSSH002',51.98,'eastar4','denisemvargo','denisevargo@yahoo.com','Denise Vargo','2503 Northfork Ct','Pearland','TX','UNITED STATES','77584-5969','(713) 851-7696','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 14:07:41',0,NULL,3,1,1,1,'\\ ','denisemvargo'),(3313,784113767012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',12.8,'eastar4','jdelrie','jacobdelrie@aol.com','jacob h delrie','765 breeze way','cordova','TN','UNITED STATES','38018-1485','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 14:11:34',0,NULL,3,1,1,1,'\\ ','jdelrie\racer 5pin1.25 15cm\r再发一个黄膜天线*2'),(3314,784116248012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','jdelrie','jacobdelrie@aol.com','jacob h delrie','765 breeze way','cordova','TN','UNITED STATES','38018-1485','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 14:14:03',0,NULL,8,1,17,0,NULL,'jdelrie'),(3315,705971722011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',3,'HSNO008',45,'eastar4','mikrosgeros','mikros_geros@hotmail.com','George Douanoglou','Elassonos 7','Voula','Athens / Attiki','GREECE','16673','2108955133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 14:23:36',0,NULL,3,1,3,1,'RA117730341CN\r ','mikrosgeros\r欧标\rHSNO008'),(3316,706012030011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','justin_rao','justin.rao@gmail.com','Zhaohua Rao','45 Stavely Cres.','Etobicoke','ON','CANADA','M9W 2C2','(647) 928-0008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 15:42:13',0,NULL,3,1,2,1,'\\ ','justin_rao'),(3317,580024464013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',37.98,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 16:26:08',0,NULL,3,1,3,1,'RA117730338CN\r ','small.mac\rWLAP008'),(3318,580045017013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','blau_arni','a-johnen@gmx.de','Andrej Johnen','Kaiserstr. 34','Mönchengladbach','','GERMANY','41061','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 17:07:08',0,NULL,3,1,3,1,'RA117730386CN\r ','blau_arni\rMOSA002\r新地址\rAndrej Johnen\rGrefrather Str. 18\r47669 Wachtendonk\rDeutschland\r'),(3319,784265610012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',14.9,'eastar4uk','hermiefive','piggylane@aol.com','Martin Roberts','Wildwood<br>Bullsland Lane','Chorleywood','Hertfordshire','UNITED KINGDOM','WD3 5BQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 17:56:08',0,NULL,3,1,3,1,'RA117715905CN\r ','hermiefive\rOTHP003'),(3320,784304477012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','educationpays','mitchellw@kih.net','Robert Wilkinson II','312 Bogey Dr<br>Apt 202','Lowell','AR','UNITED STATES','72745-8327','(859) 749-0384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 18:32:43',0,NULL,3,1,1,1,'\\ ','educationpays\rMX20T'),(3321,706175663011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','dgaguine','dgaguine@blueyonder.co.uk','David Gaguine','4 Bantree Court','Bradford','West Yorkshire','UNITED KINGDOM','BD10 0SG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:05:28',0,NULL,3,1,2,1,NULL,'dgaguine\\'),(3322,784342647012,220759911881,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',41.99,'eastar4','daosis','taoizm@gmail.com','Michael Reznikov','Hanerd 17','Jerusalem','','ISRAEL','96626','972545998198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:11:40',0,NULL,3,1,3,1,'RA117715891CN\r ','daosis\rHSMO020'),(3323,784353095012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','mosxakis1966','moshakis_michael@yahoo.gr','MOSCHAKIS MICHAEL','MARKOU MALLIARAKI 16<br>PERIOXI KOBA','RODOS','','GREECE','TK 85 100','+306937501800','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 19:24:19',0,NULL,3,1,2,1,NULL,'mosxakis1966\\'),(3324,706202778011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','evelyn004','satterfieldd@comcast.net','Don R Satterfield','PO Box 62','Harriman','TN','UNITED STATES','37748-0062','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 19:37:13',0,NULL,3,1,1,1,'\\ ','evelyn004'),(3325,784373592012,220778910015,'NIB Samsung SSG-P2100S Starter Kit Two 3D Glasses',1,'GLSG002',158.99,'eastar4','jamiecrackberryaddict','jamiesperling@hotmail.com','Jamie Spelring','18948-78 Ave','Edmonton','AB','CANADA','T5T 5H7','(780) 870-2040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:45:08',0,NULL,3,1,3,1,'RA117730409CN\r ','jamiecrackberryaddict\rGLSG002'),(3326,784382281012,220456476892,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'eastar4','doszpy','adoszpy@gmail.com','Adam Doszpod','Új utca<br>119','Mélykút','','HUNGARY','6449','0036703135667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:55:57',0,NULL,3,1,2,1,NULL,'doszpy\\'),(3327,706240597011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','alan11963','troy14569@yahoo.com','Troy Rowe','50 S Maple St','Warsaw','NY','UNITED STATES','14569','(585) 786-5498','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 20:29:24',0,NULL,3,1,1,1,'\\ ','alan11963'),(3328,784427400012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','topekadesi','eatbombayduck-buy@yahoo.com','Vijay Mhatre','3502 SW Alameda Dr','Topeka','KS','UNITED STATES','66614-5110','(785) 272-5882','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 21:00:05',0,NULL,3,1,1,1,'\\ ','topekadesi'),(3329,706263656011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','ontime01','terryjane1@googlemail.com','Terry Harrison','30 Park Hill','Harpenden','Hertfordshire','UNITED KINGDOM','AL53AT','07775704042','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:13:32',0,NULL,3,1,2,1,NULL,'ontime01\\'),(3330,706270129011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','yiri_ma','dss@mail.ru','Kirill Vasilyev','Molodezhnaya<br>3/336','Moscow','','RUSSIAN FEDERATION','119226','+79653081275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:27:44',0,NULL,3,1,2,1,NULL,'yiri_ma\\'),(3331,706271785011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',2,'UDAP001',49.18,'eastar4uk','mbell7149','chattyartist@yahoo.co.uk','Mary Bell','12 McKenzie Terrace<br>Troqueer','Dumfries','Dumfries and Galloway','UNITED KINGDOM','DG2 7AR','01387250161','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 21:31:18',0,NULL,3,1,3,1,'RA117715865CN\r ','mbell7149\rUDAP001'),(3332,580198225013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','anubis_sg1','pabaezm@hotmail.com','Pablo Agustín Baez Miron','Calle Cañaveral 8, 5ºB','Granada','Andalucía Ceuta y Melilla','SPAIN','18003','630361728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:47:03',0,NULL,3,1,2,1,NULL,'anubis_sg1\\'),(3333,706294821011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001×2',269.98,'eastar4','lturner3aft','lturner@brasfieldgorrie.com','Lynette Turner','10924 Haskell Dr','Clermont','FL','UNITED STATES','34711-7804','(352) 267-1217','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 22:35:00',0,NULL,3,1,6,1,'EE442466443CN ','lturner3aft'),(3334,580212652013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','lo3795','lorenz_kleine-kalmer@t-online.de','Lorenz Kleine-Kalmer','Im Münsterfeld 16','Warendorf','','GERMANY','48231','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 22:40:33',0,NULL,3,1,2,1,NULL,'lo3795\\'),(3335,784503043012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','stylewearbrazil','stylewearbrazil@yahoo.com','Nubia Salgado','57 Lantern Rd','Revere','MA','UNITED STATES','02151-5617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 00:14:14',0,NULL,3,1,1,1,'\\ ','stylewearbrazil\r红边优联'),(3336,784526082012,220633189995,'Dell 1510 mini PCI-E half size card +2 tyco antenna',1,'WLDE002+ANTY001',19.4,'eastar4','conviqt','eric.ws.anderson@gmail.com','Eric Anderson   ATTN: HAPPY BIRTHDAY!! :)','160 Argyle Ave.<br>Unit 411','Ottawa','ON','CANADA','K2P0N2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 01:22:16',0,NULL,3,1,2,1,NULL,'conviqt \\'),(3337,784531394012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','azarzag','azarzag01@gmail.com','Aldo Zarza','128 Rue Louis-Colin','Gatineau','QC','CANADA','J8V2T1','(613) 286-2098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 01:32:58',0,NULL,3,1,2,1,NULL,'azarzag\\'),(3338,580263532013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',20.95,'eastar4','shutupandshave1','james@shutupandshave.com','James Lawrence','West Berkshire Mencap<br>Enborne Gate, Enborne Road','Newbury','Berkshire','UNITED KINGDOM','RG14 6AT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 02:16:02',0,NULL,3,1,2,1,'\\ ','shutupandshave1'),(3339,706382092011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',75.99,'eastar4','scout_it_out_2','jcmaurer2@gmail.com','John C Maurer','9113 E Rocky Lake Dr','SUN LAKES','AZ','UNITED STATES','85248-7321','(602) 614-1660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 03:30:16',0,NULL,3,1,1,1,'\\ ','scout_it_out_2'),(3340,784572206012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','heitornfp','heitornf@gmail.com','Heitor Pinto','Rua Carlito, 716<br>Vila Formosa','São Paulo','São Paulo','BRAZIL','03378000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 03:47:04',0,NULL,3,1,2,1,'\\ ','heitornfp'),(3341,784572188012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','ppmc135','peterpetrie@gmail.com','Peter Petrie','PO Box 58','Woodford','New South Wales','AUSTRALIA','2778','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 03:48:04',0,NULL,3,1,2,1,NULL,'ppmc135\r红边优联\\'),(3342,784573643012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','lemelendez','lemelendez@hotmail.com','LUIS MELENDEZ','917 Hyland Springs Dr','Ocoee','FL','UNITED STATES','34761','(407) 227-4623','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 04:01:57',0,NULL,3,1,1,1,'\\ ','lemelendez'),(3343,784584933012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','cptnnpkn','douglas.lathrop@earthlink.net','Douglas Lathrop','624 Orton Hall','Pullman','WA','UNITED STATES','99163-5567','(717) 440-6777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 04:53:10',0,NULL,3,1,1,1,'\\ ','cptnnpkn\r红边优联'),(3344,784592798012,220763389031,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',24.5,'eastar4uk','ry11siek','rysiek@data.pl','Ryszard Szyszkowski','os. Krakowiakow 11/16','Krakow','małopolskie','POLAND','31-962','501 943444','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 05:33:58',0,NULL,3,1,3,1,'RA117730324CN\r ','ry11siek\rWWSI002'),(3345,580295670013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','wjmcakair','cakair@windstream.net','William J. Manning','234 Harrison Ct','Mount Washington','KY','UNITED STATES','40047-7748','(502) 538-8680','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 05:45:21',0,NULL,3,1,1,1,'\\ ','wjmcakair\rHP 8pin 1.0 23cm '),(3346,784625873012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',3,'OTGR001+OTGR002',86.7,'eastar4uk','123leonja','leonjanorris@hotmail.com','Mrs. L.J.L. NORRIS','Peter Norris (Haulage) Limited<br>Station Approach','ST. MARY CRAY','Kent','UNITED KINGDOM','BR5 2NB','01689821417','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 08:12:47',0,NULL,3,1,4,1,' YW865907454CN\r','123leonja\rOTGR001+OTGR002\r'),(3347,706438371011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','schweinelendchen_mit_pilzen','mb2303@gmx.de','Martin Blass','Zellingerstraße 8','Erlabrunn','','GERMANY','97250','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 08:27:20',0,NULL,3,1,2,1,'\\ ','schweinelendchen_mit_pilzen'),(3348,706453831011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','pete_from_nz','pete_hunt_jenkins@hotmail.com','Peter Jenkins','65 Fraser Street<br>Tauranga South','Tauranga','Bay of Plenty','NEW ZEALAND','3112','+6475776664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 09:34:14',0,NULL,3,1,3,1,'RA117730749CN ','pete_from_nz\rPOLO07+POLO001+RCLO008*4\r'),(3349,706454706011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','gendutzz','gendutzz@yahoo.com','Abraham Bobby','JL. Jembatan Dua No. 82. FA / FB<br>(Komplek Ruko Robinson)','Jakarta Utara','DKI Jakarta','INDONESIA','14450','62 81310303075','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 09:38:08',0,NULL,3,1,2,1,'、 ','gendutzz'),(3350,784090786012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','powerdjpowermix','shanol8@yahoo.com','jose remache','19 State St<br>Apt 2L','danbury','CT','UNITED STATES','06810-3218','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 09:40:01',0,NULL,3,1,1,1,'、 ','powerdjpowermix\r美标'),(3351,706474956011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','zw0lsman','zw0lsman@hotmail.com','Floris Zwolsman','Rooseveltlaan 21-3','Amsterdam','Noord-Holland','NETHERLANDS','1079AB','+31611538685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 10:56:30',0,NULL,3,1,2,1,'、 ','zw0lsman'),(3352,784671179012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',21.9,'eastar4','sokoffdmitry','sokoff@inbox.ru','Dmitry Sokovyh','DZERZHINSKOGO 3-40','Samara','','RUSSIAN FEDERATION','443093','902-292-9256','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 10:57:04',0,NULL,3,1,2,1,'、 ','sokoffdmitry\r欧标'),(3353,784671926012,220704730389,'New GENUINE Plantronics Explorer 340 BLUETOOTH HEADSET',1,'HSPL007',14.9,'eastar4uk','foneworxfoneworx','juliefoneworx@yahoo.co.uk','FONE-WORX','59 hill street<br>newry co.down','newry','nireland','UNITED KINGDOM','bt341af','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 10:59:10',0,NULL,3,1,3,1,'RA117733881CN ','foneworxfoneworx\rHSPL007\r英标'),(3354,580345549013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',83.85,'eastar4','hikkles','churchill962@btinternet.com','nichola barnes chihuahua world','the manor house<br>lewes rd','east sussex TN225RE','East Sussex','UNITED KINGDOM','tn225re','01825840760','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 10:59:39',0,NULL,3,1,3,1,'RA117730593CN ','hikkles\rMOSA003'),(3355,533840819004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','pak7155','pakjpg@gmail.com','pakorn tuwajit','57/33 serithai road<br>klongkum bungkum','bangkok','bangkok','THAILAND','10240','662 377 2820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 11:11:30',0,NULL,3,1,3,1,'RA117730620CN ','pak7155\rOTCR001\r'),(3356,706486709011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','proximitybuyer','jaco@squaremeter.co.za','FJDV Nel','Pobox 1645<br>Rosslyn','Pretoria','Gauteng','SOUTH AFRICA','0200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 11:36:56',0,NULL,3,1,2,1,'、 ','proximitybuyer'),(3357,706501626011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',24.9,'eastar4','jackslanin','jacks@bk.ru','Evgeniy Lanin','Energetikov d.43 kv.16','Kurchatov','Kurskaya','RUSSIAN FEDERATION','307250','(910)2102002','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 12:29:02',0,NULL,3,1,2,1,'、 ','jackslanin\r欧标'),(3358,784703171012,220723590916,'New Motorola H700 Bluetooth Wireless Headset+ Caraharge',1,'HSMO011+CCMO001',10.99,'eastar4uk','les4991','lescox1@btinternet.com','LES COX','6 HILLVIEW LANE, GREAT BILLINGTON','LEIGHTON BUZZARD','Bedfordshire','UNITED KINGDOM','LU79BH','01525852229','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 12:37:14',0,NULL,3,1,3,1,'RA117730616CN ','les4991\rHSMO011+CCMO001\r'),(3359,784687111012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','terrance1307','terrancelawson@bellsouth.net','terrance lawson','2218 orleans ave.','new orleans','LA','UNITED STATES','70119','(504) 309-6236','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 12:38:00',0,NULL,3,1,1,1,'、 ','terrance1307'),(3360,784712490012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','softballmom321','lrogalsky@aol.com','Lauren Rogalsky','96 Carlton Dr','Del Rey Oaks','CA','UNITED STATES','93940-5527','(831) 394-7081','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 13:05:41',0,NULL,3,1,1,1,'、 ','softballmom321'),(3361,706515152011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',16.98,'eastar4','tiosymys2011','tiosymys@hotmail.com','JOZELIA ALBERTINA DE SOUSA NOBREGA','RUA CÔNEGO VICENTE MIGUEL MARINO, 275 APTº 101 D<br>BARRA FUNDA','SÃO PAULO','SÃO PAULO','BRAZIL','01135020','11 - 3392.1413','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 13:12:26',0,NULL,3,1,2,1,'、 ','tiosymys2011'),(3362,784739579012,220445373662,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',2,'TRTT002*10',166,'eastar4','tnetusa','ebay@tnetus.com','T-NET TECHNOLOGY INC.','39 Plymouth St<br>Fl 1st Ste D','Fairfield','NJ','UNITED STATES','07004-1633','(718) 369-3828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 14:24:53',0,NULL,3,1,4,1,'YW865907502CN ','tnetusa'),(3363,706548297011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','eric42360','eric.tissier42@orange.fr','TISSIER ERIC','42, RUE DE LA REPUBLIQUE','PANISSIERES','LOIRE','FRANCE','42360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 14:52:52',0,NULL,3,1,3,1,'RA117730735CN ','eric42360\r欧标\rHSPL009'),(3364,784755062012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',2,'WLAT009',19.98,'eastar4','rfrederick71','rf33@austin.rr.com','Ronald Frederick','3604 Silver Hill Cir','Austin','TX','UNITED STATES','78746-6683','(512) 496-8153','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 15:06:46',0,NULL,3,1,1,1,'、 ','rfrederick71'),(3365,706565894011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','braatenj1','jeff.braaten@hirshindustries.com','Jeff Braaten','12308 Valdez Dr','Urbandale','IA','UNITED STATES','50323-2374','(515) 334-9388','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 15:41:52',0,NULL,3,1,1,1,'、 ','braatenj1'),(3366,528173875003,130466041506,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',63,'cnfaner','lucato2010','lscrlstld@gmail.com','Luis Carlos Toledo','Rua Elvira Bertelli Polessi, 10 - Res Flamboyant','Itatiba','SP','BRAZIL','13253-671','55 11 4487-2333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 16:10:12',0,NULL,8,1,17,1,NULL,'lucato2010\rWWSI006+ANCN001\r与eastar4店合并了'),(3367,784782418012,220778910015,'NIB Samsung SSG-P2100S Starter Kit Two 3D Glasses',2,'GLSG002',317.98,'eastar4','alegre01','alegre01@gmail.com','Aymart Alegre','3301 SW 88th Ct','miami','FL','UNITED STATES','33165-4223','(786) 357-0300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 16:11:13',0,NULL,3,1,6,1,'EE520583318CN ','alegre01'),(3368,706577473011,320566963477,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',63,'eastar4','lucato2010','lscrlstld@gmail.com','Luis Carlos Toledo','Rua Elvira Bertelli Polessi, 10 - Res Flamboyant','Itatiba','SP','BRAZIL','13253-671','55 11 4487-2333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 16:11:58',0,NULL,3,1,3,1,'RA117730704CN ','lucato2010\rWWSI006+ANCN001'),(3369,784786509012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','bigdavedeals','dgm0225@yahoo.com','Dave Mpojeannis','15 Wigmore Drive, Suite B','Toronto','ON','CANADA','M4A 2E4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 16:20:25',0,NULL,3,1,3,1,'RA117730576CN\r ','bigdavedeals\rHSPL014'),(3370,784786603012,220759427746,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',9.2,'eastar4uk','mikelwork','info@lawsltd.co.uk','mike law','30 moorland trading estate<br>metheringham','lincoln','Lincolnshire','UNITED KINGDOM','ln43hx','01526323900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 16:20:38',0,NULL,3,1,3,1,'RA117730752CN ','mikelwork\rHSPL001'),(3371,784792064012,220759518239,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',27.99,'eastar4uk','58415','kolbasa76@yandex.ru','Vetchinkin Evgeniy','ul. 22 April, dom 8-v, kv.4','Omsk','','RUSSIAN FEDERATION','644088','0079131410180','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 16:34:06',0,NULL,3,1,3,1,'RA117730721CN ','58415\rCMLO001'),(3372,784809071012,220713846526,'New in box GENUINE NOKIA HS 11W BLUETOOTH HEADSET',1,'HSNO024',12.9,'eastar4uk','kapa2ou3','rmarmelo@gmail.com','Rafael Marmelo','Instituto Pedro Nunes - FeedZai<br>Rua Pedro Nunes','Coimbra','Coimbra','PORTUGAL','3030-199','+351964158903','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 17:09:25',0,NULL,3,1,3,1,'RA117730655CN ','kapa2ou3\rHSNO024\r欧标'),(3373,784810851012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',14.99,'eastar4uk','markf9283','mark@septemberhouse.plus.com','Mark Feeney','September House, Potters Croft, Stone Rd,<br>Tittensor','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','ST12 9HB','01728373666','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 17:13:43',0,NULL,3,1,3,1,'RA117730562CN ','markf9283\rOTGR001'),(3374,784811015012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','diegopascon23','diegopascon@terra.com.br','Diego T Pascon','Rua Gastão do Rego Monterio,666<br>Ap. 51','São Paulo','SP','BRAZIL','05594030','551194703368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 17:15:33',0,NULL,3,1,2,1,'、 ','diegopascon23'),(3375,784815468012,220713846504,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET',1,'HSNO025',35.9,'eastar4uk','angiekoku','angelabilauri@hotmail.co.uk','Angela Bilauri','66 Yarmouth Crescent','Tottenham','London','UNITED KINGDOM','N17 9PQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 17:21:51',0,NULL,3,1,3,1,'RA117730678CN ','angiekoku\rHSNO025\r英标'),(3376,580440648013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',5,'WLAT001',159.2,'eastar4','athenafreya','klnguyen_1998@yahoo.com','Kim Nguyen','25050 Riding Plz<br>Ste 130-250','South Riding','VA','UNITED STATES','20152-5925','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 17:29:51',0,NULL,3,1,1,1,'\\ ','athenafreya\r再发5 个NEW Atheros AR5B93 Half Height Wireless WiFi card 300M\r新地址\rKIM NGUYEN\r14280 SULLYFIELD CIR # DS04952\rCHANTILLY VA\rUNITED STATES 20151-1699'),(3377,706619360011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','rjpower76','rjpower76@yahoo.com','Rafael Joa','19937 Harrison Ave','Walnut','CA','UNITED STATES','91789-2848','(626) 536-4631','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 17:48:00',0,NULL,3,1,1,1,'、 ','rjpower76\r新地址\rRafael Joa\r22937 Rio Lobos Rd.\rDiamond Bar, CA 91765\rUSA\r'),(3378,784832130012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','leonveliki','leon.stare@gmail.com','Leon Stare','Dragocajna 9a','Smlednik','','SLOVENIA','1216','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 17:54:25',0,NULL,3,1,2,1,'、 ','leonveliki'),(3379,580460645013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',61.99,'eastar4','invernesse','cbosnyak@hotmail.com','Csaba Bosnyák','Borsó u. 44.','Budapest','Budapest','HUNGARY','1173','+36204500650','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-09 18:12:01',0,NULL,3,1,3,1,'RA117730681CN ','invernesse\rHSNO019\r欧标'),(3380,580480156013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',7,'WWSI005',216.3,'eastar4','magalies2001','marius@magalies.net','Marius Bijker','1274 Walter avenue<br>Waverley','Pretoria','Gauteng','SOUTH AFRICA','0186','(083) 627-4872','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 19:01:05',0,NULL,3,1,3,1,'RA117731418CN\r ','magalies2001\rWWSI005\r'),(3381,528247441003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','buythewayside','kievers@comcast.net','Robert S Kiever','17660 Wayside Ln','Lake Oswego','OR','UNITED STATES','97034-6450','(503) 353-1560','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 19:45:21',0,NULL,3,1,1,1,'、 ','buythewayside'),(3382,784903195012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','jarolumon','javito@jrlm.jazztel.es','Javier Rodríguez Lucas-Montoya','Ronda de Segovia Nº79 2ºB','Madrid','Madrid','SPAIN','28005','636425374','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 19:48:24',0,NULL,3,1,2,1,'、 ','jarolumon'),(3383,580496674013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','1193dave','davegagnon007@hotmail.com','Dave Gagnon','414 Diane #1','longueuil','QC','CANADA','j4j2c3','(450) 646-1156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 19:52:04',0,NULL,3,1,2,1,'、 ','1193dave'),(3384,706183925011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',2,'HSMO019',45.98,'eastar4','lionheadbaby','simon_kwok@msn.com','Simon Kwok','3043 Charles St.','Vancouver','BC','CANADA','V5K 3B4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 19:52:34',0,NULL,3,1,3,1,'RA117730633CN ','lionheadbaby\rHSMO019'),(3385,706693746011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','piedra_79','jfernandezv@att.net','Jaime Fernandez','2250 Eldridge Pkwy<br>Apt 711','Houston','TX','UNITED STATES','77077-1862','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 20:06:05',0,NULL,3,1,1,1,'、 ','piedra_79'),(3386,580517243013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',61.8,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 20:35:58',0,NULL,3,1,3,1,'RA117730664CN ','update_marcelo\rWWSI005'),(3387,706715751011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',2,'RELO002',25.98,'eastar4','jasemanus','jhintz@comcast.net','Jason Hintz','1327 Yorkshire Rd','Grosse Pointe Park','MI','UNITED STATES','48230-1107','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 20:45:39',0,NULL,3,1,1,1,'、 ','jasemanus'),(3388,784943300012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','tonymiddo2011','tonymiddo@yahoo.co.uk','tony middleton','54 rensherds place','high legh','Merseyside','UNITED KINGDOM','wa16 6ng','01925354301','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 21:00:08',0,NULL,3,1,3,1,'RA117730718CN ','tonymiddo2011\r英标\rHSSE006\r'),(3389,580532444013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','devcar_sys','devin@devcar.com','Devin Gregoire','31262 Old Baton Rouge Hwy','Hammond','LA','UNITED STATES','70403-8352','(225) 202-3894','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 21:23:08',0,NULL,3,1,1,1,'、 ','devcar_sys'),(3390,580538665013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','smal7005','kumarm2010@hotmail.com','Shreejana Malla','20 Lindenwoods Rd.','Norwalk','CT','UNITED STATES','06851','(203) 286-8757','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 21:46:53',0,NULL,3,1,1,1,'、 ','smal7005'),(3391,706764253011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','cybercenter816','cyber.center@live.com','Alexander Kornus','11518 N Walnut St','Kansas City','MO','UNITED STATES','64155-1120','(816) 508-9961','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 23:04:52',0,NULL,3,1,1,1,'、 ','cybercenter816'),(3392,784992059012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',1,'BALO005',7.1,'eastar4','vcollection777','vlad13@gmail.com','Vlad Zhitnitzky','11/9-13 Coorigil Rd.','Carnegie','Victoria','AUSTRALIA','3163','01395687167','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 23:14:21',0,NULL,3,1,2,1,'、 ','vcollection777'),(3393,580556148013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','joehsker','jrhusker@gmail.com','joseph holt','1627 woodlawn ave','terre haute','IN','UNITED STATES','47804-4052','(812) 236-0745','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 23:24:40',0,NULL,3,1,1,1,'、 ','joehsker'),(3394,784282396012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','alma_hernandez','ivanhoe.escobar@hotmail.com','Alma Hernandez','511 E San Ysidro Blvd<br># 2253','San Ysidro','CA','UNITED STATES','92173','(619) 567-6292','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 00:14:28',0,NULL,3,1,1,1,'、 ','alma_hernandez'),(3395,577536202013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','denice202001','denice202001@yahoo.com','TASHONDRA D ROPER','8100 Winterwood Dr','Little Rock','AR','UNITED STATES','72209-7319','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 00:34:32',0,NULL,3,1,1,1,'、 ','denice202001'),(3396,580554099013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','green.318','l44948@bellsouth.net','gregory cooper','4029 Union Ave','shreveport','LA','UNITED STATES','71108-2231','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 00:53:24',0,NULL,3,1,1,1,'、 ','green.318'),(3397,706799373011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','hcl0','tugkans@gmail.com','Tugkan Sahinler','302 Sokak No:18 Daire:7<br>Şirinyer','İzmir','','TURKEY','35140','+905326404544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 01:33:02',0,NULL,3,1,2,1,'、 ','hcl0'),(3398,785033711012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','anthonyl5253','mindofhisown@gmail.com','Anthony L Pietrangelo III','1528 Forest Hill Rd','Staten Island','NY','UNITED STATES','10314-6336','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 01:42:58',0,NULL,3,1,1,1,'、 ','anthonyl5253\r红边优联'),(3399,701885205011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','victorasieduyoung','victor.asieduyoung51@gmail.com','Victor Asiedu-Young','71 Nightstar Drive','Richmond Hill','ON','CANADA','L4C 8H5','(647) 701-5952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 02:40:02',0,NULL,3,1,2,1,'、 ','victorasieduyoung'),(3400,706820884011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','blaze-won','blaze_won@yahoo.com','James A. Guerrero Jr.','5062 N Maywood Ave','Los Angeles','CA','UNITED STATES','90041','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 02:54:01',0,NULL,3,1,1,1,'、 ','blaze-won'),(3401,580618362013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','tomek2961817','orion_101@hotmail.com','Tomek','12 Karlson Way','Cranbourne North','Victoria','AUSTRALIA','3977','0410021806','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 05:04:10',0,NULL,3,1,2,1,'、 ','tomek2961817\rCAB-6060'),(3402,785067830012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.8,'eastar4','inkyrat01','inkyrat@yahoo.com','Alice Garratt','60 Edward Street','carlton','New South Wales','AUSTRALIA','2218','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 05:19:20',0,NULL,3,1,2,1,'、 ','inkyrat01\rHP 6pin 1.0 12cm '),(3403,706847506011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','joserodriguezcuevas','jarcvs88@gmail.com','JOSE RODRIGUEZ','1131 Leahy RD','MONTEREY','CA','UNITED STATES','93940-7451','(831) 831-5572','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 05:19:56',0,NULL,3,1,1,1,'、 ','joserodriguezcuevas'),(3404,785097567012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','georger0906','yellow_54@hotmail.com','George Romanacce','109 Meadowfield Ln','Longwood','FL','UNITED STATES','32779-4412','(407) 415-7905','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 06:35:26',0,NULL,3,1,1,1,'、 ','georger0906'),(3405,580637558013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','bronyaurstomp0123','the335@gmail.com','Yuki Tokuhiro','YAMASA Institute<br>1-2-1 Hanehigashimachi','Okazaki','Aichi','JAPAN','444-8691','(080) 421-0179 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 07:34:01',0,NULL,3,1,2,1,'\\ ','bronyaurstomp0123'),(3406,785111506012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','peckchoonheng','chpeck@pacific.net.sg','Peck Choon Heng','No.2 Lebuh Sungai Nyior','Butterworth','Penang','MALAYSIA','12100','043311717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 07:40:42',0,NULL,3,1,2,1,'\\ ','peckchoonheng'),(3407,706875125011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','aaleez','aaleezee@hotmail.com','Aaron Lee','15 Sandrigo Way','Stirling','Western Australia','AUSTRALIA','6021','0892072879','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 07:44:49',0,NULL,3,1,2,1,'\\ ','aaleez'),(3408,785118751012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',49.99,'eastar4','3560michelle','hipwell.m@euro.apple.com','Michelle Hipwell','Apple Operations Europe<br>Hollyhill Industrial Estate','Cork','Cork','IRELAND','default','0872791980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 08:13:14',0,NULL,3,1,3,1,'RA117730973CN ','3560michelle\rCMLO001\r'),(3409,785130656012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','emanuel333','efogl@yahoo.com','Emanuel Fogl','Lanište 17b','Zagreb','Zagreb','CROATIA','10000','0998460071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 09:02:57',0,NULL,3,1,2,1,'\\ ','emanuel333\r红边优联'),(3410,534126918004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','4werter','bbccdd@bk.ru','Oleg Mashtakov','Krasnodarskaya street<br>house 51, building 4, office 98','Moskva','','RUSSIAN FEDERATION','109559','+7 9198275574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 09:34:39',0,NULL,3,1,3,1,'RA117733161CN\r ','4werter\rWWSI005'),(3411,670953943001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','zlc2002','zlc20022@yahoo.com','AZ','11831 Sir Winston Way','Orlando','FL','UNITED STATES','32824-6035','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 10:44:16',0,NULL,3,1,1,1,'\\ ','zlc2002\rLK048091408CN'),(3412,785158544012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',25.8,'eastar4','zander.83','zander83@gmail.com','Alex Ulanovski','Bialik 94<br>Entrance B','Ramat Gan','','ISRAEL','52536','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 10:50:35',0,NULL,3,1,2,1,'、 ','zander.83'),(3413,580672259013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','flashy69','myglock17@gmail.com','MARIOS MICHAIL','GRIGORIOU KOUSIDOU 7','ZOGRAFOU','ATHENS, GREECE','GREECE','15773','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 11:05:35',0,NULL,3,1,3,1,'RA117732798CN\r ','flashy69\rMOSA002'),(3414,785175632012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','alindsay','alex@lindsay.cc','Alex Lindsay','179 George St','Redfern','New South Wales','AUSTRALIA','2016','0419490735','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 11:50:33',0,NULL,3,1,2,1,'\\ ','alindsay'),(3415,706935739011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',134.99,'eastar4','hhjeb','blaue69@verizon.net','Harold Blaue','69 Lincoln Rd','Sutton','MA','UNITED STATES','01590','(508) 865-5374','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 11:58:12',0,NULL,3,1,1,1,'\\ ','hhjeb'),(3416,785181536012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','dracul6ijb','rudy_boc@yahoo.com.sg','Rudy Harjanto','30 Ah Hood Road<br>#08-01','Singapore','','SINGAPORE','329976','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 12:08:36',0,NULL,3,1,11,1,'\\ ','dracul6ijb\rHSPL010'),(3417,785187626012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',1,'ANYA002',19.5,'eastar4','jasambond','vedran_radonic@yahoo.com','Vedran Radonić','Milana Rešetara 12','Zagreb','','CROATIA','10090','0922055172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 12:31:01',0,NULL,3,1,11,1,'\\ ','jasambond\rANYA002'),(3418,580690703013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','elm1232011','eliavmoryoussef@gmail.com','Eliav Moryoussef','Ha\'meginim 1','Nesher','','ISRAEL','36620','972 0502298900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 12:38:57',0,NULL,3,1,2,1,'\\ ','elm1232011'),(3419,706955942011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','uglyfish73','quincy00@hotmail.co.uk','Jody McKenzie','SOCO, Slough Police Station<br>Windsor Road','Slough','Berkshire','UNITED KINGDOM','SL1 2HH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 13:02:58',0,NULL,3,1,3,1,'RA117732775CN\r ','uglyfish73\rMOAP001'),(3420,785206735012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','d.kim.15','dkim.15@gmail.com','Tae Kim','1477 N. Pembroke Dr.','South Elgin','IL','UNITED STATES','60177','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 13:25:47',0,NULL,3,1,1,1,NULL,'d.kim.15\r红边优联\\'),(3421,785212172012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','globaltres','globaltreasure1@gmail.com','Global Treasures LLC','38 Glenaire Dr','Greer','SC','UNITED STATES','29650-2573','(484) 336-7324','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 13:42:53',0,NULL,3,1,1,1,'\\ ','globaltres'),(3422,579155490013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','havix_end','h_a_v_i_x@yahoo.com','Philip Johnson','182 Mount Marie Ave NW','Canton','OH','UNITED STATES','44708','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 14:09:06',0,NULL,3,1,1,1,'\\ ','havix_end'),(3423,706982664011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','nadia_rick','nadia_alcindor@yahoo.com','Nadia Alcindor','10 Starbird Ave','Roslindale','MA','UNITED STATES','02131','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 14:33:57',0,NULL,3,1,1,1,'\\ ','nadia_rick'),(3424,785232176012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',23.98,'eastar4uk','pinkhairdreser','s.b.murray@btinternet.com','shauna murray','26 shantallow avenue<br>belmont','derry','Londonderry','UNITED KINGDOM','b48 7ub','02871352174','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 14:41:53',0,NULL,3,1,3,1,'RA117732784CN\r ','pinkhairdreser\rHSMO018\r英标\r'),(3425,706987395011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','anthonyyeung1106','anthony1106@gmail.com','Anthony Yeung','9/20 Gochean Ave, Bentley','Perth','Western Australia','AUSTRALIA','6102',' 0432748941','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 14:45:27',0,NULL,3,1,2,1,'\\ ','anthonyyeung1106'),(3426,706992436011,320566963477,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',2,'WWSI006+ANCN001',126,'eastar4','pljubas1806','pljubas@vip.hr','Petar Ljubas','Dankovecka 3','Zagreb','Zagreb','CROATIA','10040','+385 91 2293388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 15:00:41',0,NULL,3,1,3,1,'RA117733303CN\r ','pljubas1806\rWWSI006+ANCN001'),(3427,706993484011,320566963477,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',2,'WWSI006+ANCN001',126,'eastar4','pljubas1806','pljubas@vip.hr','Dalibor Ljubic','I Trnava 39','Zagreb','Zagreb','CROATIA','10040','+385 91 2293388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 15:07:11',0,NULL,3,1,3,1,'RA117733294CN\r ','pljubas1806\rWWSI006+ANCN001'),(3428,707014576011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','massoodi','m_massood@hotmail.com','Mohamed Massoud','Airport Road<br>P.O.BOX: 43853','Abu Dhabi','UT','UNITED ARAB EMIRATES','02','00971504190911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 16:02:26',0,NULL,3,1,2,1,'\\ ','massoodi'),(3429,785275422012,220627153736,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',26.59,'eastar4','titichou64','jendav64@hotmail.fr','david cirillo','7 impasse d\'ossau<br>résidence la florentine app. B-06','lons','Aquitaine','FRANCE','64140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 16:32:26',0,NULL,3,1,2,1,'\\ ','titichou64\r欧标'),(3430,580752542013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','joaaann','ametllamotard@gmail.com','Joan Antoni González Crego','Amistat<br>38','L\'Ametlla del Vallès','Cataluña','SPAIN','08480','666971370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 16:50:45',0,NULL,3,1,2,1,'\\ ','joaaann'),(3431,580752480013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',11.99,'eastar4','rickoh1970','rickoh88@gmail.com','Rick Oh','13118 Sunstone pt','San Diego','CA','UNITED STATES','92130-5775','(858) 229-5923','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 16:53:17',0,NULL,3,1,1,1,'\\ ','rickoh1970'),(3432,785305692012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','nj_kung','reginaqn@hotmail.com','Tossaporn Jiamsrisukhon','835/3   Sathupradit.RD trok watjannai<br>Bangprongprang   Yannawa　Poka House   room 2404','Bangkok','Center','THAILAND','10120','0891807100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 17:40:43',0,NULL,3,1,2,1,'\\ ','nj_kung'),(3433,707064144011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','sega_vs','sega1984@gmail.com','Sergey Vasiliev','Engelsa 74-89','Verkhnaya Salda','Sverdlovskaya oblast','RUSSIAN FEDERATION','624766','+7 909 0171040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 18:00:33',0,NULL,3,1,2,1,'\\ ','sega_vs\r欧标'),(3434,785344165012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','dsully20202','dsully2020@yahoo.com','Daniel Sullivan','330 Cabot St','Beverly','MA','UNITED STATES','01915-3340','(978) 998-2481','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 18:49:40',0,NULL,3,1,1,1,'\\ ','dsully20202'),(3435,784889120012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','pauleo1214','pauleliasson@gmail.com','Paul Eliasson','3925 Beech Ave<br>APT 213','Baltimore','MD','UNITED STATES','21211-2254','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 18:56:43',0,NULL,3,1,1,1,'\\ ','pauleo1214'),(3436,785352749012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','cdaisjr','cdaisjr@yahoo.com','Charles F. Dais II','3866 Tamarack Dr','Green Bay','WI','UNITED STATES','54313-4815','(920) 865-3866','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 19:04:02',0,NULL,3,1,1,1,'\\ ','cdaisjr'),(3437,580807799013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','remybobo06','remy_nos@hotmail.com','remy BORGHESE','87 avenue des combattants d\'afn','st laurent du var','Provence-Alpes-Côte d\'Azur','FRANCE','06700','0493143662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 19:28:38',0,NULL,3,1,2,1,'\\ ','remybobo06'),(3438,785358320012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','909everardo','evercarmin@hotmail.com','Everardo Carrillo Mijares','15047 seville ave','fontana','CA','UNITED STATES','92335-7009','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 19:30:35',0,NULL,3,1,1,1,'\\ ','909everardo'),(3439,707108454011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','sircarodoc','barrier@rogers.com','B.M. WASSMANSDORF','120 - 1915 Broad Hollow Gate','Mississauga','ON','CANADA','L5L 6A3','(905) 820-5225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 19:56:48',0,NULL,3,1,2,1,'\\ ','sircarodoc\r\r'),(3440,707128003011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','curtis3332','nicholascurtis@f2s.com','Nicholas Curtis','2 St Barnabas Villas<br>Stockwell','London','London','UNITED KINGDOM','SW8 2EH','02076223471','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 20:02:06',0,NULL,3,1,3,1,'RA117733229CN\r ','curtis3332\rMOAP001'),(3441,707128943011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',11.95,'eastar4','altimadude22','diegoalfredo@me.com','Diego A Lopez','1009 Lamar St','Marion','NC','UNITED STATES','28752-5835','(828) 460-8112','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 20:04:56',0,NULL,3,1,1,1,'\\ ','altimadude22'),(3442,707136973011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',134.99,'eastar4','tempo817','eblacourt@hotmail.com','Edwin Burgos','Urb. Colinas de San Martin calle 4 D3','Juana Diaz','PR','UNITED STATES','00795','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 20:19:12',0,NULL,3,1,1,1,'\\ ','tempo817'),(3443,707139324011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','wf-m','wf-m@freenet.de','Waldemar Felk','Josefa-Berens-Str. 23','Finnentrop','','GERMANY','57413','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:24:42',0,NULL,3,1,2,1,'\\ ','wf-m'),(3444,785400208012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',22.93,'eastar4','kovois','sykora@shaw.ca','Bohumil Sykora','3920 Westridge Ave<br>SYSCA INTERNATIONAL corp.','West Vancouver','BC','CANADA','V7V3H7','(604) 925-5749','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:26:13',0,NULL,3,1,2,1,'\\ ','kovois\r再发一个New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card\r'),(3445,785414885012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','remcoz','remcoz@hotmail.com','Remco van der Zon','1e Kruisstraat 15','Deventer','','NETHERLANDS','7413 VE','0624696071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:55:55',0,NULL,3,1,2,1,'\\ ','remcoz\r红边优联'),(3446,707155538011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','robertosoltz','roberto@robertosoltz.com','Roberto Soltz','Av. Afonso Pena Street # 732, 9 andar<br>Centro, CEP: 30.130-003','Belo Horizonte, MG','Belo Horizonte, MG, Brazil','BRAZIL','30.130-003','31 3274-2900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 21:11:07',0,NULL,3,1,3,1,'RA117733189CN\r ','robertosoltz\rUDAP001'),(3447,785421729012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','14111981ihsan','ihsan_akar@hotmail.com','ihsan akar','hürriyet mah.başaran caddesi no:45/3<br>küçükköy','gaziosmanpaşa','istanbul','TURKEY','34250','00902126169039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 21:13:00',0,NULL,3,1,2,1,'\\ ','14111981ihsan\r欧标'),(3448,534307319004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',44.98,'cnfaner','retorosiba','holger.noack@web.de','Sven-Holger Noack','Gartenstr.4','Sarstedt','','GERMANY','31157','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 21:27:36',0,NULL,3,1,3,1,'RA117733246CN\r ','retorosiba\rWWOT001'),(3449,580859820013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',2,'HSJA002',43,'eastar4','7043yeshua','jkhouchens@q.com','Kimberly Houchens','7737 Columbine Ct','Rapid City','SD','UNITED STATES','57702-9078','(605) 343-1849','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 22:12:55',0,NULL,3,1,1,1,'\\ ','7043yeshua'),(3450,580825636013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','alhasas96','mohd8609@hotmail.com','mohammed ali Al-Hasaei','ALBA P.O.Box 570<br>Inst. Red. Maint. CC 26','Bahrain','Middle East','BAHRAIN','No','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 22:27:30',0,NULL,3,1,2,1,'\\ ','alhasas96'),(3451,707188490011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','pgprazak','prazak@westnet.com.au','Peter Prazak','37 Pine Avenue','Wentworth Falls','New South Wales','AUSTRALIA','2782','0247571458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 22:31:04',0,NULL,3,1,2,1,'\\ ','pgprazak'),(3452,707187503011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','lour_madrid','lourdes190684@gmail.com','Lourdes Villa Fernandez','C/ Luxemburgo Nº13, 3º2','Fuenlabrada','Madrid','SPAIN','28943','676162768','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 22:33:00',0,NULL,3,1,3,1,'RA117731421CN\r ','lour_madrid\rGLSG001'),(3453,785458672012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','gimpybonez','gimpybonez@yahoo.com','Chris Swartz','22260 Riverwalk','Rocky River','OH','UNITED STATES','44116','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 22:51:05',0,NULL,3,1,1,1,'\\ ','gimpybonez'),(3454,785463266012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','trxtoby','toby@littleport46.freeserve.co.uk','TOBY PRICE','21 ELY ROAD','ELY','Cambridgeshire','UNITED KINGDOM','CB61HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 23:05:35',0,NULL,3,1,3,1,'RA117733175CN\r ','trxtoby\rANCN001'),(3455,534332583004,140481827793,'New Plantronics Voyager 851/855 Bluetooth Headse track#',1,'HSPL009',49.9,'cnfaner','154neuville','yvesstamant@msn.com','Yves St-Amant','154 rue Côté','Neuville','QC','CANADA','G0A2R0','(418) 876-3465','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 23:32:22',0,NULL,3,1,3,1,'RA117731435CN\r ','154neuville\rHSPL009\r'),(3456,785478426012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',12.5,'eastar4','mrdjol','mrdjol@yahoo.fr','Olivier GOYFFON','4 Rue du Dr Horand','Lyon','Rhône-Alpes','FRANCE','69009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 00:05:30',0,NULL,3,1,2,1,'\\ ','mrdjol\r4pin 1.25'),(3457,785487573012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',2,'WLAP001+WLAP004',37.98,'eastar4','ciclirossetto','ciclirossetto@excite.com','Cicli Rossetto','4401 San Leandro St<br>Apt 51','Oakland','CA','UNITED STATES','94601-4461','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 00:56:02',0,NULL,3,1,1,1,'\\ ','ciclirossetto'),(3458,580890330013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','wendo1jose','jwendo1@yahoo.com','jose fernandez','1473 lydia ave','elmont','NY','UNITED STATES','11003-4529','(347) 476-0852','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 00:58:01',0,NULL,3,1,1,1,'\\ ','wendo1jose'),(3459,580263159013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','jaboo76','jaboo76@yahoo.com','Jason Boo','Blk 238 Compassvale Walk<br>#10-552','default','','SINGAPORE','540238','96854522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 01:05:38',0,NULL,3,1,11,1,'\\ ','jaboo76\rWLIN010'),(3460,580892072013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',48.95,'eastar4','salemalharthy','rasta915@hotmail.com','Salem Said Al Harthy','P O  Box 1572','Musact','Al Khwair','OMAN','133','+96899333480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 01:09:19',0,NULL,3,1,3,1,'RA117733250CN ','salemalharthy\rOTRA002'),(3461,785502298012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','motorcyclearcher1960','peter@repairman.com','peter needham','59 Oakland St','medford','MA','UNITED STATES','02155','(781) 396-4800','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 01:33:47',0,NULL,3,1,1,1,'\\ ','motorcyclearcher1960'),(3462,707236444011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','alanyhsiao','alan_y_hsiao@yahoo.com','Alan Hsiao','5/2 Bechert Rd','Chiswick','New South Wales','AUSTRALIA','2046','0297155472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 01:47:58',0,NULL,3,1,2,1,'\\ ','alanyhsiao'),(3463,707245426011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','g_odagi','odagi@internode.on.net','George Odagi','3 Dale Court','Bundall','Queensland','AUSTRALIA','4217','0755735949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 02:28:43',0,NULL,5,1,18,1,' ','g_odagi\r因缺货  已退款'),(3464,785518462012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','yonseikim02','yonseikim@hotmail.com','Hyunjin Kim','310 Chestnut hill st','Gaithersburg','MD','UNITED STATES','20878-2178','(301) 358-5082','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 02:34:04',0,NULL,3,1,1,1,'\\ ','yonseikim02\r红边优联'),(3465,785526192012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','manoj27814','manoj27814@gmail.com','Manoj Menon','1131 Pinnacle Fls','San Antonio','TX','UNITED STATES','78260-2481','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 03:07:14',0,NULL,3,1,1,1,NULL,'manoj27814\r红边优联'),(3466,580917560013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',23.98,'eastar4','xes7488','slbuddy@att.net','Steven Romund','55417 Macintosh Ct','Shelby Township','MI','UNITED STATES','48316','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 03:26:48',0,NULL,3,1,1,1,'\\ ','xes7488'),(3467,707271997011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','mamallama53','mamallama51@mac.com','Margaret Boersma','1017 Bandera Ave','Douglas','WY','UNITED STATES','82633-3040','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 04:42:15',0,NULL,3,1,1,1,'\\ ','mamallama53'),(3468,707274682011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','uptown_anthem','uzzy_man_01@hotmail.com','Usman Majid','72 ROCKWELL ROAD','LIVERPOOL','MERSEYSIDE','UNITED KINGDOM','L12 4XZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 04:55:14',0,NULL,3,1,3,1,'RA117733215CN\r ','uptown_anthem\rMOAP001\r'),(3469,707275977011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',133.99,'eastar4','rdvolkman','renovatio_2006@comcast.net','Robert Volkman','15032 Mission Ave','Oak Forest','IL','UNITED STATES','60452-1311','(708) 401-3194','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 05:05:10',0,NULL,3,1,1,1,'\\ ','rdvolkman'),(3470,580934645013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','flam4086','franki@techo-bloc.com','Franki Lam','7162 Cartier Street','Montreal','QC','CANADA','H2E 2J2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 05:37:26',0,NULL,3,1,2,1,'\\ ','flam4086'),(3471,580939840013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','worawisut','worawisut@gmail.com','Worawisut Pinyoyang','518/480 The Room Ratchada Ladprao<br>Chankasem Chatuchak','Bangkok','','THAILAND','10900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 06:21:48',0,NULL,3,1,3,1,'RA117731449CN\r ','worawisut\rBAZA001'),(3472,785569844012,220778495356,'New Replaceable Shell 4 logitech anywhere MX Mouse M905',3,'SHLO005',50.97,'eastar4','eilu120','einar.lund@broadpark.no','Einar Lund','Ringvolveien 120','Trondheim','','NORWAY','7089','+047 41568957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 06:47:44',0,NULL,3,1,3,1,'RA117727784CN ','eilu120\rSHLO005\r\r发两个鼠标壳\r退了一个的钱'),(3473,707297183011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','athena3967','alex3967@gmail.com','Alexandre DUFER','Villa 18 Street 89<br>Jumeirah 1 PO 214929','DUBAI','UNITED ARAB EMIRATES','UNITED ARAB EMIRATES','214929','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 07:00:33',0,NULL,3,1,3,1,'RA117731585CN\r ','athena3967\rEXLO001\r'),(3474,580969410013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','motael123','tarekrules@hotmail.com','Tarek El-hamawi','284 Waterloo Road<br>Greenacre','Sydney','New South Wales','AUSTRALIA','2190','0297426405','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'motael123'),(3475,580971336013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',26,'eastar4','balage001','speed.limit@freemail.hu','Tözser Balazs','Etele ter 3. fszt. 2.','Budapest','','HUNGARY','1115','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 09:51:52',0,NULL,3,1,3,1,'RA117731727CN ','balage001\rCACN004\r\r'),(3476,707334113011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',3,'OTCN002',11.97,'eastar4','kirillt1979','89184488446@mail.ru','Kirill Tachanov','2-ya liniya 48','Krasnodar','Krasnodar','RUSSIAN FEDERATION','350004','+79184488446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 09:53:50',0,NULL,3,1,2,1,'、 ','kirillt1979'),(3477,785616766012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',2,'RELO003',23.98,'eastar4','mmapasflg','mmapas@gmail.com','Marek Pinc','Bukova 94','p.Jince','','CZECH REPUBLIC','26223','+420603182733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 10:01:18',0,NULL,3,1,2,1,'\\ ','mmapasflg\r红边优联'),(3478,707346323011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','liron_levi','lironxxx@gmail.com','liron levi','meshek 78','shetulim','israel','ISRAEL','79280','97288552336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 10:43:18',0,NULL,3,1,2,1,'、 ','liron_levi'),(3479,785629744012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','makdel11','makdel@mycosmos.gr','AVRAAM DELIGIANNIS','ANTHEON & ELLIS','THESSALONIKI','','GREECE','57019','+302392075376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 10:48:00',0,NULL,3,1,2,1,'、 ','makdel11\r红边优联'),(3480,580286952013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','krjrs','scissol@hotmail.com','Laura Scissons','RR#2 2203 Ashton Station Road','Ashton','ON','CANADA','K0A 1B0','(613) 257-4366','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 11:56:14',0,NULL,3,1,2,1,'、 ','krjrs'),(3481,785651930012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',61.68,'eastar4','i.gabunia','igabunia@yandex.ru','Ilya Gabuniya','2-y Novopodmoskovnyy pereulok, 6, Ap.270','Moscow','','RUSSIAN FEDERATION','125130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 12:01:13',0,NULL,3,1,3,1,'RA117732705CN ','i.gabunia\rANCN002+WWOT001\r再发一个NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530'),(3482,784886792012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','compraszeballos','mozovidal.dyo@gmail.com','Oscar Justiniano / Zeballos','2931 NW 26th St','Miami','FL','UNITED STATES','33142-6415','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 12:06:09',0,NULL,3,1,1,1,'、 ','compraszeballos'),(3483,534447061004,140523331018,'New Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',65,'cnfaner','raziel7002','markus.benkert@gmx.net','Markus Benkert','Max-Reger-Straße 1','Ostheim','','GERMANY','97645','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 12:07:12',0,NULL,3,1,3,1,'RA117733277CN ','raziel7002\rMOLO001'),(3484,707379668011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',1,'HSNO008',15,'eastar4','vickygill18','vicky_gill18@yahoo.com.au','Davinder Singh','2/377 Regency Road','Prospect','South Australia','AUSTRALIA','5082','0430230035','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'vickygill18\rECHECK'),(3485,707401624011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','wayne1967','wgalutz@gmail.com','Wayne Galutz','5533 Bingley Ln','Clay','NY','UNITED STATES','13041-9714','(315) 420-0910','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 13:53:36',0,NULL,3,1,1,1,'、 ','wayne1967'),(3486,707414225011,320465511535,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',3.87,'eastar4','hgirllittleb','mattothomas@hotmail.com','Matt Thomas','14023 Halprin Creek','Cypress','TX','UNITED STATES','77429','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 14:33:21',0,NULL,3,1,1,1,'、 ','hgirllittleb'),(3487,577087904013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',23.5,'eastar4','christopher_ms77','christopher_ms@yahoo.com','Christopher Smith','14750 Ries Rd','Venedocia','OH','UNITED STATES','45894-9628','(419) 303-4824','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 14:49:57',0,NULL,3,1,1,1,'、 ','christopher_ms77'),(3488,580956754013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','goopgive','goopgive.ebay@gmail.com','Chalika Jai-Ai','813/29 Kheha Chumchon Nawa Min Moo10 Nawamin Street<br>Khlong Kum Bueng Kum','Bangkok','Thailand','THAILAND','10230','066-834347898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:33:18',0,NULL,3,1,3,1,'RA117732740CN ','goopgive\rBAZA001\r新地址\rMr.Khankorn Punyamanob 263/25 saengthong condo ruamjit rd. Cha-am Phetchaburi 76120 \rThailand\r 0818577047'),(3489,581043974013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',83,'eastar4','bubu742011','resp.esv@gmail.com','bruno piotin','55 ROUTE DE BOSSEY<br>BP 25','COLLONGES-SOUS-SALEVE','Rhône-Alpes','FRANCE','74165','0450436023','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:40:52',0,NULL,3,1,3,1,'RA117731713CN ','bubu742011\rTRTT002*10'),(3490,581047400013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','rxgn','ongwaileong@hotmail.com','waileong ong','Blk 946 Jurong West St 91<br>#07-669','default','','SINGAPORE','640946','+6594766562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:49:59',0,NULL,3,1,11,1,'、 ','rxgn\rCACN004'),(3491,707441716011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','finecard','michael@intelore.com','Mikhail Bolshakov','P.O. BOX 139','Vologda','','RUSSIAN FEDERATION','160000','79115109314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:53:41',0,NULL,8,1,17,0,NULL,'finecard'),(3492,707451265011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','flying_monkey80','victorsoe@hotmail.com','Victor Soe','5 Covepark Bay NE','Calgary','AB','CANADA','T3K6K8','(403) 606-8315','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 16:18:19',0,NULL,3,1,3,1,'RA117732753CN ','flying_monkey80\rRCLO006'),(3493,707455257011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','move_along_now','patbright07@googlemail.com','Pat Bright','101 London Road<br>Marks Tey','Colchester','Essex','UNITED KINGDOM','CO6 1EB','01206212878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 16:29:09',0,NULL,3,1,2,1,'、 ','move_along_now'),(3494,785752879012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','finecard','michael@intelore.com','Mikhail Bolshakov','P.O. BOX 139','Vologda','','RUSSIAN FEDERATION','160000','79115109314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 16:38:26',0,NULL,3,1,2,1,'、 ','finecard\r再发一个Bracket of half intel 5300 6250 wireless card to pci-e'),(3495,707461040011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRMX002',8.55,'eastar4','notadmin','jen140@gmail.com','Yevgen Goncharuk','Rua Nuno Netto De Almeida Nº3 1ºDir.','Santarém','Jardim De Baixo','PORTUGAL','2005-280','967106719','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 16:45:39',0,NULL,3,0,2,1,'、 ','notadmin'),(3496,528779689003,130490590870,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',83,'cnfaner','rakanbi1jel','rakanbi@yahoo.com','robert babs cole','16225 Greenfield apt # 309','detroit','MI','UNITED STATES','48235','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-11 16:50:31',0,NULL,3,1,1,1,'、 ','rakanbi1jel'),(3497,581069295013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',2,'MOSA002',143.94,'eastar4','robertobaggiocalcio','robybrescia_baggio@yahoo.de','Gaetano Cambria Zurro','Marienbaderstr. 2','Hünfelden / Nauheim','','GERMANY','65597','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 17:02:14',0,NULL,3,1,4,1,'YW865907631CN ','robertobaggiocalcio'),(3498,534516385004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','l-1-vaivis','a.vaivods@e-no.lv','Aivars Vaivods','Rigas iela 41-56','Livani','Preilu raj','LATVIA','LV-5316','22370725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 17:08:43',0,NULL,3,1,3,1,'RA117732682CN\r ','l-1-vaivis\rHSNO005\r欧标'),(3499,785791524012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','mariamercedessalcedo','edwardjm50@hotmail.com','maria salcedo','1808 Amethyst St<br>Fl 1','bronx','NY','UNITED STATES','10462-3516','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-11 18:03:25',0,NULL,3,1,1,1,'、 ','mariamercedessalcedo'),(3500,707508457011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',133.99,'eastar4','panocha48','tramoyeres48@hotmail.com','jose tramoyeres sanchez','abenida de las ferias <br>patio 12 puerta 16','valencia','Comunidad Valenciana','SPAIN','46035','96 3641085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 18:31:37',0,NULL,3,1,3,1,'RA117732665CN ','panocha48\rGLSG001*2'),(3501,581099773013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','macman5000','macman1000@web.de','M-Design Berlin Michael Wodtke','Feldtmannstr. 143a','Berlin','','GERMANY','13088','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 18:34:29',0,NULL,3,1,2,1,'、 ','macman5000'),(3502,581100386013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',79.9,'eastar4','musicconsummer','mybuffalo@yandex.ru','Vladimir Sadkovskiy','122 Mira Str.','Krasnodar,village Maryanskaya','','RUSSIAN FEDERATION','353823','7861659651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 18:47:40',0,NULL,3,1,3,1,'RA117731758CN ','musicconsummer\rOTES001'),(3503,581107294013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','superiousblueangel','ebay@bummens.de','Thomas Stein','Beukenweg 21','Vlotho','','GERMANY','32602','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 18:51:21',0,NULL,1,1,2,1,NULL,'superiousblueangel'),(3504,785816712012,220770080684,'Logitech Harmony RF extender 890 pro 1000 1100 90% new',1,'RCLO007',29.99,'eastar4','franka1380','gsbol@upcmail.nl','frank asmus','adriaen van der doeslaan 47','rotterdam','zh','NETHERLANDS','3054 eb','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 18:52:18',0,NULL,3,1,2,1,'、 ','franka1380'),(3505,785827898012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','cj13bny','rben84@yahoo.com','Mircea Talos','Str. Trotusului Nr. 5<br>BL. Y5 Ap. 31','Cluj-Napoca','Cluj','ROMANIA','400621','40742120190','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 19:02:57',0,NULL,4,1,2,1,'','cj13bny\r欧标 paypal 有问题 '),(3506,707528360011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','segreto7','kristinsegreto@gmail.com','kristin segreto','3416 silver meadow way','plant city','FL','UNITED STATES','33566-0724','(813) 458-5776','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 19:07:21',0,NULL,3,1,1,1,'、 ','segreto7'),(3507,581116962013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',23.5,'eastar4','pengguj','pengguj2000@yahoo.com','pengguang jiang','2860 Geer Rd','turlock','CA','UNITED STATES','95382-1141','(209) 668-9988','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 19:15:17',0,NULL,3,1,1,1,'、 ','pengguj'),(3508,581126193013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','rx8-323','gioiuliano@yahoo.com','John Iuliano','1 Hanover rd Cameron Park','Newcastle','New South Wales','AUSTRALIA','2285','0249530664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 19:40:15',0,NULL,3,1,2,1,'、 ','rx8-323'),(3509,707546504011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',2,'HSNO006',29.9,'eastar4','okker3578123','okkerdeklerk@vodamail.co.za','Okker de Klerk','PO Box 1437','KURUMAN','Northern Cape','SOUTH AFRICA','8460','0828290292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 19:43:27',0,NULL,3,1,2,1,'、 ','okker3578123'),(3510,707576466011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',2,'WLAT001+ANTY002',33.98,'eastar4','deaduska','rip1985@mail.ru','Evgenij Shajgam','ul. Sovnarkomovskaja, d.34, kv.157','Nizhnij Novgorod','','RUSSIAN FEDERATION','603086','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 20:50:08',0,NULL,3,1,3,1,'RA117732807CN\r ','deaduska\rWLAT001+ANTY002'),(3511,707577514011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','eeldivad','david@eeldivad.com','David Lee','326 Golden Rod Ln','Auburn','GA','UNITED STATES','30011-3309','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 21:03:57',0,NULL,3,1,1,1,'、 ','eeldivad'),(3512,707610419011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',19.99,'eastar4','alexdems','alex.desmonts@noos.fr','alexandre DESMONTS','3 SQUARE DES ALLOBROGES','VILLIERS SUR MARNE','Île-de-France','FRANCE','94350','0676739815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 22:13:53',0,NULL,3,1,2,1,'、 ','alexdems'),(3513,785929994012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','xyzdave','martindavidson@live.ca','martin davidson','1335 andy','st-hubert','QC','CANADA','J4T1H1','(450) 926-8626','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 22:31:31',0,NULL,3,1,2,1,'、 ','xyzdave'),(3514,785936169012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','scarri20','scarri2016@yahoo.com','Sarah Carrington','300 N 725 W','Orem','UT','UNITED STATES','84057-4511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 22:53:11',0,NULL,3,1,1,1,'、 ','scarri20'),(3515,785936056012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','jahfam2010','jahfam@clearwire.net','jason hietala','1221 E 9th st','duluth','MN','UNITED STATES','55805-1608','(218) 786-0859','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 22:54:39',0,NULL,3,1,1,1,'、 ','jahfam2010'),(3516,707624243011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','maxibons','dannydgolding@gmail.com','Danny Golding','163 Albemarle Road','York','North Yorkshire','UNITED KINGDOM','YO231HD','01904611940','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 23:06:33',0,NULL,3,1,3,1,'RA117732696CN ','maxibons\rMOAP001'),(3517,785957196012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',39.99,'eastar4uk','sylvalab','sgalipeau@videotron.ca','sylvain labrie','261 desbouleaux','charlemagne','QC','CANADA','j5z3z1','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 00:16:44',0,NULL,8,1,17,0,' ','sylvalab\rBAZA001'),(3518,581194959013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','sylvalab','sgalipeau@videotron.ca','sylvain labrie','261 desbouleaux','charlemagne','QC','CANADA','j5z3z1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 00:18:15',0,NULL,3,1,3,1,'RA117732736CN\r ','sylvalab\rBAZA001\r一共买了两个\r与EASTAR4UK 合并'),(3519,707643614011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',10,'CASS003',87,'eastar4','andre.iacono','lorenalive@hotmail.co.uk','Lorena Oliveira','SRTVS, Qd 701 - Bloco K - Sala 725<br>Edificio Embassy Tower','BRasilia','Brasil','BRAZIL','70340908','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 00:32:57',0,NULL,3,1,3,1,'RA117731611CN ','andre.iacono\rCASS003'),(3520,785972804012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','rcwindy','rcwindy@gmail.com','Richard Williams','8709 Orchard Grove Ln','Camby','IN','UNITED STATES','46113-8218','(317) 821-2218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 01:12:33',0,NULL,3,1,1,1,'、 ','rcwindy'),(3521,707658507011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','thanz','jmthanz@yahoo.com','jonathan mariano','DepEd, Pagadian City Division<br>San Jose Heights','pagadian city','zamboanga del sur','PHILIPPINES','7016','9298438569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 01:35:14',0,NULL,3,1,2,1,'、 ','thanz\r银色的'),(3522,785990757012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','caldie226','crcaldie@gmail.com','Christian Caldie','1166 Carmel Cir<br>Apt 420','Casselberry','FL','UNITED STATES','32707-6455','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 02:18:46',0,NULL,3,1,1,1,'、 ','caldie226'),(3523,581223530013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','outbidem_all','harlan@pbdesigns.biz','Harlan Bachmayer','12101 FM 619','Coupland','TX','UNITED STATES','78615-4973','(512) 352-7475','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 02:58:08',0,NULL,3,1,1,1,'、 ','outbidem_all'),(3524,580881482013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','dennisfl3','dstav@bellsouth.net','Dennis Tavares','1810 NW 86th Ave','Pembroke Pines','FL','UNITED STATES','33024-3354','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 03:02:56',0,NULL,3,1,1,1,'、 ','dennisfl3'),(3525,786003720012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',12.5,'eastar4','miriambaby1983','miriam_curtidor@yahoo.com','MIRIAM ESPARZA','17701 avalon blvd<br>spc 203','carson','CA','UNITED STATES','90746','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 03:11:03',0,NULL,3,1,1,1,'\\ ','miriambaby1983\racer 6pin1.25 23cm'),(3526,786012077012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','bfg542','bfg221@yahoo.co.uk','Stephen Coppins','124 Ringway','Waverton','Cheshire','UNITED KINGDOM','CH3 7NR','01244332182','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 03:50:06',0,NULL,3,1,3,1,'RA117731744CN ','bfg542\rHSPL010\r英标\r'),(3527,707687740011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','moviefreak88','barboza@entouch.net','Leslee Barboza','26702 Blanchard Grove Dr','Katy','TX','UNITED STATES','77494-0377','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 03:51:46',0,NULL,3,1,1,1,'、 ','moviefreak88'),(3528,707687978011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','venturarick','venturarick@sbcglobal.net','Rick K Watanabe','2083 Foster Ave','Ventura','CA','UNITED STATES','93001-2419','(805) 653-1378','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 03:54:35',0,NULL,3,1,1,1,'、 ','venturarick'),(3529,707687560011,320617832827,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET BH 500',1,'HSNO015',71.98,'eastar4','tavisakp','tavisak@email.com','Tavisak Poontanes','302 / 64 Lardprao 1 Road,<br>Jormpol, Jatujak,','Bangkok','','THAILAND','10900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 04:00:53',0,NULL,3,1,3,1,'RA117731687CN ','tavisakp\rHSNO015\r一共买了两个'),(3530,786014289012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','reyerwalk','mwalker@alum.mit.edu','Martin Walker','378 Cambridge Ave<br>Suite N','Palo Alto','CA','UNITED STATES','94306-1544','(650) 331-0200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 04:01:27',0,NULL,3,1,1,1,'、 ','reyerwalk'),(3531,707693590011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',2,'HSNO008',30,'eastar4','fabiorbarbosa','fabiobarbosaa@gmail.com','FÁBIO BARBOSA','RUA CARDOSO DE ALMEIDA<br>668 APTO 166','SÃO PAULO','SÃO PAULO','BRAZIL','05013000','551198140834','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 04:25:02',0,NULL,3,1,3,1,'RA117731700CN ','fabiorbarbosa\rHSNO008'),(3532,785560312012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','kings_park','ckwkwong@shaw.ca','Chris Kwong','UBC Okanagan, IT Services<br>3333 Unversity Way','Kelowna','BC','CANADA','V1V 1V7','(250) 807-9149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 04:39:37',0,NULL,3,1,2,1,'、 ','kings_park\r红边优联'),(3533,786033559012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',2,'HSSH002',51.98,'eastar4','sirlonramos','sirlonbaixo@hotmail.com','Amando Ramos','Rua Fortaleza qd 29 lt 03<br>Jd das Esmeraldas','Aparecida de Goiânia','Goias','BRAZIL','74905060','6281275304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 05:47:39',0,NULL,3,1,3,1,'RA117731660CN ','sirlonramos\rHSSH002'),(3534,786043376012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','jacobpank','jacob.pank@gmail.com','Jacob Pankovski','7 Ha-Gai St.','Jerusalem','Israel','ISRAEL','96262','02-6521153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 06:36:08',0,NULL,3,1,2,1,'、 ','jacobpank'),(3535,534688966004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','muratd77murat','donmez-murat@hotmail.com','murat dönmez','124 sok. no:2 sevenyuva apt. K.1 D.1<br>evka-3 Mahalle Bornova','izmir','izmir','TURKEY','35050','+905335069291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 07:13:27',0,NULL,3,1,3,1,'RA117731673CN ','muratd77murat\rHSMO007\r欧标\r'),(3536,581258359013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','gerasinalexander','gerasinao@mail.ru','Gerasin Alexander','District 3, house 1, flat 117','Moscow Area, Leninskiy District, Moskovskiy City','+79262625080','RUSSIAN FEDERATION','142784','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 07:20:16',0,NULL,3,1,3,1,'RA117731695CN ','gerasinalexander\rOTRA001'),(3537,707685755011,320443658204,'New Visenta Wireless keyboard Muti-point Touch pad',1,'KBVI001',101,'eastar4','bahaa_123','ccbc_canada@hotmail.com','BAHAA AL-SILWDI','P.O.BOX 7534 ; THE CANADIAN COMMERCIAL BROKER COMPANY,AIRPORT RD<br>OWEIDAH BUIDING, OFFICE FLOOR # 3','ABU DHABI','','UNITED ARAB EMIRATES','P.O.BOX 7534','(971) 506-4230 ext.: 39','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 08:27:55',0,NULL,3,1,3,1,'RA117731965CN','bahaa_123\rKBVI001\r'),(3538,707737938011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',2,'BALO007',23.4,'eastar4','jeroenjohnny','jeroenbaas@gmail.com','Jeroen Baas','Willem Hedastraat 3','UTRECHT','','NETHERLANDS','3552AN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 08:30:28',0,NULL,3,1,2,1,NULL,'jeroenjohnny\\'),(3539,581273592013,230546985871,'New Motorola H700 Bluetooth Wireless Headset+carcharger',1,'HSMO011+CCMO001',14.99,'eastar4','kimi2005','rklaw@bigpond.com','Kirstie Law','685 Burke Road','Camberwell','Victoria','AUSTRALIA','3113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 09:04:27',0,NULL,3,1,2,1,NULL,'kimi2005\\'),(3540,532427257004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',32.9,'cnfaner','bjarnei','bjaisak@gmail.com','Bjarne Isaksen','Øvre Brennelv','9700 LAKSELV','Finnmark','NORWAY','9700','(047)91574179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 09:23:15',0,NULL,3,1,3,1,'RA117733365CN ','bjarnei\rHSNO003\r欧标'),(3541,786091954012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.49,'eastar4uk','zermattjohn','jmsanderson@gmail.com','John Sanderson','30 Pytha Fold Road','Manchester','Lancashire','UNITED KINGDOM','M20 4UH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 10:00:29',0,NULL,3,1,3,1,'RA117733325CN ','zermattjohn\rRELO002'),(3542,786093714012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','charitysunshine','newyorkhardbody@gmail.com','Charity Edwards','455 EOSS/IN','APO','AE','AA','09352','(716) 200-6107','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 10:08:41',0,NULL,3,1,1,1,'、 ','charitysunshine'),(3543,581283747013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',42.65,'eastar4','lexj2010','222468@mail.ru','Alex Solodyankin','Tipanova 34 korp 3 kv.32','Sankt-Peterburg','','RUSSIAN FEDERATION','196233','79119704264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 10:09:17',0,NULL,3,1,3,1,'RA117727055CN ','lexj2010\rWLIN014\r再发一个Bracket of half intel 5300 6250 wireless card to pci-e\r'),(3544,528985234003,130493270294,'New Sony Ericsson HBH-608 BLUETOOTH HEADSET track#',1,'HSSE007',19.9,'cnfaner','ebuddhika','asankabuddhika@gmail.com','Asanka Alwis','No 190/1<br>Madelgamuwa','Gampaha','Other','SRI LANKA','11000','0094773333117','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 10:13:34',0,NULL,3,1,3,1,'RA117733396CN ','ebuddhika\rHSSE007\r'),(3545,786107947012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',8,'HSPL010',191.2,'eastar4','andi728i','andi.fottner@freenet.de','Firma FBH GmbH A. Fottner','Hirschenhausener Str. 11','Hilgertshausen','','GERMANY','86567','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:03:22',0,NULL,3,1,3,1,'RA117733436CN ','andi728i\r欧标\rHSPL010'),(3546,581294103013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','horsechristy_lynn','christydunkle@zoominternet.net','christy dunkle','203 McFate Rd','pleasantville','PA','UNITED STATES','16341-5203','(814) 589-5334','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-12 11:05:50',0,NULL,3,1,1,1,'、 ','horsechristy_lynn'),(3547,581295304013,230620420999,'NIB GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO029',38.9,'eastar4','tpaje','tristan_paje@hotmail.com','Tristan Paje','Colonial First State<br>Level 23, 52 Martin Place','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:13:15',0,NULL,3,1,3,1,'RA117733263CN ','tpaje\rHSNO029\r澳标\r盒装'),(3548,786114476012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','sjor_bepo','dario.kranjcec@yahoo.com','Dario Kranjčec','Oktavijana Valića 53','Rijeka','primorsko-goranska','CROATIA','51000','+385917623972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:24:41',0,NULL,3,1,2,1,'、 ','sjor_bepo\r欧标'),(3549,707788228011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',8.7,'eastar4','szhu0618','sam.junzhu@gmail.com','Jun Zhu','123 George Street','Scoresby','Victoria','AUSTRALIA','3179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:58:10',0,NULL,3,1,2,1,'、 ','szhu0618'),(3550,707805986011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',15.9,'eastar4','igm1','igor@mmmm.sk','Igor Maly','Palkovicova 16','Bratislava','','SLOVAK REPUBLIC','82108','903404453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 12:58:49',0,NULL,3,1,2,1,'、 ','igm1'),(3551,786152431012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA001',25.59,'eastar4uk','raum2010','raum2000@yandex.ru','Valeriy Smirnov','Kosmonavtov 8-33','Noyabrsk','Russian Federation','RUSSIAN FEDERATION','629802','+7 922 464 8888','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 13:36:34',0,NULL,3,1,3,1,'RA117733379CN ','raum2010\rOTRA001'),(3552,707827905011,320462974714,'2.0 New ASUS Bluetooth Module +cable epc901 epc1000',1,'BTHU2004',12.5,'eastar4','123-kirkp','ianwkirkpatrick@tiscali.co.uk','Ian Kirkpatrick','11 Oaklands Terrace, London Road<br>Kessingland','Lowestoft','Suffolk','UNITED KINGDOM','NR33 7PH','01502740157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 14:10:09',0,NULL,3,1,2,1,'、 ','123-kirkp\r华硕 10 pin 1.0 5cm'),(3553,786181284012,220759518691,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',35.49,'eastar4uk','hmcc7560','peter.mcculloch@homecall.co.uk','Heather Mcculloch','22 Clarence court<br>Weavering','Maidstone','Kent','UNITED KINGDOM','Me14 5up','01622734279','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 14:41:46',0,NULL,3,1,3,1,'RA117727033CN ','hmcc7560\rMOLO001\r'),(3554,786161778012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','pintuzeza','pintu_zeza@yahoo.com','DHARMANTO RAHARDJO','JL FLAMBOYAN NO. 118<br>KOMPLEK KODAM - KEBON JERUK','JAKARTA BARAT','DKI JAKARTA','INDONESIA','11530','08812001568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 15:02:43',0,NULL,3,1,2,1,'、 ','pintuzeza'),(3555,707848429011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','lubiha','lutz.liepelt@arcor.de','Lutz Liepelt','Zum Steinpleiser Bahnhof 2','Werdau','','GERMANY','08412','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 15:13:58',0,NULL,3,1,2,1,'、 ','lubiha'),(3556,707852478011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','dictatorhales','jhales.perth@gmail.com','James Hales','24 Dollis Way Kingsley','Perth','Western Australia','AUSTRALIA','6026','0411664073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 15:25:38',0,NULL,3,0,2,1,'、 ','dictatorhales'),(3557,786199722012,220546791970,'Yagi 16dBi 2.4 GHz 802.11b/g Wifi Antenna RP-SMA',2,'ANYA001',28.9,'eastar4','silver_1976','concordia@ole.com','Francisco Vela Ledesma','c/ Veremundo perera nº 20  1ºdcha','Santa Cruz de Tenerife','Canarias','SPAIN','38006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 15:31:53',0,NULL,3,1,3,1,'RA117731982CN ','silver_1976\rANYA001'),(3558,786230856012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','zversabvbg','zefir@bginfo.net','Zefir Psaryanov','Konstantin Velichkov 34','Burgas','Burgas','BULGARIA','8001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 16:44:57',0,NULL,3,1,2,1,'、 ','zversabvbg'),(3559,784700231012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','neiloppiton','ebay@neilwoolford.co.uk','Neil Woolford','27 York Place','Worcester','Worcestershire','UNITED KINGDOM','WR13DR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 16:53:12',0,NULL,3,1,3,1,'RA117733422CN\r ','neiloppiton\rOTCN003\r'),(3560,786234124012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',34.8,'eastar4','rootphreak','nawcom@nawcom.com','Ben Nawrocki','31600 W 9 Mile Rd<br>Apt 307','Farmington Hills','MI','UNITED STATES','48336-4136','(810) 623-8947','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 16:54:12',0,NULL,3,0,1,1,'、 ','rootphreak'),(3561,581378643013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','enok','ojaiburke@gmail.com','ADRIAN BURKE','2575 Vista Del Mar Dr','Ventura','CA','UNITED STATES','93001-3920','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 17:06:16',0,NULL,3,1,1,1,'、 ','enok'),(3562,534807721004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','sasthaonlinestore','rsganesh@gmail.com','Neela Ganesh','20 South Beach Avenue<br>M.R.C.Nagar, R.A.Puram','Chennai','TN','INDIA','600028','9840385675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 17:28:31',0,NULL,3,1,3,1,'RA117733348CN ','sasthaonlinestore\rHSPL001'),(3563,581385836013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','henry2870','henryfujita@yahoo.com','Henry Fujita','2870 Booth Rd<br># B','Honolulu','HI','UNITED STATES','96813-1140','(808) 533-6658','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 17:31:58',0,NULL,3,1,1,1,'、 ','henry2870'),(3564,707904861011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','hitman593','hitman593@hotmail.com','LUTICK Gregory','62 RUE FOCH<br>appartement 1','IWUY','Nord-Pas-de-Calais','FRANCE','59141','0624633978','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 17:39:19',0,NULL,3,1,2,1,'、 ','hitman593'),(3565,786260011012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','revvon','revkrisvon@aol.com','Kris von Maluski','100 Ochre Point Ave','Newport','RI','UNITED STATES','02840-4149','(401) 481-8887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 17:46:17',0,NULL,3,1,1,1,'、 ','revvon'),(3566,786159815012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','sun-light108','lequanghai@gmx.de','Giamy Le (Tou Chia Mei)','167 / F7 Dayou Rd','Taoyuan','','TAIWAN','330','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 17:55:56',0,NULL,3,1,2,1,'、 ','sun-light108'),(3567,786275166012,220778955222,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',59,'eastar4','sharif_matadar','matadar@bell.blackberry.net','Sharif Matadar','1070 Kos Blvd','Mississauga','ON','CANADA','L5J4L6','(905) 609-6969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 18:18:42',0,NULL,3,1,3,1,'RA117731761CN ','sharif_matadar\rKBFF001'),(3568,707934877011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','tsavdhm_123','tsavdhm@yahoo.gr','DIMITRIOS TSAVTARIDIS','111 PTERYGA MAXHS','NEA AGHIALOS','MAGNISIAS','GREECE','37400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 18:40:33',0,NULL,3,1,2,1,'、 ','tsavdhm_123\r欧标'),(3569,707942347011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','martinh85','3dcoder@gmail.com','Martin Hoffesommer','3246 Deluna Dr','Rancho Palos Verdes','CA','UNITED STATES','90275-6264','(310) 377-1348','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 18:55:49',0,NULL,3,1,1,1,'、 ','martinh85'),(3570,786298013012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',44.23,'eastar4','i.gabunia','igabunia@yandex.ru','Ilya Gabuniya','2-y Novopodmoskovnyy pereulok, 6, Ap.270','Moscow','','RUSSIAN FEDERATION','125130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 19:00:46',0,NULL,3,1,3,1,'RA117727047CN ','i.gabunia\r\r一共买了\r\r（1）一个New genuine Intel WiMAX 6250 622AGXHRU wifi\r（2）一个Triple Tyco Universal Wireless Laptop Antenna Mini PCI\r（3）一个 NEW Sierra WWAN MC8781  +3G antenna\r（4）一个IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781\r（5）两个Bracket of half intel 5300 6250 wireless card to pci-e\r\r\r'),(3571,786314110012,220462732570,'IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781',1,'ANCN003',60.98,'eastar4','i.gabunia','igabunia@yandex.ru','Ilya Gabuniya','2-y Novopodmoskovnyy pereulok, 6, Ap.270','Moscow','','RUSSIAN FEDERATION','125130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 19:24:45',0,NULL,8,0,17,0,NULL,'i.gabunia'),(3572,786330302012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',2,'HSSH001',51.98,'eastar4','sekkebek100','sekkebek@hotmail.com','Jens Kristian Wikstøl','Sentrum','Hægeland','Vest-Agder','NORWAY','4720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 19:56:32',0,NULL,3,1,3,1,'RA117733317CN ','sekkebek100\rHSSH001'),(3573,786335521012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','eastale818','dpmeng@hotmail.com','da meng','8508 Frandsen St','San Gabriel','CA','UNITED STATES','91776-2020','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 20:03:43',0,NULL,3,1,1,1,'、 ','eastale818\r红边优联'),(3574,786341721012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',2,'HSSH001',51.98,'eastar4','sirlonramos','sirlonbaixo@hotmail.com','Amando Ramos','Rua Fortaleza qd 29 lt 03<br>Jd das Esmeraldas','Aparecida de Goiânia','Goias','BRAZIL','74905060','6281275304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 20:24:23',0,NULL,3,1,3,1,'RA117733382CN ','sirlonramos\rHSSH001'),(3575,786362400012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','jc.berna525','joao.carlos@giacomini.net.br','Joao Carlos Giacomini','R. Antonia Bizarro, 70<br>apto 112','Osasco','São Paulo','BRAZIL','06083-160','55 11 99530714','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 20:59:17',0,NULL,3,1,3,1,'RA117733453CN ','jc.berna525\rHSPL010'),(3576,786365527012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','dwagner222','dave.wagner.art@gmail.com','David Wagner','275 Sprowl Creek Rd','Garberville','CA','UNITED STATES','95542-3305','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 21:03:57',0,NULL,3,1,1,1,'、 ','dwagner222'),(3577,786324592012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','gushart','ghartmann2@gmail.com','Cory Hartmann','904 Harrison Ave','South Bend','IN','UNITED STATES','46616-1217','(512) 826-1765','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 21:18:43',0,NULL,3,1,1,1,'、 ','gushart\r红边优联'),(3578,534889623004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','hofharili','harald.hofstadler@liwest.at','Harald Hofstadler','Peuerbachstr. 23','Linz','','AUSTRIA','4040','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 21:46:18',0,NULL,3,1,3,1,'RA117733405CN ','hofharili\rHSNO022\r欧标\r'),(3579,708022898011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','januzi.2009','gani.januzi@hotmail.co.uk','gani januzi','129 blenheim court<br>navestock crescent','woodford green','Essex','UNITED KINGDOM','ig8 7bb','07930416324','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 21:53:55',0,NULL,3,1,3,1,'RA117733351CN ','januzi.2009\rUDAP001\r'),(3580,671986508001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','pele10eng','pele10eng@hotmail.com','Vladislav Petkovic','3214 Hornbeam Crescent','Mississauga','ON','CANADA','L5L 1B4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 21:55:01',0,NULL,3,1,3,1,'RA117733334CN ','pele10eng\rOTSO001'),(3581,708024044011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','i.gabunia','igabunia@yandex.ru','Ilya Gabuniya','2-y Novopodmoskovnyy pereulok, 6, Ap.270','Moscow','','RUSSIAN FEDERATION','125130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 21:57:03',0,NULL,8,0,17,0,NULL,'i.gabunia'),(3582,708024759011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','buildandtest','kkyip1@gmail.com','Kenneth Yip','45 E 89th St<br>Apt 32B','New York','NY','UNITED STATES','10128-1231','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 22:01:50',0,NULL,3,1,1,1,'、 ','buildandtest'),(3583,786417303012,220778910015,'NIB Samsung SSG-P2100S Starter Kit Two 3D Glasses',1,'GLSG002',158.99,'eastar4','tex_rasco','mtr_rasco@yahoo.com','Mike Rasco','476 NW County Road 3140','Purdon','TX','UNITED STATES','76679-3049','(254) 578-3878','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 23:43:40',0,NULL,3,1,1,1,'、 ','tex_rasco'),(3584,581503173013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','amanda112699','almad_2003@yahoo.com','almadelia escobar','5328 monterey rd suite c','san jose','CA','UNITED STATES','95111','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 00:19:27',0,NULL,1,1,1,1,NULL,'amanda112699'),(3585,708060766011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','pete7476','ben1297@cox.net','Ben Owen','452 Fort Worth ST','Hampton','Va','UNITED STATES','23669','(757) 851-3702','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 00:22:36',0,NULL,3,1,1,1,'、 ','pete7476'),(3586,581505834013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','cheeho04','cheeho04@yahoo.com','Chee Ho Wong','A17<br>212 State Highway 17','Albany','Auckland','NEW ZEALAND','0632','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 00:34:19',0,NULL,3,1,3,1,'RA117733440CN ','cheeho04\rBAZA001\r'),(3587,786480133012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','ahmedk3333','koitas2000@yahoo.com','AHMED KOITA','2100 Tiebout Ave<br>Apt 403','bronx','NY','UNITED STATES','10457-3162','(718) 295-6867','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 03:57:08',0,NULL,3,1,1,1,'、 ','ahmedk3333\r单机 发之前好好测试'),(3588,708127911011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','caxe13','caxe13@yahoo.com','Tommy Honton','1411 W Kenneth Rd #A','Glendale','CA','UNITED STATES','91201','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 05:58:01',0,NULL,3,1,1,1,'\\ ','caxe13'),(3589,708138326011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','arveni85','arven_c@hotmail.com','arven cuko','Rr.\"Kongresi Manastirit\" Internet Cajupi perball shkolles Cajupi','tirane','tirane','ALBANIA','00000','00355672159964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 06:51:35',0,NULL,3,1,2,1,'、 ','arveni85'),(3590,708140067011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',2,'ANTY001*3',7.16,'eastar4','max12365','malhashem111@gmail.com','Mahmoud A Alhashem','3375 SE Shoreline Dr','Corvallis','OR','UNITED STATES','97333-3197','(541) 602-7780','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 07:00:26',0,NULL,3,0,1,1,'、 ','max12365'),(3591,708141645011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001×2',267.98,'eastar4','055saxon','macandjo4@bigpond.com','Ross Mckinnon','22 Brotherglen drive','Kew','New South Wales','AUSTRALIA','2439','0265590296','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 07:07:46',0,NULL,3,1,6,1,'EE520583321CN ','055saxon\r加到这行了'),(3592,708146270011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','ldk-xz','hw@hw-computer.de','Harry Weber','Solmserstr. 6','Waldsolms','','GERMANY','35647','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 07:30:39',0,NULL,3,1,2,1,'\\ ','ldk-xz'),(3593,784737853012,220763389064,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',26,'eastar4uk','kicsishaman','vidaj@tvnetwork.hu','Vida János','Kecskeméti utca 1','default','','HUNGARY','6723','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 08:06:25',0,NULL,3,1,3,1,'RA117727775CN ','kicsishaman\rWWSI002+ANCN001\r加到这行了'),(3594,581574313013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','jrudnickis','j.rudnickis@clear.net.nz','FOR JURIJS RUDNICKIS (TO COLLECT)','C/O NZ POST SHOP MIRAMAR<br>67 MIRAMAR AVENUE, MIRAMAR','WELLINGTON 6022 (027) 2976341','NORTH ISLAND, NEW ZEALAND','NEW ZEALAND','6022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 08:11:02',0,NULL,3,1,2,1,'\\ ','jrudnickis'),(3595,526699965003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','2682ensor','j.gettmann@web.de','johannes Gettmann','Benzweg 5','Darmstadt','','GERMANY','64293','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 08:11:23',0,NULL,3,1,3,1,'RA117727095CN ','2682ensor\rMOSA002\r加到这行了'),(3596,786537793012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.98,'eastar4','mpr312kadir','bympr312@hotmail.com','kadir dinçer','Yenibağlar mah<br>Ömür Sok No: 17','BURSA','osmangazi / BURSA','TURKEY','16160','5345991392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 08:34:54',0,NULL,3,1,2,1,'\\ ','mpr312kadir'),(3597,581579085013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','connectic','connectic7@gmail.com','Andrei Janajev','Katleri 17- 73','Tallinn','Haarjumaa','ESTONIA','13915','+37255545416','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 08:42:00',0,NULL,3,1,2,1,'\\ ','connectic\r黑色的'),(3598,708166426011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','stevestr1ke','stevestr1ke@yahoo.com','Steve Strykowski','69 Merrimac St','Laconia','NH','UNITED STATES','03246-3864','(603) 738-0544','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 09:03:21',0,NULL,0,0,1,0,NULL,'stevestr1ke'),(3599,786545306012,220462732570,'IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781',1,'ANCN003',20.99,'eastar4','s.kamenskih','skamenskih@gmail.com','Sergey Kamenskikh','Leninskij pr., d. 79, k.2, kv. 318','Saint-Petersburg','RU','RUSSIAN FEDERATION','198332','(921) 9464710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 09:06:39',0,NULL,3,1,2,1,NULL,'s.kamenskih\\'),(3600,708185180011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','jamusjae','jamusjae@talk21.com','jamus wood','240 mina road<br>st werburghs','Bristol','Bristol','UNITED KINGDOM','BS29YP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:28:13',0,NULL,0,1,3,0,NULL,'jamusjae\rMOAP001'),(3601,786578729012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','tommi123_37','tommi123_37@hotmail.com','Tommy Nichols','31 Bourne drive<br>Langley Mill','Nottingham','Nottinghamshire','UNITED KINGDOM','NG164BJ','07511156471','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 11:11:54',0,NULL,0,1,2,0,NULL,'tommi123_37'),(3602,784946594012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','leventsd11','levent.dikmen@deu.edu.tr','levent Dikmen','Dokuz Eylul Univercity IIBF Bilgi Islem<br>Dokuzcesmeler - Buca','IZMIR','','TURKEY','35124','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 11:12:40',0,NULL,0,1,2,0,NULL,'leventsd11'),(3603,708221743011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','sell_stuff_today','plewis00_uk@yahoo.co.uk','Peter Lewis','BPD, 1 The Belfry<br>4400 Parkway','Whiteley','Hampshire','UNITED KINGDOM','PO15 7FJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 12:41:23',0,NULL,0,1,2,0,NULL,'sell_stuff_today'),(3604,581628685013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','secodu','g.raichev@gmail.com','George Raichev','3 Kraishte str.<br>Rozeli cofee shop','Sofia','Bulgaria','BULGARIA','1504','359 895 655 555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 13:12:54',0,NULL,0,1,2,0,NULL,'secodu'),(3605,581638163013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',27,'eastar4','sergifcsergio','sergifc@gmail.com','sergio cavaco','rua aquiles monteverde n28 6dto','Lisboa','Lisboa','PORTUGAL','1000-018','961128652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 13:53:47',0,NULL,0,1,2,0,NULL,'sergifcsergio\r一共买了两个\r欧标'),(3606,581639286013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','andru*2011','andru6a@bk.ru','Andrey Nikishin','Sheremetievskaya 19-2-149','Moscow','Moscow','RUSSIAN FEDERATION','127521','+79031059699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 14:05:26',0,NULL,0,1,2,0,NULL,'andru*2011'),(3607,581649904013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','servingthecreator08','rdrye78@yahoo.com','Dottie Rye','676 Durham Rd','Adams','TN','UNITED STATES','37010-9007','(931) 933-5600','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 14:43:15',0,NULL,0,1,1,0,NULL,'servingthecreator08'),(3608,786647204012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','joejoe803','oliver.joe64@yahoo.com','joe oliver','3665 heritage ct','oxford','NC','UNITED STATES','27565-6512','(803) 460-0313','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 14:50:43',0,NULL,0,1,1,0,NULL,'joejoe803'),(3609,786663701012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','perchiehouse','islander@ntlworld.com','nicholas friendlay','51, Sidney Rd','Walton-On-Thames','Surrey','UNITED KINGDOM','KT12 2LZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 15:27:23',0,NULL,0,1,3,0,NULL,'perchiehouse\rHSPL010\r英标'),(3610,786667575012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','nhritz','nhritz@hotmail.com','Nick Hritz','606 Rittenhouse St NW','Washington','DC','UNITED STATES','20011-1239','(571) 232-9152','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 15:38:45',0,NULL,0,1,1,0,NULL,'nhritz'),(3611,708279508011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','risingsn','tony@risingsuntechnologies.com','Tony Davis','7524 Baird Way','Citrus Heights','CA','UNITED STATES','95610','(916) 485-2998','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 15:39:50',0,NULL,0,1,1,0,NULL,'risingsn'),(3612,786673015012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',47.8,'eastar4','wozniakr','robert11415@gmail.com','Robert Wozniak','8110 135th St<br>Apt 519','Briarwood','NY','UNITED STATES','11435-1048','(718) 825-4796','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 15:52:34',0,NULL,0,1,1,0,NULL,'wozniakr'),(3613,708305228011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',25.96,'eastar4','enescobedo','enrique_escobedo@transalta.com','Enrique Escobedo','4501B Golf Course Road Apt 309','Stony Plain','AB','CANADA','T7Z2N4','(780) 499-8951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 16:52:13',0,NULL,0,1,2,0,NULL,'enescobedo\r一共买了两个'),(3614,705413516011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','sdodang15','sdodang@online.fr','DO Dang Son','25 rue Pasteur','BRUNOY','Essonne','FRANCE','91800','0688071814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 17:02:17',0,NULL,0,1,3,0,NULL,'sdodang15\rRCLO007+POLO001+RCLO008*4'),(3615,786711192012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','foxhound27','ivt@georgetown.edu','Ivo Tchernev','8727 Harding','Skokie','IL','UNITED STATES','60076','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 17:28:29',0,NULL,0,1,1,0,NULL,'foxhound27'),(3616,786721271012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','hoveringmallard','gaviens@gmail.com','Gerard Viens','645 Flagstaff Drive','Wyoming','OH','UNITED STATES','45215','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 17:46:51',0,NULL,0,1,1,0,NULL,'hoveringmallard'),(3617,581711668013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','napple252','ncapple24@yahoo.com','DEBBIE BAGGETT','148 Godwin Town Rd','AHOSKIE','NC','UNITED STATES','27910-9455','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 18:27:55',0,NULL,0,1,1,0,NULL,'napple252'),(3618,786745065012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','boubeth','litteautr@gmail.com','Robin LITTEAUT','12 Avenue Auguste Renoir','Marly le roi','Ile-de-France','FRANCE','78160','+33670894638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 18:37:47',0,NULL,0,1,2,0,NULL,'boubeth'),(3619,581716163013,230393459225,'2.1 New Acer Timeline 3810 3810T Bluetooth Module+cable',1,'BTAC2118',12.43,'eastar4','molacacho','valverman@hotmail.com','Jesus Valverde Romero','C/ Pensamiento, 27, esc. dcha. 7º 1','Madrid','Madrid','SPAIN','28020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 18:42:48',0,NULL,0,1,2,0,NULL,'molacacho\racer 8pin1.0 3cm'),(3620,708356237011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',28.49,'eastar4','glen5958','steyn01@hughes.net','Glen Steyn','15844 Lambert Rd','Saint Marys','OH','UNITED STATES','45885-9202','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 18:58:15',0,NULL,0,1,1,0,NULL,'glen5958'),(3621,581726279013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','matfaub','matfaubert@hotmail.com','Mathieu  Faubert','16585 ave Lajoie','Saint-Hyacinthe','QC','CANADA','J2T3J7','(450) 768-4747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 19:11:47',0,NULL,1,1,2,0,NULL,'matfaub'),(3622,708366741011,320552968178,'New Motorola HS810 Bluetooth Wireless Headset HS-810',1,'HSMO017',20.99,'eastar4','agekai','hermann.foester@versanet.de','Föster Hermann','Rebell 12','Meschede','','GERMANY','59872','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 19:22:19',0,NULL,0,1,2,0,NULL,'agekai\r欧标'),(3623,581732736013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','csrcarlson','tom@nmpcmd.com','tom carlson','344 aliso dr ne','albuquerque','NM','UNITED STATES','87108','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 19:34:46',0,NULL,0,1,1,0,NULL,'csrcarlson'),(3624,708379279011,320694423879,'NIB Samsung SSG-2200KR Rechargeable Child 3D Glasses',1,'GLSG003',89,'eastar4','lombricultura0','jmmatiu@hotmail.com','Juan Monserrat','Dean Funes 226<br>Castelar','Buenos Aires','Buenos Aires','ARGENTINA','1712','1561477848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 19:52:50',0,NULL,0,1,3,0,NULL,'lombricultura0\rGLSG003'),(3625,581741731013,230545855021,'2.1 Acer TM 3000 3020 /AS5760 Bluetooth Module+cable',1,'BTAC2126',12.43,'eastar4','raponchito','jc.naranjo@terra.es','Jair Naranjo','C/ Leon y Castillo, 128 - Local Comercial','Las Palmas de Gran Canaria','Las Palmas','SPAIN','35004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 20:00:41',0,NULL,0,1,2,0,NULL,'raponchito\racer 8pin1.25 10cm '),(3626,786807849012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',129.69,'eastar4','draken177','lukasmbm@hotmail.com','Lucas Bezerra','Avenida Ailton Gomes, 3204','Juazeiro do Norte','Ceará','BRAZIL','63020-000','88-35713708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 20:49:16',0,NULL,0,1,3,0,NULL,'draken177\r再发一个New in box genuine SONY 3D Active Glasses TDG-BR100'),(3627,786817200012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','grayle70','pilgrim7000@gmail.com','Jerry  San Jose','2126 Glenbrook Ave','Camarillo','CA','UNITED STATES','93010-1926','(805) 987-1179','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 21:10:04',0,NULL,0,1,1,0,NULL,'grayle70\r红边优联'),(3628,786824704012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','organphil','philipbrk584@gmail.com','Philip Burke','202 Misty Point Ln','Newport News','VA','UNITED STATES','23603-1441','(757) 369-0693','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 21:28:41',0,NULL,0,1,1,0,NULL,'organphil\r红边优联'),(3629,708432044011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','tigersbd','masudy2k@hotmail.com','Masud Rahman','909 Laurel Meadow Dr','FORT MILL','SC','UNITED STATES','29708-7891','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 21:59:36',0,NULL,4,1,1,0,NULL,'tigersbd\r客户可能要退款撤单'),(3630,581780419013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','d12aurorarichard','d12aurora@hotmail.com','Richard Desruisseaux','PO Box 292<br>9 Birch st','Greenwood','NS','CANADA','B0P1N0','(902) 840-0814','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'d12aurorarichard'),(3631,581781638013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','hrissan','hrissan@mail.ru','Grigory Buteyko','Sadovaya 90 kv 10','Sankt-Peterburg','','RUSSIAN FEDERATION','190121','+7(921)986-93-21','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 22:30:04',0,NULL,0,1,2,0,NULL,'hrissan'),(3632,786871697012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','yvette-b','yvettebonnet@hotmail.com','Yvette Bonnet','16301 Englewood Ave','Los Gatos','CA','UNITED STATES','95032','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 00:08:11',0,NULL,0,1,1,0,NULL,'yvette-b'),(3633,535188690004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','viensm','marcviens@videotron.ca','Marc Viens','1477 Louis-Francoeur','Québec','QC','CANADA','g1y 1n7','(418) 653-7012','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 00:14:43',0,NULL,0,1,3,0,NULL,'viensm\rOTGR002'),(3634,708466208011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','austink','laustinthought@gmail.com','Austin Karpola','1438 N Greenview Ave<br>Frnt 3F','Chicago','IL','UNITED STATES','60642-6784','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 00:19:26',0,NULL,0,1,1,0,NULL,'austink'),(3635,786879987012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',2,'HSSH001',51.98,'eastar4','ericf9385','efx88@sbcglobal.net','Mary Eilzabeth Pettinelli','7123 N Paulina St<br>Apt 3N','Chicago','IL','UNITED STATES','60626-2550','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 00:48:17',0,NULL,0,1,1,0,NULL,'ericf9385'),(3636,786881635012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','arpi','rpvarga@msn.com','Arpad Varga','139 S 100 E','American Fork','UT','UNITED STATES','84003','(801) 756-5099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 00:51:00',0,NULL,0,1,2,0,NULL,'arpi'),(3637,708483414011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','pig_meat','nickpotter@netspace.net.au','Nicholas Potter','PO Box 2064','Fitzroy M.D.C.','Victoria','AUSTRALIA','3065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 01:42:14',0,NULL,0,1,2,0,NULL,'pig_meat'),(3638,786894036012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',12.5,'eastar4','m0rd0','nat@manic-cabbage.com','Nathanael Dyke','Hewlett Packard, Bld 1<br>Longdown Avenue, Stoke Gifford','Bristol','Avon','UNITED KINGDOM','BS34 8QZ','07747467457','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 01:45:38',0,NULL,0,1,2,0,' ','m0rd0\racer 8pin1.00 8cm'),(3639,786895460012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','walleyenutts','timkluss007@yahoo.com','Tim Kluss','405 Markham Rd','Eagle','WI','UNITED STATES','53119-2207','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 01:57:40',0,NULL,0,1,1,0,NULL,'walleyenutts'),(3640,535203624004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','auctionmaster111','auctionmaster111@gmail.com','Wing Lau','68 Warraroong Street','Beverly Hills,  Sydney','New South Wales','AUSTRALIA','2209','0411253710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 02:00:23',0,NULL,0,1,3,0,NULL,'auctionmaster111\rBALO007'),(3641,581686472013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',2,'BTHP2107',24.86,'eastar4','rccomputer33','rcraney@live.com','Richard Raney','PO Box 1881<br>112 Ohio','Bloomfield','NM','UNITED STATES','87413-1881','(505) 860-5225','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 04:29:01',0,NULL,0,1,1,0,NULL,'rccomputer33\rHP 8pin 1.0 23cm '),(3642,535226855004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','geduc2010','gatucristian@yahoo.com','Gatu Cristian','Stefan cel mare, 199, E, 13','Vaslui','Vaslui','ROMANIA','730006','+40335401562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 05:03:38',0,NULL,0,1,3,0,NULL,'geduc2010'),(3643,786936298012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','caitudo74','molotov1976@yahoo.com','Cesar Lopez','952 east 112th st','Los Angeles','CA','UNITED STATES','90059','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 05:27:50',0,NULL,0,1,1,0,NULL,'caitudo74'),(3644,786936769012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','ramiro123','ramirofuentes@msn.com','Ramiro Fuentes','14787 Valley View Dr','Mount Vernon','WA','UNITED STATES','98273-3279','(360) 848-1625','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 05:28:54',0,NULL,0,1,1,0,NULL,'ramiro123'),(3645,581845412013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','amy*eden','amyeden30@yahoo.com','Amy Eden','12200 Newgard ave','Sylmar','CA','UNITED STATES','91342-5059','(818) 675-6648','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 05:45:04',0,NULL,0,1,1,0,NULL,'amy*eden'),(3646,786949244012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','tiasaff','tiasaff@ntlworld.com','debbie marchant','130 coventry road','ilford','Essex','UNITED KINGDOM','ig1 4rg','02082205626','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-14 06:35:00',0,NULL,0,1,3,0,NULL,'tiasaff'),(3647,581852957013,230504995230,'New Motorola H670 Bluetooth Wireless Headset H 670',1,'HSMO010',14.99,'eastar4','rafalow','rafalow@zonnet.nl','R Kuipers','dassenbos 116','Hoofddorp','Nh','NETHERLANDS','2134RH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 06:40:48',0,NULL,0,1,2,0,NULL,'rafalow\r黑色的'),(3648,708536144011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','francis9118','michellefrancis@wanadoo.fr','francis lempereur','50 rue Hallé','HAMEL','Nord-Pas-de-Calais','FRANCE','59151','0327922916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 06:54:23',0,NULL,0,1,2,0,NULL,'francis9118'),(3649,581894673013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','krimson_dk','jesper@krimson.dk','Jesper Kleis Jensen','Havdrupvej 26','Brønshøj','','DENMARK','2700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 10:51:40',0,NULL,0,1,2,0,NULL,'krimson_dk'),(3650,708602408011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','dolphin270479','jazzy001@hotmail.co.uk','Christine Beman','34 Hillborough Road','Westcliff on Sea','Essex','UNITED KINGDOM','SS0 0SA','07970015387','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-14 11:06:57',0,NULL,0,0,0,0,NULL,'dolphin270479'),(3651,581899232013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',107.97,'eastar4','huszar.adam','oregonlogos@gmail.com','Ádám Huszár','István 41','Gyöngyöstarján','Heves','HUNGARY','3036','+36204474046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 11:08:41',0,NULL,0,1,3,0,NULL,'huszar.adam\rWWSI005'),(3652,581908345013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','danielelel27','bassindaniel@gmail.com','Daniel Bassin','Kibutz Kfar-aza 85142','Kfar-aza','ID','ISRAEL','85142','972506344103','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 11:52:57',0,NULL,0,0,0,0,NULL,'danielelel27'),(3653,708625595011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','amanolar','aristos@manolarakis.gr','Aristos Manolarakis','Odos Blyxadas<br>Pano apo tavern Haris','Kato Gouves','Heraklion Crete','GREECE','70014','00306944456620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 12:27:09',0,NULL,0,0,0,0,NULL,'amanolar'),(3654,787061821012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','jurica1976','jurica.stojkovic1@zg.t-com.hr','Jurica Stojkovic','Skolska 6','Novoselec','','CROATIA','10315','0912385194','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 13:03:05',0,NULL,0,0,0,0,NULL,'jurica1976'),(3655,535270466004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','del1riouz','lipteh@usa.com','Lip Gen Teh','8 Nardina Crescent','Dalkeith','Western Australia','AUSTRALIA','6009','0893865263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 14:14:05',0,NULL,0,0,0,0,NULL,'del1riouz'),(3656,581945004013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','rajiv61','rajivpooja@yahoo.com','Rajiv Ramrakhiani','3611 Chimney Rock Dr','Carrollton','TX','UNITED STATES','75007-2785','(504) 355-9999','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 14:25:44',0,NULL,0,0,0,0,NULL,'rajiv61'),(3657,708669236011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','hmadah','hmadah1384@hotmail.com','Hala Maddah','Flat 6, Watervale<br>Vale Farm Road','Woking','Surrey','UNITED KINGDOM','GU21 6AB','07882697666','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-14 14:31:07',0,NULL,0,0,0,0,NULL,'hmadah'),(3658,708697363011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','isadore529','johneforges@hotmail.com','Johne Forges','12241 Fairfield House Dr<br>Apt 311','Fairfax','VA','UNITED STATES','22033-3954','(202) 746-6348','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 15:38:07',0,NULL,0,0,0,0,NULL,'isadore529');
/*!40000 ALTER TABLE `hmsh_ebay_eastar_transaction` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_itemstatus`
--

DROP TABLE IF EXISTS `hmsh_ebay_itemstatus`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_itemstatus` (
  `id` int(10) unsigned NOT NULL,
  `description` varchar(255) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_itemstatus`
--

LOCK TABLES `hmsh_ebay_itemstatus` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_itemstatus` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_itemstatus` VALUES (0,'NA'),(1,'Ready for Packaging');
/*!40000 ALTER TABLE `hmsh_ebay_itemstatus` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_shippingmethod`
--

DROP TABLE IF EXISTS `hmsh_ebay_shippingmethod`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_shippingmethod` (
  `id` int(10) unsigned NOT NULL,
  `index` int(11) NOT NULL,
  `Shipper` varchar(255) DEFAULT NULL,
  `description` varchar(255) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_shippingmethod`
--

LOCK TABLES `hmsh_ebay_shippingmethod` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_shippingmethod` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_shippingmethod` VALUES (0,0,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® '),(1,1,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® '),(2,2,'新加坡小包平邮 ','新加坡小包平邮'),(3,3,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® '),(4,4,'燕文','燕文'),(5,5,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® '),(6,6,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® '),(7,7,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® '),(8,8,'航空大包','航空大包'),(9,9,'新加坡小包平邮','新加坡小包平邮'),(10,10,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® '),(11,11,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® '),(12,12,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® '),(13,13,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® '),(14,14,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® '),(15,15,'æ–°åŠ å¡å°åŒ…å¹³é‚® ','æ–°åŠ å¡å°åŒ…å¹³é‚® ');
/*!40000 ALTER TABLE `hmsh_ebay_shippingmethod` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_sku_item`
--

DROP TABLE IF EXISTS `hmsh_ebay_sku_item`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_sku_item` (
  `id` int(8) NOT NULL AUTO_INCREMENT,
  `sku` varchar(255) NOT NULL,
  `item_id` bigint(20) NOT NULL,
  `quantity` int(8) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=4871 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_sku_item`
--

LOCK TABLES `hmsh_ebay_sku_item` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_sku_item` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_sku_item` VALUES (1,'AB2208',100001,1),(2,'AB2209',100002,1),(3,'AB2210',100003,1),(4,'AB2211',100004,1),(5,'AB2212',100005,1),(6,'AB2214',100006,1),(7,'AA3201',100007,1),(8,'AA3202',100008,1),(9,'AA3203',100009,1),(10,'AA3204',100010,1),(11,'AA3205',100011,1),(12,'AA3206',100012,1),(13,'AA3207',100013,1),(14,'AA3208',100014,1),(15,'AA3209',100015,1),(16,'AA3210',100016,1),(17,'AA3211',100017,1),(18,'AA3212',100018,1),(19,'AA3229',100019,1),(20,'AA3213',100020,1),(21,'AA3214',100021,1),(22,'AA2219',100022,1),(23,'AA2220',100023,1),(24,'AA2221',100024,1),(25,'AA3218',100025,1),(26,'AA3219',100026,1),(27,'AA3220',100027,1),(28,'AA3221',100028,1),(29,'AA3222',100029,1),(30,'AA3223',100030,1),(31,'AA3224',100031,1),(32,'AA3225',100032,1),(33,'AA3226',100033,1),(34,'AA3227',100034,1),(35,'AA3228',100035,1),(36,'AA2201',100036,1),(37,'AA2202',100037,1),(38,'AA2203',100038,1),(39,'AA2204',100039,1),(40,'AA2205',100040,1),(41,'AA2206',100041,1),(42,'AB3301',100042,1),(43,'AB3303',100043,1),(44,'AB3305',100044,1),(45,'AB3317',100045,1),(46,'AB3307',100046,1),(47,'AB3309',100047,1),(48,'AB3311',100048,1),(49,'AB3313',100049,1),(50,'AB3315',100050,1),(51,'AB3318',100051,1),(52,'AB3319',100052,1),(53,'AB3320',100053,1),(54,'AB3321',100054,1),(55,'AB3325',100055,1),(56,'AB3326',100056,1),(57,'AB3322',100057,1),(58,'AB3323',100058,1),(59,'AB3324',100059,1),(60,'AB3302',100060,1),(61,'AB3304',100061,1),(62,'AB3306',100062,1),(63,'AB3308',100063,1),(64,'AB3310',100064,1),(65,'AB3312',100065,1),(66,'AB3314',100066,1),(67,'AB3327',100067,1),(68,'AB3328',100068,1),(69,'AB3329',100069,1),(70,'AB3330',100070,1),(71,'AB3331',100071,1),(72,'AB3332',100072,1),(73,'AA3301',100073,1),(74,'AA3302',100074,1),(75,'AA3303',100075,1),(76,'AA3304',100076,1),(77,'AA3305',100077,1),(78,'AA3306',100078,1),(79,'AA3307',100079,1),(80,'AA3308',100080,1),(81,'AA3309',100081,1),(82,'AA3310',100082,1),(83,'AA3311',100083,1),(84,'AA3312',100084,1),(85,'AA3313',100085,1),(86,'AA3314',100086,1),(87,'AE2301',100087,1),(88,'AE2302',100088,1),(89,'AE2303',100089,1),(90,'AE2304',100090,1),(91,'AE2305',100091,1),(92,'AE2306',100092,1),(93,'AE2307',100093,1),(94,'AE2308',100094,1),(95,'AE2309',100095,1),(96,'AE2310',100096,1),(97,'AE2311',100097,1),(98,'AE2312',100098,1),(99,'AE2313',100099,1),(100,'AE2314',100100,1),(101,'AA3315',100101,1),(102,'AA3316',100102,1),(103,'AA3317',100103,1),(104,'AA3318',100104,1),(105,'AA3319',100105,1),(106,'AA3320',100106,1),(107,'AA3321',100107,1),(108,'AE3201',100108,1),(109,'AE3202',100109,1),(110,'AE3203',100110,1),(111,'AE3204',100111,1),(112,'AE3205',100112,1),(113,'AE3206',100113,1),(114,'AE3207',100114,1),(115,'AE3208',100115,1),(116,'AE3209',100116,1),(117,'AE3210',100117,1),(118,'AE3211',100118,1),(119,'AE3212',100119,1),(120,'AE3213',100120,1),(121,'AE3214',100121,1),(122,'AE3215',100122,1),(123,'AE3216',100123,1),(124,'AE3217',100124,1),(125,'AE3218',100125,1),(126,'AE3219',100126,1),(127,'AE3220',100127,1),(128,'AE3221',100128,1),(129,'AE3222',100129,1),(130,'AE3223',100130,1),(131,'AE3224',100131,1),(132,'AE3225',100132,1),(133,'AE3226',100133,1),(134,'AE3227',100134,1),(135,'AE3228',100135,1),(136,'AA2301',100136,1),(137,'AA2302',100137,1),(138,'AA2303',100138,1),(139,'AA2304',100139,1),(140,'AA2305',100140,1),(141,'AA2306',100141,1),(142,'AA2307',100142,1),(143,'AA2308',100143,1),(144,'AA2309',100144,1),(145,'AA2310',100145,1),(146,'AA2311',100146,1),(147,'AA2312',100147,1),(148,'AA2313',100148,1),(149,'AA2314',100149,1),(150,'AA2315',100150,1),(151,'AA2207',100151,1),(152,'AA2208',100152,1),(153,'AA2209',100153,1),(154,'AA2210',100154,1),(155,'AA2211',100155,1),(156,'AA2212',100156,1),(157,'AA2213',100157,1),(158,'AA2214',100158,1),(159,'AA2222',100159,1),(160,'AA2215',100160,1),(161,'AA2216',100161,1),(162,'AA2316',100162,1),(163,'AA2317',100163,1),(164,'AA2318',100164,1),(165,'AA2319',100165,1),(166,'AA2320',100166,1),(167,'AA2322',100167,1),(168,'AA2321',100168,1),(169,'AA2323',100169,1),(170,'AA2324',100170,1),(171,'AA2325',100171,1),(172,'AE2315',100172,1),(173,'AE2316',100173,1),(174,'AE2317',100174,1),(175,'AA2326',100175,1),(176,'AE2318',100176,1),(177,'AE1201',100177,1),(178,'AE1202',100178,1),(179,'AE1203',100179,1),(180,'AB1301',100180,1),(181,'AB1302',100181,1),(182,'AB1303',100182,1),(183,'AB1304',100183,1),(184,'AB1305',100184,1),(185,'AB1306',100185,1),(186,'AB1307',100186,1),(187,'AA3401',100187,1),(188,'AA3402',100188,1),(189,'AA3403',100189,1),(190,'AA3404',100190,1),(191,'AA3405',100191,1),(192,'AA3406',100192,1),(193,'AA3407',100193,1),(194,'AA3408',100194,1),(195,'AA1301',100195,1),(196,'AA1302',100196,1),(197,'AA1303',100197,1),(198,'AA1304',100198,1),(199,'AA1305',100199,1),(200,'AA1306',100200,1),(201,'AA1307',100201,1),(202,'AA1308',100202,1),(203,'AA1309',100203,1),(204,'AA1314',100204,1),(205,'AA1315',100205,1),(206,'AA1310',100206,1),(207,'AA1311',100207,1),(208,'AA1312',100208,1),(209,'AA1313',100209,1),(210,'AA3101',100210,1),(211,'AA3102',100211,1),(212,'AA1201',100212,1),(213,'AA1202',100213,1),(214,'AA1203',100214,1),(215,'AA1204',100215,1),(216,'AA1205',100216,1),(217,'AA1206',100217,1),(218,'AA2217',100218,1),(219,'AA2218',100219,1),(220,'AA1207',100220,1),(221,'AA1208',100221,1),(222,'AA1209',100222,1),(223,'AA1210',100223,1),(224,'AA1211',100224,1),(225,'AA1212',100225,1),(226,'AA1213',100226,1),(227,'AA1214',100227,1),(228,'AC2301',100228,1),(229,'AC2302',100229,1),(230,'AC2303',100230,1),(231,'AC1301',100231,1),(232,'AC2304',100232,1),(233,'AC2305',100233,1),(234,'AC1302',100234,1),(235,'AC1303',100235,1),(236,'AC1304',100236,1),(237,'AC1305',100237,1),(238,'AC1201',100238,1),(239,'AC1202',100239,1),(240,'AC1203',100240,1),(241,'AC1204',100241,1),(242,'AC2202',100242,1),(243,'AC2203',100243,1),(244,'AC2204',100244,1),(245,'AC3201',100245,1),(246,'AC3301',100246,1),(247,'AC3401',100247,1),(248,'AC3302',100248,1),(249,'AC3303',100249,1),(250,'AC3304',100250,1),(251,'AE2501',100251,1),(252,'AC2401',100252,1),(253,'AC2402',100253,1),(254,'AC2403',100254,1),(255,'AB1201',100255,1),(256,'AE1401',100256,1),(257,'AE1601',100257,1),(258,'AB1202',100258,1),(259,'AE1502',100259,1),(260,'AB1203',100260,1),(261,'AE1503',100261,1),(262,'AE1101',100262,1),(263,'AE1102',100263,1),(264,'AO0001',100264,1),(265,'AO0022',100265,1),(266,'AO0023',100266,1),(267,'AE2101',100267,1),(268,'AB1204',100268,1),(269,'AE2102',100269,1),(270,'AE1602',100270,1),(271,'AE1603',100271,1),(272,'AE1604',100272,1),(273,'AO0027',100273,1),(274,'AO0020',100274,1),(275,'AO0017',100275,1),(276,'AE3101',100276,1),(277,'AE3102',100277,1),(278,'AE3103',100278,1),(279,'AE3104',100279,1),(280,'AE3401',100280,1),(281,'AE3501',100281,1),(282,'AE3402',100282,1),(283,'AE3403',100283,1),(284,'AE3404',100284,1),(285,'AD1401',100285,1),(286,'AD1402',100286,1),(287,'AB2301',100287,1),(288,'AB2302',100288,1),(289,'AB1401',100289,1),(290,'AE1301',100290,1),(291,'AE1302',100291,1),(292,'AE3301',100292,1),(293,'AE2401',100293,1),(294,'AE2201',100294,1),(295,'AE2202',100295,1),(296,'AE2203',100296,1),(297,'AE2204',100297,1),(298,'AO0002',100298,1),(299,'AO0009',100299,1),(300,'AO0010',100300,1),(301,'AO0011',100301,1),(302,'AO0012',100302,1),(303,'AO0005',100303,1),(304,'AO0018',100304,1),(305,'AO0019',100305,1),(306,'AO0050',100306,1),(307,'AO0003',100307,1),(308,'AE3601',100308,1),(309,'AO0004',100309,1),(310,'AO0013',100310,1),(311,'AO0014',100311,1),(312,'AO0015',100312,1),(313,'AO0028',100313,1),(314,'AO0029',100314,1),(315,'AO0030',100315,1),(316,'AO0031',100316,1),(317,'AO0032',100317,1),(318,'AO0033',100318,1),(319,'AO0034',100319,1),(320,'AO0035',100320,1),(321,'AA1102',100321,1),(322,'AA1103',100322,1),(323,'AA1104',100323,1),(324,'AA2101',100324,1),(325,'AA2102',100325,1),(326,'AA2103',100326,1),(327,'AA2104',100327,1),(328,'AA2105',100328,1),(329,'AA2106',100329,1),(330,'AA2107',100330,1),(331,'AA2108',100331,1),(332,'AA2109',100332,1),(333,'AA2110',100333,1),(334,'AA2111',100334,1),(335,'AA2112',100335,1),(336,'AB1402',100336,1),(337,'AB2401',100337,1),(338,'AB1403',100338,1),(339,'AB1404',100339,1),(340,'AB1405',100340,1),(341,'AB1406',100341,1),(342,'AB1407',100342,1),(343,'AB1408',100343,1),(344,'AB1409',100344,1),(345,'AB1410',100345,1),(346,'AB1411',100346,1),(347,'AKT001',100058,1),(348,'AKT001',100059,2),(349,'AKT002',100058,1),(350,'AKT002',100059,3),(351,'AKT013',100058,1),(352,'AKT013',100059,1),(353,'AKT003',100280,1),(354,'AKT003',100293,1),(355,'AKT003',100276,1),(356,'AKT004',100280,1),(357,'AKT004',100293,1),(358,'AKT004',100276,1),(359,'AKT004',100308,1),(360,'AKT005',100298,1),(361,'AKT005',100303,1),(362,'AKT005',100280,2),(363,'AKT005',100293,2),(364,'AKT005',100308,2),(365,'AKT005',100347,1),(366,'AKT006',100162,1),(367,'AKT006',100163,1),(368,'AKT006',100164,1),(369,'AKT006',100165,1),(370,'AKT006',100166,1),(371,'AKT006',100167,1),(372,'AKT006',100168,1),(373,'AKT006',100169,1),(374,'AKT006',100170,1),(375,'AKT006',100171,1),(376,'AKT006',100154,1),(377,'AKT006',100160,1),(378,'AKT006',100176,1),(379,'AKT007',100307,2),(380,'AKT008',100163,1),(381,'AKT008',100166,1),(382,'AKT008',100167,1),(383,'AKT008',100169,1),(384,'AKT008',100170,1),(385,'AKT008',100171,1),(386,'AKT008',100179,1),(387,'AKT009',100280,2),(388,'AKT009',100290,2),(389,'AKT009',100285,2),(390,'AKT009',100347,1),(391,'AKT010',100282,1),(392,'AKT010',100289,1),(393,'AKT014',100280,1),(394,'AKT014',100287,1),(395,'AKT014',100286,1),(396,'AKT052',100280,1),(397,'AKT052',100288,1),(398,'AKT052',100286,1),(399,'AKT015',100299,1),(400,'AKT015',100303,2),(401,'AKT016',100280,2),(402,'AKT016',100293,2),(403,'AKT016',100347,1),(404,'AKT017',100280,2),(405,'AKT017',100293,2),(406,'AKT017',100308,2),(407,'AKT017',100347,1),(408,'AKT018',100152,1),(409,'AKT018',100160,1),(410,'AKT019',100153,1),(411,'AKT019',100160,1),(412,'AKT020',100154,1),(413,'AKT020',100160,1),(414,'AKT021',100155,1),(415,'AKT021',100160,1),(416,'AKT022',100156,1),(417,'AKT022',100160,1),(418,'AKT023',100157,1),(419,'AKT023',100160,1),(420,'AKT024',100158,1),(421,'AKT024',100160,1),(422,'AKT053',100151,1),(423,'AKT053',100160,1),(424,'AKT054',100159,1),(425,'AKT054',100160,1),(426,'AKT025',100152,1),(427,'AKT025',100153,1),(428,'AKT025',100154,1),(429,'AKT025',100155,1),(430,'AKT025',100156,1),(431,'AKT025',100157,1),(432,'AKT025',100158,1),(433,'AKT025',100160,1),(434,'AKT026',100169,1),(435,'AKT026',100170,1),(436,'AKT026',100171,1),(437,'AKT026',100154,1),(438,'AKT026',100160,1),(439,'AKT028',100167,1),(440,'AKT028',100154,1),(441,'AKT028',100160,1),(442,'AKT029',100195,10),(443,'AKT030',100280,1),(444,'AKT030',100276,1),(445,'AKT031',100280,2),(446,'AKT032',100073,10),(447,'AKT033',100082,10),(448,'AKT034',100013,10),(449,'AKT035',100182,10),(450,'AKT036',100220,10),(451,'AKT037',100301,1),(452,'AKT037',100305,1),(453,'AKT037',100280,2),(454,'AKT037',100290,2),(455,'AKT037',100285,2),(456,'AKT037',100307,4),(457,'AKT037',100347,1),(458,'AKT038',100301,1),(459,'AKT038',100304,1),(460,'AKT038',100280,2),(461,'AKT038',100290,2),(462,'AKT038',100285,2),(463,'AKT038',100307,4),(464,'AKT038',100347,1),(465,'AKT039',100280,2),(466,'AKT039',100294,2),(467,'AKT039',100307,8),(468,'AKT039',100347,1),(469,'AKT040',100294,2),(470,'AKT041',100298,1),(471,'AKT041',100303,1),(472,'AKT041',100280,2),(473,'AKT041',100285,2),(474,'AKT041',100290,2),(475,'AKT041',100308,4),(476,'AKT041',100347,1),(477,'AKT042',100080,1),(478,'AKT042',100094,1),(479,'AKT042',100129,1),(480,'AKT042',100101,1),(481,'AKT042',100178,1),(482,'AKT043',100081,1),(483,'AKT043',100095,1),(484,'AKT043',100130,1),(485,'AKT043',100102,1),(486,'AKT043',100178,1),(487,'AKT044',100082,1),(488,'AKT044',100096,1),(489,'AKT044',100131,1),(490,'AKT044',100103,1),(491,'AKT044',100178,1),(492,'AKT045',100083,1),(493,'AKT045',100097,1),(494,'AKT045',100132,1),(495,'AKT045',100104,1),(496,'AKT045',100178,1),(497,'AKT046',100084,1),(498,'AKT046',100098,1),(499,'AKT046',100133,1),(500,'AKT046',100105,1),(501,'AKT046',100178,1),(502,'AKT047',100085,1),(503,'AKT047',100099,1),(504,'AKT047',100134,1),(505,'AKT047',100106,1),(506,'AKT047',100178,1),(507,'AKT048',100086,1),(508,'AKT048',100100,1),(509,'AKT048',100135,1),(510,'AKT048',100107,1),(511,'AKT048',100178,1),(512,'AKT049',100308,2),(513,'AKT050',100301,1),(514,'AKT050',100304,1),(515,'AKT050',100280,2),(516,'AKT050',100293,2),(517,'AKT050',100308,2),(518,'AKT050',100347,1),(519,'AKT051',100206,2),(520,'AKT055',100310,1),(521,'AKT055',100312,1),(522,'AKT056',100251,1),(523,'AKT056',100280,1),(524,'AKT057',100310,1),(525,'AKT057',100312,1),(526,'AKT057',100284,1),(527,'AKT058',100311,5),(528,'AKT059',100312,5),(529,'AKT060',100280,1),(530,'AKT060',100312,1),(531,'AKT060',100310,1),(532,'AKT061',100280,1),(533,'AKT061',100291,1),(534,'AKT061',100285,1),(535,'AKT062',100169,1),(536,'AKT062',100170,1),(537,'AKT062',100171,1),(538,'AO0036',100347,1),(539,'AD1101',100348,1),(540,'AA2401',100349,1),(541,'AA2113',100350,1),(542,'AA2114',100351,1),(543,'AA2115',100352,1),(544,'AA2116',100353,1),(545,'AA2117',100354,1),(546,'AA2118',100355,1),(547,'AA2119',100356,1),(548,'AA2120',100357,1),(549,'AA2121',100358,1),(550,'AA2122',100359,1),(551,'AA2123',100360,1),(552,'AD1102',100361,1),(553,'AD1103',100362,1),(554,'AD1104',100363,1),(555,'AD1105',100364,1),(556,'AD1106',100365,1),(557,'AD1107',100366,1),(558,'AD1108',100367,1),(559,'AD1109',100368,1),(560,'AKT063',100301,1),(561,'AKT063',100305,1),(562,'AKT063',100280,2),(563,'AKT063',100293,2),(564,'AKT063',100308,2),(565,'AKT063',100347,1),(566,'AKT064 ',100280,1),(567,'AKT064 ',100276,1),(568,'AKT064 ',100293,1),(569,'AKT064 ',100308,1),(570,'AKT065 ',100301,1),(571,'AKT065 ',100305,1),(572,'AKT065 ',100280,2),(573,'AKT065 ',100291,2),(574,'AKT065 ',100286,2),(575,'AKT065 ',100308,2),(576,'AKT065 ',100347,1),(577,'AKT066 ',100280,3),(578,'AKT066 ',100276,1),(579,'AKT066 ',100293,3),(580,'AKT066 ',100308,3),(581,'AKT066 ',100347,1),(4863,'AA1215 ',100389,1),(4864,'AA1216 ',100390,1),(4865,'AA1217 ',100391,1),(4866,'AA1218 ',100392,1),(4867,'AKT067 ',100206,1),(4868,'AKT067 ',100207,1),(4869,'AD1110 ',100393,5),(4870,'AD1111 ',100394,5);
/*!40000 ALTER TABLE `hmsh_ebay_sku_item` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_stock`
--

DROP TABLE IF EXISTS `hmsh_ebay_stock`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_stock` (
  `item_id` bigint(20) NOT NULL,
  `item_name` varchar(2048) NOT NULL,
  `item_condition` varchar(255) DEFAULT NULL,
  `item_type` varchar(255) DEFAULT NULL,
  `item_stock` int(8) NOT NULL,
  `item_price` double DEFAULT NULL,
  `update_time` datetime DEFAULT NULL,
  PRIMARY KEY (`item_id`)
) ENGINE=MyISAM AUTO_INCREMENT=4862 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_stock`
--

LOCK TABLES `hmsh_ebay_stock` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_stock` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_stock` VALUES (100001,'GGS 3.0\'','New','Photo',0,15,'2011-03-13 19:37:28'),(100002,'GGS 450D/500D','New','Photo',0,27,'2011-03-17 19:51:37'),(100003,'GGS 550D','New','Photo',8,27,'2011-04-14 20:11:08'),(100004,'GGS 50D/5DII','New','Photo',3,27,'2011-03-27 08:40:27'),(100005,'GGS D90','New','Photo',5,30,'0000-00-00 00:00:00'),(100006,'品胜3.0‘','New','Photo',12,1.2,'2011-03-12 21:30:27'),(100007,'爵影无线N1','New','Photo',9,70,'2011-05-02 23:08:29'),(100008,'爵影无线N3','New','Photo',6,70,'0000-00-00 00:00:00'),(100009,'爵影无线C1','New','Photo',13,70,'2011-04-05 08:09:38'),(100010,'爵影无线C3','New','Photo',-1,70,'2011-04-29 18:57:55'),(100011,'爵影无线S1','New','Photo',3,70,'2011-04-06 20:37:56'),(100012,'爵影无线E2','New','Photo',0,70,'2011-05-09 19:15:40'),(100013,'爵影快门线N1','New','Photo',6,12,'2011-05-09 19:25:26'),(100014,'爵影快门线N2','New','Photo',9,12,'2011-04-21 18:09:36'),(100015,'爵影快门线N3','New','Photo',0,12,'0000-00-00 00:00:00'),(100016,'爵影快门线C1','New','Photo',-1,12,'2011-05-11 03:29:41'),(100017,'爵影快门线C3','New','Photo',16,12,'2011-04-24 17:23:49'),(100018,'爵影快门线S1','New','Photo',7,12,'0000-00-00 00:00:00'),(100019,'爵影快门线 E2','New','Photo',8,12,'2011-03-14 19:25:06'),(100020,'永诺 RS-802 N2','New','Photo',6,22,'0000-00-00 00:00:00'),(100021,'永诺 YN128-S1','New','Photo',4,80,'0000-00-00 00:00:00'),(100022,'优永佳快门线 A C3','New','Photo',7,13,'0000-00-00 00:00:00'),(100023,'优永佳快门线 B N1','New','Photo',7,13,'2011-04-05 01:54:18'),(100024,'优永佳快门线 G N2','New','Photo',6,13,'2011-05-04 20:56:18'),(100025,'永诺 MC-N1','New','Photo',0,140,'0000-00-00 00:00:00'),(100026,'永诺 MC-N2','New','Photo',0,140,'2011-03-05 21:25:42'),(100027,'永诺 MC-N3','New','Photo',0,140,'0000-00-00 00:00:00'),(100028,'永诺 MC-C1','New','Photo',6,140,'2011-04-21 22:53:50'),(100029,'永诺 MC-C3','New','Photo',5,140,'2011-03-10 02:48:10'),(100030,'永诺 MC-S1','New','Photo',1,140,'2011-05-12 21:40:23'),(100031,'爵影mc-c3 ','New','Photo',1,100,'0000-00-00 00:00:00'),(100032,'永诺 YN126- N1','New','Photo',0,115,'0000-00-00 00:00:00'),(100033,'永诺 YN126- N3','New','Photo',1,115,'0000-00-00 00:00:00'),(100034,'永诺 YN126- C1','New','Photo',0,115,'0000-00-00 00:00:00'),(100035,'永诺 YN126- C3','New','Photo',1,115,'0000-00-00 00:00:00'),(100036,'爵影红外 nikon','New','Photo',10,9,'2011-05-04 19:34:42'),(100037,'爵影红外 canon ','New','Photo',6,9,'2011-05-12 01:09:09'),(100038,'爵影红外 sony','New','Photo',14,9,'2011-05-11 19:12:30'),(100039,'爵影红外 olympus','New','Photo',17,9,'2011-03-20 20:10:31'),(100040,'爵影红外 5 in 1','New','Photo',1,9,'2011-05-13 00:19:15'),(100041,'永诺仿原装 canon RC-5','New','Photo',0,9,'2011-05-13 08:48:04'),(100042,'永诺闪光灯  YN465 for NIKON ','New','Photo',0,330,'0000-00-00 00:00:00'),(100043,'永诺闪光灯  YN465 for CANON ','New','Photo',1,330,'0000-00-00 00:00:00'),(100044,'永诺闪光灯  YN462','New','Photo',1,145,'0000-00-00 00:00:00'),(100045,'永诺 64LED 灯','New','Photo',2,115,'0000-00-00 00:00:00'),(100046,'永诺 SF18- CANON','New','Photo',1,190,'2011-05-10 18:56:53'),(100047,'永诺 SF18- NIKON SB800','New','Photo',2,190,'2011-04-17 21:04:12'),(100048,'永诺 SF18- NIKON SB900','New','Photo',-2,190,'2011-05-13 04:13:41'),(100049,'永诺 SF17- CANON','New','Photo',3,160,'0000-00-00 00:00:00'),(100050,'永诺 SF17- NIKON SB800','New','Photo',0,160,'2011-05-03 22:20:13'),(100051,'永诺 sony热靴转换器','New','Photo',0,25,'0000-00-00 00:00:00'),(100052,'爵影1m 多功能ttl线 ','New','Photo',2,75,'0000-00-00 00:00:00'),(100053,'永诺 nikon ttl 线  3m','New','Photo',5,90,'0000-00-00 00:00:00'),(100054,'永诺 canon ttl 线  1m','New','Photo',2,70,'2011-04-27 01:43:10'),(100055,'永诺 Canon ttl线  3m','New','Photo',3,90,'2011-05-05 19:28:13'),(100056,'永诺 Canon ttl线  10m','New','Photo',3,140,'0000-00-00 00:00:00'),(100057,'永诺 YN-04 引闪器一套','New','Photo',-1,70,'2011-05-09 22:21:36'),(100058,'永诺 CTR-301P 触发器','New','Photo',5,30,'2011-05-02 07:28:49'),(100059,'永诺 CTR-301P 接受器','New','Photo',13,70,'2011-05-02 07:28:49'),(100060,'NG200 柔光罩 ','New','Photo',7,25,'2011-05-06 07:53:32'),(100061,'NG128 柔光罩','New','Photo',10,18,'2011-05-10 20:19:38'),(100062,'爵影碗罩P1','New','Photo',4,18,'2011-04-05 01:16:44'),(100063,'爵影碗罩P2','New','Photo',10,18,'2011-03-20 19:27:48'),(100064,'爵影碗罩P3','New','Photo',5,18,'0000-00-00 00:00:00'),(100065,'爵影碗罩P4','New','Photo',2,18,'2011-04-28 18:26:16'),(100066,'万用遮光罩','New','Photo',5,10,'2011-04-09 07:48:36'),(100067,'闪光的柔光箱   40cm','New','Photo',13,110,'2011-03-29 19:31:47'),(100068,'闪光的柔光箱   50cm','New','Photo',1,135,'2011-04-18 17:55:44'),(100069,'闪光的柔光箱   60cm','New','Photo',2,120,'2011-05-05 19:19:20'),(100070,'肥皂盒 柔光罩   sb800 sb600','New','Photo',9,4,'2011-05-09 19:46:33'),(100071,'肥皂盒 柔光罩  430EX','New','Photo',30,4,'2011-05-07 21:14:57'),(100072,'肥皂盒 柔光罩   580EX','New','Photo',24,4,'2011-05-09 00:43:31'),(100073,'绿叶 UV  52mm','New','Photo',7,6,'2011-05-14 08:29:47'),(100074,'绿叶 UV  55mm','New','Photo',12,5.5,'2011-05-09 19:05:07'),(100075,'绿叶 UV  58mm','New','Photo',4,6.5,'2011-05-04 19:29:06'),(100076,'绿叶 UV  62mm','New','Photo',24,8,'2011-05-09 19:29:48'),(100077,'绿叶 UV  67mm','New','Photo',10,9,'2011-05-14 08:26:48'),(100078,'绿叶 UV  72mm','New','Photo',28,9.5,'2011-05-10 19:45:40'),(100079,'绿叶 UV  77mm','New','Photo',17,11.5,'2011-05-12 18:41:39'),(100080,'绿叶 CPL  52mm','New','Photo',29,18,'2011-05-02 00:06:39'),(100081,'绿叶 CPL  55mm','New','Photo',13,18,'2011-05-09 18:59:11'),(100082,'绿叶 CPL  58mm','New','Photo',1,19,'2011-05-13 08:48:12'),(100083,'绿叶 CPL  62mm','New','Photo',13,19,'2011-05-13 08:48:15'),(100084,'绿叶 CPL  67mm','New','Photo',11,20,'2011-05-09 22:27:42'),(100085,'绿叶 CPL 72mm','New','Photo',32,20,'2011-05-08 18:58:02'),(100086,'绿叶 CPL  77mm','New','Photo',29,22,'2011-05-10 07:40:40'),(100087,'绿叶 ND4  52mm','New','Photo',2,15,'2011-04-23 07:58:42'),(100088,'绿叶 ND4  55mm','New','Photo',8,15,'2011-04-23 07:58:08'),(100089,'绿叶 ND4  58mm','New','Photo',2,17,'2011-05-01 21:26:04'),(100090,'绿叶 ND4  62mm','New','Photo',6,17,'2011-05-09 19:30:10'),(100091,'绿叶 ND4  67mm','New','Photo',2,19,'2011-05-01 21:33:01'),(100092,'绿叶 ND4  72mm','New','Photo',1,19,'2011-04-27 23:16:24'),(100093,'绿叶 ND4  77mm','New','Photo',4,21,'2011-04-19 19:10:58'),(100094,'绿叶 ND8  52mm','New','Photo',3,15,'2011-05-02 00:06:39'),(100095,'绿叶 ND8  55mm','New','Photo',9,15,'2011-04-23 07:58:49'),(100096,'绿叶 ND8  58mm','New','Photo',3,17,'2011-05-01 21:26:11'),(100097,'绿叶 ND8  62mm','New','Photo',3,17,'2011-04-24 07:12:49'),(100098,'绿叶 ND8  67mm','New','Photo',5,19,'2011-05-08 18:36:30'),(100099,'绿叶 ND8 72mm','New','Photo',10,19,'2011-04-28 18:37:58'),(100100,'绿叶 ND8  77mm','New','Photo',4,21,'2011-05-01 21:40:34'),(100101,'绿叶 渐变镜 52mm','New','Photo',12,15,'2011-05-07 03:04:59'),(100102,'绿叶 渐变镜 55mm','New','Photo',0,15,'2011-05-09 19:48:17'),(100103,'绿叶 渐变镜 58mm','New','Photo',20,15,'2011-05-13 18:57:33'),(100104,'绿叶 渐变镜 62mm','New','Photo',21,18,'2011-05-09 19:31:07'),(100105,'绿叶 渐变镜 67mm','New','Photo',11,18,'2011-05-09 19:48:40'),(100106,'绿叶 渐变镜 72mm','New','Photo',6,22,'2011-05-12 18:40:50'),(100107,'绿叶 渐变镜 77mm','New','Photo',7,22,'2011-05-11 18:57:58'),(100108,'绿叶近摄镜 +2  52mm','New','Photo',4,12,'0000-00-00 00:00:00'),(100109,'绿叶近摄镜 +2  55mm','New','Photo',2,12,'0000-00-00 00:00:00'),(100110,'绿叶近摄镜 +2  58mm','New','Photo',0,12,'0000-00-00 00:00:00'),(100111,'绿叶近摄镜 +2  62mm','New','Photo',7,14,'0000-00-00 00:00:00'),(100112,'绿叶近摄镜 +2  67mm','New','Photo',8,17,'0000-00-00 00:00:00'),(100113,'绿叶近摄镜 +2  72mm','New','Photo',4,17,'0000-00-00 00:00:00'),(100114,'绿叶近摄镜 +2  77mm','New','Photo',6,20,'0000-00-00 00:00:00'),(100115,'绿叶近摄镜 +3  52mm','New','Photo',0,12,'0000-00-00 00:00:00'),(100116,'绿叶近摄镜 +3  55mm','New','Photo',3,12,'0000-00-00 00:00:00'),(100117,'绿叶近摄镜 +3  58mm','New','Photo',0,12,'0000-00-00 00:00:00'),(100118,'绿叶近摄镜 +3  62mm','New','Photo',8,14,'0000-00-00 00:00:00'),(100119,'绿叶近摄镜 +3  67mm','New','Photo',1,17,'0000-00-00 00:00:00'),(100120,'绿叶近摄镜 +3  72mm','New','Photo',10,17,'0000-00-00 00:00:00'),(100121,'绿叶近摄镜 +3  77mm','New','Photo',9,20,'0000-00-00 00:00:00'),(100122,'绿叶近摄镜 +4  52mm','New','Photo',10,12,'2011-03-08 19:05:44'),(100123,'绿叶近摄镜 +4  55mm','New','Photo',3,12,'2011-04-27 19:53:51'),(100124,'绿叶近摄镜 +4  58mm','New','Photo',10,12,'2011-04-14 01:39:43'),(100125,'绿叶近摄镜 +4  62mm','New','Photo',4,14,'2011-04-13 19:20:29'),(100126,'绿叶近摄镜 +4  67mm','New','Photo',10,17,'0000-00-00 00:00:00'),(100127,'绿叶近摄镜 +4  72mm','New','Photo',8,17,'0000-00-00 00:00:00'),(100128,'绿叶近摄镜 +4  77mm','New','Photo',12,20,'0000-00-00 00:00:00'),(100129,'绿叶近摄镜 +8  52mm','New','Photo',-2,12,'2011-05-02 00:06:39'),(100130,'绿叶近摄镜 +8  55mm','New','Photo',0,12,'0000-00-00 00:00:00'),(100131,'绿叶近摄镜 +8  58mm','New','Photo',-1,14,'2011-04-21 17:57:07'),(100132,'绿叶近摄镜 +8  62mm','New','Photo',3,14,'2011-04-24 07:12:49'),(100133,'绿叶近摄镜 +8  67mm','New','Photo',1,17,'2011-05-08 18:36:30'),(100134,'绿叶近摄镜 +8  72mm','New','Photo',2,17,'2011-04-29 03:59:12'),(100135,'绿叶近摄镜 +8  77mm','New','Photo',-1,20,'2011-05-01 21:40:34'),(100136,'天涯 cpl 52mm','New','Photo',2,18,'2011-04-09 07:57:23'),(100137,'天涯 cpl 55mm','New','Photo',4,20,'2011-03-17 20:05:46'),(100138,'天涯 cpl 58mm','New','Photo',0,21,'2011-05-06 02:32:19'),(100139,'天涯 cpl 62mm','New','Photo',1,25,'0000-00-00 00:00:00'),(100140,'天涯 cpl 67mm','New','Photo',0,23,'0000-00-00 00:00:00'),(100141,'天涯 cpl 72mm','New','Photo',5,25,'2011-05-09 19:29:05'),(100142,'天涯 cpl 77mm','New','Photo',0,26,'0000-00-00 00:00:00'),(100143,'天涯 ND8 52mm','New','Photo',1,20,'0000-00-00 00:00:00'),(100144,'天涯 ND8 55mm','New','Photo',6,20,'0000-00-00 00:00:00'),(100145,'天涯 ND8 58mm','New','Photo',1,24,'0000-00-00 00:00:00'),(100146,'天涯 ND8 62mm','New','Photo',5,28,'2011-05-09 19:28:11'),(100147,'天涯 ND8 67mm','New','Photo',1,28,'0000-00-00 00:00:00'),(100148,'天涯 ND8 72mm','New','Photo',3,30,'2011-05-09 19:28:34'),(100149,'天涯 ND8 77mm','New','Photo',0,30,'0000-00-00 00:00:00'),(100150,'天涯uv 82mm','New','Photo',9,28,'0000-00-00 00:00:00'),(100151,'方形滤镜接口环 49mm','New','Photo',10,3,'2011-05-03 19:42:49'),(100152,'方形滤镜接口环 52mm','New','Photo',39,3,'2011-05-08 18:56:55'),(100153,'方形滤镜接口环 55mm','New','Photo',44,3,'2011-05-02 07:51:17'),(100154,'方形滤镜接口环 58mm','New','Photo',22,3,'2011-05-11 18:32:37'),(100155,'方形滤镜接口环 62mm','New','Photo',24,3,'2011-05-03 20:30:47'),(100156,'方形滤镜接口环 67mm','New','Photo',38,3,'2011-05-10 19:10:00'),(100157,'方形滤镜接口环 72mm','New','Photo',30,3,'2011-05-09 05:00:08'),(100158,'方形滤镜接口环 77mm','New','Photo',28,3,'2011-05-09 21:11:41'),(100159,'方形滤镜接口环 82mm','New','Photo',11,3,'2011-05-05 02:00:01'),(100160,'方形滤镜 镜片卡座','New','Photo',102,3.5,'2011-05-11 18:32:37'),(100161,'方镜卡座 广角托架','New','Photo',77,6,'2011-05-14 08:27:13'),(100162,'天涯方形滤镜  渐变红','New','Photo',14,21,'2011-04-27 02:52:11'),(100163,'天涯方形滤镜  渐变橙','New','Photo',14,21,'2011-05-09 19:13:50'),(100164,'天涯方形滤镜  渐变黄','New','Photo',16,21,'2011-04-27 02:52:11'),(100165,'天涯方形滤镜  渐变绿','New','Photo',16,21,'2011-04-27 02:52:11'),(100166,'天涯方形滤镜  渐变蓝','New','Photo',18,21,'2011-05-09 19:13:50'),(100167,'天涯方形滤镜  渐变灰','New','Photo',5,21,'2011-05-11 18:32:37'),(100168,'天涯方形滤镜  渐变棕','New','Photo',12,21,'2011-04-27 02:52:11'),(100169,'天涯方形滤镜  ND2','New','Photo',16,21,'2011-05-09 19:13:50'),(100170,'天涯方形滤镜  ND4','New','Photo',14,21,'2011-05-09 19:13:50'),(100171,'天涯方形滤镜  ND8','New','Photo',15,21,'2011-05-09 19:13:50'),(100172,'天涯方形滤镜系列  星光镜  star4','New','Photo',1,28,'2011-05-02 07:50:57'),(100173,'天涯方形滤镜系列  星光镜  star6','New','Photo',6,28,'2011-05-08 18:22:35'),(100174,'天涯方形滤镜系列  星光镜  star8','New','Photo',5,28,'2011-05-11 18:49:42'),(100175,'天涯方形滤镜系列  CPL','New','Photo',2,58,'2011-05-11 18:49:29'),(100176,'天涯方形滤镜系列 10片装 盒子','New','Photo',2,10,'2011-04-27 02:52:11'),(100177,'3片装的滤镜袋','New','Photo',33,6,'2011-05-11 18:57:10'),(100178,'4片装的滤镜袋','New','Photo',11,6,'2011-05-08 18:36:30'),(100179,'6片装的滤镜袋','New','Photo',17,9,'2011-05-09 19:13:50'),(100180,'橡胶遮光罩 52mm','New','Photo',40,4.8,'2011-05-13 18:39:13'),(100181,'橡胶遮光罩 55mm','New','Photo',37,5.6,'2011-05-10 04:32:03'),(100182,'橡胶遮光罩 58mm','New','Photo',101,5.8,'2011-05-11 18:58:15'),(100183,'橡胶遮光罩 62mm','New','Photo',69,6.6,'2011-05-09 19:03:31'),(100184,'橡胶遮光罩 67mm','New','Photo',35,6.8,'2011-05-12 18:45:44'),(100185,'橡胶遮光罩 72mm','New','Photo',33,7.6,'2011-05-02 00:58:40'),(100186,'橡胶遮光罩 77mm','New','Photo',41,7.8,'2011-05-12 18:23:19'),(100187,'ET-60','New','Photo',6,17,'0000-00-00 00:00:00'),(100188,'ET-65B','New','Photo',3,17,'2011-04-17 09:09:08'),(100189,'HB-7','New','Photo',3,17,'0000-00-00 00:00:00'),(100190,'EW-73II','New','Photo',0,17,'0000-00-00 00:00:00'),(100191,'EW-78D','New','Photo',9,17,'0000-00-00 00:00:00'),(100192,'EW-83E','New','Photo',0,17,'0000-00-00 00:00:00'),(100193,'绿叶EW-73B','New','Photo',4,17,'0000-00-00 00:00:00'),(100194,'EW-73B','New','Photo',42,17,'2011-05-13 01:49:04'),(100195,'CANON 镜头盖  58mm','New','Photo',125,5,'2011-05-13 18:28:38'),(100196,'CANON 镜头盖  67mm','New','Photo',44,5,'2011-04-27 19:47:48'),(100197,'CANON 镜头盖  72mm','New','Photo',72,5,'2011-04-24 17:35:17'),(100198,'CANON 镜头盖  77mm','New','Photo',61,5,'2011-05-11 03:08:30'),(100199,'NIKON 镜头盖 52mm','New','Photo',45,5,'2011-05-12 01:53:44'),(100200,'NIKON 镜头盖 62mm','New','Photo',60,5,'2011-05-05 19:17:27'),(100201,'NIKON 镜头盖 67mm','New','Photo',58,5,'2011-05-14 08:44:22'),(100202,'NIKON 镜头盖 72mm','New','Photo',51,5,'2011-05-09 19:05:24'),(100203,'NIKON 镜头盖 77mm','New','Photo',53,5,'2011-04-24 17:32:55'),(100204,'机身盖/镜头后盖  Nikon','New','Photo',9,4,'2011-03-28 19:51:53'),(100205,'机身盖/镜头后盖  Canon','New','Photo',14,4,'2011-05-12 18:45:26'),(100206,'lenspen','New','Photo',218,15.5,'2011-05-14 08:43:56'),(100207,'气吹 + 布','New','Photo',91,4,'2011-04-21 17:57:25'),(100208,'麂皮','New','Photo',424,1,'2011-05-12 23:57:31'),(100209,'镜头布','New','Photo',100,1,'0000-00-00 00:00:00'),(100210,'防雨罩','New','Photo',19,23,'2011-05-14 08:42:55'),(100211,'防寒罩','New','Photo',17,42,'2011-04-15 03:11:31'),(100212,'眼罩 450D/500D','New','Photo',2,10,'2011-05-14 08:42:29'),(100213,'眼罩 40D/50D','New','Photo',-1,10,'2011-05-11 18:33:10'),(100214,'眼罩 D300','New','Photo',22,10,'2011-03-14 21:45:58'),(100215,'热靴保护盖  普通','New','Photo',11,2,'2011-05-12 18:32:38'),(100216,'热靴保护盖  sony','New','Photo',7,6,'2011-05-02 01:13:25'),(100217,'带水平仪 热靴保护盖','New','Photo',51,12,'2011-05-03 19:45:02'),(100218,'小号灰卡','New','Photo',20,21,'2011-05-13 08:41:02'),(100219,'大号灰卡','New','Photo',16,26,'2011-05-13 18:55:21'),(100220,'canon 反接环  52mm','New','Photo',22,6,'2011-05-09 19:07:17'),(100221,'canon 反接环  58mm ','New','Photo',13,6,'2011-05-12 18:20:22'),(100222,'pentax 反接环  52mm','New','Photo',4,6,'2011-05-08 18:19:34'),(100223,'nikon 反接环  52mm','New','Photo',26,6,'2011-05-14 09:18:29'),(100224,'52-52mm 双阳环','New','Photo',18,2.5,'2011-05-03 05:08:44'),(100225,'52-58mm 双阳环','New','Photo',22,2.5,'2011-05-13 08:52:11'),(100226,'58-58mm 双阳环','New','Photo',28,2.5,'2011-05-08 18:14:01'),(100227,'canon 电子触点','New','Photo',5,21,'2011-05-11 18:56:33'),(100228,'小号内胆包 无字','New','Photo',20,11,'2011-05-13 18:51:18'),(100229,'小号内胆包 Nikon','New','Photo',2,11,'2011-05-12 18:44:15'),(100230,'小号内胆包 canon ','New','Photo',6,11,'2011-05-05 19:19:49'),(100231,'中号内胆包 无字','New','Photo',14,11,'2011-05-13 08:48:08'),(100232,'中号内胆包 nikon','New','Photo',11,11,'2011-05-11 18:48:39'),(100233,'中号内胆包 canon ','New','Photo',21,11,'2011-04-20 20:10:38'),(100234,'大号内胆包 无字','New','Photo',31,11,'2011-04-28 19:03:56'),(100235,'大号内胆包 nikon','New','Photo',18,11,'2011-05-01 21:21:19'),(100236,'大号内胆包canon','New','Photo',17,11,'2011-05-03 21:05:41'),(100237,'新式内胆包','New','Photo',17,22,'2011-04-07 19:59:47'),(100238,'镜头筒 小号','New','Photo',21,6,'2011-05-13 18:57:47'),(100239,'镜头筒 中号','New','Photo',10,6,'2011-05-11 01:37:17'),(100240,'镜头筒 大号','New','Photo',22,6,'2011-04-20 19:02:28'),(100241,'镜头筒 xl 大号','New','Photo',21,9,'2011-03-27 10:25:12'),(100242,'JJC 镜头筒 JN22','New','Photo',8,20.3,'2011-03-09 19:20:25'),(100243,'JJC 镜头筒 JN23','New','Photo',7,20.7,'0000-00-00 00:00:00'),(100244,'JJC 镜头筒 JN24','New','Photo',7,24.3,'2011-04-14 19:37:57'),(100245,'反光板 100*150 40*60 5合1','New','Photo',15,65,'2011-05-14 09:02:49'),(100246,'反光板  80cm 5合1','New','Photo',5,30,'2011-05-12 18:41:55'),(100247,'反光板 110cm 5合1','New','Photo',19,40,'2011-05-03 20:01:49'),(100248,'反光板 80cm 2合1','New','Photo',18,21,'2011-05-07 21:07:31'),(100249,'反光板 60cm 2合1','New','Photo',29,14,'2011-05-09 22:11:51'),(100250,'2mx1.5m 背景板（蓝，绿）','New','Photo',8,85,'2011-05-06 18:56:55'),(100251,'反光板支架','New','Photo',50,38,'2011-05-13 18:58:13'),(100252,'圆形柔光棚 40cm','New','Photo',24,38,'2011-05-14 08:43:27'),(100253,'圆形柔光棚 50cm','New','Photo',12,45,'2011-05-12 02:51:38'),(100254,'圆形柔光棚 60cm','New','Photo',11,60,'2011-04-22 00:12:45'),(100255,'倒影板（白黑）','New','Photo',47,15,'2011-05-13 18:54:52'),(100256,'肩架','New','Photo',-33,64,'2011-05-12 21:12:27'),(100257,'三脚架  伟峰 WF-6662A','New','Photo',7,120,'2011-05-13 08:51:41'),(100258,'伟峰 6662A 快装板','New','Photo',16,15,'2011-05-07 21:19:34'),(100259,'三脚架 伟峰 WF-6663A ','New','Photo',7,155,'2011-05-04 19:15:54'),(100260,'伟峰 6663A 快装板','New','Photo',23,20,'2011-05-08 18:21:27'),(100261,'三脚架 伟峰 wf-6662A+ 6160H 球台','New','Photo',15,140,'2011-05-08 22:28:40'),(100262,'三脚架 伟峰 WF-531','New','Photo',0,140,'0000-00-00 00:00:00'),(100263,'三脚架 伟峰 WF-531B','New','Photo',5,135,'2011-04-13 19:25:17'),(100264,'三脚架 伟峰 EI-717','New','Photo',-2,580,'2011-05-06 07:54:14'),(100265,'三脚架 伟峰 EI-717  155','New','Photo',-1,600,'2011-04-19 19:36:25'),(100266,'三脚架 伟峰 EI-717  180','New','Photo',5,640,'2011-05-04 19:16:29'),(100267,'球台 伟峰 WF-717AH','New','Photo',21,310,'2011-05-09 01:15:41'),(100268,'伟峰 717 快装板','New','Photo',12,46,'2011-05-09 19:14:42'),(100269,'伟峰717 手柄','New','Photo',13,50,'2011-04-19 19:35:46'),(100270,'独脚架  伟峰 WT-1003','New','Photo',4,35,'2011-04-12 19:43:46'),(100271,'独脚架  伟峰 WT-1005','New','Photo',5,50,'2011-05-07 21:10:18'),(100272,'独脚架  伟峰 WT-1007','New','Photo',5,65,'2011-05-08 18:46:41'),(100273,'WT600','New','Photo',0,130,'2011-05-08 18:14:40'),(100274,'WFC-592T + WF-570H','New','Photo',0,530,'0000-00-00 00:00:00'),(100275,'NIB EI7060AA','New','Photo',0,1350,'0000-00-00 00:00:00'),(100276,'斜臂 ','New','Photo',53,38,'2011-05-12 18:45:06'),(100277,'大力夹','New','Photo',102,8.5,'2011-05-12 18:42:29'),(100278,'大力夹云台','New','Photo',21,16,'2011-05-11 20:14:36'),(100279,'c型大力夹','New','Photo',64,11,'2011-05-13 18:39:32'),(100280,'灯架  2m','New','Photo',182,26,'2011-05-14 09:08:03'),(100281,'灯架 84cm','New','Photo',10,20,'2011-05-13 18:28:56'),(100282,'灯架 38cm','New','Photo',5,16,'2011-05-04 19:36:17'),(100283,'2m 弹簧灯架 ','New','Photo',11,28,'2011-05-12 18:36:22'),(100284,'2.8m 弹簧灯架 ','New','Photo',7,45,'2011-05-10 22:49:43'),(100285,'反光伞','New','Photo',68,10,'2011-05-11 01:34:27'),(100286,'柔光伞','New','Photo',22,7,'2011-05-14 09:08:03'),(100287,'闪光灯B座 ','New','Photo',81,15,'2011-05-14 09:08:03'),(100288,'闪光灯云台(配合灯架）','New','Photo',20,20,'2011-05-12 19:13:27'),(100289,'桌面灯灯头','New','Photo',4,20,'2011-05-04 19:36:17'),(100290,'双灯头 ','New','Photo',46,18,'2011-05-02 07:35:45'),(100291,'单灯头','New','Photo',51,9,'2011-05-12 18:40:23'),(100292,'一转四 灯头','New','Photo',48,18,'2011-05-13 18:58:29'),(100293,'柔光箱 50-70cm 单灯头','New','Photo',61,38,'2011-05-13 18:27:43'),(100294,'柔光箱 60-60cm  四灯头','New','Photo',72,68,'2011-05-10 07:32:08'),(100295,'4灯头 灯头 孔 ','New','Photo',-1,30,'2011-05-11 18:24:25'),(100296,'50-70柔光棚 通用塑料卡口','New','Photo',25,40,'2011-05-12 18:41:24'),(100297,'50-70柔光棚 通用金属卡口','','Photo',4,45,'0000-00-00 00:00:00'),(100298,'背景架2mx 1.6m','New','Photo',13,95,'2011-05-10 19:45:19'),(100299,'背景架2mx2m ','New','Photo',14,100,'2011-05-08 18:26:44'),(100300,'背景架 2mx3m 河北 + 1.6x2.1 白 +夹子','New','Photo',7,75,'2011-05-13 04:13:31'),(100301,'背景架2m x 3m','New','Photo',10,128,'2011-05-11 02:06:31'),(100302,'3m 伸缩横杆 ','New','Photo',1,80,'2011-04-17 09:17:57'),(100303,'背景布 1.6','','Photo',-69,10,'2011-05-12 18:11:12'),(100304,'背景布 3x6 白色','','Photo',-7,72,'2011-05-11 02:06:31'),(100305,'背景布 3x6 绿色','','Photo',-26,72,'2011-05-07 21:22:02'),(100306,'背景布 3x6 黑色','','Photo',0,72,'0000-00-00 00:00:00'),(100307,'45w 5500k 灯泡','New','Photo',16,13,'2011-05-13 03:00:32'),(100308,'115w 5500k 灯泡  220v','New','Photo',206,21,'2011-05-13 18:27:43'),(100309,'115w 5500k 灯泡  110v','New','Photo',98,28,'0000-00-00 00:00:00'),(100310,'800w红头灯   ','New','Photo',2,85,'2011-05-10 22:49:43'),(100311,'800w 110v 灯泡 ','New','Photo',39,15,'2011-05-04 19:05:00'),(100312,'800w  220v 灯泡','New','Photo',82,12,'2011-05-10 22:49:43'),(100313,'sony 单肩包  A1   ','New','Photo',5,28,'2011-05-01 21:52:39'),(100314,'canon 单肩包 A1 ','New','Photo',11,28,'2011-05-09 19:02:25'),(100315,'Nikon 单肩包  A1','New','Photo',15,28,'2011-03-05 21:27:24'),(100316,'Canon 单肩包  D1','New','Photo',20,27,'2011-05-08 18:34:58'),(100317,'Nikon 单肩包 D1','New','Photo',18,27,'2011-05-13 19:10:24'),(100318,'Canon 单肩包 小包 D2','New','Photo',21,8,'2011-05-12 20:45:15'),(100319,'canon 三角包  D3','New','Photo',-7,13,'2011-05-08 19:02:37'),(100320,'Nikon 三角包  D3','New','Photo',9,13,'2011-05-13 08:33:32'),(100321,'摄影背心 夏  XL','New','Photo',5,48,'2011-05-01 21:38:10'),(100322,'摄影背心 冬夏  L','New','Photo',6,58,'2011-05-07 21:09:45'),(100323,'摄影背心 冬夏 XL','New','Photo',3,58,'2011-05-08 18:30:43'),(100324,'摄影背心 Nikon 老款 大小无特别标注为 M','New','Photo',2,80,'2011-05-02 19:15:58'),(100325,'摄影背心 Nikon  L','New','Photo',6,80,'0000-00-00 00:00:00'),(100326,'摄影背心 Nikon  XL','New','Photo',4,80,'0000-00-00 00:00:00'),(100327,'摄影背心 Nikon  XXL','New','Photo',11,80,'0000-00-00 00:00:00'),(100328,'摄影背心 Nikon  XXXL','New','Photo',9,80,'0000-00-00 00:00:00'),(100329,'摄影背心 Canon  老款 大小无特别标注为 M','New','Photo',-1,80,'2011-05-12 18:33:20'),(100330,'摄影背心 Canon  L','New','Photo',0,80,'0000-00-00 00:00:00'),(100331,'摄影背心 Canon  XL','New','Photo',10,80,'0000-00-00 00:00:00'),(100332,'摄影背心 Canon  XXL','New','Photo',7,80,'0000-00-00 00:00:00'),(100333,'摄影背心 Canon  XXXL','New','Photo',3,80,'0000-00-00 00:00:00'),(100334,'摄影背心 nikon 原厂 大小无特别标注为 L','New','Photo',17,90,'2011-03-30 20:26:20'),(100335,'摄影背心 Nikon 原厂 XL','New','Photo',3,90,'0000-00-00 00:00:00'),(100336,'尼康 90th 周年肩带  ','New','Photo',0,30,'2011-03-03 21:55:52'),(100337,'尼康 90th 周年镜头筒','New','Photo',4,15,'2011-04-20 23:06:46'),(100338,'肩带 nikon ','New','Photo',24,8,'2011-05-10 19:27:42'),(100339,'肩带 canon ','New','Photo',15,8,'2011-04-26 21:52:09'),(100340,'肩带 pentax','New','Photo',7,8,'2011-05-05 19:42:55'),(100341,'肩带 sony','New','Photo',22,8,'2011-03-29 20:32:20'),(100342,'肩带 无字','New','Photo',8,8,'2011-05-14 08:41:50'),(100343,'JJC 腕带  JJC-1','New','Photo',-1,18.8,'2011-04-05 08:00:15'),(100344,'JJC 腕带  JJC-2','New','Photo',4,30.5,'0000-00-00 00:00:00'),(100345,'JJC 腕带  JJC-3A','New','Photo',10,26,'0000-00-00 00:00:00'),(100346,'JJC 腕带  JJC-N ( 4)','New','Photo',1,36,'0000-00-00 00:00:00'),(100347,'灯架包  ','New','Photo',115,5,'2011-05-13 18:27:43'),(100348,'Canon D8 单肩包','New','Photo',11,45,'2011-04-11 20:21:23'),(100349,'井字扳手','New','Photo',0,98,'2011-04-29 18:43:58'),(100350,'摄影背心 黑色厚 sony 大小无特别标注为 XL','New','Photo',19,60,'2011-05-02 19:05:01'),(100351,'摄影背心 黑色厚 无字 大小无特别标注为XL','New','Photo',2,60,'2011-04-26 17:18:02'),(100352,'摄影背心 黑色薄 canon 大小无特别标注为XL','New','Photo',18,60,'2011-04-15 03:12:05'),(100353,'摄影背心 蓝色薄 canon 大小无特别标注为 XL','New','Photo',0,60,'2011-04-29 20:23:54'),(100354,'摄影背心 蓝色薄 nikon 大小无特别标注为XL','New','Photo',0,60,'2011-04-11 19:53:51'),(100355,'摄影背心 蓝色薄 无字大小无特别标注为 XL','New','Photo',1,60,'2011-05-03 20:02:57'),(100356,'摄影背心 绿色薄 nikon 大小无特别标注为XL','New','Photo',0,60,'2011-03-17 21:34:20'),(100357,'摄影背心 绿色薄 canon  大小无特别标注为XL','New','Photo',9,60,'2011-05-11 18:53:46'),(100358,'摄影背心 红色薄 sony  大小无特别标注为XL','New','Photo',4,60,'2011-04-26 04:52:10'),(100359,'摄影背心 红色薄 无字 大小无特别标注为 XL','New','Photo',3,60,'0000-00-00 00:00:00'),(100360,'摄影背心 驼色厚 无字 大小无特别标注为 XL','New','Photo',5,52,'0000-00-00 00:00:00'),(100361,'Sony 三角包  D3','New','Photo',7,13,'2011-05-10 19:59:21'),(100362,'摄影包 单肩  nikon  N2','New','Photo',3,55,'0000-00-00 00:00:00'),(100363,'摄影包 单肩  canon  N2','New','Photo',3,55,'2011-04-13 19:38:25'),(100364,'摄影包 单肩  nikon  N4','New','Photo',3,75,'0000-00-00 00:00:00'),(100365,'摄影包 单肩  canon  N4','New','Photo',1,75,'0000-00-00 00:00:00'),(100366,'摄影包 单肩  canon  D4','New','Photo',1,35,'0000-00-00 00:00:00'),(100367,'摄影包 单肩  nikon  M2','New','Photo',6,55,'0000-00-00 00:00:00'),(100368,'摄影包 单肩  canon  M2','New','Photo',1,55,'0000-00-00 00:00:00'),(100369,'摄影背心 黑色厚 sony XXL','New','Photo',22,60,NULL),(100370,'摄影背心 黑色厚 sony XXXL','New','Photo',20,60,NULL),(100371,'摄影背心 黑色厚 无字 XXL','New','Photo',4,60,NULL),(100372,'摄影背心 黑色厚 无字 XXXL','New','Photo',0,60,NULL),(100373,'摄影背心 黑色薄 canon XXL','New','Photo',17,60,NULL),(100374,'摄影背心 黑色薄 canon XXXL','New','Photo',19,60,NULL),(100375,'摄影背心 蓝色薄 nikon XXL','New','Photo',0,60,NULL),(100376,'摄影背心 蓝色薄 nikon XXXL','New','Photo',0,60,NULL),(100377,'摄影背心 蓝色薄 XXL','New','Photo',-1,55,NULL),(100378,'摄影背心 蓝色薄 XXXL','New','Photo',9,55,NULL),(100379,'摄影背心 绿色薄 nikon XXL','New','Photo',0,60,NULL),(100380,'摄影背心 绿色薄 nikon XXXL','New','Photo',1,60,NULL),(100381,'摄影背心 绿色薄 canon  XXL','New','Photo',10,60,NULL),(100382,'摄影背心 绿色薄 canon  XXXL','New','Photo',5,60,NULL),(100383,'摄影背心 红色薄 sony  XXL','New','Photo',3,60,NULL),(100384,'摄影背心 红色薄 sony  XXXL','New','Photo',5,60,NULL),(100385,'摄影背心 红色薄 无字 XXL','New','Photo',2,60,NULL),(100386,'摄影背心 红色薄 无字 XXXL','New','Photo',1,60,NULL),(100387,'摄影背心 驼色厚 无字 XXL','New','Photo',2,52,NULL),(100388,'摄影背心 驼色厚 无字 XXXL','New','Photo',5,52,NULL),(100389,'麦克风','New','Photo',9,110,'2011-05-04 19:04:30'),(100390,'HB-7 花瓣','New','Photo',7,31,'2011-05-14 08:28:52'),(100391,'摄影背心 夏  L ','New','Photo',10,48,NULL),(100392,'2mx1.5m 背景板（黑，白） ','New','Photo',5,85,NULL),(100393,'Q-strap 单','New','Photo',5,48,NULL),(100394,'Double-Q-strap 双','New','Photo',5,88,NULL);
/*!40000 ALTER TABLE `hmsh_ebay_stock` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_transaction`
--

DROP TABLE IF EXISTS `hmsh_ebay_transaction`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_transaction` (
  `id` int(8) NOT NULL AUTO_INCREMENT,
  `transaction_ID` bigint(20) NOT NULL,
  `ebay_itemID` bigint(20) NOT NULL,
  `ebay_itemTitle` varchar(2048) DEFAULT NULL,
  `quantity` tinyint(4) DEFAULT NULL,
  `hmsh_sku` varchar(255) DEFAULT NULL,
  `amountPaid` double DEFAULT NULL,
  `ebay_sellerID` varchar(255) DEFAULT NULL,
  `ebay_buyerID` varchar(255) DEFAULT NULL,
  `ebay_buyerEmail` varchar(255) DEFAULT NULL,
  `shipping_name` varchar(255) DEFAULT NULL,
  `shipping_street` varchar(1024) DEFAULT NULL,
  `shipping_city` varchar(255) DEFAULT NULL,
  `shipping_state` varchar(255) DEFAULT NULL,
  `shipping_country` varchar(255) DEFAULT NULL,
  `shipping_zip` varchar(255) DEFAULT NULL,
  `shipping_phone` varchar(255) DEFAULT NULL,
  `ebaypaymentstatus` varchar(255) DEFAULT NULL,
  `checkoutstatus` varchar(255) DEFAULT NULL,
  `shippingservice` varchar(255) DEFAULT NULL,
  `paid_time` datetime DEFAULT NULL,
  `shippingstatus` tinyint(4) DEFAULT '0',
  `shipping_time` datetime DEFAULT NULL,
  `item_status` tinyint(4) NOT NULL DEFAULT '0',
  `stock_status` tinyint(4) NOT NULL DEFAULT '0',
  `shipping_method` tinyint(4) NOT NULL DEFAULT '0',
  `if_printed` tinyint(2) NOT NULL DEFAULT '0',
  `tracking_id` varchar(256) DEFAULT NULL,
  `notes` varchar(2048) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `ebayDuplicate` (`transaction_ID`,`ebay_itemID`,`ebaypaymentstatus`)
) ENGINE=MyISAM AUTO_INCREMENT=9549 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_transaction`
--

LOCK TABLES `hmsh_ebay_transaction` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_transaction` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_transaction` VALUES (1926,637157497002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','vinnieherrera','vinicius_ferreira@hotmail.com','Vinicius Ferreira','Rua Marlo da Costa e Souza, 135 - apt. 707 Apple - Barra da Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22790735','55 21 99287253','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 09:14:57',0,NULL,3,1,3,1,NULL,'RR723016250CN '),(1924,598439047001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',12.99,'hermeshine','f_madika','liga.lysa@gmail.com','Fransisko Madika','Mulia Group, Wisma Mulia 53rd Floor<br>Jl. Jend. Gatot Subroto No. 42','Jakarta Selatan','DKI Jakarta','INDONESIA','12710','(62) 817-0876037','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 07:44:32',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹äº‘å°  1 \r234gï¼Ÿ'),(1923,598435381001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','jub13071','jub130@mail.ru','Vadim Pastukhov','Botanicheskaya 22-18','Krasnoyarsk','Russia','RUSSIAN FEDERATION','660030','+7 913 8359749','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 07:24:03',0,NULL,3,1,2,1,NULL,''),(1922,598434643001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','riendi','chochon@gmail.com','Marylise Devoyault','1066 Rang 1 Ouest','Sainte-Christine','QC','CANADA','J0H 1H0','(819) 858-9926','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 07:15:37',0,NULL,3,1,2,1,NULL,NULL),(1921,598413681001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',2,'AB1302',6.68,'hermeshine','ezra.bay','ezra_nj@hotmail.com','Ezra Ganesh','2747 Hooper Ave<br>Apt 13-16','Brick','NJ','UNITED STATES','08723','(732) 556-7329','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 04:51:19',0,NULL,3,1,1,1,NULL,' '),(1920,598409228001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','bobduhrke','bobduhrke@hotmail.com','Robert Duhrke','1240 W 139th St','Gardena','CA','UNITED STATES','90247-2210','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 04:23:51',0,NULL,3,1,1,1,NULL,' '),(1581,595151970001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','antonioruizg','antrg2@yahoo.es','Antonio Ruiz Galayo','Plaza 8 de Septiembre nÂº 15, 3Âº F','CÃ¡ceres','Extremadura','SPAIN','10003','649110209','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 09:00:49',0,NULL,3,1,4,1,NULL,'è¿™æ˜¯æµ‹è¯•æ•°æ®æœ€åŽä¸€ç¥¨ï¼Œä¹‹åŽæ­£å¼è¯•ç”¨'),(1582,633710294002,120462363779,'CTR-301 P Wireless Flash Trigger Kit with PC Port ',1,'AKT013',25.8,'hermeshine','enriched92','libra-oha@hotmail.com','Hong An Ong','Boon Lay Drive Blk 268a #13-584','default','Boon Lay Drive','SINGAPORE','641268','+65- 96753274','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 09:42:59',0,NULL,3,1,3,1,NULL,'301p ä¸€æ‹–ä¸€ RR658661499CN'),(1584,633729440002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','snep1968','frankjoansierra@gmail.com','NÃºria Llorca Altirriba','Calle Mayor, 67 3Âº 2Âª','Castelldefels','Barcelona','SPAIN','08860','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 11:04:41',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶  1\r2m ç¯æž¶  1 \rYW863686686CN'),(1585,633759619002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','kripstian','dominguez752@hotmail.com','Cristian Dominguez rein-loring','Alameda Urquijo 102 1Âº puerta 6','Bilbao','PaÃ­s Vasco','SPAIN','48013','663532984','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 13:02:01',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶ 1\rbåº§   1\ræŸ”å…‰ä¼ž  1\rRR658661511CN'),(1586,595212958001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8.5,'hermeshine','renef180','renefraioli@ntlworld.com','Rene Fraioli','5 Oakhill ave<br>Mount Vernon','Glasgow','Glasgow (City of)','UNITED KINGDOM','G69 7ES','01415737779','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2010-11-18 13:19:42',0,NULL,5,1,2,1,NULL,' '),(1587,595236708001,110566021028,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','lassekamppari','lasse.kamppari@gmail.com','Lasse Kamppari','Raisiontie 11 A 1','Helsinki','','FINLAND','00280','358405231721','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 14:32:03',0,NULL,3,1,2,1,NULL,'é˜²å¯’ç½©  1 '),(1588,595238195001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','mystifire1960','kurtmitstifer@yahoo.com','Kurt Mitstifer','1020 Raintree Dr','Palm Beach Gardens','FL','UNITED STATES','33410-5247','(561) 236-1402','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-18 14:37:17',0,NULL,3,1,1,1,NULL,' '),(1589,595246330001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','erjotola','erik@erikogtove.dk','Erik Johansen','Store Kongensgade 27, 4. tv','Copenhagen K','','DENMARK','1264','(45)33935610','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 15:03:25',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶  1 \rYW863686664CN'),(1590,595263608001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','nsch8980','noahschu@msn.com','noah schumacher','114 Old Homestead Hwy','North Swanzey','NH','UNITED STATES','03431-4436','(860) 912-3729','NoPaymentFailure','CheckoutComplete','Other','2010-11-18 15:55:31',0,NULL,3,1,4,1,NULL,' YW863686675CN'),(1591,595275286001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',1,'AKT029',24,'hermeshine','steven40','steven40@aol.com','Steven Sweringen','1220 E Greg St<br>Ste 15','Sparks','NV','UNITED STATES','89431','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-18 16:28:02',0,NULL,3,1,1,1,NULL,'2 x 52mm Nikon caps\r4 x  58mm Canon caps\r2 x  72mm Canon caps\r2 x 72mm Nikon caps\r161g\r\rSteve Sweringen\rCamera Clinic\r1220 E Greg Street #15\rSparks, NV 89431\r877-511-4811 \r'),(1592,595281792001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','tystange','info@ty-stange.dk','Ty Stange','16tyve, Vesterbrogade 80b, 4. sal','Kbh, V','','DENMARK','1620','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 16:54:42',0,NULL,3,1,3,1,NULL,' RR658661471CN'),(1593,595319666001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','jevgsvet','jevg88@msn.com','Jevgenia Tsikulenko','Tamme pst. 82a-3','Tartu','Tartumaa','ESTONIA','50416','58176426','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 18:15:44',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹äº‘å°  1\rNG128   1   \r\r335g\rRR658662389CN'),(1594,633880871002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE1301',23.67,'hermeshine','commandosexy','commandosexies@yahoo.com','Rattanachote Leeyanumas','12/18 Soonvijai 6, New Petchburi Road<br>Bangkapi, Huay Khwang','Bangkok','Bangkok','THAILAND','10310','66819250239','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 18:27:35',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  3 RR658661485CN'),(1595,633886461002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','samantha_jeff86','samantha_jeff86@yahoo.com','Samantha Jackson','PO Box 2014','Caseville','MI','UNITED STATES','48725-2014','(989) 551-8913','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-18 18:38:00',0,NULL,3,1,1,1,NULL,' '),(1596,594946171001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',384,'hermeshine','diepstra123','cdiepstra@tersteege.eu','Chris Diepstra','Brugakker 35-01','Zeist','','NETHERLANDS','3704LJ','030-6971545','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 19:29:41',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ ï¼‰ 1\r2m ç¯æž¶   2\r50-70 æ£š  æ¬§æ ‡  2\r115w 220v   2\råŒ…    1\rç”³æŠ¥ lighting kit $25\rYW863686701CN\r'),(1597,633954701002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','var8_metal','var.photographer@gmail.com','Photoworld di Bonato Simone','verga 1<br>CC Ipercity','albignasego','PD','ITALY','35020','+393497072977','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 20:45:07',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹  2 '),(1598,595393975001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','jbenben09','johanbencker@gmail.com','johan bencker','segervÃ¤gen 204','Ã„lvsjÃ¶','Stockholm','SWEDEN','12534','+46708614662','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 20:58:08',0,NULL,3,1,11,1,NULL,' '),(1599,595176222001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','chrholoul','christopheroulie@gmail.com','Chris Oulie','Stubberudveien 3','GrÃ¥lum','','NORWAY','1712','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 21:09:29',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR658661468CN'),(1600,595411752001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','laiiane2010','mineirinha_portuga@hotmail.com','laiane pereira','1263 north ave','bridgeport','CT','UNITED STATES','06604-2717','(203) 209-4906','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-18 21:22:41',0,NULL,3,1,3,1,NULL,' RR658661556CN'),(1601,633989948002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','guerrillero_spa','karekanopam7@gmail.com','PABLO MARTÃN AGUILAR','C/ LAS BOTIJAS , BLOQUE 5, 2Âº IZQUIERDA.<br>DOS HERMANAS','SEVILLA','AndalucÃ­a Ceuta y Melilla','SPAIN','41700','636372318','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 22:00:39',0,NULL,3,1,4,1,NULL,'6662a   1 \r\rç”³æŠ¥ tripod  $15\rYW863686712CN\r'),(1602,595282528001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',14.59,'hermeshine','kamalsanghera','kamal.sanghera@gmail.com','Kamal Sanghera','# 8925<br>135A St.','Surrey','BC','CANADA','V3V 5V2','(778) 994-1094','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 00:15:48',0,NULL,3,1,2,1,NULL,' å°å·ç°å¡  1\rLenspen  1'),(1603,595489134001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','isidoro654','doroelviss@hotmail.com','isidoro gonzalez rodriguez','plaza fuente del cantaro NÂº1-2 ATICO A','salamanca','Castilla y LeÃ³n','SPAIN','37008','630778739','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 01:26:42',0,NULL,3,1,3,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ xl  1 \rRR658661542CN'),(1604,634061039002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','admir.b','champ071@hotmail.com','admir begovic','Grbavicka 40','Sarajevo','ba','BOSNIA AND HERZEGOVINA','71000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 01:45:10',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´   æ¬§æ ‡  1\råå…‰ä¼ž   1 \rRR658661525CN'),(1605,631601984002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','repiolariel','ariel_in@hotmail.com','Ariel Butron Blanco','Correos de Bolivia. La Paz. Casilla 1583','La Paz','La Paz','BOLIVIA','591','(591)70560522','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 02:22:15',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rb åº§   1\ræŸ”å…‰ä¼ž   1RR658661600CN '),(1606,634070911002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','toppukuma','top_the_white@yahoo.com','Chatiwat Lerdvongveerachai','23 Soi Sunthornpimol  Jarumuang Road<br>Rongmuang','Patumwan','Bangkok','THAILAND','10330','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 02:23:54',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rb åº§   1\ræŸ”å…‰ä¼ž   1 RR658661595CN'),(1607,595503637001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','damoja','danmjacobs@pol.net','daniel jacobs','319 S Riverside Dr','pompano beach','FL','UNITED STATES','33062','(954) 633-4079','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 02:25:34',0,NULL,3,1,1,1,NULL,' '),(1608,595503807001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','andrew_liem','dj_drex@hotmail.com','Andrew Liem','9 Yolanda Place','Brampton','ON','CANADA','l7a3n5','(647) 294-6050','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 02:26:09',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR658661539CN'),(1610,634073228002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','nancyhumphrey','cndiamk@hotmail.com','Nancy Humphrey','102 Centre Street<br>P.O. Box 117','Vulcan','AB','CANADA','T0L 2B0','(403) 485-3116','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 02:28:47',0,NULL,3,1,2,1,NULL,' '),(1611,634103906002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','awemedia','olaf@vigilante-studios.com','Olaf Skjenna','127 Wexford Road<br>Miramar','Wellington','Wellington','NEW ZEALAND','6022','04 974-7055','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 04:40:13',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž   1 \rRR658661627CN'),(1612,595540217001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',80,'hermeshine','polognus','wencepili@yahoo.fr','Wenceslas PILIPCZUK','14 rue de vandelicourt','MARQUEGLISE','Picardie','FRANCE','60490','0344428807','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 05:33:05',0,NULL,3,1,4,1,NULL,'tripod $20\rYW863686690CN'),(1613,595549792001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','bigjamg','pjensen79@sbcglobal.net','Edson Hong','17305 Esperanza','Irvine','CA','UNITED STATES','92618','(949) 378-8015','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 06:38:26',0,NULL,3,1,1,1,NULL,'52mm-58mm åŒé˜³çŽ¯  1 '),(1614,595564947001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','racerjin22','racerjin22@hotmail.com','HYOJIN LEE','5699 Fullerton Ave<br>Apt 21','BUENA PARK','CA','UNITED STATES','90621-1968','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 08:13:09',0,NULL,3,1,1,1,NULL,'å“èƒœ  3.0 è†œ  1 '),(1615,633272317002,120564178566,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',10,'AA1310',57.7,'hermeshine','pinchukov','v_pinchukov@mail.ru','Vassiliy Pinchukov','Karasai Batyra 209/79','Almaty','','KAZAKHSTAN','050009','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 09:10:00',0,NULL,3,1,3,1,NULL,'RR658661613CN'),(1616,595594538001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','nielsremigius','niels.remigius@upcmail.nl','Paul Remigius','Krijn van den Helmstraat 33','Leeuwarden','','NETHERLANDS','8923 CL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 10:32:53',0,NULL,3,1,2,1,NULL,''),(1617,595569373001,110422380084,'Aluminium Lightweight 68\" Camera Monopod BALL HEAD New',1,'AE1604',24.2,'hermeshine','jumping_bean77','kimmy@internode.on.net','Rob Wilder','82 Sierra Drive<br>North Tamborine','Gold Coast','Queensland','AUSTRALIA','4272','0755452605','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-19 11:15:01',0,NULL,3,1,3,1,NULL,'WF-1007 ç‹¬è„šæž¶   1 \r\r842g\rRR658662185CN'),(1618,634186527002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','jerwinpuzon','jerwinpuzon@yahoo.com','Jeoffrey Erwin Puzon','44 Laurel St.','Baguio City','none','PHILIPPINES','2600','9156000086','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 11:45:31',0,NULL,3,1,2,1,NULL,' '),(1620,634190456002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','faro_marin','marin@bulat.ro','marin bulat','G. Alexandrescu 11<br>ap 43','Chisinau','Chisinau','MOLDOVA, REPUBLIC OF','2008','037379480728','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 11:59:08',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹  2\råŽé¢æœ‰ä¹°äº†ä¸€ä¸ªï¼Œåˆåœ¨ä¸€èµ·å‘'),(1621,634216231002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','brookerafaly','bvr6u@uvawise.edu','Brooke Rafaly','356 Union Mills Rd','Troy','VA','UNITED STATES','22974-3804','','NoPaymentFailure','CheckoutComplete','Other','2010-11-19 13:28:52',0,NULL,3,1,1,1,NULL,'canon æ‘„å½±èƒŒå¿ƒ  M  1 '),(1622,634217000002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','faro_marin','marin@bulat.ro','marin bulat','G. Alexandrescu 11<br>ap 43','Chisinau','Chisinau','MOLDOVA, REPUBLIC OF','2008','037379480728','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 13:30:25',0,NULL,5,1,18,0,NULL,' '),(1623,595649165001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','ocoeemom77','livsmom1@bellsouth.net','Integrity Web Development','935 Cloudview Place NE','Cleveland','TN','UNITED STATES','37312','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 13:56:01',0,NULL,3,1,1,1,NULL,' '),(1624,595677552001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','alberto1817','vengadorjust@hotmail.com','alberto sells moreno','POLÃGON INDUSTRIAL VILABLAREIX. C/ GÃœELL, 48. 17180 VILABLAREIX','girona','CataluÃ±a','SPAIN','17005','635696959','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 15:26:59',0,NULL,3,1,4,1,NULL,'tripod $15\rYW864143016CN\r '),(1625,595694146001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','colorsdclown','ctwells7@embarqmail.com','Tim Wells','1981 County Road 4','Ashley','IN','UNITED STATES','46705-9734','','NoPaymentFailure','CheckoutComplete','Other','2010-11-19 16:14:57',0,NULL,3,1,1,1,NULL,'å°¼åº·æ‘„å½±èƒŒå¿ƒ  M   1 \r656g\r'),(1626,634289011002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','dreamwalker90','crazy_edvin@hotmail.com','Edvin Kalic','Zeljeznicka b.b.','Sanski Most','','BOSNIA AND HERZEGOVINA','79260','+38761754086','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 16:54:37',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1 '),(1627,595728689001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','mentepoluida','rodrigosantiago2005@gmail.com','Luis Bernardo','83 country way','Dartmouth','MA','UNITED STATES','02748-1229','','NoPaymentFailure','CheckoutComplete','Other','2010-11-19 17:38:15',0,NULL,3,1,3,1,NULL,' æ–°åœ°å€ï¼š\rRua Helena \rVaz da Silva, nÂº13-6ÂºA \r1750-405 Lisboa \rPortugal \r\r52mm -77mm æŽ¥å£çŽ¯ + holder  1 RR658662295CN'),(1628,634308178002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','bobharker','rjharker@gmail.com','Robert Harker','8 St John Woods Terrace','London','London','UNITED KINGDOM','NW8 6JJ','02077225267','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 17:40:14',0,NULL,3,1,4,1,NULL,'717AH çƒå°  1 \rballhead  $15\rYW864143020CN\r'),(1629,595757270001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','deepportage','mbock@d.umn.edu','Martin Bock','4084 Hicken Rd','Duluth','Mn','UNITED STATES','55803-9271','(218) 721-4492','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 18:42:40',0,NULL,3,1,1,1,NULL,'å°å·é•œå¤´ç­’  1 '),(1630,595777620001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','flozzyflozz','fcnaber@yahoo.com','F.C. Naber','H.Pootstraat 15','Heemskerk','','NETHERLANDS','1962HA','+31 622869325','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 19:38:13',0,NULL,3,1,3,1,NULL,'RR658662596CN'),(1631,634358621002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','flozzyflozz','fcnaber@yahoo.com','F.C. Naber','H.Pootstraat 15','Heemskerk','','NETHERLANDS','1962HA','+31 622869325','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 19:38:14',0,NULL,5,1,18,0,NULL,'å‘ä¸‹åˆå¹¶\r '),(1632,634367745002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mastah_lew','louiscomeau@hotmail.com','Louis Comeau','71 ch Pin Rouge','Grand-Remous','QC','CANADA','j0w1e0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 19:44:27',0,NULL,3,1,2,1,NULL,''),(1633,634376729002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT007',126,'hermeshine','niji745','guarneri.luca@gmail.com','Luca Guarneri','Via Verdi 66','Catania','CT','ITALY','95129','3332879601','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 20:25:53',0,NULL,3,1,4,1,NULL,'çº¢å¤´ç¯  2  \r800w 220v ç¯æ³¡  2 \rYW864142891CN\rlight $22'),(1634,595843597001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'',7.9,'hermeshine','php0010','info@philharrisphoto.com','Phil Harris','PO Box 833','Nowra','New South Wales','AUSTRALIA','2541','0408412143','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 21:49:51',0,NULL,3,1,2,1,NULL,''),(1635,595844132001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','abahler1990','abahler@gmail.com','Aaron Bahler','6428 Iron Bridge Rd','Athens','WI','UNITED STATES','54411-8407','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 21:51:35',0,NULL,3,1,1,1,NULL,NULL),(1636,595847513001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','bears*10','t-me@live.com','Tania  emes','7 Gold Crt','Salisbury Heights','South Australia','AUSTRALIA','5109','0882587365','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 22:01:07',0,NULL,3,1,3,1,NULL,'40cm æ£š   1 RR658662335CN'),(1637,595844661001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','vedran_v','vedran.vrhovac@gmail.com','Vedran Vrhovac','Trg Antuna Cvetkovica 6','Novo Cice','','CROATIA','10415','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 21:53:02',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶'),(1638,595843458001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','vedran_v','vedran.vrhovac@gmail.com','Vedran Vrhovac','Trg Antuna Cvetkovica 6','Novo Cice','','CROATIA','10415','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 21:53:03',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1639,634435528002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','pbazsy86','pfeiffer.balazs@endi.hu','BalÃ¡zs Pfeiffer','DÃ³zsa GyÃ¶rgy 32/A','LÃ¡batlan','KomÃ¡rom-Esztergom','HUNGARY','2541','36305633536','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 22:13:40',0,NULL,3,1,2,1,NULL,' '),(1640,634437399002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','steph4712','stephp@charter.net','Stephenie Pippin','453 Hermitage Ave','Cookeville','TN','UNITED STATES','38501','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 22:18:51',0,NULL,3,1,1,1,NULL,NULL),(1641,634438285002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bencrystalr7227','bencrystalr@gmail.com','Ben Rempel','1609 Highway 32 N','Walhalla','ND','UNITED STATES','58282-4306','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 22:25:13',0,NULL,3,1,1,1,NULL,' '),(1642,634426313002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','vedran_v','vedran.vrhovac@gmail.com','Vedran Vrhovac','Trg Antuna Cvetkovica 6','Novo Cice','','CROATIA','10415','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 21:53:03',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚  1\råŒç¯å¤´ æ¬§æ ‡  1\r115w 220v   2 \ré‡3075\rCP212150759CN'),(1643,595859891001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',3,'AB1303',10.02,'hermeshine','kdphoto851','kdcaviness@hotmail.com','Keith Caviness','PO Box 851<br>203 E Main St','Ottumwa','IA','UNITED STATES','52501-0851','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 22:34:11',0,NULL,3,1,1,1,NULL,' '),(1644,634451169002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','harly01','hn@onsmail.nl','Nouwens Hans','Torenvalk 12','Veldhoven','','NETHERLANDS','5508KS','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 23:05:18',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´   1\råå…‰ä¼ž  1 \rRR658662239CN'),(1645,595896202001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','akaspudnik','swerdnase@mac.com','Chris Kenner','5690 Deer Creek Falls Ct','Las Vegas','NV','UNITED STATES','89118','(702) 301-3376','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 00:50:43',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1646,634481769002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','akaspudnik','swerdnase@mac.com','Chris Kenner','5690 Deer Creek Falls Ct','Las Vegas','NV','UNITED STATES','89118','(702) 301-3376','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 00:50:43',0,NULL,3,1,1,1,NULL,'58mm lenscap for Canon 1\r77mm lenscap for Canon 1\r '),(1647,595911629001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','limmerm','limmer.michael@gmail.com','Michael Limmer','25 Butler Blvd.','Winnipeg','MB','CANADA','R2R0Y7','(204) 296-1459','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 01:58:06',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR658662225CN'),(1648,595914295001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','s.sibley','sibleys@hotmail.com','Photo International','1186 Trestle Glen Rd.','Oakland','CA','UNITED STATES','94610','','NoPaymentFailure','CheckoutComplete','NotSelected','2010-11-20 02:26:39',0,NULL,3,1,1,1,NULL,NULL),(1649,595926776001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','kknott50','knott.kristopher@hotmail.com','Kristopher Knott','1049 Read Road','Shannonville','ON','CANADA','K0K3A0','(613) 396-5692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 03:12:01',0,NULL,3,1,2,1,NULL,' '),(1650,595931797001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','vitalmax2009','alfast@inbox.ru','Vitaly Maksimchuk','Narvskaya street 6-105','Vladivostok','Primorsky region','RUSSIAN FEDERATION','690011','+79147077862','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 03:39:04',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rRR658662171CN'),(1651,595931585001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','vitalmax2009','alfast@inbox.ru','Vitaly Maksimchuk','Narvskaya street 6-105','Vladivostok','Primorsky region','RUSSIAN FEDERATION','690011','+79147077862','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 03:39:05',0,NULL,3,1,2,1,NULL,'\rå€’å½±æ¿  1 \r351g'),(1652,634530587002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',11.34,'hermeshine','troikaventures','om_troika@yahoo.com.au','Teik Oh','1/1 Simms Road','Hamilton Hill','Western Australia','AUSTRALIA','6163','0893315288','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'å‘ä¸Šåˆå¹¶ '),(1653,595939541001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',12.99,'hermeshine','troikaventures','om_troika@yahoo.com.au','Teik Oh','1/1 Simms Road','Hamilton Hill','Western Australia','AUSTRALIA','6163','0893315288','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹äº‘å°  1\rNG128   1   \r\r335g\rRR658662389CN'),(1654,634542457002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nnightangell','nnightangel@yandex.ru','Evgeniy Zelenin','Studencheskiy proezd, 10/1, 20','Kirov','Kirov region','RUSSIAN FEDERATION','610033','+79195154445','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 05:40:59',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž  1 \rRR723016263CN'),(1655,634542651002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nnightangell','nnightangel@yandex.ru','Evgeniy Zelenin','Studencheskiy proezd, 10/1, 20','Kirov','Kirov region','RUSSIAN FEDERATION','610033','+79195154445','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 05:42:29',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž  1  \rå®¢æˆ·è¦æ±‚3ç¥¨è´§åˆ†ä¸‰å¤©å‘\rRR723016317CN'),(1656,634543408002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nnightangell','nnightangel@yandex.ru','Evgeniy Zelenin','Studencheskiy proezd, 10/1, 20','Kirov','Kirov region','RUSSIAN FEDERATION','610033','+79195154445','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 05:47:30',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž  1\rRR658662551CN '),(1657,595953023001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','prolific_hasbeen','scheuerv@nucleus.com','Vic Scheuerman','103 Beaconsfield Rd NW','Calgary','AB','CANADA','T3K 1X8','(403) 275-2622','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 05:54:40',0,NULL,3,1,3,1,NULL,'nikonæ‘„å½±èƒŒå¿ƒ M  1RR723016918CN '),(1659,634551180002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','germanautorecycler','germansolutionz85@yahoo.com','Tomas Ballesteros','2442 Iowa Ave<br>Apt A12','Riverside','CA','UNITED STATES','92507','(951) 522-4032','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 06:44:13',0,NULL,3,1,1,1,NULL,'6662a å¿«è£…æ¿   1'),(1660,634572420002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mattvegas808','mattvegas808@hotmail.com','Fat Tuesday - Matt Mochida','3500 Las Vegas Blvd S<br>Ste L23','LAS VEGAS','NV','UNITED STATES','89109-8905','','NoPaymentFailure','CheckoutComplete','Other','2010-11-20 08:49:52',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž   1 \rRR658662865CN'),(1661,595988276001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','drora1','ilanz1@zahav.net.il','Ilan Zeir Harim','12 Hativat Golani','Ra\'anana','','ISRAEL','43333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 09:29:22',0,NULL,3,1,2,1,NULL,'å‘ä¸Šåˆå¹¶ '),(1664,634576198002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',8.69,'hermeshine','drora1','ilanz1@zahav.net.il','Ilan Zeir Harim','12 Hativat Golani','Ra\'anana','','ISRAEL','43333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 09:29:23',0,NULL,3,1,3,1,NULL,' 2mç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž  1\rRR723016325CN'),(1665,634572679002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',9.6,'hermeshine','drora1','ilanz1@zahav.net.il','Ilan Zeir Harim','12 Hativat Golani','Ra\'anana','','ISRAEL','43333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 09:29:24',0,NULL,3,1,3,1,NULL,'3pcsæ»¤é•œè¢‹  2\rä¸­å·å†…èƒ†åŒ… nikon  1\rxl é•œå¤´ç­’  1\rå°å·é•œå¤´ç­’  1\rçƒ­é´æ°´å¹³ç›–   1\ré‡é‡?0.354 RR658662287CN\r'),(1670,595950316001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',86.9,'hermeshine','gregz2008','gregor.zelle@gmail.com','Gregor Zelle','4 Jobson Avenue','Mount Ousley','New South Wales','AUSTRALIA','2519','0406780709','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 10:28:16',0,NULL,3,1,6,1,NULL,'èƒŒæ™¯æž¶ ( ç™½ é»‘ ç° )  1\rEE520583689CN\r3480g\r '),(1671,596016487001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','j-joe','johann.hoff@gmail.com','Johannes Hoff','Top Floor<br>8 John Street','London','London','UNITED KINGDOM','WC1N2ES','07910586619','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 11:15:48',0,NULL,3,1,2,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž  1  '),(1672,596019899001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','futiyke','fernandout@yahoo.com.br','Fernando Utiyke','Rua Bruna,351','SÃ£o Paulo','SÃ£o Paulo','BRAZIL','03370-000','55 11 2671-7973','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 11:22:35',0,NULL,3,1,2,1,NULL,' '),(1673,596024585001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','philambre','philcare@wanadoo.fr','cayrouse philippe','2 PLACE DE L\'EGLISE','CHOISEL','Ile-de-France','FRANCE','78460','06.60.66.56.44','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 11:44:41',0,NULL,3,1,4,1,NULL,'6663a  1\rYW864142924CN\rTripod  $22 '),(1674,634623408002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','gustavobispo1981','gusvahe@hotmail.com','Gustavo Valiente Herrero','Carretera Puente Nuevo, 4, Bj C','Coria (CÃ¡ceres)','Extremadura','SPAIN','10800','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 12:05:23',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž  1 \rRR658662945CN'),(1675,596041323001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0024',6.99,'hermeshine','eshalom45b','nat8gal7@gmail.com','Alexander Moshkovich','52B Hanasi Harishon','Rehovot','','ISRAEL','76302','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 12:35:50',0,NULL,3,1,2,1,NULL,'canon å°åŒ…   1 '),(1676,596073755001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','alexdms72','alexdms@mail.ru','Alexander Pustobaev','Kropotkina 269/1 apt. 293','Novosibirsk','Novosibirskay','RUSSIAN FEDERATION','630111','+7383 214-20-70','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 14:13:37',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR658662211CN'),(1677,596077944001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','friedlimabean','freefallfroggie@yahoo.com','Alexandra Sola','12-14 Sulak Lane Apt#3','Park Ridge','NJ','UNITED STATES','07656','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 14:26:56',0,NULL,3,1,1,1,NULL,'1.6x2.1m èƒŒæ™¯å¸ƒ  é»‘è‰²  1 \r\r358g\r'),(1678,596079643001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','terrylreimer','tlrphoto@yahoo.com','Terry Reimer','1150 Settlers Landing Dr','Tappahannock','VA','UNITED STATES','22560-5071','(704) 996-2156','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 14:29:27',0,NULL,3,1,1,1,NULL,'72mm æ©¡èƒ¶ç½©  1 '),(1679,634672453002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','sandramlund','some-say@hotmail.com','Sandra Mari Lund','Jarlsborgveien 18 c','Trondheim','','NORWAY','7041','+4794436998','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 14:31:06',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(1680,634678251002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','calfab63','ebay@calzeroni.it','Fabio Calzeroni','Via Borgomanero 26','PARUZZARO','NO','ITALY','28040','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 14:51:13',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶  ( ç™½) 1\r2m ç¯æž¶  2\råŒç¯å¤´  æ¬§æ ‡  2\råå…‰ä¼ž  2\r115w 220v   4\råŒ…  1\rYW864142961CN\rlighting kit  $30\r'),(1681,596089547001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','koolinggames','fmichaux@gmail.com','Fabrice Michaux','Route de Bambois, 13','Fosses-la-Ville','','BELGIUM','5070','0473503503','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 15:04:22',0,NULL,3,1,4,1,NULL,'6663a  1\rYW864142950CN\rtripod $22\r '),(1683,634692739002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','oratrend01','oratrend@gmail.com','SZABÃ“ Ã‰VA','SzenthÃ¡romsÃ¡g utca 13.','Szeged','','HUNGARY','6725','003630-9982769','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 15:22:38',0,NULL,3,1,2,1,NULL,'115w 220v   1 \r\r362g'),(1684,596100035001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','jufede','jufedex@hotmail.com','Maria Eugenia Taboada','Avenida Del Libertador 6550 Piso 4 Dto B','NuÃ±ez','Ciudad Autonoma de Buenos Aires','ARGENTINA','C1428ARV','1564071665','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 15:28:42',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1685,596099594001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','jufede','jufedex@hotmail.com','Maria Eugenia Taboada','Avenida Del Libertador 6550 Piso 4 Dto B','NuÃ±ez','Ciudad Autonoma de Buenos Aires','ARGENTINA','C1428ARV','1564071665','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 15:28:42',0,NULL,3,1,2,1,NULL,'lenspen  1\ræ°”å¹+å¸ƒ   1\r\ré‡é‡?0.118\r '),(1686,634726968002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','roman_d_e','reremkin@gmail.com','Roman Eremkin','Belinskovo, 222, room 177','Ekaterinburg','Sverdlovskaia','RUSSIAN FEDERATION','620130','+7 908-906-3515','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 16:39:05',0,NULL,3,1,3,1,NULL,'MC-C1   1\rRR658662358CN '),(1687,596134747001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','tonymik2498','tonymik65@hotmail.com','Anatoliy Mikhaylyuk','309 Wild Azalea dr.','Inman','SC','UNITED STATES','29349','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 16:43:11',0,NULL,3,1,1,1,NULL,'éº‚çš®  1 '),(1688,634748360002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','nmiw6488','vaganova.pointe@gmail.com','Nami Miwa','12 Highland Street','Natick','MA','UNITED STATES','01760','(617) 999-6394','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 17:20:14',0,NULL,3,1,1,1,NULL,NULL),(1689,634765420002,120503730834,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',179,'hermeshine','lcas3662','luis_carlos_castillo@yahoo.es','LUIS CARLOS CASTILLO RODRIGUEZ','CRISTOBAL COLON 13 1Âº C','GETXO','PaÃ­s Vasco','SPAIN','48992','629969832','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 17:55:44',0,NULL,3,1,4,1,NULL,'tripod  $30\rYW864142880CN\r '),(1690,634884590002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','pajka2007','pajka@inbox.ru','Pavel Alekno','16 Sebert road','London','London','UNITED KINGDOM','e7 0nq','07708619085','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 22:07:02',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1691,596286730001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','pajka2007','pajka@inbox.ru','Pavel Alekno','16 Sebert road','London','London','UNITED KINGDOM','e7 0nq','07708619085','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 22:07:02',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶  1\r100-150 5in1 åå…‰æ¿  1\rYW864142913CN\rç‡•æ–‡ ä¸€ç¥¨ä¸¤ä»¶  2196g\rreflector $22 '),(1692,634912122002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jcjjt','jimncat@embarqmail.com','James L. Taylor','385 NE 59th St','Ocala','FL','UNITED STATES','34479-7609','(352) 840-0043','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 23:00:48',0,NULL,3,1,1,1,NULL,NULL),(1693,596325768001,110566018900,'EW-73II Lens Hood lenshood for Canon EF 24-85 /f3.5-4.5',1,'AA3404',8.99,'hermeshine','fraser7588','libozhang88@hotmail.com','Libo Zhang','#203 - 5835 Hampton Place','Vancouver','BC','CANADA','V6T 2G2','(778) 866-8695','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 23:40:35',0,NULL,3,1,2,1,NULL,'EW-73II   1 '),(1694,596333308001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','albert02','lqc@sbcglobal.net','Y Choi','5410 Isabella Ct','Agoura Hills','CA','UNITED STATES','91301','(818) 879-8716','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 00:06:50',0,NULL,3,1,1,1,NULL,NULL),(1695,634950070002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','cookingdigs','cookingdigs@hotmail.com','Debbie Depriest','18118 E Mansfield Ave','Spokane valley','WA','UNITED STATES','99016-5091','(509) 921-1178','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 01:14:23',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1696,596348260001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','cookingdigs','cookingdigs@hotmail.com','Debbie Depriest','18118 E Mansfield Ave','Spokane valley','WA','UNITED STATES','99016-5091','(509) 921-1178','NoPaymentFailure','CheckoutComplete','Other','2010-11-21 01:14:23',0,NULL,3,1,1,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ xl  1 \r72mm æ©¡èƒ¶ç½©   1'),(1697,596379990001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mikeythetiregod','t_ateah@yahoo.ca','mike alexander','B 45658 lewis ave','CHILLIWACK','BC','CANADA','V2P3C6','(604) 418-1502','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 03:24:06',0,NULL,5,1,18,0,NULL,' '),(1698,596387453001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','yigit_urk','yigit007@gmail.com','yigit urkmezturk','bilkent university dorm (yurt) 75<br>room(oda) 207','bilkent','Ankara','TURKEY','06800','(312) 290 - 4846','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 04:03:48',0,NULL,3,1,2,1,NULL,NULL),(1699,635000464002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','kknarf','frank@kingkiner.com','Frank Kingkiner','21 Van Zandt Rd','Skillman','NJ','UNITED STATES','08558','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 04:38:30',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1700,596394504001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','kknarf','frank@kingkiner.com','Frank Kingkiner','21 Van Zandt Rd','Skillman','NJ','UNITED STATES','08558','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 04:39:55',0,NULL,3,1,1,1,NULL,'58mm lenscap  canon  1 \r77mm lenscap  canon  1\ræ˜¨å¤©åŒ…å¥½äº†ï¼Œä½†æ˜¯éœ€è¦æ£€æŸ¥ä¸€ä¸‹ä¼¼ä¹Žåˆ†å¼€åŒ…çš„è¿˜æ˜¯åŒ…åœ¨ä¸€èµ·äº†'),(1701,596394133001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','prasada_g','prasada_g2001@yahoo.com','Prasada Goonaratne','335/1 Kotte Road','Nugegoda','Western Province','SRI LANKA','02','94777749480','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 04:42:14',0,NULL,3,1,2,1,NULL,NULL),(1702,635016087002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','aa657','aanger2@sympatico.ca','Amanda Anger','207-6530 Wyandotte St E','Windsor','ON','CANADA','N8S 1P2','(519) 945-8918','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 06:10:14',0,NULL,3,1,3,1,NULL,' RR658662199CN'),(1703,596408397001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','homesik','homesik@yahoo.com','Jon Thiessen','16316 Prairie Farm Cir','Parker','CO','UNITED STATES','80134-3050','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 06:11:52',0,NULL,3,1,1,1,NULL,' '),(1705,690047805015,250692242462,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',3.5,'hutongstore','aldo1052','eelcpo@tin.it','Aldo Porretta','Le Quadra ,3','Castelliri','Frosinone','ITALY','03030','3287160778','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-21 07:34:30',0,NULL,3,1,2,1,NULL,NULL),(1706,635038799002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','frub9407','frubio@geutebruckspain.com','Francisco Jose Rubio Sanchez','C/ Carmen Martin Gaite 3 Portal E 2B','San Sebastian de los Reyes','Madrid','SPAIN','28702','639081738','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-21 08:21:33',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864142935CN'),(1707,689128962015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','pic1711','rdw1711@googlemail.com','Robin Walker','2 North Park Villas','Saltash','Cornwall','UNITED KINGDOM','PL126LP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-21 09:03:13',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  nikon   1 '),(1708,596446467001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','us4yayhoos','erinscellphone@gmail.com','George Swanson','5410 Whittlington Dr','Charlotte','NC','UNITED STATES','28215-9607','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 09:17:33',0,NULL,3,1,1,1,NULL,' '),(1709,635064055002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','gadget_geek2000','rjzandvoort@gmail.com','Robert-Jan Zandvoort','Klooslaan 53','Groningen','','NETHERLANDS','9721XM','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 09:43:31',0,NULL,3,1,2,1,NULL,NULL),(1710,635078610002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','aschecky','andrew@waygen.com','Andrew Scheck','14 Carrie Dr','Marlboro','NJ','UNITED STATES','07746','(732) 490-8414','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-21 10:20:53',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  1 '),(1711,635131811002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','gregtlawson','lawsongr@hotmail.com','Greg T Lawson','22 Limestone Dr','Moncton','NB','CANADA','E1G 5P4','(506) 854-0076','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 12:23:18',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… canon  1 '),(1712,596555451001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','astashkinpa','pastashkin@gmail.com','Pavel Astashkin','19 Schmitovskiy proezd, App. 38','Moscow','Moscow','RUSSIAN FEDERATION','123100','+79032041572','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 13:36:45',0,NULL,3,1,2,1,NULL,NULL),(1713,596556853001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','juane1012','juanesdan@hotmail.com','juan espluga de antonio','c/san miguel,2,2Âº','barbastro','AragÃ³n','SPAIN','22300','616931522','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-21 13:43:27',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚  1\rYW864142876CN\rlight stand $18 '),(1714,596563756001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','traktooorn','traktoorn@hotmail.com','Erik Ã–stberg','VÃ¤stra Ã–savÃ¤gen 18','Alfta','','SWEDEN','82240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 13:51:30',0,NULL,3,1,2,1,NULL,'45w  2 '),(1715,635180240002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','manu-dienekes','dienekes73@hotmail.com','MANUEL REGADERA EGUIZABAL','C/ ANASTASIO MATEO NÂº 2 BAJO','VILLAMEDIANA DE IREGUA','La Rioja','SPAIN','26142','629486140','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-21 14:09:11',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\rbåº§  2\ræŸ”å…‰ä¼ž  2\r2643g\rtripod $25      \rYW864143031CN'),(1716,635208271002,120581555566,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','mike1arooau','mikefreeman@iinet.net.au','Mike Freeman','8 Olivedale Road','Madeley','Western Australia','AUSTRALIA','6065','0893024770','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 14:54:13',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon  1 '),(1717,635223471002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','phobic0_0','ramonprince@theprincespalace.com','Ramon Prince','4021 Sand Dollar Ct','Seabrook','TX','UNITED STATES','77586-7500','(281) 827-9158','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 15:19:41',0,NULL,3,1,1,1,NULL,' '),(1718,596637515001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','albertouy','alberto_moroy14@hotmail.com','Matias Fernandez','Alferez CÃ¡mpora y SimÃ³n Bolivar<br>Chalet: (name of the house) \"Marina Piccola\"','Punta del Este','Maldonado','URUGUAY','20000','42225530','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 16:01:01',0,NULL,3,1,2,1,NULL,' '),(1719,596706776001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','omer.erkol','omer-erkol@hotmail.com','Ã–mer ERKOL','223 Sokak No:59 D:3 Buca','Izmir','','TURKEY','35390','905077244797','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-21 17:28:54',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶   1 \r2870G\rCP212235091CN'),(1720,635411509002,120570270887,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',26.99,'hermeshine','sound.matter','forest.dude@gmail.com','Steve Cox','553 Parkview Rd','Nashville','IN','UNITED STATES','47448-8066','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 18:56:14',0,NULL,3,1,1,1,NULL,'1m ttl çº¿   canon   1 \ré‡é‡ï¼Ÿ171g'),(1721,635416278002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','tvykulil','tvykulil@msn.com','Tom Vykulil','1191 E Jupiter Pl','Chandler','AZ','UNITED STATES','85225-8912','(480) 633-0524','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 19:01:11',0,NULL,3,1,1,1,NULL,' '),(1722,635425894002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE1301',29.04,'hermeshine','tenero30','sistampi@gmail.com','Rosati Luca','Via tore 16','Scauri','LT','ITALY','04028','328-3131500','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 19:08:47',0,NULL,3,1,3,1,NULL,'cåž‹å¤§åŠ›å¤¹  3 \ré‡é‡ï¼Ÿ\r737g\rRR658662517CN'),(1723,690645562015,250634555406,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'',2.75,'hutongstore','peterszeged74','juhaszpeterszeged@vipmail.hu','Peter Juhasz','2 Major Road','Stratford','London','UNITED KINGDOM','E15 1EE','0044755383409','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-21 20:52:26',0,NULL,3,1,2,1,NULL,'sony çº¢å¤–   1 '),(1724,635576010002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rosehyps','cherol@comcast.net','Cheryl Olson','13016 126th Ave E','puyallup','WA','UNITED STATES','98374-3658','(253) 845-4830','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 22:08:35',0,NULL,5,1,18,0,NULL,''),(1725,635575879002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rosehyps','cherol@comcast.net','Cheryl Olson','13016 126th Ave E','puyallup','WA','UNITED STATES','98374-3658','(253) 845-4830','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 22:08:36',0,NULL,5,1,18,0,NULL,''),(1726,635574866002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rosehyps','cherol@comcast.net','Cheryl Olson','13016 126th Ave E','puyallup','WA','UNITED STATES','98374-3658','(253) 845-4830','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 22:08:36',0,NULL,5,1,18,0,NULL,' åˆå¹¶ä¸Šç¥¨ '),(1727,635575764002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rosehyps','cherol@comcast.net','Cheryl Olson','13016 126th Ave E','puyallup','WA','UNITED STATES','98374-3658','(253) 845-4830','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 22:08:37',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›– canon  4'),(1728,690722641015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'',3.62,'hutongstore','mosspalmeronline','mosspalmer@inbox.com','Mossiah Palmer','6 Southside Apartments St John\'s Walk','Birmingham','West Midlands','UNITED KINGDOM','B5 4TF','01216225263','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-21 22:36:32',0,NULL,3,1,2,1,NULL,' '),(1729,596994867001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',92,'hermeshine','qq**96','2zola@att.net','Helen Yesui, EZ Smog','2900 Mitchell Rd<br>Ste B','ceres','CA','UNITED STATES','95307-5035','','NoPaymentFailure','CheckoutComplete','Other','2010-11-21 23:27:01',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\r50-70 æ£š  1\ræ–œè‡‚    1\r115w 110v   1\rlight stand   $25\rYW864142946CN\r'),(1730,677368814016,260660051690,'Neoprene Lens Pouch Case 9.5cmx23cm 80-200 70-200mm XL',1,'',4.38,'hutongstore','albertkc2007','albertkc2008@yahoo.com','Albert Cabreira','6801 W Ocotillo Rd APT#2047 Apt 2047','Glendale','AZ','UNITED STATES','85303','(602) 653-4972','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-22 00:30:25',0,NULL,3,1,1,1,NULL,'xl é•œå¤´ç­’  1 '),(1731,635639653002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3302',55.99,'hermeshine','kw56','kenwelte@hotmail.com','Ken Welte','1854 extension Rd','Nanaimo','BC','CANADA','v9x 1b1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 00:33:28',0,NULL,3,1,3,1,NULL,'60cm é—ªå…‰ç¯æŸ”å…‰ç½© \ræˆ‘æ¥åŒ… \ré‡é‡ï¼Ÿ\r1312g\rRR658662242CN\r '),(1732,596967193001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',21.99,'hermeshine','jopafavoritus','sojo@sapo.pt','Joao Pires','Farmacia Teixeira Bessa Lda<br>Avenida Foz Sousa 1715','Foz Sousa','Foz Sousa','PORTUGAL','4515-084','+351 960075265','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 00:34:20',0,NULL,3,1,3,1,NULL,' RR658662208CN'),(1733,597026202001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',3,'AB1303',10.02,'hermeshine','647gloria','johnknippel@live.com','JOHN KNIPPEL','4060 LAWRENCE AVE EAST<br>UNIT 411','SCARBOROUGH','ON','CANADA','M1E4V4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 00:56:08',0,NULL,3,1,2,1,NULL,'58mm æ©¡èƒ¶ç½©  3 '),(1734,690787836015,250600501508,'Continuous Lighting System soft box photography studio ',1,'',68,'hutongstore','leaaudreyhardy80','leaaaa.xx@hotmail.com','Lea Hardy','p.o box 306','mudgeeraba','Queensland','AUSTRALIA','4213','61448117993','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-11-22 01:01:15',0,NULL,3,1,6,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š  æ¾³æ ‡  2\råŒ…  1\rEE520583715CN'),(1735,597032581001,110600486184,'TianYa 67mm CPL filter New 67 Circular Polarizing C-PL',1,'AA2305',6.5,'hermeshine','theandreagail','kcyeow61@hotmail.com','Yeow Kong Chong','Blk 161 #10-623 Woodlands Street 13, Singapore 730161','default','','SINGAPORE','730161','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 01:12:27',0,NULL,3,1,11,1,NULL,' '),(1736,635658544002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','aravena562','jaravenaa@mi.cl','juan carlos aravena acuna','Pasaje Santiago de Compostela #1834<br>Villa Mirador de la Bahia','Puerto Montt','Decima Region','CHILE','5480000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 01:22:17',0,NULL,3,1,2,1,NULL,NULL),(1737,690823714015,250599931689,'New TianYa Star 6 points filters for Cokin P Series',1,'',7.8,'hutongstore','mooseheadorangenet','jhyndman@brookes.ac.uk','Jim Hyndman','Westminster Institute of Education Oxford Brookes University','Oxford','Oxon','UNITED KINGDOM','OX2 9AT','07815734857','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 02:23:57',0,NULL,3,1,2,1,NULL,' '),(1738,635684893002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',2,'',17.8,'hermeshine','andresabadg','andresabad@gmail.com','ANDRES ABAD','1140 SORRENTO DR','WESTON','FL','UNITED STATES','33326-4553','(786) 556-4869','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-22 02:44:59',0,NULL,3,1,1,1,NULL,' 74g'),(1739,597068245001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','saa153','saa153@gmail.com','Scott Ayres','1053 Cayer Dr','Glen Burnie','MD','UNITED STATES','21061','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 02:52:22',0,NULL,3,1,1,1,NULL,NULL),(1740,635685888002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'',39,'hermeshine','auchorhing','we168168@hotmail.com','Albert Chor Hing Au','21 Drawbridge Drive','Markham','ON','CANADA','L6C 2B3','(416) 618-1588','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 02:59:43',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1741,597060553001,110609032219,'Redhead Red head 800w w bulb + Spring Cushioned Stand ',1,'AKT007',130,'hermeshine','auchorhing','we168168@hotmail.com','Albert Chor Hing Au','21 Drawbridge Drive','Markham','ON','CANADA','L6C 2B3','(416) 618-1588','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 02:59:43',0,NULL,3,1,8,1,NULL,'å¼¹ç°§ç¯æž¶  1\rçº¢ç¯å¤´  1\r800w 110v  6 \råˆ†ä¸¤ç¥¨å‘\rCP212150731CN\rCP212150745CN\r'),(1742,635697070002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','pet_lab','troykim1@cox.net','Kim Malpass','176 Pond St','Vanceboro','NC','UNITED STATES','28586-7618','(252) 244-3566','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 03:02:41',0,NULL,3,1,1,1,NULL,NULL),(1743,635697489002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',5,'AKT049',175,'hermeshine','emelymares','mares95b@yahoo.es','Maria E. Fernandez','2800 S Lamb Blvd<br>Spc 32','Las Vegas','NV','UNITED STATES','89121-1810','','NoPaymentFailure','CheckoutComplete','Other','2010-11-22 03:14:18',0,NULL,3,1,4,1,NULL,'115w110v  10 \rlight $25\r3.4kg\r\rYW864143182CN'),(1747,635722150002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','*.digital','angel.3f@gmail.com','David Barrera MartÃ­nez','Independencia No. 40<br>Col. Centro','Mixquiahuala','Hidalgo','MEXICO','42700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 04:29:16',0,NULL,5,1,18,0,NULL,'2m ç¯æž¶  2\rbåº§   2\ræŸ”å…‰ä¼ž   2 \r\r'),(1744,597077331001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','thrashtractor','dominicgangx@gmail.com','Dominic Gan','Blk 211, Pasir Ris Street 21<br>#12-248','default','','SINGAPORE','510211','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 03:21:09',0,NULL,3,1,11,1,NULL,' '),(1745,597089326001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','discountjunkseller','discountjunk@yahoo.com','James McDonald','PO Box 1962','Rockingham','NC','UNITED STATES','28380-1962','(910) 273-8819','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 04:07:45',0,NULL,3,1,1,1,NULL,' '),(1746,635717545002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','cristinaandkids','ooocristinaooo@sbcglobal.net','Cristina Medeiros','764 Santos Ave','Ripon','CA','UNITED STATES','95366-9354','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 04:07:48',0,NULL,3,1,1,1,NULL,'test-Jiangang '),(1748,597107245001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','drapolla2010','drapolla@gmail.com','Adriana de la Rocha Aguirre','Rio Amarillo #280 Col. Residencial Fluvial Vallarta','Puerto Vallarta','Jalisco','MEXICO','48312','3222246588','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 05:53:33',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´  1\r '),(1749,635739034002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','jrsola3566','jsola1032@gmail.com','Jose Sola','45 Blvd Media Luna D-1008<br>Villas de Parque Escorial','Carolina','PR','PUERTO RICO','00987','(787) 668-7332','NoPaymentFailure','CheckoutComplete','Other','2010-11-22 05:56:26',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \r\rRR658662579CN'),(1750,597111008001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',3,'',23.7,'hermeshine','75cnx','zeeazaaa@gmail.com','Thunyathorn Traisirichok','40/8 Moo.5 T.Suthep','Chiang Mai','','THAILAND','50200','66869212039','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 06:13:30',0,NULL,3,1,3,1,NULL,'\rRR658662605CN'),(1751,597113124001,110566021028,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','flybear8','han67391@optusnet.com.au','Heather Anderson','10 Etherington Ave<br>Spearwood','Perth','Western Australia','AUSTRALIA','6163','0894186718','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 06:29:13',0,NULL,3,1,3,1,NULL,'é˜²å¯’ç½©  1 \r\rRR658662582CN'),(1752,597119555001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','archdeluxe696','sedemihcra34@yahoo.com','archie mandap','3250 Port Pacific Ln','Elk Grove','CA','UNITED STATES','95758-3606','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 07:09:00',0,NULL,3,1,1,1,NULL,NULL),(1753,597138854001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','maakkonen','makko2000_@hotmail.com','Mikko Suomalainen','Ketunkatu 9','HyvinkÃ¤Ã¤','','FINLAND','05460','0405233925','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 08:56:17',0,NULL,3,1,4,1,NULL,'717 155cm   1 \rTripod $25\rYW864143005CN'),(1754,635774256002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','inverse_of_zero','from_zero_to_infinity@live.com.au','George Papadopoulos','Fastfit Automotive Specialist<br>601 Paramatta Road','Leichhardt','New South Wales','AUSTRALIA','2040','0414442332','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 09:20:00',0,NULL,3,1,2,1,NULL,' '),(1755,597150807001,110600486184,'TianYa 67mm CPL filter New 67 Circular Polarizing C-PL',1,'AA2305',6.5,'hermeshine','jeanmarie2726','jean.marie.trautmann@gmail.com','Jean-Marie TRAUTMANN','84 route d\'Aspach','Vieux-Thann','Alsace','FRANCE','68800','03 89 37 05 89','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 09:48:54',0,NULL,5,1,2,1,NULL,' åˆå¹¶ä¸Šç¥¨'),(1756,635808342002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',9.25,'hermeshine','jeanmarie2726','jean.marie.trautmann@gmail.com','Jean-Marie TRAUTMANN','84 route d\'Aspach','Vieux-Thann','Alsace','FRANCE','68800','03 89 37 05 89','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 11:21:08',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ… æ— å­—  1 '),(1757,690987597015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','denegg','denniswalker@ntlworld.com','Dennis Walker','335 Poulton Road','Wallasey','Merseyside','UNITED KINGDOM','CH44 4DE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 12:12:21',0,NULL,3,1,2,1,NULL,NULL),(1758,690991124015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','kamilasv','kamila.varadova@seznam.cz','Kamila VaraÄovÃ¡','RilskÃ¡ 3181/2','Praha','','CZECH REPUBLIC','14300','731-528-798','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-11-22 12:22:18',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡  2\r115w 220v   2\råŒ…  1 \rCP212150688CN'),(1759,635831467002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','zjflowers','zjflowers@aol.com','Maelene dianne Zuniga','15650 Ludlow St','Granada Hills','CA','UNITED STATES','91344','(818) 363-1055','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 12:42:59',0,NULL,3,1,1,1,NULL,' '),(1760,691014054015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'',22,'hutongstore','horsehead1980','tony.janoska@gmail.com','MSC Ireland (Anton Janoska)','3rd FLOOR, NORTH POINT HOUSE, NORTH POINT BUSINESS PARK, NEW MALLOW ROAD','CORK','Cork','IRELAND','default','085 7126466','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-22 13:28:20',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR658662888CN'),(1764,597216503001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','pinkrsvp','renupandya@yahoo.com','Renu Pandya','70 Beebe St<br>Staten Island','Staten Island','NY','UNITED STATES','10301-4545','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 13:49:52',0,NULL,3,1,1,1,NULL,'æ¸å˜æ©™   1 '),(1766,635858321002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','jukkav','jukka.vuokko@iki.fi','Jukka Vuokko','TÃ¤hkÃ¤polku 4 B 62','Turku','Finland','FINLAND','20720','+358504352787','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 14:03:46',0,NULL,3,1,2,1,NULL,NULL),(1767,635856182002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','hyeminsz','hyemin-sz@hotmail.com','Hyemin Park','Unit 2207 108 Albert Street','Brisbane','Queensland','AUSTRALIA','4000','0423624191','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 14:11:34',0,NULL,3,1,2,1,NULL,NULL),(1768,635863150002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','dtracing614','dreamteamracing614@yahoo.com','franklin bohanan','785 barberry spur ave','delaware','OH','UNITED STATES','43015-3415','(614) 949-2633','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 14:18:02',0,NULL,3,1,1,1,NULL,NULL),(1769,635868313002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','boothjad','drboothjones@cinci.rr.com','Angela Jones','2891 Bentbrook Dr','Cincinnati','OH','UNITED STATES','45251-1107','(513) 825-4708','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 14:33:05',0,NULL,3,1,1,1,NULL,NULL),(1770,635867730002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','adrian.quintano','adrianquintano@gmail.com','adrian quintano','jl. bogor no. 349/m cinere','jakarta selatan','jakarta','INDONESIA','16514','628557894455','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 14:34:57',0,NULL,3,1,2,1,NULL,NULL),(1771,597232000001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8.5,'hermeshine','summerlad','kdc@ducann.com','kenneth  ducann','27 miller  street','summerseat','manchester','UNITED KINGDOM','bl9 5px','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2010-11-22 14:37:22',0,NULL,3,1,2,1,NULL,NULL),(1772,635891075002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','maunal1905','maunal1987@gmail.com','mehmet ali Ã¼nal','gÃ¼neÅŸtepe mahallesi.sergi sokak.no:7 daire: 5<br>gÃ¼ngÃ¶ren / istanbul','istanbul','TN','TURKEY','34164','+905352680228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 15:38:17',0,NULL,3,1,2,1,NULL,NULL),(1773,691075217015,250623448641,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'',7.52,'hutongstore','larguetas','manijero73@gmail.com','jorge arroyo ovalle','cruz de granada BL 2 piso 7 puerta 4','granada','AndalucÃ­a Ceuta y Melilla','SPAIN','18015','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-22 15:53:27',0,NULL,3,1,2,1,NULL,'lenspen  2 '),(1774,635895704002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','phunter_majia','phunter.lau@gmail.com','Anne-Claire Decorvet to Hongliang Liu','56 route du SalÃ¨ve Entrance E','PrÃ©vessin-MoÃ«ns','RhÃ´ne-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:11:09',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1775,635903501002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','phunter_majia','phunter.lau@gmail.com','Anne-Claire Decorvet to Hongliang Liu','56 route du SalÃ¨ve Entrance E','PrÃ©vessin-MoÃ«ns','RhÃ´ne-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:11:07',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶  '),(1776,635891103002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','phunter_majia','phunter.lau@gmail.com','Anne-Claire Decorvet to Hongliang Liu','56 route du SalÃ¨ve Entrance E','PrÃ©vessin-MoÃ«ns','RhÃ´ne-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:11:08',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶  '),(1777,635895400002,120601699920,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',3.55,'hermeshine','phunter_majia','phunter.lau@gmail.com','Anne-Claire Decorvet to Hongliang Liu','56 route du SalÃ¨ve Entrance E','PrÃ©vessin-MoÃ«ns','RhÃ´ne-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:11:09',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶  '),(1778,597255990001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',2,'AKT024',9.74,'hermeshine','phunter_majia','phunter.lau@gmail.com','Anne-Claire Decorvet to Hongliang Liu','56 route du SalÃ¨ve Entrance E','PrÃ©vessin-MoÃ«ns','RhÃ´ne-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:11:10',0,NULL,3,1,3,1,NULL,'77mm çŽ¯æž¶  2\r58mm æŽ¥å£çŽ¯  1\r67mm æŽ¥å£çŽ¯  1\rå¹¿è§’æ‰˜æž¶   2 \rRR658662959CN'),(1779,635908247002,120531377860,'JueYing Lambency Flash Diffuser for 430EX F36AM',1,'AB3308',22,'hermeshine','demitryvolovich','demion1403@gmail.com','Demitry volovich','zolotorov 1b','hadera','beit eliaezer','ISRAEL','38496','0544691631','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 16:18:40',0,NULL,3,1,3,1,NULL,'ç¢—ç½© P2   1 \rRR658662931CN'),(1780,635911002002,120644812085,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0024',27.9,'hermeshine','roger2008br','rogerioishikawa@uol.com.br','Rogerio Ishikawa','Rua Manoel Barbosa Filho, 345<br>Granja Olga III','Sorocaba','SÃ£o Paulo','BRAZIL','18017-228','55-15-3228-1414','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 16:25:51',0,NULL,3,1,3,1,NULL,'Canon A1 æ–°æ¬¾åŒ…ï¼Œ æˆ‘æ¥å§ï¼Œ\r563g\rRR658662928CN'),(1781,597271109001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'',35,'hermeshine','dis7784935','munadis@hotmail.com','mohamed munadis','H.oikolhuge<br>roashaneemagu','male\'','henvayru','MALDIVES','20033','009607784935','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:26:31',0,NULL,3,1,3,1,NULL,'800w 220v ç¯æ³¡  5\r132gï¼Ÿ\r RR658662914CN'),(1782,635931640002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dainius_67','dainius67@gmail.com','Dainius Aleliunas','Projektuotoju 12-71','Panevezys','','LITHUANIA','37131','(370) 68042471','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 17:10:27',0,NULL,3,1,2,1,NULL,' '),(1783,691126682015,250643703886,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'',7.99,'hutongstore','lebaneer1981','lebanneer@gmail.com','Darius Jonyla','Main Street, Collon \'Collon Furniture\'','Collon','Louth','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-22 17:31:27',0,NULL,3,1,2,1,NULL,'1.6x2.1m èƒŒæ™¯å¸ƒ  é»‘è‰²  1 '),(1784,635960554002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','brookebattery','brooke@pacific.net','Brooke Clarke','3425 Deerwood Dr.','Ukiah','CA','UNITED STATES','95482','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-22 18:08:08',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1785,597318345001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8.5,'hermeshine','chappersanddave','davidmichaels.odt@hotmail.com','Dave Rudkin','41 silken court','Nuneaton','Warwickshire','UNITED KINGDOM','cv11 5nn','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2010-11-22 18:10:46',0,NULL,3,1,2,1,NULL,NULL),(1786,691152189015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','shmulis','stalbergs@tvnet.lv','janis stalbergs','lielais pr.68-30','ventspils','','LATVIA','lv-3601','37126529567','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-22 18:11:15',0,NULL,3,1,2,1,NULL,''),(1787,597319597001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','brookebattery','brooke@pacific.net','Brooke Clarke','3425 Deerwood Dr.','Ukiah','CA','UNITED STATES','95482','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 18:11:44',0,NULL,3,1,1,1,NULL,'40cm æ£š  1\rå¤§åŠ›å¤¹   2 '),(1788,689606675015,250692242462,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',3.5,'hutongstore','lukecciara','ciaraluke@hotmail.co.uk','ciara luke','7 hillside view','newtonabbey','Antrim','UNITED KINGDOM','bt36 6de','07935095562','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 18:47:47',0,NULL,3,1,2,1,NULL,NULL),(1789,677759149016,260660053665,'New TianYa Star 6 points filters for Cokin P Series',1,'',7.8,'hutongstore','mjc771','collins.castledrive@ntlworld.com','Martin Collins','35 Castle Drive','Dover','Kent','UNITED KINGDOM','CT163EN','01304820786','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 19:02:07',0,NULL,3,1,2,1,NULL,'æ˜Ÿå…‰é•œ  star  4  1 '),(1790,636006018002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','chnkyeyes','ryu022@yahoo.com','Rex Yu','72 tangerine','irvine','CA','UNITED STATES','92618-4574','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 19:26:00',0,NULL,3,1,1,1,NULL,NULL),(1791,595037884001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','kristiem25','kristiemantle@hotmail.com','Kristie Mantle','8410 Centre street NE','calgary','AB','CANADA','T3K1Y1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 19:27:45',0,NULL,3,1,2,1,NULL,NULL),(1792,597399009001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','gr778899','gr778899@gmail.com','GREGORY ATHANASIADIS','15, Diou str, Ionia','Thessaloniki','','GREECE','GR-57008','6999778899','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 20:30:58',0,NULL,3,1,3,1,NULL,' RR658662826CN'),(1793,597402793001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','ruslanl','ruslanla@ukr.net','Ruslan Lyulya','11 Dudykina<br>108','Zaporizhzhya','Zaporizhzhya','UKRAINE','69065','38-050-6610745','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 20:40:10',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR658662905CN'),(1794,636067608002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',20,'AKT051',230,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 21:10:49',0,NULL,3,1,3,1,NULL,'lenspen  40\r1808g\r RR658662891CN'),(1795,691302937015,250692238279,'New 72mm 72 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','addo-d','addo-d@excite.com','Samuel Addo-Debrah','11 Garfield Street','Watford','Hertfordshire','UNITED KINGDOM','WD24 5HA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 21:51:44',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶  1 '),(1796,597440727001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','stiopatatata','dr.stef4o@abv.bg','Stefan Mladenov','7 High Street Buckingham House Dental Practice','Buckingham','Buckinghamshire','UNITED KINGDOM','MK18 1NT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 21:53:27',0,NULL,3,1,2,1,NULL,NULL),(1797,597456489001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','rosanolu','nrogic@exchange.ubc.ca','Novak Rogic','#1170-2329 West Mall','Vancouver','BC','CANADA','V6T 1Z4','(604) 221-6010','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 22:32:20',0,NULL,3,1,5,1,NULL,' \rCP212235247CN\r'),(1798,636108141002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','moni-maga-sym','moniimages@yahoo.com','Monica Larson','7226 W Sheila Ln','phoenix','AZ','UNITED STATES','85033-4337','(623) 266-2683','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 22:35:02',0,NULL,3,1,1,1,NULL,' '),(1799,691348917015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'',1.88,'hutongstore','js_almada','js.almada87@gmail.com','Santiago Almada','Lupton Flats, Alma Road, Block D Room 2.12','LEEDS','West Yorkshire','UNITED KINGDOM','LS6 2PG','7505657609','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 23:21:00',0,NULL,3,1,2,1,NULL,'77mm lenscap nikon  1 '),(1800,636129610002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','john4160','jbjcdj@yahoo.com','John Jeffers','25399 Broadway Road','Morton','IL','UNITED STATES','61550','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 23:34:34',0,NULL,3,1,1,1,NULL,'6662a å¿«è£…æ¿    1'),(1801,636133140002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','hp_777','evergreen_frn@yahoo.com.au','Helen Paulus','10 Pambula Ave','Prestons','New South Wales','AUSTRALIA','2170','0287839277','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 23:46:13',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR658662874CN'),(1802,597486488001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','pauleljoda','eljoda@hotmail.com','paul zambrano','r. euclides da cunha, 1387<br>apto 101','Curitiba','ParanÃ¡','BRAZIL','80730-360','(041) 9137-7475','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 00:16:08',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1803,636139057002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','pauleljoda','eljoda@hotmail.com','paul zambrano','r. euclides da cunha, 1387<br>apto 101','Curitiba','ParanÃ¡','BRAZIL','80730-360','(041) 9137-7475','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 00:16:09',0,NULL,3,1,2,1,NULL,'58mm é•œå¤´ç›–  canon  1\r77mm é•œå¤´ç›–  canon  1 '),(1804,597493669001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','sell2ski','sell2ski@hotmail.com','Tim Grant','3035 Uplands Dr SE','Grand Rapids','MI','UNITED STATES','49506-1932','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 00:35:56',0,NULL,3,1,1,1,NULL,NULL),(1805,636148404002,120564178566,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.77,'hermeshine','domduf78','dominicdufault@hotmail.com','Dominic Dufault','3895 Lavoie','St-Hubert','QC','CANADA','J3Y 5E3','(450) 445-4101','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 00:47:21',0,NULL,3,1,2,1,NULL,' '),(1806,597511576001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','aravena562','jaravenaa@mi.cl','juan carlos aravena acuna','Pasaje Santiago de Compostela #1834<br>Villa Mirador de la Bahia','Puerto Montt','Decima Region','CHILE','5480000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 01:48:03',0,NULL,3,1,2,1,NULL,' '),(1809,636193504002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','henryyxyu','henryyxyu@gmail.com','Henry Yu','5173 Maison Ave','Los Angeles','CA','UNITED STATES','90041-1623','(323) 257-7609','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 03:23:34',0,NULL,3,1,1,1,NULL,' '),(1807,592070727001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','kweenofcanada','retromodern2@gmail.com','Rick Fritschy','111 Cunnington AVE.','Winnipeg','MB','CANADA','R2M 0W6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 02:28:23',0,NULL,3,1,2,1,NULL,NULL),(1808,636181753002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','r_trelles','rtrelles@bellsouth.net','Rick Trelles','PO Box 650264','Miami','FL','UNITED STATES','33265-0264','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-23 02:41:59',0,NULL,3,1,1,1,NULL,NULL),(1810,597543795001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','burs','bursey3@cogeco.ca','paul e. bursey','2153 sunnyvale Dr','Oakville','ON','CANADA','l6l1w6','(905) 847-9573','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 03:59:12',0,NULL,3,1,2,1,NULL,' '),(1811,597554362001,110502916835,'New 62mm ring adapter replacement for cokin P series',1,'AA2211',3.55,'hermeshine','ta_tum','thossapon@infomec-it.com','thossapon kammoon','32/7 moo2 klong9<br>rangsit-nakornnayok road. brungsanan','tanyaburi','Patumtani','THAILAND','12110','6629089249','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 04:56:53',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶'),(1812,636213903002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','ta_tum','thossapon@infomec-it.com','thossapon kammoon','32/7 moo2 klong9<br>rangsit-nakornnayok road. brungsanan','tanyaburi','Patumtani','THAILAND','12110','6629089249','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 04:58:01',0,NULL,3,1,2,1,NULL,'3pcs æ»¤é•œè¢‹  1\r62mm æŽ¥å£çŽ¯  1 '),(1813,597564945001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','plainamericanguy','grandbob@gmail.com','Robert Otey','3824 Virginia Avenue SE','Charleston','WV','UNITED STATES','25304-1508','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 06:05:54',0,NULL,3,1,1,1,NULL,NULL),(1814,636224815002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','willax1','willirotorua@aol.com','wilhelm werner','65 utuhina road','Rotorua','BOP','NEW ZEALAND','3015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 06:07:27',0,NULL,3,1,3,1,NULL,NULL),(1815,636231707002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','pepster-returns','arcoona.estate@bigpond.com','Peter Burke','12 Arcoona Avenue','Rostrevor','South Australia','AUSTRALIA','5073','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 06:54:04',0,NULL,3,1,6,1,NULL,'EE520583661CN\r'),(1816,636248083002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','spiritrx-7','dragntek@hotmail.com','henry   lam','2624 darwin ave','los angeles','CA','UNITED STATES','90031','(323) 788-5896','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-23 08:28:30',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹   1 '),(1817,597593243001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64.99,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Kazankov Valery','Rokossovskogo avenue, 115, appartment 3','Minsk','','BELARUS','220085','+375447127692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 09:01:10',0,NULL,3,1,3,1,NULL,'çº¢å¤´ç¯ 1\r800w 220v  1\ræŽ§åˆ¶2kg  \rRA022499146CN\r'),(1818,636257780002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ttuffghost','c.gian@yahoo.com','Christopher Gian','2826 Telegraph Ave<br>Apt 1','Berkeley','CA','UNITED STATES','94705-1125','(714) 305-4003','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 09:17:24',0,NULL,3,1,1,1,NULL,' '),(1819,636258900002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','adorroimpressions13','adorroimpressions@gmail.com','Jessica Wolfe','Katrina Christ Photographer<br>58 Burwood Rd','Hawthorn','Victoria','AUSTRALIA','3122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 09:20:12',0,NULL,3,1,2,1,NULL,NULL),(1820,597610105001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','brandokhoo','bckkhoo@hotmail.com','Brando Khoo','2418 Talavera Dr','San Ramon','CA','UNITED STATES','94583-2226','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 10:16:09',0,NULL,3,1,1,1,NULL,'  67MM adapter ring and ND2 + ND4 + ND8 filters, and the holder '),(1821,678105153016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'',120,'hutongstore','oldxavier','pinechip25@yahoo.it','Saverio Giaquinta','via Nervi, 7','Ravenna','RA','ITALY','48100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-23 10:47:29',0,NULL,3,1,4,1,NULL,'2mç¯æž¶ 2\r4ç¯å¤´æ£š  æ¬§æ ‡  2\r45w 220v  8\råŒ…  1 \rlighting kit  $30\rYW864143123CN\r'),(1822,636279146002,120601700875,'TianYa New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','mariagonzalez80','mariagonzalezmarro@hotmail.com','Maria Gonzalez Marro','C/ Bilbao 237, 6Âº 3Âª Esc. 7','Barcelona','CataluÃ±a','SPAIN','08018','630088027','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 10:50:08',0,NULL,3,1,2,1,NULL,''),(1823,636279585002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','cooper74ura','urpl999@gmail.com','Ura Plusnin','Vostrecova d. 3 kv. 106','Cheliabinsk','ru','RUSSIAN FEDERATION','454106','81079043069971','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 10:51:42',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž  1 \rRR723016303CN\r'),(1824,636283437002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','mantonnet','netmarn@gmail.com','Navin Thongdee','THAI CHAINS<br>2/99 Moo 14  Seri Thai 58 Rd,Minburi','Minburi','Bangkok','THAILAND','10510','+66850564399','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 11:05:36',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(1825,636285352002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','pedrosanc','pedrosan@ono.com','Pedro Vicente Sanconstantino Ossorio','Pedro Vicente Sanconstantino Ossorio<br>Carrera Fuente San LuÃ­s, 62 -7','Valencia','Valencia','SPAIN','46013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 11:11:02',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(1826,597629152001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','martinsubrt','mar_s@centrum.cz','Martin Å ubrt','PÅ™Ã­ÄnÃ¡ 254/5','Bolatice','','CZECH REPUBLIC','74723','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 11:32:20',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1827,636290176002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','martinsubrt','mar_s@centrum.cz','Martin Å ubrt','PÅ™Ã­ÄnÃ¡ 254/5','Bolatice','','CZECH REPUBLIC','74723','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 11:32:20',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rå•ç¯å¤´  1 æ¬§æ ‡ \råå…‰ä¼ž  1\r115w 220v  1 \ré‡é‡ï¼ŸRR723016351CN\r'),(1828,597633560001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','captaindanieo','josedanielps@gmail.com','Jose Daniel PÃ©rez Serralvo','Escritor Angel Palomino nÂº3 bq1 2ÂºC','Torremolinos (MÃ¡laga)','AndalucÃ­a Ceuta y Melilla','SPAIN','29620','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 11:50:08',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864143101CN'),(1829,636020910002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','kenaram55','dafzal@yahoo.com','Dawood Afzal','1403 Queens Ct<br>Apt C','Kirksville','MO','UNITED STATES','63501-2798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 12:53:58',0,NULL,3,1,1,1,NULL,' '),(1830,597657077001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','digital-nala','dzt2000@hotmail.com','Gang-hun Lee','314-55, 2F<br>Inchang-dong','Guri-si','Gyeonggi-do','KOREA,REPUBLIC OF','471-833','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 13:17:47',0,NULL,3,1,2,1,NULL,''),(1831,635529093002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ejar5071','teddy2084428@yahoo.com','Elzbieta Jaracz','6009 69th ave<br>1Fl','Ridgewood','NY','UNITED STATES','11385-5139','(718) 366-3958','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 13:19:13',0,NULL,3,1,1,1,NULL,' '),(1832,597681340001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','delicioussakura','shadow404@gmx.net','Katharina Barkley','3-10-19 kitahama<br>Noda bldg. 205','Beppu','Oita','JAPAN','8740920','08067875678','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 14:38:28',0,NULL,3,1,6,1,NULL,'2mx3m èƒŒæ™¯æž¶ 1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\råŒç¯å¤´  2\råå…‰ä¼ž 2\råŒ…  1\r æ–°åŠ å¡ EMS\rEX000080445SG\r'),(1833,636362685002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','brogers121','rogerscreativenh@yahoo.com','Bill Rogers','323 Powder Mill Rd','Alton','NH','UNITED STATES','03809-4937','(603) 875-8315','NoPaymentFailure','CheckoutComplete','Other','2010-11-23 15:25:27',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRA022499075CN\r'),(1834,597721930001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','omerunlu','omerunlu@yahoo.com','Dr. DT. Omer Unlu','TepebaÅŸÄ± AÄŸÄ±z ve DiÅŸ SaÄŸlÄ±ÄŸÄ± Merkezi<br>GÃ¼Ã§lÃ¼ Kaya Mah. Fatih Cad. Ã‡aÄŸla Sok. No:2 KeÃ§iÃ¶ren','Ankara','','TURKEY','06310','4954847','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 16:37:07',0,NULL,3,1,2,1,NULL,''),(1836,597723574001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','jeanjb2007','raptormatrix137@hotmail.com','jeanj breau','48 rue de l\'eglise','neguac','NB','CANADA','e9g 1b8','(506) 776-8795','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 16:41:17',0,NULL,3,1,2,1,NULL,NULL),(1837,597702193001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11.2,'hermeshine','dziknsk','dkhodarenok@gmail.com','Dmitry Khodarenok','Pechatnikov str. 1-24','Novosibirsk','','RUSSIAN FEDERATION','630057','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 16:46:10',0,NULL,3,1,2,1,NULL,' '),(1838,597728520001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',4,'AB1301',13.36,'hermeshine','malldova1st','z55001987@rambler.ru','Eugeniu Grosul','str.Podul Inalt 14/2 ap.12','Chisinau','','MOLDOVA, REPUBLIC OF','2023','37368221313','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 16:52:47',0,NULL,3,1,2,1,NULL,''),(1839,597738434001,110566021597,'New YN Flash Battery Pack SF-17 Canon Flash 580EX CP-E4',2,'AB3313',82.98,'hermeshine','stanshih2007','stanshihcomputers@gmail.com','Paul Khoury','530 S Lake Ave<br>Ste 350','Pasadena','CA','UNITED STATES','91101-3515','(818) 209-7168','NoPaymentFailure','CheckoutComplete','Other','2010-11-23 17:23:29',0,NULL,3,1,1,1,NULL,''),(1840,636431803002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','diogof88','diogof1988@hotmail.com','Diogo Ferreira','Rua D.LourenÃ§o de Almeida nÂº13','Lisbon','Lisboa','PORTUGAL','1400-125','+ 351 96 86 86 080','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 18:18:37',0,NULL,3,1,2,1,NULL,NULL),(1841,678314262016,260660050674,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'',16.99,'hutongstore','aaronlava','letsburndownsomethingbeautiful@hotmail.co.uk','aaron leaman','25 arnison avenue','high wycombe','Buckinghamshire','UNITED KINGDOM','hp13 6dd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-23 19:00:45',0,NULL,3,1,2,1,NULL,''),(1842,636464235002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','mannel2411','t092728s@terra.es','Manuel Hernandez Garcia','Avda. Ventisquero de la Condesa, 7, ptal. B, 4Âº D','MADRID','Madrid','SPAIN','28035','913 76 51 90','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 19:11:10',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon  1 '),(1843,597804968001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','sekstiseks','syttisyv@gmail.com','Fredrik Aasland','GrÃ¥steinveien 20','OSLO','OSLO','NORWAY','1157','004790162108','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 19:31:35',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723016285CN\r'),(1844,636475794002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','nurzur','kristijan.vuckovic@gmail.com','Kristijan Vuckovic','Ruziceva 31','Rijeka','Croatia','CROATIA','51000','+385917361999','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 19:32:21',0,NULL,3,1,2,1,NULL,''),(1845,691795151015,250606688659,'New IR Remote Control for Pentax K10D K20D K100D',1,'',2.75,'hutongstore','jasonpm007','jpmarsh007@gmail.com','jason marsh','104 tamar house james street devonport','plymouth','Devon','UNITED KINGDOM','pl1 4hj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-23 20:12:52',0,NULL,3,1,2,1,NULL,'5åˆ1 çº¢å¤–é¥æŽ§   1 '),(1846,597821403001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','radubogdan87','radu.bogdan@yahoo.com','Bogdan Radu','133 Stefan cel Mare Street','Sibiu','Sibiu','ROMANIA','550321','0040727821388','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 20:17:20',0,NULL,3,1,2,1,NULL,''),(1847,597830979001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','spacylittlecowgirl','fyrelyzard@yahoo.com','Florence Chan','16 Dallimore Circle<br>Unit #201','North York','ON','CANADA','M3C 4C4','(416) 919-1761','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 20:18:48',0,NULL,3,1,3,1,NULL,'52mm-77mm æŽ¥å£çŽ¯  ä¸€å¥—\ræ‰˜æž¶  1 \rRA022499225CN\r'),(1848,633100236002,120562082179,'Photo Studio Background Support (2mÃ—2m)+ Free Backdrop',1,'AO0002',96.8,'hermeshine','strelez57','nnproton612@gmail.com','ARKADY RABINOVICH','YEHUDA HAMACCABI 31room2','ASHDOD','','ISRAEL','77544','','NoPaymentFailure','CheckoutComplete','AU_OtherInternational','2010-11-23 20:24:47',0,NULL,3,1,8,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ï¼‰  1 \rCP212235065CN\r'),(1849,691817373015,250692240898,'Wireless Remote Shutter Release for Sony A900/A200/â€‹A10',1,'',11.47,'hutongstore','hastingsseagulls','kurtvinz@hotmail.com','vincent geli','2-4 holmesdale garden flat 12 furness mount','hastings','East Sussex','UNITED KINGDOM','tn34 1ly','01424425076','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-23 20:46:52',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ S1  1 '),(1850,636526157002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','alejasena16041983','alejasena@hotmail.com','Vanessa HernÃ¡ndez MuÃ±oz','C/La Chercha. NÂº77<br>La Gallega','Santa Cruz de Tenerife','Canarias','SPAIN','38107','686920799','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 20:59:12',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ï¼‰  1\r2m ç¯æž¶  2\råŒç¯å¤´ 2 æ¬§æ ‡\råå…‰ä¼ž  2\r115w 220v   4\råŒ…   1\rlighting kit $30\r YW864143112CN\r'),(1851,636533253002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'',39,'hermeshine','spos86','spos86@gmail.com','Paolo Esposito','606 Greenville Ave','Staunton','VA','UNITED STATES','24401','(301) 237-3689','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-23 21:12:49',0,NULL,3,1,1,1,NULL,'800w 110v   5 '),(1852,595641522001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','minoltiano_es','hgb@wanadoo.es','HIGINIO GOMEZ BARRERAS','C/ Manzanares, 15 - 1Âº A','La Penilla de CayÃ³n','Cantabria','SPAIN','39650','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 22:19:36',0,NULL,3,1,3,1,NULL,'Nikon æ‘„å½±èƒŒå¿ƒ XXXL   1 \rRA022499234CN\r'),(1853,691877230015,250599423735,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'',1.88,'hutongstore','elsinore001','dickie.gallagher@gmail.com','Richard Gallagher','1st Floor Flat 53 Bovill Road','London','London','UNITED KINGDOM','SE23 1EX','07748430022','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-23 22:27:39',0,NULL,3,1,2,1,NULL,NULL),(1854,636573012002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','marcomention','occasionsandbeyond@yahoo.com','MARCO MENTION','4801 Baker Grove Rd NW<br>Apt 503','ACWORTH','GA','UNITED STATES','30101-6331','(404) 399-3452','NoPaymentFailure','CheckoutComplete','Other','2010-11-23 22:43:06',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRA022499248CN\r'),(1855,636593418002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','tlee02','tlee83@gmail.com','Taehune Lee','3101 N Hampton Dr<br>Apt 314','Alexandria','VA','UNITED STATES','22302-1520','(806) 681-1614','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 23:42:01',0,NULL,3,1,1,1,NULL,NULL),(1856,597916466001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',3,'AE1302',29.4,'hermeshine','f.lopes10','almirflmoura@yahoo.com.br','almir fontes lopes de moura','av.oliveira bello n 1179 /301<br>vila da penha','rio de janeiro','RI','BRAZIL','21221-300','212481-1985','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 23:47:49',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶'),(1857,597916273001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','susnosversus','susnosversus@gmail.com','diego galvan','gran via 12  6Âºdcha','San Sebastian','PaÃ­s Vasco','SPAIN','20002','675592652','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 23:48:46',0,NULL,3,1,2,1,NULL,'115w 220v   1 '),(1858,597917681001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64.99,'hermeshine','jayaraujo','jay@lacedinteractive.com','JOAO LUIZ MARQUES ARAUJO JR','Rua Fidalma Martins de Carvalho 4355<br>Bloco 2 - Apartamento 202 Bairro Ininga','Teresina','Piaui','BRAZIL','64048-190','+55 86 3237 1915','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 23:49:55',0,NULL,3,1,3,1,NULL,'çº¢å¤´ç¯  1\r800w 220v  1\ræŽ§åˆ¶é‡é‡2kgä»¥ä¸‹ \rRA022499251CN\r'),(1859,636605442002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','f.lopes10','almirflmoura@yahoo.com.br','almir fontes lopes de moura','av.oliveira bello n 1179 /301<br>vila da penha','rio de janeiro','RI','BRAZIL','21221-300','212481-1985','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 00:24:42',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶ 1\ræ–œè‡‚  1\r50-70 æ£š  1 \rå•ç¯å¤´ 3 \ræ£€æŸ¥ä¸€ä¸‹è¦æ˜¯ç¾Žæ ‡çš„\r3300ï¼Ÿ\rCP212150572CN\r'),(1860,636617212002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mariepiert90','marie_pier_t90@msn.com','marie-pier Tremblay','495 J.R.ThÃ©berge','chicoutimi','QC','CANADA','g7j 3s3','(418) 545-3473','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 01:08:32',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1 \rRR723016215CN\r'),(1861,596205163001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','jkobcso','jko@zoomtown.com','Jennifer Kotzbauer','4655 Catalpa Ct','Burlington','KY','UNITED STATES','41005','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 01:16:09',0,NULL,3,1,1,1,NULL,'ä¸­å·é•œå¤´ç­’  1 '),(1862,597118309001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',52.99,'hermeshine','sonjarothwell888','sonja_888@hotmail.com','Sonja Rothwell','P.O. Box 1178','Wangaratta','Victoria','AUSTRALIA','3677','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2010-11-24 01:42:33',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\räº‘å° 1\ræŸ”å…‰ä¼ž  1 \rRA022499163CN\r'),(1863,597946063001,110533631413,'CTR-301P Flash Trigger Kit with 2 Receivers ctr301p',1,'AKT001',41.9,'hermeshine','kufrik','stano1@optonline.net','Stanislav Repko','251 PORT READING AVE','PORT READING','NJ','UNITED STATES','07064-1925','(908) 787-5249','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-24 01:46:50',0,NULL,3,1,1,1,NULL,'301p ä¸€æ‹–äºŒ  1 '),(1864,597528493001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','93nx2k','93nx2k+ebay@gmail.com','Vinnie Nguyen','PO Box 21802','San Jose','CA','UNITED STATES','95151-1802','(408) 828-4237','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 02:16:15',0,NULL,3,1,1,1,NULL,NULL),(1865,597476536001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','nameohname','psychonoetic@gmail.com','Fotios Vrionis','70 LYNDEN STREET, CAMBERWELL','MELBOURNE','Victoria','AUSTRALIA','3124','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 03:25:52',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRA022499177CN\r'),(1866,636666197002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',3,'AA1309',7.4,'hermeshine','danit8569','danit6985@yahoo.com','Daniel Dyar','8020 Sunny Ln','Fort Wayne','IN','UNITED STATES','46835','(812) 278-6172','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 04:26:05',0,NULL,3,1,1,1,NULL,NULL),(1867,636670557002,120601698793,'Canon 58mm Reverse Adapter 50mm 1.4 40D 7D 5DII Macro',1,'AA1208',4.4,'hermeshine','james007th','viman_w@yahoo.com','wiman worasiriwat','kp house 9 sukhumvit 62 road<br>yak3 soi rim-tang-daun 4 bangchak','prakhanong','bangkok','THAILAND','10260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 04:50:58',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1868,636670448002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','james007th','viman_w@yahoo.com','wiman worasiriwat','kp house 9 sukhumvit 62 road<br>yak3 soi rim-tang-daun 4 bangchak','prakhanong','bangkok','THAILAND','10260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 04:50:58',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1869,636670497002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3401',2.6,'hermeshine','james007th','viman_w@yahoo.com','wiman worasiriwat','kp house 9 sukhumvit 62 road<br>yak3 soi rim-tang-daun 4 bangchak','prakhanong','bangkok','THAILAND','10260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 04:50:59',0,NULL,3,1,2,1,NULL,'580ex è‚¥çš‚ç›’ 1\r58mm - canon åæŽ¥çŽ¯  1\r72mm é•œå¤´ç›–  canon  1'),(1870,597989110001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',75,'hermeshine','tecworks10','citizengav-1@yahoo.com.au','Wallace Gavin Lardner','13/5 Clancy Crt','Tugun','Queensland','AUSTRALIA','4224','0756070458','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2010-11-24 05:07:41',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rç¯æž¶  1\rRR723016229CN\r'),(1871,636682472002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','proforica','profor@vanea.net','IVAN PROFOR','Sciusev 4/8','Balti','Balti','MOLDOVA, REPUBLIC OF','3100','37369833368','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 06:01:34',0,NULL,3,1,3,1,NULL,' 2mç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž  1\r\rRR723016232CN\r'),(1872,636687268002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','anko3452','busi4avk@gmail.com','Andrey Kozhevnikov','proezd Solnechny 5 - 109','Tyumen','','RUSSIAN FEDERATION','625022','+79058201992','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 06:34:02',0,NULL,3,1,2,1,NULL,'50cm æ£š  1 '),(1873,597899410001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',6.6,'hermeshine','pekesurf','kaslokapacha@hotmail.com','Esther GarcÃ­a','Petrarca 6,  3Âº  2Âª','Sabadell','Barcelona','SPAIN','08206','937171609','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 06:46:38',0,NULL,3,1,2,1,NULL,'52mm uv   2 '),(1874,598005408001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.95,'hermeshine','photos6288','ttocsm@gmail.com','Matt Scott','14 Cantonments Rd<br>Lyttelton Manor','Centurion','Gauteng','SOUTH AFRICA','0157','0732128584','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 06:55:06',0,NULL,3,1,2,1,NULL,NULL),(1875,598008554001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','miroslavkatrak','miroslav.katrak@gmail.com','Miroslav Katrak','VyÅ¡nÃ¡<br>5','KoÅ¡ice Slovakia','','SLOVAK REPUBLIC','00421','00421907481988','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 07:46:01',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´  1 æ¬§æ ‡\r '),(1876,636703217002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','balintkiss','valentine969@gmail.com','Strasser Katalin','Kassai utca 166/b','Budapest','Pest','HUNGARY','1142','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 08:07:45',0,NULL,3,1,3,1,NULL,'RR723016294CN\r'),(1877,636246783002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','koen20102010','koenvanderjagt@upcmail.nl','Koen van der Jagt','Buitenweg 21','Krimpen aan de Lek','','NETHERLANDS','2931AC','0031180521022','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 08:41:45',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 \rRR723016246CN\r'),(1878,636477825002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','acesnakas','a.cesnakas@gmail.com','Audrius Cesnakas','Ukmerges g. 224-42','VILNIUS','','LITHUANIA','07162','+37060166236','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 08:54:38',0,NULL,3,1,2,1,NULL,NULL),(1879,598037037001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','vaidas.m','turistas30@hotmail.com','Vaidas Morkevicius','R.Jukneviciaus 48-41','Marijampole','','LITHUANIA','68201','+37065994399','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 09:40:36',0,NULL,3,1,2,1,NULL,NULL),(1880,598040658001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','tarmarlai','tarja.laitinen@gmail.com','Tarja Laitinen','Niittykallio 2 F 48','ESPOO','','FINLAND','02200','+358 40 709 5731','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 09:56:15',0,NULL,3,1,2,1,NULL,'115w 220v  1 '),(1881,689503733015,250692239871,'Photo Studio Background Support (2mÃ—2m)+ Free Backdrop',1,'',46.9,'hutongstore','2009yazza','blondy_x_1990@hotmail.com','yasmin graham','32 cromwell close walcote','lutterworth','Leicestershire','UNITED KINGDOM','LE17 4JJ','01455698987','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-11-24 10:00:07',0,NULL,3,1,4,1,NULL,'background support  $20 \rYW864143263CN'),(1883,692100073015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'',7.48,'hutongstore','voldinsh','valdis.andersons@apollo.lv','Valdis Andersons','21, Ventas Str.','Liepaja','','LATVIA','LV-3407','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-24 11:45:34',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(1884,598077476001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',2,'AB3307',99.98,'hermeshine','luizacfbr','luizacf@gmail.com','Luiz Ferreira','R Pedroso , 486 cj 44','Sao Paulo','sp','BRAZIL','01322010','55 11 32894599','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 12:23:13',0,NULL,3,1,10,1,NULL,'sf18-canon   2 RF052234730SG8\r'),(1885,598083473001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','shemeshmor','mor@shafit.com','mor shemesh','kfar warburg','kfar warburg','','ISRAEL','70998','972544726838','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 12:45:38',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶  1 '),(1886,636772519002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','stelevan','stelevan@yahoo.it','Stefano Cristiani','Corso Cavour 118 c/o chiosco edicola','Barletta','BA','ITALY','70051','3477947366','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 12:57:16',0,NULL,3,1,2,1,NULL,''),(1887,678692705016,260660054309,'Shutter Release Remote Cord For Canon 550D 450D RS-60E3',1,'',2.98,'hutongstore','larslidgren','larlid@gmail.com','Lars Lidgren','Thulegatan 7','HÃ¤ssleholm','Sweden','SWEDEN','28139','4645141201','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-24 13:25:37',0,NULL,3,1,2,1,NULL,'RS-C1   1 '),(1888,692156743015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','khaledroshdy','khaledroshdy@hotmail.com','Khaled Roshdy','19 The Quadrangle','Manchester','Greater Manchester','UNITED KINGDOM','M1 5QF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-24 14:25:24',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´  1 '),(1889,692163847015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','utchyba','bd4vy@aol.com','craig davy','42 montague road, north end','portsmouth','hampshire','UNITED KINGDOM','po2 0nf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-24 14:41:50',0,NULL,3,1,2,1,NULL,'45w   2 '),(1890,636824473002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','rockelis','rokas.rokelis@gmail.com','Rokas Bubelis','Taikos pr. 58-24','Kaunas','','LITHUANIA','51303','+37062769295','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 15:40:24',0,NULL,3,1,3,1,NULL,'ç”³æŠ¥ gift $10 \rRA022499305CN\r'),(1891,598141389001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','vader2501','jim_jaroo@yahoo.co.uk','john morris','31 Alwen<br>Plas Madoc','Wrexham','Wrexham','UNITED KINGDOM','LL14 3ET','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 15:54:55',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶  ï¼ˆ ç™½ é»‘ï¼‰  1 \rbackground support  $25\rYW864143171CN\r'),(1892,598145011001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',3,'AB1303',10.02,'hermeshine','turquoise-web','turquoise.web@gmail.com','GURSOY HAFIZOGLU','HURRIYET MAH. 276 SOK. NO:7/3<br>GAZIOSMANPASA','ISTANBUL','IST','TURKEY','34240','(212) 537 6390','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 15:59:41',0,NULL,3,1,2,1,NULL,''),(1893,598168747001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','roodyroody','ojilly@gmail.com','Jill Petersen','36 Settler\'s Landing Drive','Belleville','ON','CANADA','K8N 4Z2','(613) 969-9860','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 17:01:47',0,NULL,3,1,2,1,NULL,NULL),(1894,598182213001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','kobiavr69','kobiavraham69@yahoo.com','kobi avraham','Ben Hur 4/12<br>Em Hamoshavot','Petach Tikva','','ISRAEL','49063','+972578124269','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 17:33:19',0,NULL,3,1,2,1,NULL,'æŸ¥ï¼Œåº”è¯¥æ˜¯æ¼å‘äº† '),(1895,598192306001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jfreyesjr','rjj2jljr2@yahoo.com','JOSE REYES','10527 W Chautauga MTN','LITTLETON','CO','UNITED STATES','80127-3858','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 17:53:05',0,NULL,3,1,1,1,NULL,' '),(1896,598214173001,110566018900,'EW-73II Lens Hood lenshood for Canon EF 24-85 /f3.5-4.5',1,'AA3404',8.99,'hermeshine','rick42d','rick42@waterw.com','Richard DeCristofaro','18 Fir Lane','Voorhees','NJ','UNITED STATES','08043','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 18:38:30',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1897,636903830002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','rick42d','rick42@waterw.com','Richard DeCristofaro','18 Fir Lane','Voorhees','NJ','UNITED STATES','08043','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 18:39:45',0,NULL,3,1,1,1,NULL,'67mm é•œå¤´ç›– canon  1\rEW-73II   1 '),(1898,636924115002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','n8ciz','combs6136@yahoo.com','carl a. combs','2288 Oxford Middletown Rd','hamilton','OH','UNITED STATES','45013-9751','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 19:18:46',0,NULL,3,1,1,1,NULL,NULL),(1899,692313607015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'',22,'hutongstore','gab00pok','gabriel.vigo@gmail.com','Gabriel Vigo','207 Odessa Road','London','London','UNITED KINGDOM','E79DX','07957308234','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-24 19:22:12',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRA022499217CN\r'),(1900,692341153015,250666866568,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'',62,'hutongstore','2bstylish','mamaliebox-ebay@yahoo.co.uk','Mr M Parkook','31 Grahame Park Way','Mill Hill','London','UNITED KINGDOM','NW7 2LA','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-11-24 20:03:03',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚  1\r50-70 æ£š  1\r115w 220v  1\rYW864143252CN\rlighting kit  $22'),(1901,598253897001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','viva_villa_productions','247help@vivipro.org','Guillermo Villa','810 E 14th St<br>Ste 193','Brownsville','TX','UNITED STATES','78520-5714','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 20:13:07',0,NULL,3,1,1,1,NULL,NULL),(1902,636964035002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','radkolesay','rlesay@gmail.com','Radoslav Lesay','530 Riverdale Ave<br>Apt 6K','Yonkers','NY','UNITED STATES','10705-3558','(646) 620-1190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-24 20:26:19',0,NULL,3,1,1,1,NULL,''),(1904,597863917001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',4,'AB1302',26.72,'hermeshine','moppersmurfje1971','mario@redeker.nl','Mario Redeker','Elise van Calcarstraat 66','Den Haag','','NETHERLANDS','2522MD','0622929989','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 20:38:14',0,NULL,3,1,3,1,NULL,'55mm æ©¡èƒ¶ç½©  4\r58mm æ©¡èƒ¶ç½©   4\rRA022499279CN\r'),(1905,598291783001,110471802137,'New Rotate Flash Bracket for Canon Nikon VH 2000',1,'AB3316',25.99,'hermeshine','jpyem','wgwxnuso@panamanetbuy.com','Panama Netbuy','8424 NW 56th St<br>Ste PTY-1779','Doral','FL','UNITED STATES','33166-3327','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 21:00:50',0,NULL,3,1,1,1,NULL,'Låž‹æ”¯æž¶  1 \ré‡é‡'),(1906,692394782015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'',2.39,'hutongstore','debian.user','peter@millarduk.com','peter millard','10 Antrim Close','basingstoke','Hampshire','UNITED KINGDOM','RG22 5BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-24 21:22:00',0,NULL,3,1,2,1,NULL,'67mm æŽ¥å£çŽ¯   1 '),(1907,598304832001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','ivarsk9598','ivars.kukainis@apollo.lv','Ivars Kukainis','Valdeku 50/1-33','Riga','Latvia','LATVIA','LV-1058','+37126549201','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 21:29:57',0,NULL,3,1,3,1,NULL,'æ–°çš„é‚£ä¸ªç¯æž¶  1\ré‡é‡ï¼Ÿ 1595\rRA022499282CN\r'),(1908,636998523002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','tingzhao1688','vincent82123@hotmail.com','Min Wong','10352 Stone Ave N<br>Apt 6','seattle','WA','UNITED STATES','98133-9494','(206) 605-3138','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 21:31:03',0,NULL,3,1,1,1,NULL,' '),(1909,692409652015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','meretemusen','jon@enovo.dk','Merete Jensen','Pebermyntevej 69 2.sal.th','Viborg','Jylland','DENMARK','8800','(0045)23270418','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-24 21:51:39',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´  1 '),(1911,637048629002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',2,'AA1303',5,'hermeshine','kimbenstore','kimbenstore@gmail.com','Phillip Nguyen','2006 W 3rd Ave','Kennewick','WA','UNITED STATES','99336','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 23:52:12',0,NULL,3,1,1,1,NULL,NULL),(1912,637070164002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','jdavis9184','jeffdavis82778@gmail.com','jeffrey Davis','12689 stallion CT','Jacksonville','FL','UNITED STATES','32223-2094','(904) 260-9793','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-11-25 01:23:34',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶ 1\råå…‰æ¿æ”¯æž¶  1 \rYW864143230CN\rlight stand  1 '),(1915,598384943001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','dll003','dll_cisfca@yahoo.com','David Leo','730 17th Avenue','San Francisco','CA','UNITED STATES','94121','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 02:18:19',0,NULL,3,1,1,1,NULL,'ä¸­å·é•œå¤´ç­’  1 '),(1916,598385323001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','sonographer56','delizzio209@comcast.net','david delizzio','209 swedes run dr','delran','NJ','UNITED STATES','08075-2117','(856) 764-7825','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 02:20:36',0,NULL,3,1,1,1,NULL,NULL),(1917,598393909001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cjyards588','jbpanka@juno.com','Roger Knepp','58216 Olde Towne Dr','Goshen','IN','UNITED STATES','46528-8916','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 03:01:50',0,NULL,3,1,1,1,NULL,NULL),(1918,598397625001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','wyatt2502008','wyatt250@gmail.com','Mark Wyatt','409-3868<br>Shelbourne Street','Victoria','BC','CANADA','V8P5J1','(250) 590-1039','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 03:20:12',0,NULL,3,1,2,1,NULL,NULL),(1919,637101276002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','plumcrazy65','mike@plumcrazy.ca','Michael McLaughlin','6715 Cools Rd','Vernon','BC','CANADA','V1B3T2','(250) 542-7022','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 03:47:42',0,NULL,3,1,2,1,NULL,NULL),(1927,598467975001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','semircok','gurnik@gmail.com','Marianna Janeczkova','Galakticka 34','Kosice','Slovakia','SLOVAK REPUBLIC','04012','+421911100700','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 10:07:52',0,NULL,3,1,2,1,NULL,NULL),(1928,597577712001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','mrgattermaier','gattermaier@ig.com.br','Oscar Gattermaier Junior','Gorge Road<br>47/159','Queenstown','Otago','NEW ZEALAND','9300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 10:55:52',0,NULL,3,1,2,1,NULL,' '),(1929,679186158016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','monkjunior','dave@davewhite.com.au','David J White','PO Box 599','Waverley','New South Wales','AUSTRALIA','2024','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-11-25 12:08:32',0,NULL,3,1,6,1,NULL,' 2mx3mèƒŒæ™¯æž¶ 1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶ 2\r50-70æ£š æ¾³æ ‡  2\r115w 220v   2\råŒ…   1\rçœ‹çœ‹ä½“ç§¯æ˜¯å¦å¯ä»¥å‘æ–°åŠ å¡ems\rEX000041637SG'),(1930,637203512002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','salaba_tadeas','salaba.tadeas@yahoo.com','Tadeas Salaba','Dolni Libchavy 261<br>Libchavy','Usti nad Orlici','CZECH','CZECH REPUBLIC','56116','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 12:27:17',0,NULL,3,1,2,1,NULL,'éº‚çš®  1'),(1931,598511081001,110502563166,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA1310',4.5,'hermeshine','jayachands18','mjaya18@gmail.com','MURUGESAN JAYA CHANDRAN','NANBATASINDEN 96-8<br>TAKUMI ENGG. CO. LTD., ROOM NO : 101','FUJIMI SHI','Saitama','JAPAN','354-0003','+81-90-6642-0363','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 13:03:03',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1932,598511655001,110502563166,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA1310',4.5,'hermeshine','jayachands18','mjaya18@gmail.com','MURUGESAN JAYA CHANDRAN','NANBATASINDEN 96-8<br>TAKUMI ENGG. CO. LTD., ROOM NO : 101','FUJIMI SHI','Saitama','JAPAN','354-0003','+81-90-6642-0363','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 13:05:00',0,NULL,3,1,2,1,NULL,'77mm uv  2 '),(1933,598532534001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','ddsnyc','artdds@gmail.com','Arthur Yam','19 Skytop Rd','Edison','NJ','UNITED STATES','08820','','NoPaymentFailure','CheckoutComplete','Other','2010-11-25 14:16:35',0,NULL,3,1,1,1,NULL,NULL),(1934,598536041001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','mindofdead','akrutofalov@gmail.com','Aleksey Krutofalov','Russia, Moscow, ul. Svobody,  dom 91, kv. 164','Moscow','','RUSSIAN FEDERATION','125481','+79167850747','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 14:36:20',0,NULL,3,1,2,1,NULL,NULL),(1935,679246999016,260660051690,'Neoprene Lens Pouch Case 9.5cmx23cm 80-200 70-200mm XL',1,'',4.38,'hutongstore','kebippi','roahpe@gmail.com','Antti Soini','Portaankorvankatu 5','Tampere','','FINLAND','33820','+358407614849','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-25 15:04:27',0,NULL,3,1,2,1,NULL,' é•œå¤´ç­’ xl å¤§å·  1'),(1936,637254984002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','cedricma','cedric.marchand@laposte.net','Cedric Marchand','10  Avenue Nelson Mandela','Tremblay en France','Ile-de-France','FRANCE','93290','09 50 31 84 55','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 15:21:17',0,NULL,3,1,2,1,NULL,NULL),(1937,598554103001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','rkharbuck','gharbuck@gmail.com','Regina Harbuck','823 Creek Trl','Anniston','AL','UNITED STATES','36206-1043','(256) 820-9120','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 15:25:43',0,NULL,5,1,18,0,NULL,NULL),(1938,637273202002,120499333257,'Flash Softbox Diffuser for external flash SB800 580EX',1,'AB3302',8.8,'hermeshine','dingc9','charlie@charlieding.com','Charlie Ding','Flat K, Wolfson House<br>49 Weston Street','London','London','UNITED KINGDOM','SE1 3RB','07812218123','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2010-11-25 16:13:31',0,NULL,3,1,2,1,NULL,'NG200   1 '),(1939,598569809001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','sxgreenee','sxgreenee@gmail.com','Pedro Martins','Rua do Cantinho, 13<br>Ceflar','CANTANHEDE','PORTUGAL','PORTUGAL','3060','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 16:22:10',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864143215CN\ré‚®ç¼–æ˜¯3060225\r'),(1940,598579528001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',4,'AA1310',22,'hermeshine','linxaut','linxautomacao@terra.com.br','Sandro G. Mabilia','RUA BORTOLO ZANI, 97, SALA 1<br>B. CRUZEIRO','CAXIAS DO SUL','RIO GRANDE DO SUL','BRAZIL','95072-000','+55 054 32285664','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 16:37:01',0,NULL,3,1,2,1,NULL,' '),(1941,598579908001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','ydna52','andywinfield@sbcglobal.net','Jack winfield','115 Jasmine Way','East Palo Alto','CA','UNITED STATES','94303','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 16:38:50',0,NULL,3,1,1,1,NULL,NULL),(1942,637287947002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 16:58:22',0,NULL,3,1,8,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´æ£š  2\r45w 220v  8\råŒ…  1 \råå…‰æ¿æ”¯æž¶  1\r2mç¯æž¶  1\ré‡é‡\rCP212150586CN\r'),(1943,636120147002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 16:58:23',0,NULL,5,1,18,0,NULL,'å‘ä¸‹åˆå¹¶ '),(1944,637303992002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','jonathangrandmont','jonathangrandmont@hotmail.com','Jonathan Grandmont','1180 rang 4','Saint-Cyrille-de-Wendover','QC','CANADA','j1z 1t7','(819) 397-4686','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 17:29:23',0,NULL,3,1,2,1,NULL,' '),(1945,637306176002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','sagebrushnomad','tanja_henderson@yahoo.com','roderik henderson','palmar de ocoa 743<br>palmas de chimba','copiapo','atacama','CHILE','1535037','(568) 493-4565','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 17:37:01',0,NULL,3,1,2,1,NULL,NULL),(1946,598623713001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','motero34juan','joninza@hotmail.com','Juan Antonio Inza','Plaza Harrobieta NÂº15 1Âº C','San Sebastian','Guipuzcoa','SPAIN','20017','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 18:21:18',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143075CN'),(1947,637344748002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','sharkwobbegong','greenworksus@yahoo.com','R. Brian Green','837 Hcr 1313','Hillsboro','TX','UNITED STATES','76645-5052','(254) 744-5760','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 19:00:36',0,NULL,3,1,1,1,NULL,' '),(1948,637351251002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','th_rjs','th_rjs@yahoo.com','Rajesh Thapa','5616 EL DORADO AVE<br>Apt 2','El Cerrito','CA','UNITED STATES','94530-3434','(415) 425-3068','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 19:11:33',0,NULL,3,1,1,1,NULL,NULL),(1949,637400811002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mmcgheejr','saugerman@comcast.net','Rick and Tiffany Mayberry','150 Old Coalfield Rd','Harriman','TN','UNITED STATES','37748-4316','(865) 882-2610','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 20:45:12',0,NULL,3,1,1,1,NULL,NULL),(1950,598697736001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','tal_blit1','tal_blit@yahoo.com','Tal Blitstein','Shlomo 8','Petach Tikva','Israel','ISRAEL','49581','972508631347','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 20:49:21',0,NULL,3,1,11,1,NULL,NULL),(1951,637403542002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2401',24.95,'hermeshine','ivarsk9598','ivars.kukainis@apollo.lv','Ivars Kukainis','Valdeku 50/1-33','Riga','Latvia','LATVIA','LV-1058','+37126549201','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 20:50:53',0,NULL,3,1,3,1,NULL,' 50-70é€šç”¨å¡å£ æ£š  1\ræˆ‘æ¥\ré‡é‡639\rRA022499910CN\r'),(1952,637181237002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','melinabeads','ermushina@mail.ru','Yuriy Ermushin','Krasnyi pereulok d. 2  kv. 271','Aleksandrov','Vladimirskaya oblast','RUSSIAN FEDERATION','601650','+79066155124','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 20:55:29',0,NULL,3,1,2,1,NULL,' '),(1953,679443921016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'',7.56,'hutongstore','damrua','dam.rua@googlemail.com','Davide Rua','109 Wentworth Road','CROYDON','Surrey','UNITED KINGDOM','CR0 3HZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-25 21:11:15',0,NULL,3,1,2,1,NULL,NULL),(1954,637423452002,120601698256,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','olivierludsko','odulieu@yahoo.fr','Olivier Dulieu / PMU EQUIDIA','165 boulevard de Valmy<br>Batiment D porte 401','Colombes','Ile-de-France','FRANCE','92700','0682932662','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 21:38:29',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1955,637422650002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','olivierludsko','odulieu@yahoo.fr','Olivier Dulieu / PMU EQUIDIA','165 boulevard de Valmy<br>Batiment D porte 401','Colombes','Ile-de-France','FRANCE','92700','0682932662','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 21:38:30',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 \r58mm çŽ¯æž¶  1'),(1956,637414619002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','rgbman40','rgbman40@hotmail.com','Rogier Bruggeman','Hamerstraat 3','Heerlen','','NETHERLANDS','6411 cS','045-5717167','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 21:13:58',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´  1  æ¬§æ ‡\råå…‰ä¼ž   1 \rRA022499866CN\r'),(1957,692907878015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','jacek.jakubas','karolina.opiola@yahoo.co.uk','JACEK JAKUBAS','42e Chalkhill Road','LONDON','Middlesex','UNITED KINGDOM','HA9 9FN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-25 21:18:30',0,NULL,3,1,2,1,NULL,NULL),(1958,637441478002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','flagator10','flagator10@hotmail.com','Charles Perry','2280 S Highway 97','Cantonment','FL','UNITED STATES','32533-9794','(859) 937-8373','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 22:20:48',0,NULL,3,1,1,1,NULL,NULL),(1959,637448641002,120601698609,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','hofferpeter','hofferpter@gmail.com','PÃ©ter Hoffer','MÃ³ricz Zs u. 10.','Tapolca','VeszprÃ©m','HUNGARY','8300','36309363971','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 22:41:25',0,NULL,3,1,3,1,NULL,'wf1005  1 \rRA022499954CN\r'),(1960,637452877002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','andreamaas0','andreamaasr@hotmail.com','eduardo lopez bermejo','c. simancas 60 1b','las palmas de gran canaria','Canarias','SPAIN','35010','633501622','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 22:55:24',0,NULL,3,1,4,1,NULL,'ballhead $16 \rYW864143042CN'),(1961,598759525001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','super_best_ebuyer','nikolas99@mail.ru','ALEXANDER ISCHIMJI','8 Valea Crucii Str. Ap. 143','Chisinau','','MOLDOVA, REPUBLIC OF','2072','+373 69014721','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 23:40:35',0,NULL,3,1,2,1,NULL,''),(1962,637469063002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','callcybercop','callcybercop@gmail.com','Naveen Gagadam','107 May Dr<br>Apt 2','Camp Hill','PA','UNITED STATES','17011-5020','(407) 579-1415','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-11-25 23:56:28',0,NULL,3,1,1,1,NULL,'canonä¸‰è§’åŒ…  1 '),(1963,692981474015,250692240898,'Wireless Remote Shutter Release for Sony A900/A200/â€‹A10',1,'',11.47,'hutongstore','neil242vnv','n.white242@yahoo.com','Neil white','232 bramford lane','Ipswich','Suffolk','UNITED KINGDOM','ip1 4ep','01473744030','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 00:29:39',0,NULL,3,1,2,1,NULL,' çˆµå½±æ— çº¿ S1  1 '),(1964,692998840015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'',1.88,'hutongstore','thejamstrangler','box.andy1@googlemail.com','andy box','106 randwick drive','worcester','Worcestershire','UNITED KINGDOM','WR4 9LR','01905452858','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 01:40:24',0,NULL,3,1,2,1,NULL,'77mm é•œå¤´ç›– Nikon   1 '),(1965,637513914002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','pnd-nsw','pnd@zip.com.au','Paul Douriaguine','55 Montview Pde','Hornsby Heights','New South Wales','AUSTRALIA','2077','0413009303','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 03:19:17',0,NULL,3,1,3,1,NULL,' RA022499945CN\r'),(1966,637515510002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','shawnd0520','shawnd0520@comcast.net','Shawn Douglas','601 Amy Cir','Bryant','AR','UNITED STATES','72022-4116','(501) 626-2800','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 03:27:37',0,NULL,3,1,1,1,NULL,NULL),(1967,598805724001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','jlmsid09','jlmsid@gmail.com','Jose Luis Sidero','Bermejo 2386','San Justo','Buenos Aires','ARGENTINA','1754','4484-5968','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 03:36:50',0,NULL,3,1,3,1,NULL,' RA022499937CN\r'),(1968,637521077002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','philhogansr','philhogansr@msn.com','Phil  Hogan','27269 Terrytown Rd','Sun City','CA','UNITED STATES','92586-3210','(951) 837-3224','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 03:57:30',0,NULL,3,1,1,1,NULL,NULL),(1969,637538016002,120570270887,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',26.99,'hermeshine','mattisal','mattisal@hotmail.com','Matti Salminen','Vanhakartanontie 38','Pori','','FINLAND','28660','+358443552886','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 05:44:43',0,NULL,3,1,3,1,NULL,' RA022499923CN\r'),(1970,598832351001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1309',7.4,'hermeshine','just.one.more.deck','imdillinger@yahoo.com','Justin MArtens','39355 Calistoga Dr','Murrieta','CA','UNITED STATES','92563-6805','(951) 323-1135','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 06:32:23',0,NULL,3,1,1,1,NULL,' '),(1971,637556132002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','sudeepmandal','sudeepmandal@gmail.com','Sudeep Mandal','880 East St<br>Apt 1A','Lee','MA','UNITED STATES','01238-9120','(607) 342-4772','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 07:39:51',0,NULL,3,1,1,1,NULL,'æ²¡å‘ \råº”è¯¥æ²¡å‘'),(1972,598849360001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','valkeajoki1','valkeajoki@gmail.com','Jussi Valkeajoki','Makikuja 3','Orivesi','','FINLAND','35300','358452308491','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 08:09:16',0,NULL,3,1,2,1,NULL,NULL),(1973,637565123002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','valkeajoki1','valkeajoki@gmail.com','Jussi Valkeajoki','Makikuja 3','Orivesi','','FINLAND','35300','358452308491','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 08:27:29',0,NULL,5,1,3,1,NULL,NULL),(1974,637574911002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','alex-yuger','brn_karamel@mail.ru','Aleksey Germanov','Entuziastov 42/64','Barnaul','Altayskiy','RUSSIAN FEDERATION','656065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 09:14:42',0,NULL,3,1,2,1,NULL,'é€’å››æ–¹ '),(1975,598866328001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','heilyninette','jailynin@hotmail.com','Claudio Gabriel Ceino Gordillo','Via Gastaldi 9A-9<br>16043','Chiavari (GE)','GE','ITALY','16043','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 09:33:39',0,NULL,3,1,4,1,NULL,'tripod dolly  $20\rYW864143241CN'),(1976,598868452001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','ramab80','rama_bungaroo@yahoo.com','Rama Bungaroo','Morcellement Diocese','Rose Belle','','MAURITIUS','230','2306274473','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 09:39:34',0,NULL,3,1,3,1,NULL,'æ–°çš„é‚£ä¸ªç¯æž¶ \rRA022500003CN\r'),(1977,598868463001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','taladrin.simon','taladrin@andaluciajunta.es','Jose Luis SimÃ³nLÃ³pez','C/ CÃ¡novas del Castillo nÂº14 2ÂºB','AlcalÃ¡ de Henares','Madrid','SPAIN','28807','619661971','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 09:42:57',0,NULL,3,1,2,1,NULL,'é€’å››æ–¹ '),(1978,637592277002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','pa.85','patriciag1985@hotmail.com','Patricia Garcia Canut','C/ JoaquÃ­n Rodrigo nÂº9; 5Âº B','Zaragoza (Zaragoza)','AragÃ³n','SPAIN','50012','679778843','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 10:30:08',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1RR723016776CN\r'),(1979,679665574016,260660055606,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',2,'',4,'hutongstore','homemadeah47','alfred@hoole.myzen.co.uk','Alfred Hoole','14 Queen Elizabeth Crescent','Accrington','Lancashire','UNITED KINGDOM','BB52AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:03:03',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1980,693126065015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',3,'',5.64,'hutongstore','homemadeah47','alfred@hoole.myzen.co.uk','Alfred Hoole','14 Queen Elizabeth Crescent','Accrington','Lancashire','UNITED KINGDOM','BB52AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:03:03',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1981,693129436015,250599423735,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'',1.88,'hutongstore','homemadeah47','alfred@hoole.myzen.co.uk','Alfred Hoole','14 Queen Elizabeth Crescent','Accrington','Lancashire','UNITED KINGDOM','BB52AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:07:42',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1982,679666492016,260660056106,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'',4.8,'hutongstore','robperfectmo','rob@vision-thing.com','Rob Alexander','Perfect Motion Media The Media Centre, 15 - 17 Middle Street','Brighton','East Sussex','UNITED KINGDOM','BN1 1AL','01273806099','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:09:35',0,NULL,3,1,2,1,NULL,NULL),(1983,693129934015,250692242614,'72mm Snap-on Front Cap for Nikon 72mm Filters Lens New',1,'',2.4,'hutongstore','homemadeah47','alfred@hoole.myzen.co.uk','Alfred Hoole','14 Queen Elizabeth Crescent','Accrington','Lancashire','UNITED KINGDOM','BB52AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:20:16',0,NULL,5,1,18,0,NULL,' å‘ä¸Šåˆå¹¶ '),(1984,693128824015,250692242108,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',2,'',4.8,'hutongstore','homemadeah47','alfred@hoole.myzen.co.uk','Alfred Hoole','14 Queen Elizabeth Crescent','Accrington','Lancashire','UNITED KINGDOM','BB52AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:05:45',0,NULL,3,1,3,1,NULL,'52mm é•œå¤´ç›–  Nikon  2\r62mm é•œå¤´ç›– Nikon  2\r67mm é•œå¤´ç›– Nikon  1 \r72mm é•œå¤´ç›– Nikon  1\r77mm é•œå¤´ç›– Nikon  3RR723016966CN\r'),(1985,598901136001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','flowfr','florian.casse.mail@gmail.com','Florian CASSE','9 rue des Marronniers','Paris','ÃŽle-de-France','FRANCE','75016','06.65.21.99.18','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 11:48:55',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1986,598900873001,110464615814,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',8.69,'hermeshine','flowfr','florian.casse.mail@gmail.com','Florian CASSE','9 rue des Marronniers','Paris','ÃŽle-de-France','FRANCE','75016','06.65.21.99.18','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 11:48:55',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ… æ— å­— 1\r67mm uv   1 '),(1987,598908966001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2101',59,'hermeshine','petrs4321','svoboda@lmail.cz','Petr Svoboda','Budovcova 1149, -','Podebrady','-','CZECH REPUBLIC','29001','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 12:20:31',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1988,598908035001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','petrs4321','svoboda@lmail.cz','Petr Svoboda','Budovcova 1149, -','Podebrady','-','CZECH REPUBLIC','29001','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 12:20:32',0,NULL,3,1,3,1,NULL,'Nikon æ‘„å½±èƒŒå¿ƒ xxxl  1\råŽŸåŽ‚nikon èƒŒå¿ƒ xl  1 RR723016816CN\r'),(1989,637621908002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ivofotev','ivofotev@yahoo.com','Ivo Fotev','42 Traiko Kitanchev str','Bourgas','Bourgas','BULGARIA','8000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 12:30:28',0,NULL,3,1,2,1,NULL,NULL),(1990,598912660001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','salihovic.almir','salihovic.almir@gmail.com','Almir Salihovic','Hasana Brkica 9','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','+38761190745','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 12:32:41',0,NULL,3,1,2,1,NULL,NULL),(1991,598915577001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','compilog','iromeo77@ya.ru','Roman Ivlev','Kronverskiy pr., d.59, kv.30','Saint-Petersburg','','RUSSIAN FEDERATION','197198','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 12:43:09',0,NULL,3,1,2,1,NULL,' '),(1992,597037499001,110489360129,'JueYing Lambency Flash Diffuser for Nikon SB600 SB800 ',1,'AB3306',22,'hermeshine','caduviterbo','caduprado@gmail.com','Carlos Eduardo Viterbo Prado','Rua Soares Couto 201/03','Belo Horizonte','Minas Gerais','BRAZIL','30380760','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 13:50:47',0,NULL,3,1,3,1,NULL,'ç¢—ç½© P1   1 RR723016997CN\r'),(1993,637649332002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','borichka','boris@ceva-dsp.com','Boris Shpitser','CEVA DSP<br>2(D) Maskit St.','Herzelia','','ISRAEL','46120','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 13:59:33',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž  1 RR723016855CN\r'),(1994,598939727001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','num_r','numchai_g@yahoo.com','Numchai Rungratpatana','22/58 M.6  Phahonyothin road<br>Saimai      Saimai','Bangkok','THAILAND','THAILAND','10220','0813432318','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 14:06:42',0,NULL,3,1,2,1,NULL,''),(1995,637652269002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','sistersobeautiful','director@ilcaffediroma.com.sg','Gina Tan/Preston Chang','300 Tanjong Katong Road<br>02-08 Chelsea Lodge','default','','SINGAPORE','437083','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 14:08:39',0,NULL,3,1,11,1,NULL,NULL),(1996,637632417002,120565901367,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','dsbarlow','diretoria@culturainglesapb.com.br','Davidrlow Ba','Av Epitacio Pessoa 2953','Joao Pessoa ','Paraiba','BRAZIL','58030002','83 88025330','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 15:29:46',0,NULL,3,1,5,1,NULL,'717 135cm  1 \rCP212150569CN\r'),(1997,679773660016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'',12,'hutongstore','mollyrice007','rbeip@hotmail.co.uk','M Kitchen','16 Newfield Road','Liss','Hampshire','UNITED KINGDOM','GU33 7BW','01730890006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 16:00:26',0,NULL,3,1,2,1,NULL,'1.6x3m ç™½è‰²èƒŒæ™¯å¸ƒ  1 '),(1998,598982260001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','sekstiseks','syttisyv@gmail.com','Fredrik Aasland','GrÃ¥steinveien 20','OSLO','OSLO','NORWAY','1157','004790162108','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 16:11:00',0,NULL,3,1,2,1,NULL,NULL),(1999,598982446001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','i_fes','anabioz@list.ru','Igor Fesenko','Orangeva, 66','Dnipropetrovsk','','UKRAINE','49007','067-742-7256','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 16:11:55',0,NULL,5,1,2,1,NULL,'å‘ä¸Šåˆå¹¶ '),(2000,637704407002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',3,'AA1305',7.4,'hermeshine','briankauf','briankauf@gmail.com','Main','5705 Merlin St.','Fitchburg','WI','UNITED STATES','53711','(608) 469-4359','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 16:31:04',0,NULL,5,1,18,0,NULL,' å‘ä¸Šåˆå¹¶ '),(2001,637703605002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',3,'AA1303',7.4,'hermeshine','briankauf','briankauf@gmail.com','Main','5705 Merlin St.','Fitchburg','WI','UNITED STATES','53711','(608) 469-4359','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 16:31:04',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2002,598989307001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','briankauf','briankauf@gmail.com','Main','5705 Merlin St.','Fitchburg','WI','UNITED STATES','53711','(608) 469-4359','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 16:31:05',0,NULL,3,1,1,1,NULL,'77mm é•œå¤´ç›–  canon 2\r72mm é•œå¤´ç›– canon 3\r52mm é•œå¤´ç›– nikon  3 '),(2003,599013992001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','brenzef','ebay@brenzef.com','R. van der Knaap','Poelruit 25','Reeuwijk','','NETHERLANDS','2811SW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 17:28:14',0,NULL,3,1,2,1,NULL,NULL),(2004,599015982001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','melissamustard2010','melissarjmark@hotmail.com','Melissa Mark','box 20743','Whitehorse','YT','CANADA','Y1A 7A2','(867) 633-3024 ext.: 1','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 17:32:53',0,NULL,3,1,11,1,NULL,NULL),(2005,599016599001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','entropia2387','amag87@hotmail.com','Ana MarÃ­a Alvarez Gonzalez','el castro nÂº38','Piedras Blancas','Asturias','SPAIN','33450','649553760','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 17:34:05',0,NULL,3,1,2,1,NULL,NULL),(2006,637761340002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','atlas125','tpapa23@hotmail.com','Thomas Papanikolaou','4270 Vilamoura Dr','Avon','OH','UNITED STATES','44011-3753','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 18:36:20',0,NULL,3,1,1,1,NULL,NULL),(2007,679874622016,260661403826,'TianYa 72mm ND8 filter New 72 Neutral Density Grey NIB',1,'',5.78,'hutongstore','tp472007','terho.paavilainen@elisanet.fi','Terho Paavilainen','Virolahdentie 385','Viljakkala','','FINLAND','39310','358414450082','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-26 19:09:33',0,NULL,3,1,2,1,NULL,' '),(2008,637789772002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','guita000','big004@hotmail.com','Mr. Chaiwat Lertwongchaikul','99/178 moo3 Soikamnanmaen28, Eakchai Road,<br>Bangkuntian,Jomthong, Bangkok 10150 Thailand','default','BA','THAILAND','10150','+66865498234','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 19:31:00',0,NULL,3,1,2,1,NULL,''),(2009,637454473002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',5,'AA1303',12.2,'hermeshine','ilya-narizniy','narizniy@ukr.net','illia naryzhnyi','Gritsevca st., 11-a, 22','Kharkiv','','UKRAINE','61172','(050) 403-6544','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 20:10:23',0,NULL,3,1,3,1,NULL,' RR723017003CN\r'),(2010,693388083015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','roland660','paulhughes6@blueyonder.co.uk','Paul Hughes','1 Ilfracombe Avenue','Southend on Sea','Essex','UNITED KINGDOM','SS12QX','01702319682','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 20:27:27',0,NULL,3,1,2,1,NULL,'3pcs æ»¤é•œè¢‹  1 '),(2011,599102691001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',2,'AB1301',6.68,'hermeshine','anselmoas','anselmoas@yahoo.com.br','Valesca dos Santos Lima','Rua Saldanha Marinho, 558 - Neves','SÃ£o GonÃ§alo','Rio de Janeiro','BRAZIL','24425-227','+55(21) 2628-3775','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 20:31:56',0,NULL,3,1,2,1,NULL,NULL),(2012,637848313002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','71dodgefan','dmdhmc@yahoo.com','Brian DeLong','56 Academy St','Presque Isle','ME','UNITED STATES','04769-2948','(207) 764-1928','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 21:30:37',0,NULL,3,1,1,1,NULL,NULL),(2013,693485564015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','lz_boutique','lilmisslb_xxx@hotmail.com','Lauren Brown','16 Hermiston Avenue','London','London','UNITED KINGDOM','N8 8NL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 23:46:25',0,NULL,3,1,2,1,NULL,NULL),(2014,637907036002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','rhianspaypal','rhianpaypal@yahoo.com','R Cope','C/O ERMA<br>20 customhouse quay','Wellington','New Zealand','NEW ZEALAND','6140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 00:19:05',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶'),(2015,598541059001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','nomarelis','venture20042@yahoo.com','sr mendez','611 Calle Jacinto','Juncos','PR','UNITED STATES','00777-3932','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 00:36:54',0,NULL,3,1,1,1,NULL,NULL),(2016,599195693001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3401',10,'hermeshine','harioe','harioe2002@yahoo.com.au','Hari Oetomo','5 Bordeaux Crescent, Castle Hill','Sydney','New South Wales','AUSTRALIA','2154','0288501729','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2010-11-27 00:49:54',0,NULL,3,1,2,1,NULL,''),(2017,637954909002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','cdreemz2','cdreemz2@aol.com','Cindy Nina','3216 112th Pl<br>Fl 3','East Elmhurst','NY','UNITED STATES','11369-2532','(347) 624-1444','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 03:31:46',0,NULL,3,1,1,1,NULL,NULL),(2018,599244074001,110534332901,'New Flash Hot Shoe Adapter YN-H3 for Alpha and Minolta',1,'AKT002',7.9,'hermeshine','mayromlo','mayromlo@ryerson.ca','Many Ayromlou','1 Bentwood Crescent','Thornhill','ON','CANADA','L4J8R3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 04:34:16',0,NULL,3,1,2,1,NULL,'æ°¸è¯ºçƒ­é´è½¬æ¢  1 '),(2019,599260263001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','makanani9919m','makanani9@juno.com','irene gombac','15 Kulanihakoi St<br>Apt 7E','kihei','HI','UNITED STATES','96753-7341','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 06:18:39',0,NULL,3,1,1,1,NULL,'æ°”å¹+å¸ƒ  1 '),(2020,637989757002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','kimerydw','dave.kimery@gmail.com','David Kimery','Suite 201, 620 - 12 Avenue SW','Calgary','AB','CANADA','T2R 0H5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 06:57:46',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723016847CN\r'),(2021,637993679002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','seri7516','seri7516@hotmail.com','SERI BOUN','46 RUNCORN Street<br>ST. JOHNS PARK','Fairfield ','New South Wales','AUSTRALIA','2176','0298233469','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 07:23:08',0,NULL,3,1,6,1,NULL,'æ–°åŠ å¡ EMS \r717ah  1\rEX000113360SG'),(2022,638012609002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','zortteil','olivierchaume@yahoo.fr','olivier chaume','56 rue Pierre CAZENEUVE','TOULOUSE','Midi-PyrÃ©nÃ©es','FRANCE','31200','0660973802','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 09:01:56',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143311CN\r'),(2024,693631673015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','giorgos_v','vlageorg@otenet.gr','GEORGIOS VLACHOS','1 TSELIOU STREET','THESSALONIKI','THESSALONIKI','GREECE','54352','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-27 09:22:14',0,NULL,3,1,2,1,NULL,NULL),(2025,598492795001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','bonda-andrew','bonda.andrew@gmail.com','Bonda Andrew','Sovetskaya str<br>9, ComputerMarket','Novozybkov','Bryanskaya obl','RUSSIAN FEDERATION','243020','+79051767474','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 11:10:17',0,NULL,3,1,2,1,NULL,NULL),(2026,693668944015,250600489459,'New Hairlight photostudio boom arm ',1,'',23.9,'hutongstore','nameohname','psychonoetic@gmail.com','Fotios Vrionis','70 LYNDEN STREET, CAMBERWELL','MELBOURNE','Victoria','AUSTRALIA','3124','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-27 11:15:00',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723016780CN\r'),(2027,638063200002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','i_fes','anabioz@list.ru','Igor Fesenko','Orangeva, 66','Dnipropetrovsk','','UKRAINE','49007','067-742-7256','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 12:09:01',0,NULL,3,1,3,1,NULL,'50cm æ£š   1\rå€’å½±æ¿   1\r846g\rRR723017533CN\r'),(2028,692626565015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','brettarcher','kba68@hotmail.com','kevin archer','19 ferrymoore ham','surrey','Surrey','UNITED KINGDOM','tw10 7sd','020899401108','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 12:53:53',0,NULL,3,1,2,1,NULL,''),(2029,680240128016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'',5.9,'hutongstore','eazy-trade','tds10@uk2.net','Paul Bridgeman','124 Claymoor Flora Street','Oldham','Lancashire','UNITED KINGDOM','OL12XG','08445670302','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 13:07:37',0,NULL,3,1,2,1,NULL,''),(2030,638083999002,120564178467,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','maggi1970','magnus@amphilion.com','Magnus Palmarsson','Glosolum 5','Kopavogur','IS','ICELAND','201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 13:12:54',0,NULL,3,1,2,1,NULL,' 58mm æ©¡èƒ¶ç½©   1\rï¼ˆå®¢æˆ·æ”¹è®¢å•äº†æ³¨æ„ï¼‰'),(2031,599363871001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',3,'AB1301',10.02,'hermeshine','alexander_magnum','alexandr.churakov@gmail.com','Alexander Churakov','Gorky str. 27 Apt 16','Kirov','Kirovskaya obl','RUSSIAN FEDERATION','610017','79127347358','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 13:23:14',0,NULL,3,1,2,1,NULL,'æ˜¯3ä¸ª '),(2032,599372205001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','kojisama','satirx@hotmail.com','Ruben Sousa Perez','Zuazaurre NÂº 23 4Âº A','Galdakao','Vizcaya','SPAIN','48960','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 13:47:22',0,NULL,3,1,2,1,NULL,NULL),(2033,693757789015,250692240760,'Wireless Remote Control Cord for Canon 500D/550D/450D',1,'',11.47,'hutongstore','gibbare10','gibbare@hotmail.com','Jonas Karlsson','Innervik 627','SkellefteÃ¥','VÃ¤sterbotten','SWEDEN','93191','+46 70 33 63 170','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-27 14:53:40',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ C1   1 '),(2034,693764898015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'',13.9,'hutongstore','stargr1l','matnsara@gmail.com','Mathew Street','DÃ¶rfl 48','Reichenau an der Rax','','AUSTRIA','2651','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-27 15:05:15',0,NULL,3,1,2,1,NULL,''),(2035,599403947001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','jargoncia','mailalex@mixmail.com','alejandro gonzalez garcia','lleida 9, 3-1','sant adria de besos. Barcelona','CataluÃ±a','SPAIN','08930','607076698','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 15:11:29',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ ç™½ç›’  1 RR723016762CN\r'),(2036,599446276001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','susana1000','susande23@hotmail.com','Susana Sande Cadenas','C/ Romero Robledo,20 2ÂºB','Madrid','Madrid','SPAIN','28008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 16:46:44',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2037,599446147001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','susana1000','susande23@hotmail.com','Susana Sande Cadenas','C/ Romero Robledo,20 2ÂºB','Madrid','Madrid','SPAIN','28008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 16:46:45',0,NULL,3,1,3,1,NULL,'80cm 5in1 åå…‰æ¿  1\r40cm æ£š   1\ré‡é‡ï¼Ÿ 832g\rRR723017547CN\r'),(2038,599233542001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','riis1883norge','lincoln_10tpr@email.com','Timothy Reese','PO Box 1641','Monterey','CA','UNITED STATES','93942-1641','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 17:20:54',0,NULL,3,1,1,1,NULL,NULL),(2039,680426055016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','markhalset3','halseym9@aol.com','MARK HALSEY','28 MILLSHOTT CLOSE','FULHAM','London','UNITED KINGDOM','SW6 6PG','02073859140','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 19:00:27',0,NULL,5,1,18,0,NULL,NULL),(2040,680429128016,260660055664,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',2.7,'hutongstore','markhalset3','halseym9@aol.com','MARK HALSEY','28 MILLSHOTT CLOSE','FULHAM','London','UNITED KINGDOM','SW6 6PG','02073859140','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 19:00:27',0,NULL,5,1,18,0,NULL,NULL),(2041,693901120015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',2.6,'hutongstore','markhalset3','halseym9@aol.com','MARK HALSEY','28 MILLSHOTT CLOSE','FULHAM','London','UNITED KINGDOM','SW6 6PG','02073859140','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 19:00:28',0,NULL,5,1,18,0,NULL,NULL),(2042,693902286015,250599395859,'55mm 55 Close Up  Macro Close-Up +8 Filter New',1,'',3.6,'hutongstore','markhalset3','halseym9@aol.com','MARK HALSEY','28 MILLSHOTT CLOSE','FULHAM','London','UNITED KINGDOM','SW6 6PG','02073859140','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 19:00:28',0,NULL,3,1,3,1,NULL,'55mm +8  1\r72mm uv   1\r55mm uv   1\rlenspen   1 RR723016970CN\r'),(2043,638266726002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','dmerchan920','davidmerchan920@hotmail.com','David Merchan Munoz','C/ Lira  47','Getafe- Madrid','madrid','SPAIN','28905','615097868','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 19:45:04',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\rbåº§   2\ræŸ”å…‰ä¼ž  2 \rlight stand $22\rYW864143300CN\r\r'),(2044,599554940001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','lameton','thalassi@euskalnet.net','ANGEL MARIA ZAMANILLO MARTINEZ','LOIOLA ANDER DEUNA, 28-2ÂºD','SOPELANA','PaÃ­s Vasco','SPAIN','48600','656781982','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 20:12:12',0,NULL,3,1,4,1,NULL,'tripod $22 \rYW864143296CN\r'),(2045,638288125002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','mcgeester','mariannem7@bellsouth.net','Marianne McGee','8175 Landing S','Atlanta','GA','UNITED STATES','30350','(770) 650-7907','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 20:23:13',0,NULL,3,1,1,1,NULL,NULL),(2046,599563645001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','dannyandtrish','dannyandtrish@msn.com','Patricia Dunham','4450 N Loma Vista Rd','Willcox','AZ','UNITED STATES','85643-3221','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 20:27:19',0,NULL,3,1,1,1,NULL,NULL),(2047,599597141001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','jnr_t','jnr_t@hotmail.com','roy Thomas','85 Mansfield Drive','Hayes','Middlesex','UNITED KINGDOM','ub4 8eb','07931761779','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 21:54:06',0,NULL,3,1,3,1,NULL,'RR723016833CN\r'),(2048,599606852001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','tsur2701','suresht@upmc.edu','tunga suresh','750 washington road apt 1607','pittsburgh','PA','UNITED STATES','15228','(412) 200-5368','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 21:57:46',0,NULL,3,1,1,1,NULL,NULL),(2049,638338462002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','co-manche','fabrice.burguet@free.fr','Fabrice Burguet','14 rue du pavillon','VALOGNES','Basse-Normandie','FRANCE','50700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 22:08:42',0,NULL,3,1,2,1,NULL,NULL),(2050,599596075001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','trigomots88','trigomots@yahoo.com','Setlhare Lucas Motsamai','50 Palmoral Avenue','Kingston 6','St Andrew','JAMAICA','00000','(876) 455-5988','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 22:10:49',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 RR723016895CN\r'),(2051,694054376015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','voiceofsoul','voiceofsoul143@gmail.com','gul hassan','21 moy glass way Lucan','Dublin','Dublin','IRELAND','00','0860659288','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-27 23:16:22',0,NULL,3,1,2,1,NULL,NULL),(2052,599636948001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','borfo','ebay@k-town.on.ca','rob kittredge','APT 902 - 736 SPADINA AVE','Toronto','ON','CANADA','M5S 2J6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 23:17:28',0,NULL,3,1,2,1,NULL,NULL),(2053,637761077002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jerryx2004','yvet_sanxag@yahoo.com','JERRY XAGORARIS','31201 FM 3069','LOS FRESNOS','TX','UNITED STATES','78566-4692','(956) 561-3405','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 23:31:14',0,NULL,3,1,1,1,NULL,NULL),(2054,637500716002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','knittinpearl','car0lyn@charter.net','Carolyn Keiser','208 Cedar Grove Dr','Saint Charles','MO','UNITED STATES','63304','(636) 448-9442','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 02:58:21',0,NULL,3,1,1,1,NULL,NULL),(2055,638432435002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE1301',23.67,'hermeshine','brasilcarvalhaes','cristinacarvalhaes@yahoo.com.br','Cristina Carvalhaes','Rua Ilacir Pereira Lima, 419 apt 503','Belo Horizonte','Minas Gerais - Belo Horizonte','BRAZIL','31140540','55-31-25152211','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 03:06:45',0,NULL,3,1,2,1,NULL,NULL),(2056,638433422002,120601699920,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',3.55,'hermeshine','lpaulw1','lpaulw@charter.net','L. PAUL WASSERMAN','2433 S Nadine St<br>Apt 2','WEST COVINA','CA','UNITED STATES','91792-3559','(818) 625-0947','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 03:08:13',0,NULL,3,1,1,1,NULL,'58mm æŽ¥å£çŽ¯  1 '),(2057,599719353001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','julie_jeff_138','jljk@nb.sympatico.ca','Julie Leger','138 Mckay Ave','Moncton','NB','CANADA','E1A3N4','(506) 878-3174','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-28 04:45:53',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 RR723016820CN\r'),(2058,599730236001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','open2shop','deb@finelineintl.com','Bill Lavallie','c/o Fine Line International<br>19474 State Hwy 88, Suite A','Pine Grove','CA','UNITED STATES','95665','(209) 296-4450','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 05:45:34',0,NULL,3,1,1,1,NULL,NULL),(2059,638485237002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','sdavidi','sdavidi@pendari.com','Steven Davidi','1800 Century Park E<br>Ste 600','Los Angeles','CA','UNITED STATES','90067-1508','(310) 229-5722','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 07:36:02',0,NULL,3,1,1,1,NULL,NULL),(2060,599752733001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',92,'hermeshine','martynas_siauciunas','martynas.siauciunas@gmail.com','Martynas Siauciunas','Nedre Valdersneset 80','Sletta','Radoy','NORWAY','5939','37067533975','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-28 08:16:20',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶ 1\ræ–œè‡‚  1\r50-70 æ£š  1  æ¬§æ ‡ \r115w 220v   1\rlighting kit $26 \rYW864143285CN\r'),(2061,638497851002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','racer_hollic','christian_aninzo@yahoo.com','CHRISTIAN ANINZO','P.O.BOX 4218','YIGO','GU','UNITED STATES','96929','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 08:34:30',0,NULL,3,1,1,1,NULL,'éº‚çš®  1 '),(2062,691351777015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'',4.5,'hutongstore','kconway84','kateconway84@hotmail.co.uk','Kate Conway','Flat 1015, 1 Courthouse Lane Metropolis Building','Auckland Central','Auckland','NEW ZEALAND','1010','00640212618206','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-28 09:29:51',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… canon  1 '),(2063,680788014016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','avonloco','graham.white@bentley.com','Graham White','1a Albion Road','Sandhurst','Berkshire','UNITED KINGDOM','GU47 9BP','01252861831','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 10:38:46',0,NULL,3,1,2,1,NULL,'canon æœºèº«ç›–/é•œå¤´åŽç›–   1 '),(2064,599812928001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','saviocc','saviocc@ig.com.br','Savio Cavalcante','Rua Rodrigues Ferreira, 45 - 1602B<br>Varzea','Recife','PE','BRAZIL','50810-020','+55 81 9961-0767','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 10:55:02',0,NULL,3,1,2,1,NULL,NULL),(2065,599858134001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','celter','to@kjellevand.no','Tor Ole Kjellevand','Inkognito terrasse 7B','Oslo','','NORWAY','0256','4722558085','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 12:36:39',0,NULL,3,1,2,1,NULL,NULL),(2066,599887307001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',2,'AB1303',6.68,'hermeshine','moppersmurfje1971','mario@redeker.nl','Mario Redeker','Elise van Calcarstraat 66','Den Haag','','NETHERLANDS','2522MD','0622929989','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 13:40:33',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶'),(2067,599887295001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',2,'AB1301',6.68,'hermeshine','moppersmurfje1971','mario@redeker.nl','Mario Redeker','Elise van Calcarstraat 66','Den Haag','','NETHERLANDS','2522MD','0622929989','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 13:40:34',0,NULL,3,1,2,1,NULL,'52mm æ©¡èƒ¶ç½©  2\r58mm æ©¡èƒ¶ç½©   2 '),(2068,638624889002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','ville12345','villelappi@hotmail.com','Ville Lappi','Nokia Siemens Networks<br>PL 785','Tampere','','FINLAND','33101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 13:42:39',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2069,694371152015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','lynnmaccabe','lynn_maccabe@hotmail.com','BCC','7 Borthwick Place','Balmullo','Fife','UNITED KINGDOM','KY160EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 13:50:16',0,NULL,3,1,2,1,NULL,''),(2070,680977883016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','1962iskander','afan1962@gmail.com','ALEXANDR AFANASYEV','s-t BALAKIREVA 37D-42','VLADIMIR','','RUSSIAN FEDERATION','600028','9206275301','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-28 15:56:20',0,NULL,3,1,2,1,NULL,'lenspen  1 '),(2071,694459104015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'',7.48,'hutongstore','conaty8809','stevec85@aol.com','stephen conaty','43 Biddlestone Creasant','North Shields','Tyne and Wear','UNITED KINGDOM','NE29 7JW','01912895154','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 15:56:51',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡  1 '),(2072,638698985002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','53240169','everfree5273@gmail.com','Yi Zou','4417 2nd Ave<br>Apt 401','Detroit','MI','UNITED STATES','48201-1257','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 15:57:35',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(2073,599991947001,110533631413,'CTR-301P Flash Trigger Kit with 2 Receivers ctr301p',1,'AKT001',41.9,'hermeshine','njoh6323','nealalbrechtjohnson@gmail.com','Neal Johnson','11105 Scotland Well Dr.','Cedar Park','TX','UNITED STATES','78750','(512) 496-1920','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-28 16:32:48',0,NULL,3,1,1,1,NULL,'301p ä¸€æ‹–äºŒ  1 '),(2074,681047644016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','sorigonvadim','sorigon@gmail.com','Vadim Ljubimov','Riga, Stirnu 37a-67','Riga','Vidzeme','LATVIA','lv-1084','+37127877502','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-28 17:12:29',0,NULL,3,1,2,1,NULL,'lenspen  1 '),(2075,600060894001,110532007108,'72mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1303',2.6,'hermeshine','chalyk','chaly_k@hotmail.com','chaly khoeun','19903 13th ave s','seatac','WA','UNITED STATES','98148','(206) 422-4701','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 17:55:00',0,NULL,3,1,1,1,NULL,''),(2076,600072796001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','elhelado','specialist1982@mail.ru','Yulia Tveritinova','Zhivopisnaya ulitsa, dom 8, kvartira 41','Balashiha','Moscow region','RUSSIAN FEDERATION','143905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 18:07:03',0,NULL,3,1,2,1,NULL,' '),(2077,638807946002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','adriano_bitencourt','adrianosaj@gmail.com','Adriano Bitencourt','Av. EsperanÃ§a, 279/267 ou 194<br>Maria Preta','Santo AntÃ´nio de Jesus','Bahia','BRAZIL','44570-670','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-28 18:07:13',0,NULL,3,1,3,1,NULL,' canon æ‘„å½±èƒŒå¿ƒ M   1 RR723016878CN\r'),(2078,694600891015,250599423735,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'',1.88,'hutongstore','allenbesley','informmark@gmail.com','Mark Allen','Garfield 1 Boldrewood','Burghfield Common','Berkshire','UNITED KINGDOM','RG7 3LR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 18:16:04',0,NULL,3,1,2,1,NULL,NULL),(2079,638835880002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','melissacramer062908','melissacramer@hotmail.com','Melissa Cramer','2570 Coyote Rd','Willits','CA','UNITED STATES','95490-9034','(707) 841-0803','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 18:32:48',0,NULL,3,1,1,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon   1 '),(2080,694618124015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','kew30','graham-webber@sky.com','Karen Webber','123 London Road','Colchester','Essex','UNITED KINGDOM','CO3 9AW','01206545610','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 18:35:37',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³   1 '),(2081,694715035015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'',16,'hutongstore','redwoodsnemesis','henrik@thierry.nu','Henrik Thierry','Digital Lifestyle Torvet 15','Koege','','DENMARK','4600','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-28 19:41:09',0,NULL,3,1,3,1,NULL,'wf1003   1 RR723016949CN\r'),(2082,694720122015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','hooya892000','alifnur@gmail.com','Alif Nurhaziq Abd Rahman','373 Claremont Road','Manchester','Greater Manchester','UNITED KINGDOM','M14 7PA','07895356003','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 19:41:02',0,NULL,3,1,2,1,NULL,NULL),(2083,600174310001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','m.ognedal','mognedal@gmail.com','Magnus Ognedal','Feisteinveien 4B','STAVANGER','ND','NORWAY','4026','+47 90949197','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 19:38:46',0,NULL,3,1,2,1,NULL,'40cm æ£š   1 '),(2084,681318010016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','dentistsmiling311','sneetverma@hotmail.com','sunita verma','Sparkle Dental Boutique 311 Boston road','Hanwell','London','UNITED KINGDOM','W13 8PT','02085674344','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-11-28 20:54:42',0,NULL,3,1,4,1,NULL,'2m x3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  è‹±æ ‡  2\r115w 220v   2\råŒ…    1 \rYW864143274CN\r\rlighting kit  $32'),(2085,600272678001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','alflamer','alvarofl@gmail.com','Ãlvaro FernÃ¡ndez','C/ Cardenal Solis nÂº10---1ÂºG','Madrid','Madrid','SPAIN','28012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 21:31:15',0,NULL,3,1,2,1,NULL,'40cm æ£š  1 '),(2086,600273762001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','ham1248','graham@scotlandscapes.com','graham macfarlane','bellsmyre pharmacy<br>7c merkins avenue','bellsmyre dumbarton','West Dunbartonshire','UNITED KINGDOM','g82 3eb','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 21:33:14',0,NULL,3,1,2,1,NULL,NULL),(2087,694847071015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'',7.48,'hutongstore','pixel_vision','gary@haveyourcakeandeatit.org','Gary Brown','356-358 Spendmore Lane, Coppull','Chorley','Lancashire','UNITED KINGDOM','PR7 5DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 21:44:44',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡  1 '),(2088,599771709001,110531023633,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',21.6,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7Âº 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 21:58:12',0,NULL,3,1,2,1,NULL,'æ¸å˜è“  1\ræ¸å˜æ©™   1\ræ¸å˜æ£•  1 '),(2089,694883303015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'',23.9,'hutongstore','madmogga','a.morhall@btinternet.com','mrs a morhall','30 the drive','mayland','essex','UNITED KINGDOM','cm3 6aa','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 22:38:14',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723016921CN\r'),(2090,694893732015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'',3.59,'hutongstore','jayceephotography10','jayceephotography@hotmail.co.uk','jay cee','40 wheatash road','addlestone','Surrey','UNITED KINGDOM','kt15 2es','07951729684','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 22:57:12',0,NULL,3,1,2,1,NULL,'å°å·é•œå¤´ç­’   1 '),(2091,600323115001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','peroni_es','por@retemail.es','Pere Onieva','Av. Barcelona 108 6-2','IGUALADA','SPAIN','SPAIN','08700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-28 23:13:17',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 RR723016904CN\r'),(2092,600360887001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','cbairbrush','clburrell34@att.net','Casandra Burrell','9809 Rosehill Ave<br>Apt 1','Cleveland','OH','UNITED STATES','44104-3659','(216) 253-0921','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 00:59:35',0,NULL,3,1,1,1,NULL,'1.6mx2.1m èƒŒæ™¯å¸ƒ  2 ï¼ˆéƒ½æ˜¯ç™½è‰²çš„ï¼‰  '),(2093,600365204001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','br4nk1nho','marco_g@netmadeira.com','Marco AntÃ³nio F. GonÃ§alves','C. St. AntÃ³nio, 80, Edificio Gemini, bloco B; X','Funchal','Madeira','PORTUGAL','9020-001','+351919731777','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-11-29 01:12:17',0,NULL,3,1,2,1,NULL,' '),(2094,638920114002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','rhianspaypal','rhianpaypal@yahoo.com','R Cope','C/O ERMA<br>20 customhouse quay','Wellington','New Zealand','NEW ZEALAND','6140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 01:19:41',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2095,638916760002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','rhianspaypal','rhianpaypal@yahoo.com','R Cope','C/O ERMA<br>20 customhouse quay','Wellington','New Zealand','NEW ZEALAND','6140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 01:19:40',0,NULL,3,1,6,1,NULL,'3m æ¨ªæ†  3\r2900g\ræ–°åŠ å¡ ems  EX000113356SG\r'),(2096,639121535002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','emoskau','office@ericmoskau.com','Eric Moskau','32 Falcon Dr','Mandeville','LA','UNITED STATES','70471-2952','(985) 626-3417','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 01:44:48',0,NULL,3,1,1,1,NULL,' '),(2097,639125504002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','eliassaint9','cefritz@yahoo.com','Carmelot Eliassaint','9 Sandy Ln','Norwich','CT','UNITED STATES','06360-3156','(860) 887-4603','NoPaymentFailure','CheckoutComplete','Other','2010-11-29 01:58:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rå•ç¯å¤´  1\råå…‰ä¼ž   1 RR723016881CN\r'),(2098,630960812002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',57.9,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7Âº 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-12 19:26:07',0,NULL,5,1,18,0,NULL,''),(2099,639141959002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','jaylindsay','jaylindsaydds@gmail.com','Jay Lindsay','57 Fox Ln','Fredericksburg','TX','UNITED STATES','78624-7346','(830) 997-6457','NoPaymentFailure','CheckoutComplete','Other','2010-11-29 02:41:50',0,NULL,3,1,3,1,NULL,' RR723016952CN\r'),(2100,639174202002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','ruanoooo','ruano11@hotmail.com','Ruano Oliveira','Rua Aguiar, nÂº 55/apto 204<br>Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','20261120','55 21 25675616','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 04:17:34',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1 RR723016864CN\r'),(2101,600431714001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','m4bz','mark@markforbes.com','Mark Forbes','873 W Y St','Washougal','WA','UNITED STATES','98671-7434','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 04:46:37',0,NULL,3,1,1,1,NULL,NULL),(2102,639193053002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','mickflag','michael_drapeau@hotmail.com','Michael Drapeau','1505 Des Roses','Sherbrooke','QC','CANADA','J1E 4J2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 05:47:02',0,NULL,3,1,2,1,NULL,NULL),(2103,600445844001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'',7.9,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Kazankov Valery','Rokossovskogo avenue, 115, appartment 3','Minsk','','BELARUS','220085','+375447127692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 06:10:37',0,NULL,5,1,18,0,NULL,' å‘ä¸Šåˆå¹¶'),(2104,600446152001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64.99,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Kazankov Valery','Rokossovskogo avenue, 115, appartment 3','Minsk','','BELARUS','220085','+375447127692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 06:12:01',0,NULL,3,1,5,1,NULL,'çº¢ç¯å¤´  1\r800w 220v   2\rCP212235180CN\r '),(2105,639199203002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','mgpharmd','vfmartinelli@yahoo.com','Vincent Martinelli','5941 Ruthwood Dr','Calabasas','CA','UNITED STATES','91302-1076','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 06:23:10',0,NULL,3,1,1,1,NULL,NULL),(2106,639195179002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','nandofjs','nandofjs@ig.com.br','FERNANDO STELSER','4 OAK GROVE AVE<br>DOMINOS PIZZA','BATH','ME','UNITED STATES','04530','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-11-29 06:34:25',0,NULL,3,1,3,1,NULL,' RR723016935CN\r'),(2107,600452738001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','osmanay2010','osmanay63@mynet.com','OSMAN AYDIN','Basaksehir 4.Etap I.Kisim L3 Blok Da.18 Basaksehir','ISTANBUL','','TURKEY','34000','0212 4537939','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 07:00:34',0,NULL,3,1,2,1,NULL,NULL),(2108,600456512001,110533631413,'CTR-301P Flash Trigger Kit with 2 Receivers ctr301p',1,'AKT001',41.9,'hermeshine','picok2','picok2@net.hr','Goran Svaco','Kralja Tomislava 87','Djurdjevac','','CROATIA','48350','0038598452426','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 07:17:51',0,NULL,3,1,3,1,NULL,' RR723016983CN\r'),(2109,600460636001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','cscrrg2010','csc.rrg@hotmail.com','Rachel Gentry','PO Box 6084','Silverdale','WA','UNITED STATES','98315-6084','(360) 447-0806','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 07:41:41',0,NULL,5,1,18,0,NULL,NULL),(2110,600268832001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11.2,'hermeshine','kreved','coolez@ya.ru','Konstantin Krysanov','Ul. Izumskaya street dom 30 kv 14','Moscow','Moscow','RUSSIAN FEDERATION','117624','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 08:50:47',0,NULL,3,1,2,1,NULL,NULL),(2111,600481755001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','felabgu','fela93@gmail.com','Felix Krikun','Shalom ash 26/2','Rishon Le-Zion','','ISRAEL','75607','972528716353','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 09:22:29',0,NULL,3,1,2,1,NULL,NULL),(2112,639234567002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','litobocon','miguelginermg@gmail.com','miguel giner','polo y peyrolon n5 pta 19','valencia','Comunidad Valenciana','SPAIN','46021','963695436','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 09:22:36',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723017119CN\r'),(2113,639236736002,120448751271,'Remote Shutter Release for SONY A100 A200 A900 =RM-S1AM',1,'AA3212',6.98,'hermeshine','linas565','linas@paintbaleris.lt','Linas Navardauskas','Taikos 84-54','Kaunas','lithuania','LITHUANIA','LT51275','37068723366','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 09:30:08',0,NULL,3,1,2,1,NULL,'RS-S1  1 '),(2114,695140088015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','02izzie02','pat-stone@tiscali.co.uk','Patricia Stone','73, The Glebe','West Calder','West Lothian','UNITED KINGDOM','EH55 8BL','01506871651','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 11:19:34',0,NULL,3,1,2,1,NULL,NULL),(2115,695142520015,250634555406,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'',2.75,'hutongstore','02izzie02','pat-stone@tiscali.co.uk','Patricia Stone','73, The Glebe','West Calder','West Lothian','UNITED KINGDOM','EH55 8BL','01506871651','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 11:26:11',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§  sony  1 '),(2116,600527995001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','ohcejohkanharri','hilehtonen@gmail.com','Harri Lehtonen','RievanrÃ¡dnu 7 D 10','Utsjoki','','FINLAND','99980','358-40-5211043','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 12:12:05',0,NULL,3,1,2,1,NULL,NULL),(2117,639294816002,120653773659,'for wenndysebli',1,'',49,'hermeshine','wenndysebli','wenndy_sebli@yahoo.com','Wenndy Sebli','Lot 3652, No. 19, Taman Selasih, Jalan Cenderawasih,<br>Off Jalan Depo, Petra Jaya','Kuching','Sarawak','MALAYSIA','93100','6082230032','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 12:53:47',0,NULL,3,1,3,1,NULL,' 1- ND8 for 67mm( brand tianya)\r2- CPL for 67mm ( brand tianya\r3- Black color non woven  ( 1.6m x 3m)\r4- Chocolate color non woven ( 1.6m x 3m)\rRR723017476CN\r\r'),(2118,638582167002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',14.19,'hermeshine','gaw530','markdayoc@yahoo.com','Ghuinn Mark Dayoc','6 Desmond Place Rivervale','Perth','Western Australia','AUSTRALIA','6103','61451308848','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 12:58:40',0,NULL,3,1,2,1,NULL,' ew-73b   1\r67mm  Lens Cap for Canon 2\r'),(2119,600561521001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','projet2001','projetizmir@superonline.com','Gokhan Ergun','273 / 7 Sok.No:4<br>Projet A.S. Bornova','Izmir','','TURKEY','35047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 13:59:50',0,NULL,3,1,2,1,NULL,NULL),(2120,639143586002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','skokie1996','mansur1954@hotmail.com','Anvar Khodzhaev','821 W 17th St<br>Unit A','Houston','TX','UNITED STATES','77008-3576','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 14:01:20',0,NULL,3,1,1,1,NULL,'çˆµå½±æ— çº¿  N1   1 '),(2121,600567335001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',2,'AE3401',74.9,'hermeshine','meaow2007','larfta2@aol.com','Tiyana Mardesich','10 Etherington Ave<br>Spearwood','Perth','Western Australia','AUSTRALIA','6163','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 14:14:32',0,NULL,3,1,6,1,NULL,'æ–°çš„ç¯æž¶     2\ræ–°åŠ å¡ems \rEX000165322SG'),(2122,681740220016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','viliushunter','viliuscece@gmail.com','Vilius Cesevicius','Diana 8','Scunthorpe','Lincolnshire','UNITED KINGDOM','DN15 6AX','07564070334','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 14:51:29',0,NULL,3,1,2,1,NULL,NULL),(2123,695233241015,250600501508,'Continuous Lighting System soft box photography studio ',1,'',68,'hutongstore','watcook','louise.cookson@hotmail.co.uk','Louise Cookson','Chy-An-Kernow Botley Road, Horton Heath','Eastleigh','Hampshire','UNITED KINGDOM','SO50 7DW','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-11-29 15:10:58',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š  è‹±æ ‡   2\råŒ…   1 \rlighting kit $26\rYW864143440CN\r'),(2124,639346768002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','tove123martin','mart-k@online.no','Martin KrokÃ¥','Furuvegen 8','Tornes i Romsdal','MÃ¸re og Romsdal','NORWAY','6443','(047)41325840','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 15:17:23',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…   1 \rRR723017493CN\r'),(2125,600599866001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','lauminsh21','rfjodorovs@gmail.com','Reinis Fjodorovs','13 florys Court<br>Augustus Rd.','London','London','UNITED KINGDOM','Sw19 6ra','02087805743','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 15:41:06',0,NULL,3,1,2,1,NULL,'40cm æ£š    1 '),(2126,639369058002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','megafashion-2009','megafashion2009@gmail.com','Keishla Davila','11606 NW 29th St<br>Apt. A-4','Coral Springs','FL','UNITED STATES','33065-3471','','NoPaymentFailure','CheckoutComplete','Other','2010-11-29 16:12:36',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž    1 \rRR723017480CN\r'),(2127,695264165015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','johnenty','johnenty@btopenworld.com','John Entwistle','38 Clarence St','Bolton','Lancashire','UNITED KINGDOM','BL47RF','01204795985','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 16:12:50',0,NULL,3,1,2,1,NULL,' '),(2128,639383911002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','minishre','mindashreve@yahoo.com','Minda Shreve','699 N Vulcan Ave<br>Spc 88','Encinitas','CA','UNITED STATES','92024','(760) 809-7484','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 16:45:21',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…   nikon   1 '),(2129,600459359001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','ronyeden','ronybarbi@gmail.com','Elad Zalman','Ovadya 24 apartment 6','Haifa','Israel','ISRAEL','34563','972-52-8526626','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 16:57:16',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rRR723017462CN\r'),(2130,639411697002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','cuquico','victorsoriano@terra.es','victor soriano','marquÃ©s de la ensenada 10-6A','murcia','Murcia','SPAIN','30007','669792300','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 17:42:44',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2131,639409623002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','cuquico','victorsoriano@terra.es','victor soriano','marquÃ©s de la ensenada 10-6A','murcia','Murcia','SPAIN','30007','669792300','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 17:42:45',0,NULL,5,1,18,0,NULL,' å‘ä¸Šåˆå¹¶ '),(2132,639409112002,120489236687,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','cuquico','victorsoriano@terra.es','victor soriano','marquÃ©s de la ensenada 10-6A','murcia','Murcia','SPAIN','30007','669792300','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 17:42:46',0,NULL,5,1,18,0,NULL,' å‘ä¸Šåˆå¹¶ '),(2133,600653638001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','cuquico','victorsoriano@terra.es','victor soriano','marquÃ©s de la ensenada 10-6A','murcia','Murcia','SPAIN','30007','669792300','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 17:42:45',0,NULL,3,1,3,1,NULL,' æŸ”å…‰ä¼ž  1\råå…‰ä¼ž   1\rbåº§   1\r80cm 5in1 åå…‰æ¿   1\rRR723017555CN\r'),(2134,600659311001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','redivivaii','gokyori@shaw.ca','Roger Simpson','20850  72nd Ave,','Langley','BC','CANADA','V2Y 1T3','(604) 510-3150','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 17:50:27',0,NULL,3,1,2,1,NULL,NULL),(2135,639426427002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','mamuphoto','d.malorzo@teletu.it','damiano malorzo','strada per minnuta ,1B','brindisi','BR','ITALY','72100','0831/451993','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 18:07:41',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\rbåº§  2\ræŸ”å…‰ä¼ž   2 \rlight stand   $22\rYW864143425CN\r'),(2136,600674224001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','tomas9141','tom.coufal@gmail.com','Tomas Coufal','Olomoucka 87','Prostejov','','CZECH REPUBLIC','79601','+420603919590','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 18:19:49',0,NULL,3,1,2,1,NULL,NULL),(2137,639449941002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','hottabich','aleks2003@inbox.lv','Aleksandrs Lukicovs','Marupe,Liela 39-43','Riga','','LATVIA','2167','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 18:48:13',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…   1 \rRR723017428CN\r'),(2138,639451585002,120598267827,'Camera shoulder bag with raincover for Canon 550D 40D',1,'AO0021',28.99,'hermeshine','eagle4801','tsblaw@netamumail.com','Teri Boland','303 2nd St S','Swea City','IA','UNITED STATES','50590','','NoPaymentFailure','CheckoutComplete','Other','2010-11-29 18:49:46',0,NULL,3,1,3,1,NULL,'canon R2 å•è‚©åŒ…   1 \rRR723017502CN\r'),(2139,695370110015,250690849529,'Background Support & Light Kit 3m x 6m 10 x 20ft white ',1,'',134,'hutongstore','janice7077','jailpalmer@hotmail.com','janice palmer','unit cleaners ltd 286 brixton road','london','London','UNITED KINGDOM','sw96ag','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-11-29 19:01:39',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç™½è‰²èƒŒæ™¯å¸ƒ  1\r2mç¯æž¶   2\råŒç¯å¤´  2 è‹±æ ‡\råå…‰ä¼ž   2\r45w ç¯æ³¡   4\råŒ…   1 \rYW864143436CN\r\rLighintg kit  $30'),(2140,639477718002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','pipo-9820','peterkiryakov@mail.bg','Peter Kiryakov','Rozen blvd 25<br>ATY BALKAN','sofia','sofia','BULGARIA','1220','0035929369820','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 19:29:41',0,NULL,3,1,2,1,NULL,NULL),(2141,639352402002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','8mmaster','siggaarne@hotmail.com','Stig Satherskar','Midteggen 16','7078 Saupstad NO','Trondheim','NORWAY','7000','+47 92609238','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 19:37:19',0,NULL,5,1,18,0,NULL,NULL),(2142,639312814002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','8mmaster','siggaarne@hotmail.com','Stig Satherskar','Midteggen 16','7078 Saupstad NO','Trondheim','NORWAY','7000','+47 92609238','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 19:37:19',0,NULL,5,1,18,0,NULL,' '),(2143,600558373001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'',13.99,'hermeshine','8mmaster','siggaarne@hotmail.com','Stig Satherskar','Midteggen 16','7078 Saupstad NO','Trondheim','NORWAY','7000','+47 92609238','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 19:37:20',0,NULL,3,1,3,1,NULL,'nikon 90th é•œå¤´ç­’   1\rä¸­å·å†…èƒ†åŒ… nikon   1\r3pcs æ»¤é•œè¢‹      1 \rRR723017312CN\r'),(2144,600735716001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','bigdlls','bigdlls@sbcglobal.net','David Moore','416 S Waverly Dr','Dallas','TX','UNITED STATES','75208-5728','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 19:56:23',0,NULL,3,1,1,1,NULL,NULL),(2145,639510166002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','eskimoyety','radko.vavrik@gmail.com','Radko Vavrik','Dlhy rad 165','Velke Zaluzie','','SLOVAK REPUBLIC','95135','+421948048821','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 20:19:55',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2146,600747079001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','eskimoyety','radko.vavrik@gmail.com','Radko Vavrik','Dlhy rad 165','Velke Zaluzie','','SLOVAK REPUBLIC','95135','+421948048821','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 20:19:55',0,NULL,3,1,2,1,NULL,'52mm rubber æ©¡èƒ¶ç½©  1\rå°å·ç°å¡   1 '),(2147,639516277002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','cubarican1985','foxyfire6000@yahoo.com','Angela Solis','1151 Evening Trail Drive','Wesley Chapel','FL','UNITED STATES','33543','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 20:28:40',0,NULL,3,1,1,1,NULL,NULL),(2148,695451731015,250615143615,'YongNuo Flash Battery Pack SF-17 for Canon Flash 580EXI',1,'',28.99,'hutongstore','dawiddrozdz','dawid.drozdz@gmail.com','Dawid Drozdz','46 Grovelands Close','london','London','UNITED KINGDOM','se5 8jn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 20:41:37',0,NULL,3,1,3,1,NULL,'RR723017391CN\r'),(2149,695461326015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','lannos79','lanceguyatt@gmail.com','Lance Guyatt','Wilson Fletcher 1 Old Nichol Street','London','London','UNITED KINGDOM','E2 7HR','07723198662','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 20:54:47',0,NULL,3,1,2,1,NULL,NULL),(2150,600790178001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 21:26:09',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2151,600733651001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','bhlevin','blevin@imagerygroup.com','Barry Levin','3245 Whipple Rd','Union City','CA','UNITED STATES','94587','(510) 324-4020','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 21:45:58',0,NULL,3,1,1,1,NULL,NULL),(2152,639563927002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','gtgaute','gtgaute@gmail.com','Gaute Thogersen','Skrenten 48 C','Larvik','Vestfold','NORWAY','3258','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 21:52:19',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR723017388CN\r'),(2153,639573116002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 22:10:54',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š  2  æ¬§æ ‡\råŒ…  1\r2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž  1 \rlighting kit  $28\rYW864143414CN\r'),(2154,639579050002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','bphoto57','bphotousa@live.com','steve brudzinski','5 S Longyard Rd<br>Apt C4','southwick','MA','UNITED STATES','01077-9379','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 22:24:04',0,NULL,3,1,1,1,NULL,NULL),(2155,695532679015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'',2.98,'hutongstore','andyg840','andrewguest@live.co.uk','Andrew Guest','16 Oak Stret','Northwich','Cheshire','UNITED KINGDOM','CW9 5LJ','0160647310','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 23:06:50',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2156,695535595015,250600523459,'Shutter Release Remote Cord For Canon 500D 450D RS-60E3',1,'',2.98,'hutongstore','andyg840','andrewguest@live.co.uk','Andrew Guest','16 Oak Stret','Northwich','Cheshire','UNITED KINGDOM','CW9 5LJ','0160647310','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 23:06:50',0,NULL,3,1,2,1,NULL,'RS-C1   1\rRS-C3   1 '),(2157,639599626002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','duhgoober','tomoleary1@juno.com','THOMAS R. OLEARY','13443 Fm 346 E','WHITEHOUSE','TX','UNITED STATES','75791','(903) 752-2703','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 23:15:15',0,NULL,3,1,1,1,NULL,NULL),(2158,600846470001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',28.99,'hermeshine','gmzsur','gmzsur@hotmail.com','Jose Antonio  Gamez Mangas','MUEBLES CASANDRES Ctra. Badajoz-Montijo km.22 (EX209)','Pueblonuevo del Guadiana','Extremadura','SPAIN','06184','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 23:41:46',0,NULL,3,1,3,1,NULL,'3m ttlçº¿   for  Canon   1 \rRR723017374CN\r'),(2159,600853714001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','bafalda','lolov16@hotmail.fr','laurent gibouin','10 rue des Jonquilles','la BruffiÃ¨re','Pays de la Loire','FRANCE','85530','0637654197','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 00:14:43',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´   æ¬§æ ‡   1 '),(2160,638723265002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',10,'hermeshine','msgdlsmith','msgdlsmithret@aol.com','Darrell L. Smith','519 Logan St','Frankfort','KY','UNITED STATES','40601-3517','(502) 682-0028','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 00:53:09',0,NULL,3,1,1,1,NULL,'72mm canon é•œå¤´ç›–  2\r58mm canon é•œå¤´ç›–  2 '),(2161,639645725002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','margaux100680','utkidmm@comcast.net','Margaux Morgan','7165 Alice Springs Ln','Corryton','TN','UNITED STATES','37721-3956','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 01:38:28',0,NULL,3,1,1,1,NULL,NULL),(2162,600885405001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','underashes2008','agkurylo@gmail.com','Adam Kurylo','1112 S Zenith Ave','Davenport','IA','UNITED STATES','52802-2541','(563) 726-2747','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 01:51:14',0,NULL,3,1,1,1,NULL,' 1112 S. Zenith Ave \rDavenport Iowa\r52802\r'),(2163,639654032002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','surabky_123','stockphotothailand@hotmail.com','Sura Nualpradid','BKY Co.,Ltd. 93/9 Moo 1 Praram 2 Road<br>Bangnamjaed, Maung','Samutsakorn','','THAILAND','74000','6624528564','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 02:10:26',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶'),(2164,639657117002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','surabky_123','stockphotothailand@hotmail.com','Sura Nualpradid','BKY Co.,Ltd. 93/9 Moo 1 Praram 2 Road<br>Bangnamjaed, Maung','Samutsakorn','','THAILAND','74000','6624528564','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 02:14:00',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹  2 '),(2165,639668289002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','traveltime88','tarahss77@gmail.com','Tara  Neuheisel','223 N 193rd Dr','Buckeye','AZ','UNITED STATES','85326-5899','(623) 853-0954','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 03:00:27',0,NULL,3,1,1,1,NULL,NULL),(2166,639361616002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE1301',23.67,'hermeshine','originalstadium','originalstadium@palermoplanet.it','William Anselmo','Via Lancia di Brolo, 82','Palermo','Palermo','ITALY','90100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 03:16:27',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  3 \rRR723017459CN\r'),(2167,599583903001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','adelbot2','bavlyab@yahoo.com','ADEL BOTROUS','451 E Rowland St<br>Apt 11','COVINA','CA','UNITED STATES','91723','(626) 339-7488','NoPaymentFailure','CheckoutComplete','Other','2010-11-30 03:41:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rRR723017445CN\r'),(2168,695647387015,250692239997,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'',4.99,'hutongstore','nevilleclarke','nobby7921@hotmail.com','N T Clarke','19 Ryland Close Sydenham','Leamington Spa','Warks','UNITED KINGDOM','CV31 1HU','01926335539','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 03:56:49',0,NULL,3,1,2,1,NULL,NULL),(2169,590564606001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3305',3.6,'hermeshine','mello021','rafael.calero@hotmail.com','Rafael Calero','Rua GirÃ£o Barroso 100<br>Bloco 3B apartamento 202 Alcantara','SÃ£o GonÃ§alo','Rio de Janeiro','BRAZIL','24711-160','55 21 87050724','NoPaymentFailure','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,NULL),(2170,639690358002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','brian730407','brian0407@gmail.com','BYUNG KYU LEE','1353 2ND AVE<br>SEDGBURY CLEANERS','NEW YORK','NY','UNITED STATES','10021-4560','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-11-30 04:04:39',0,NULL,3,1,3,1,NULL,' RR723017431CN\r'),(2171,595160345001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','dionne782','crazy_climber6@hotmail.com','Dionne Dionne','5214-49st','Lacombe','AB','CANADA','T4L1J3','(403) 782-7224','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 04:26:15',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3m x6m ç™½è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  2\r115w110v  2\råŒ…   1 \rCP212150609CN\r'),(2172,639700926002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','$dealz','git.ur.dun@hotmail.com','Darcy Neigel','1139 Henleaze Ave','Moose Jaw','SK','CANADA','S6H 3V8','(306) 693-8795','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 04:50:33',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´  1 '),(2173,639707518002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','tfarms3150','tfarms@wildblue.net','Thomas Barfield','17401 Katydid Ln','Immokalee','FL','UNITED STATES','34142-9689','(239) 657-4181','NoPaymentFailure','CheckoutComplete','Other','2010-11-30 05:29:13',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž  1 \rRR723017414CN\r'),(2174,695675910015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','delvars','steverowse@gmail.com','Steven Rowse','22 Huxley Close','Godalming','Surrey','UNITED KINGDOM','GU72AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 05:53:02',0,NULL,3,1,2,1,NULL,NULL),(2175,600928227001,110502916835,'New 62mm ring adapter replacement for cokin P series',1,'AA2211',3.55,'hermeshine','meetmyoffer','sgbox@live.com','steven goldstein','1815 215th St<br>apt 4P','bayside','NY','UNITED STATES','11360-2132','(516) 287-8821','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 06:21:03',0,NULL,3,1,1,1,NULL,NULL),(2176,639657992002,120560203167,'77mm Lens lenscap for Canon Combined shipping discounts',1,'AA1304',2.6,'hermeshine','nwmaple206','nwmaple@gmail.com','Wei Lu','5829 133rd PL SW','Edmonds','WA','UNITED STATES','98026','(425) 329-7689','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 06:24:02',0,NULL,3,1,1,1,NULL,NULL),(2177,600643605001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','wizardonbay','sergio.o@tugamail.com','SÃ©rgio Oliveira','Rua Nuno Amorim, nÂº6 - 4Âº Esquerdo Frente','Braga','Braga','PORTUGAL','4710-505','962548954','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 08:56:00',0,NULL,3,1,2,1,NULL,NULL),(2178,639762574002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','tomasi_030','tomers.ts@gmail.com','tomer shalom','beery 8 ( Entry b  - Apartment 3)','givat-shmuel','','ISRAEL','54035','972-722-322-864','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 10:04:40',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2179,600483661001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',107.96,'hermeshine','bador.lifestrike','matthew.carlson92@gmail.com','Matthew Carlson','5041 Alabama St<br>Apt 54','El Paso','TX','UNITED STATES','79930-2643','(661) 904-0145','NoPaymentFailure','CheckoutComplete','Other','2010-11-30 11:03:09',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\ræ–œè‡‚  2 \rlight stand $22\rYW864143462CN'),(2180,601022764001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','benington','ben.secs@dsl.pipex.com','Martin Halley','16 The Beeches<br>Fetcham','LEATHERHEAD','Surrey','UNITED KINGDOM','KT22 9DT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 12:08:31',0,NULL,3,1,2,1,NULL,''),(2181,639803672002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','alpha-sphere','yilkee@gmail.com','Yilkee Lam','Groenewegje 67','Den Haag','Zuid-Holland','NETHERLANDS','2515LM','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 12:36:59',0,NULL,3,1,2,1,NULL,''),(2182,639811622002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','bam666','bamitche@execpc.com','Brian Mitchell','452 Sunset Dr','De Forest','WI','UNITED STATES','53532-1128','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 13:03:07',0,NULL,3,1,1,1,NULL,NULL),(2183,639813527002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','sasanka87sasanka','sricotechnologies@gmail.com','Sasanka Rajapaksa','5, Udyana Mawatha,<br>Pepiliyana Road,','Nugegoda.','Colombo','SRI LANKA','10250','0774193065','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 13:11:28',0,NULL,3,1,2,1,NULL,''),(2185,695807957015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','j.smity','julian@julsplace.co.uk','Julian Smith','4 Iron Way tondu','bridgend','Bridgend','UNITED KINGDOM','cf329bf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 13:27:01',0,NULL,3,1,2,1,NULL,NULL),(2186,601053409001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','jubeai','big@euskalnet.net','Juan Arrrondo Ecenarro','Asteasuain kalea NÂº3-5ÂºD','Lasarte-Oria','Guipuzcoa','SPAIN','20160','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 13:41:05',0,NULL,3,1,4,1,NULL,'tripod $15\rYW864143506CN'),(2187,695813065015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'',6.95,'hutongstore','jskorupa80','jakub.skorupa@yahoo.pl','Jakub Skorupa','Flat A, Chiswick Court, 1A, Silver Crescent','LONDON','LONDON','UNITED KINGDOM','W4 5SF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 13:41:29',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2188,639830819002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','proforica','profor@vanea.net','IVAN PROFOR','Sciusev 4/8','Balti','Balti','MOLDOVA, REPUBLIC OF','3100','37369833368','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 14:09:46',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR723017839CN\r'),(2189,639845258002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','misterohlsson','mistero@live.se','Anders Ohlsson','AnanasvÃ¤gen 5','JÃ¤rfÃ¤lla','Stockholm','SWEDEN','175 49','+4687391691','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 14:43:20',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\räº‘å° 1\ræŸ”å…‰ä¼ž   1 \rRR723017842CN\r'),(2190,639848602002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','malldova2nd','z55001987@yahoo.com','Larisa Grosul','str.Podul Inalt 14/2 ap.12','ChiÅŸinau','','MOLDOVA, REPUBLIC OF','MD2023','37368418989','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 14:52:04',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRR723017856CN\r'),(2191,639860674002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','exdeo84','exdeo84@gmail.com','Synergy Computers','901Quartz Ct<br>Unit B','Cedar Park','TX','UNITED STATES','78613','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 15:25:24',0,NULL,3,1,1,1,NULL,NULL),(2192,639862210002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','recycle3','mlc1usa@msn.com','Michael Cullom','204 E Sunny Sands Rd','Cathlamet','WA','UNITED STATES','98612-9728','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 15:30:30',0,NULL,3,1,1,1,NULL,' '),(2193,601094849001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','fzetec','fcerrato@gmail.com','fernando marques','gabriel de lara 293','sao paulo','sao paulo','BRAZIL','04582050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 15:43:03',0,NULL,3,1,2,1,NULL,NULL),(2194,639871653002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','regety','avplus@list.ru','Alexandr Plusnin','ulica Kuznecova, 6, kv.54','Kotlas','Arhangelskaya obl','RUSSIAN FEDERATION','165300','8-911-565-04-69','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 15:55:35',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…  1 '),(2195,601131064001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','user-maat-ra-63','felix-arranz-martin@hotmail.com','FÃ‰LIX ARRANZ MARTÃN','CARRETERA DE LA GRANJA, 4<br>CONSEJERÃA DE EDUCACIÃ“N','COLLADO VILLALBA','Madrid','SPAIN','28400','656560066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 17:10:19',0,NULL,3,1,2,1,NULL,'å°å·é•œå¤´ç­’  1 '),(2196,636267630002,120564178566,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',11.54,'hermeshine','andris_ogre','ogreasd@inbox.lv','Andris Gelzinis','Tinuzu 18-11','Ogre','Ogre','LATVIA','LV-5001','+37129343432','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 17:13:54',0,NULL,3,1,2,1,NULL,'lenspen   2 '),(2197,601147949001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','alvins1204','alvins1987@gmail.com','Alvin Scherbahn','Feldbergstrasse 58','Mannheim','','GERMANY','68163','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 17:45:50',0,NULL,3,1,4,1,NULL,'æ–œè‡‚  1\r2m ç¯æž¶   1 \rlight stand  $16\rYW864143510CN'),(2199,682500854016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',38,'hutongstore','formby650','charlie@smudge.uk.com','Hannah Flannery','2 Ryder Way','Ickleford','Hertfordshire','UNITED KINGDOM','SG5 3XL','07722052721','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 19:17:20',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶  1\r2m ç¯æž¶  1 \rYW864143473CN\rreflector  holder  $15\r'),(2200,639978716002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','protrekmao','protrek@centrum.cz','Martin Vylasek','Husova 100','Bedihost','','CZECH REPUBLIC','79821','+420776747441','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 19:34:07',0,NULL,5,1,2,1,NULL,''),(2201,601206075001,110533631256,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','protrekmao','protrek@centrum.cz','Martin Vylasek','Husova 100','Bedihost','','CZECH REPUBLIC','79821','+420776747441','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 19:34:06',0,NULL,3,1,2,1,NULL,' å°å·ç°å¡   1 \r77mm æ©¡èƒ¶ç½©   1'),(2202,696006691015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'',1.88,'hutongstore','johnenty','johnenty@btopenworld.com','John Entwistle','38 Clarence St','Bolton','Lancashire','UNITED KINGDOM','BL47RF','01204795985','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 19:34:29',0,NULL,3,1,2,1,NULL,NULL),(2203,639988636002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','dbigby1','dylan@macaframa.com','Dylan Bigby','533 Frederick St','San Francisco','CA','UNITED STATES','94117-2753','(415) 990-6769','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 19:46:20',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡  1 '),(2204,695855991015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',6,'',11.28,'hutongstore','annie592','andrea-solomon@ntlworld.com','Andrea Solomon','15 Bentley Way','Essex','Essex','UNITED KINGDOM','IG80SE','02085029996','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 22:19:33',0,NULL,3,1,3,1,NULL,'RR723017811CN '),(2205,640070872002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','the_fishtank_2007','bigfatfish@hotmail.co.uk','James Penrose','2500 Asp Ave<br>Traditions Square East Bldg H Rm 303','Norman','OK','UNITED STATES','73072-6409','02084625929','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 22:19:38',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ… nikon   1 '),(2206,696126822015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'',3.76,'hutongstore','flaffy*123','go_wild_6@hotmail.com','Jenny Johns','23 Benson Drive Northam','Bideford','Devon','UNITED KINGDOM','EX39 1UY','01237423950','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 22:33:56',0,NULL,3,1,2,1,NULL,NULL),(2207,601309326001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','msxodesigns','msxodesigns2@yahoo.com','Alonna Leverett','23111 Laurel Valley Ct<br># 10','southfield','MI','UNITED STATES','48034-2085','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 22:47:31',0,NULL,3,1,1,1,NULL,'1.6x2.1 é»‘è‰²èƒŒæ™¯å¸ƒ  1 '),(2208,696153386015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','7812dg','davidgiddins7812@hotmail.com','David Giddins','5, Sussex Drive, Belle Vue','Shrewsbury','Shropshire','UNITED KINGDOM','SY3 7NQ','01743368590','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 23:36:56',0,NULL,3,1,2,1,NULL,NULL),(2209,601326370001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','4037edward','eppiv@juno.com','edward pawley','10600 Griffin Rd<br># A105','Davie','FL','UNITED STATES','33328-3208','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 23:37:36',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ…  nikon   1 '),(2210,640106936002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','mipro83','prilepokm@gmail.com','Miroslav Prilepok','Prievozska 1','Bratislava','Slovakia','SLOVAK REPUBLIC','821 09','+421905616600','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 23:51:05',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 \rRR723017825CN\r'),(2211,640108566002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','efm6660','e.mcnamara6@verizon.net','Elizabeth McNamara','18 Prospect St','East Greenwich','RI','UNITED STATES','02818-3217','(401) 885-6497','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 23:56:28',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2212,640108154002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','efm6660','e.mcnamara6@verizon.net','Elizabeth McNamara','18 Prospect St','East Greenwich','RI','UNITED STATES','02818-3217','(401) 885-6497','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 23:56:28',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2213,640108405002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','efm6660','e.mcnamara6@verizon.net','Elizabeth McNamara','18 Prospect St','East Greenwich','RI','UNITED STATES','02818-3217','(401) 885-6497','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 23:56:29',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›–  canon 3 '),(2214,640114247002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','jorgerr2007','joryaanso15@yahoo.com','Jorge Rivera','PO Box 154','Juncos','PR','UNITED STATES','00777','(787) 361-8398','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 00:14:37',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(2215,640073975002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','oaks','rj_6@hotmail.com','RAVI JOSHI','955 desmet way','san jose','CA','UNITED STATES','95125-6362','(408) 746-6018','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 01:25:25',0,NULL,3,1,1,1,NULL,NULL),(2216,601356664001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','heet9885','jheetland@ou.edu','Jesse Heetland','1003 King St','Lancaster','OH','UNITED STATES','43130-3243','(740) 215-8223','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 01:33:45',0,NULL,3,1,1,1,NULL,'æ¸å˜ç°  1\r58mm çŽ¯æž¶   1 '),(2217,640143439002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','tydus1957','tydusleon@yahoo.com','Tydus Huddleston','4133 Mountain Oak Cv','Stone Mountain','GA','UNITED STATES','30083-1229','(678) 522-7266','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 01:55:55',0,NULL,3,1,1,1,NULL,NULL),(2218,601366315001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',2,'AC1201',9.8,'hermeshine','kasenter','sas33@psu.edu','S. Alex Studniarz','205 Mercer Ave','Hermitage','PA','UNITED STATES','16148','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 02:01:32',0,NULL,3,1,1,1,NULL,'å°å·é•œå¤´ç­’  2 '),(2219,601367104001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','nunocosmos','franfvc@gmail.com','FRANCISCO VIDAL CUESTA','LANZAROTE, 42 (ESQ. VALENTIN IGLESIAS) PISO 2, PTA. 43','BARCELONA','CataluÃ±a','SPAIN','08030','639137962','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 02:04:54',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR723017768CN\r'),(2220,601374033001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','fredleescot','fredleepoirier@hotmail.com','frederic poirier','la moriniere (GPS=grimordiere)','avoise','Pays de la Loire','FRANCE','72430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 02:29:58',0,NULL,3,1,2,1,NULL,NULL),(2221,640158725002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','agatha354','sekhmet_syo@hotmail.com','Carla Carcamo Vidal','Libertad 595','Coyhaique','XI','CHILE','5950102','56974891217','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 02:47:03',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶   '),(2222,640158654002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','agatha354','sekhmet_syo@hotmail.com','Carla Carcamo Vidal','Libertad 595','Coyhaique','XI','CHILE','5950102','56974891217','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 02:47:03',0,NULL,3,1,3,1,NULL,'6662a  1\rä¸­å·å†…èƒ†åŒ… nikon   1 \rRR723017895CN'),(2223,601383408001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','macmanrules','macmanfan@hotmail.com','Scott   McEwan','221 Elmwood St','Dearborn','MI','UNITED STATES','48124-1467','(248) 797-3846','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 03:03:47',0,NULL,3,1,1,1,NULL,'å°å·é•œå¤´ç­’   1 '),(2224,640167386002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','boby98','rob.worthington@bigpond.com','Robert Worthington','52 Winifred St','Condell Park','New South Wales','AUSTRALIA','2200','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 03:16:18',0,NULL,3,1,3,1,NULL,'84cm ç¯æž¶   1 \rRR723017771CN\r'),(2225,640168760002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','gazali2010','m_gazali2001@yahoo.com','Mohammed Gazali Rashad','503 W 138th St<br>Apt 2D','new york','NY','UNITED STATES','10031-7768','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 03:20:07',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…nikon   1 '),(2226,601400446001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',4,'AA1309',9.8,'hermeshine','itriedtofixit','thetech@gmail.com','Dave Ullman','7525 Aurora Ave N','seattle','WA','UNITED STATES','98103','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 04:10:43',0,NULL,5,1,18,0,NULL,NULL),(2227,640181767002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',2,'AA1303',5,'hermeshine','itriedtofixit','thetech@gmail.com','Dave Ullman','7525 Aurora Ave N','seattle','WA','UNITED STATES','98103','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 04:11:41',0,NULL,3,1,1,1,NULL,'72mm é•œå¤´ç­’ canon 2\r77mm é•œå¤´ç­’  canon 4 '),(2228,601404466001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','jenja5','jen.snyder@verizon.net','Jennifer Jacoby Snyder','46 Image DR','Scotrun','PA','UNITED STATES','18355-9656','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 04:30:32',0,NULL,3,1,1,1,NULL,''),(2229,601406157001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.9,'hermeshine','georgeting','georgetingfz@gmail.com','George Ting','1st Floor, Lot 8795 Pending Court<br>Jalan Kwong Lee Bank','Kuching','Sarawak','MALAYSIA','93450','0128861512','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 04:39:01',0,NULL,3,1,2,1,NULL,''),(2230,601413901001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','lbk46','hbseagull@verizon.net','LEON KOGAN','4297 Via Cerritos','Thousand Oaks','CA','UNITED STATES','91320-6821','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 05:23:42',0,NULL,8,1,17,1,NULL,'å‘ä¸Šåˆå¹¶ '),(2231,601413543001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','lbk46','hbseagull@verizon.net','LEON KOGAN','4297 Via Cerritos','Thousand Oaks','CA','UNITED STATES','91320-6821','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 05:23:42',0,NULL,3,1,1,1,NULL,'å°å·é•œå¤´ç­’  1\rå°å·å†…èƒ†åŒ… æ— å­—   1 '),(2232,640197153002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','flatfenders','dennyscjs@aeroinc.net','Dennis L. Goethe','11408 N Pecatonica Rd','Durand','IL','UNITED STATES','61024-9609','(815) 248-2553','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 05:27:37',0,NULL,3,1,1,1,NULL,NULL),(2233,640197480002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'',39,'hermeshine','jarrod.basl','jarrodsumpter@gmail.com','Jarrod Sumpter','3215 NE 143rd St<br># A170','Seattle','WA','UNITED STATES','98125-3753','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-01 05:27:44',0,NULL,3,1,1,1,NULL,'Jarrod Sumpter\r14021 15th Ave NE \rApt 304N \rSeattle, WA 98125\rUNITED STATES\r\r'),(2234,601424347001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','ralphie805','ralphie@gmail.com','Zach Ingram','289 Brentwood way','Goleta','CA','UNITED STATES','93117-1032','(805) 570-7313','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-01 06:25:35',0,NULL,3,1,1,1,NULL,NULL),(2235,640208726002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','gregz2008','gregor.zelle@gmail.com','Gregor Zelle','4 Jobson Avenue','Mount Ousley','New South Wales','AUSTRALIA','2519','0406780709','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 06:34:59',0,NULL,3,1,2,1,NULL,NULL),(2236,640221235002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','thargjunior','algood@iinet.net.au','A L Goodland','P O Box 117<br>North Perth','Perth','Western Australia','AUSTRALIA','6906','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 07:48:01',0,NULL,3,1,6,1,NULL,' EE520583595CN'),(2237,601445584001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','yairamoyal','yair_amoyal@walla.com','yair amoyal','eli cohen<br>41/8','ashkelon','israel','ISRAEL','78718','972 917086842715','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 08:26:31',0,NULL,3,1,3,1,NULL,'æ–°ç¯æž¶ æ½˜'),(2238,640229285002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','xdesign_george','xdesigngroup@gmail.com','George Georgiev','Mladost, bl. 156, ap. 24','Varna','Varna','BULGARIA','9000','+359889382582','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 08:27:55',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž  1 æ½˜'),(2239,696319836015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'',45.99,'hutongstore','rik67','bob.clark25@btinternet.com','Mrs Michelle Riley','Ras Al Khaimah English Speaking School P.O. Box 975','Ras Al Khaimah','United Arab Emirates','UNITED ARAB EMIRATES','','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-01 09:16:25',0,NULL,3,1,3,1,NULL,'\rRR723018009CN\r'),(2240,696320133015,250693634824,'TianYa 58mm ND8 filter New 58 Neutral Density Grey NIB',1,'',4.78,'hutongstore','markfr1','markfr1uk@yahoo.co.uk','Mark Fisher','62 St Leonards Road','Beverley','East Riding of Yorkshire','UNITED KINGDOM','HU177HJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-01 09:17:59',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯çš„58mm nd8   1 '),(2241,640241186002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jorfermo','jferrando@cc.upv.es','Jorge Ferrando Monterde','C/Chiva 20, 7Âª','Valencia','Comunidad Valenciana','SPAIN','46018','659576903','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 09:22:50',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143484CN'),(2242,639302994002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','stef0653','sp_style@live.nl','stef swinkels','vullingsstraat 11','leunen','','NETHERLANDS','5809at','0478586947','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 09:25:56',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRR723017927CN\r'),(2243,601461196001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','robinm5407','robinm5407@aol.com','Robin M OBrien','5513 Brookmere St','Edwards','IL','UNITED STATES','61528-9407','(309) 692-1733','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-01 09:36:00',0,NULL,3,1,3,1,NULL,'çº¢ç›’ç¯æž¶   1 \rRR723017913CN\r'),(2244,640251731002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mrgeo1024','jiri.lapka@seznam.cz','Jiri Lapka','Slavikova 1758','Ostrava-Poruba','Czech Republic','CZECH REPUBLIC','70800','00420603756500','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 10:01:01',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1 \rRR723017989CN\r'),(2245,640072289002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','pupss0','djkob3on@yahoo.com','octavian malai','cuza-voda 24 apt 85<br>MD-2060','chisinau','','MOLDOVA, REPUBLIC OF','md2060','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 10:14:42',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š  æ¬§æ ‡  2\r115w 220v   2\råŒ…   1 \rCP212235159CN'),(2246,640256429002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',3,'AKT014',131.7,'hermeshine','doublem6','matustikm@yahoo.com','Marek Matustik','Ctyrkoly 115','Cercany','','CZECH REPUBLIC','25722','00420724110409','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 10:22:14',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  3\räº‘å°  3\ræŸ”å…‰ä¼ž  3 \rCP212235145CN'),(2247,640222413002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',3,'AB1202',20.97,'hermeshine','lan-mas-ter','vacaciones@rambler.ru','Gennadiy Zuev','st. Kolcevay 159/1 - 57','Ufa','Bashkortostan','RUSSIAN FEDERATION','450038','917-345-2848','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 10:23:48',0,NULL,3,1,2,1,NULL,'6662a å¿«è£…æ¿  3 '),(2248,639225955002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',89.78,'hermeshine','icevace1982','icevace@mail.ru','Marsel Valiullin','Zarechnaya ulitsa<br>dom 7, kvartira 132','Moscow','Moscow','RUSSIAN FEDERATION','121087','79031599999','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 10:47:52',0,NULL,3,1,5,1,NULL,'50-70 é€šç”¨å¡å£æŸ”å…‰æ£š  2\r100-150 5in1 åå…‰æ¿   1 \rCP212235131CN\ré‡é‡ï¼Ÿ'),(2249,696359176015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','missmeggles2005','test_tube_daisies@hotmail.com','Megan Craggs','31/7 gillespie crescent','Edinburgh','Midlothian','UNITED KINGDOM','EH104HX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-01 11:18:08',0,NULL,3,1,2,1,NULL,NULL),(2250,601488619001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','washo68','kwa83620@bigpond.net.au','Peter Washington','40 Hillcrest Rd, Nerrina','Ballarat','Victoria','AUSTRALIA','3350','0353388804','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 11:23:55',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723017992CN\r'),(2251,640277286002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','aschecky','andrew@waygen.com','Andrew Scheck','14 Carrie Dr','Marlboro','NJ','UNITED STATES','07746','(732) 490-8414','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-01 11:35:24',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  1 '),(2252,640280213002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0014',18,'hermeshine','lassekamppari','lasse.kamppari@gmail.com','Lasse Kamppari','Raisiontie 11 A 1','Helsinki','','FINLAND','00280','358405231721','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 11:47:53',0,NULL,3,1,2,1,NULL,'1.6mx3m ç°è‰²èƒŒæ™¯å¸ƒ  1 '),(2253,601498140001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','catlos.ales','ales.catlos@gmail.com','Ales Catlos','Iljusinova 4','Bratislava','SC','SLOVAK REPUBLIC','85101','+421903555899','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 11:54:20',0,NULL,3,1,2,1,NULL,'éº‚çš®  2 '),(2254,601512965001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','drtsos124','drtsos@gmail.com','Dimitris Karabetsos','32, Xiromerou Str<br>Ampelokipoi','Athens','Ampelokipoi, Athens','GREECE','11526','00306934505633','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 12:45:23',0,NULL,3,1,3,1,NULL,'60cm æ£š   1 \rRR723014245CN\r'),(2255,696406774015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','tobysdruso','tobysdruso@yahoo.it','Tomas Sheridan','7/1 Montpelier Park','Edinburgh','lothian','UNITED KINGDOM','eh104lu','07708795648','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-01 13:34:28',0,NULL,3,1,2,1,NULL,NULL),(2256,640317977002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'',39,'hermeshine','cheaphuntgear','ytail@roadrunner.com','Blaine Anthony','123 Unity Rd','Benton','ME','UNITED STATES','04901','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-01 13:46:14',0,NULL,3,1,1,1,NULL,'800w 110v   5 '),(2257,640319795002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','bmwracer41','ross@atlasaerospace.com','ross bleustein','7820 NW 56th St','Doral','FL','UNITED STATES','33166-3524','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 13:52:21',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡  1 '),(2258,640318150002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','mustafakarli','mkarli1@yahoo.com','Mustafa KARLI','BIL LOJMANLARI A. BLOK D.4<br>GOLOVASI MEVKII CEYHAN','ADANA','','TURKEY','01985','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 13:55:22',0,NULL,3,1,2,1,NULL,'531t çš„å¿«è£…æ¿ï¼Œ ä¸‹åˆåˆ° '),(2259,601537636001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','joao2k1','info@portugalgay.pt','joao paulo','Rua St. Ant. Contumil, 152-6Dto','Porto','','PORTUGAL','4350-285','919030229','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 14:07:53',0,NULL,3,1,2,1,NULL,' '),(2260,640328881002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','matteosaderis80','matteosaderis@gmail.com','Matteo Saderis','Via Toscana 15','Segrate','MI','ITALY','20090','3402300727','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 14:18:05',0,NULL,3,1,3,1,NULL,'canon æ‘„å½±èƒŒå¿ƒ  L   1\rè€æ¬¾ \rRR723014316CN'),(2261,640338738002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','fornan100','johan.fornstedt@gmail.com','Johan Fornstedt','Kuppbolsvagen 70A','GAVLE','GAVLE','SWEDEN','80430','+46736494260','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 14:44:16',0,NULL,3,1,3,1,NULL,'RR723014280CN\r '),(2262,601575653001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.3,'hermeshine','twiggy_mtl','patrice33@videotron.ca','Patrice Cuerrier','1, Alexandre-Graham-Bell<br>Wing E4','Verdun','QC','CANADA','H3E3B3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 15:48:18',0,NULL,8,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2263,640361856002,120454219152,'Green.L 52mm Neutral Density ND4 Filter ND 4 52',1,'AE2301',5.8,'hermeshine','twiggy_mtl','patrice33@videotron.ca','Patrice Cuerrier','1, Alexandre-Graham-Bell<br>Wing E4','Verdun','QC','CANADA','H3E3B3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 15:48:19',0,NULL,8,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2264,640362036002,120454225464,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',1,'AE2308',5.8,'hermeshine','twiggy_mtl','patrice33@videotron.ca','Patrice Cuerrier','1, Alexandre-Graham-Bell<br>Wing E4','Verdun','QC','CANADA','H3E3B3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 15:48:19',0,NULL,3,1,2,1,NULL,NULL),(2265,601594378001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',3.79,'hermeshine','mbagah1','kamenyi1@yahoo.com','Robert Kamenyi','714 N Washington Ave','Warrensburg','MO','UNITED STATES','64093-1153','(816) 679-1970','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 16:32:45',0,NULL,3,1,1,1,NULL,NULL),(2267,640408623002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','ilovelamp15','jonnylong15@gmail.com','Jonathan Long','3604 NE 80th St','Vancouver','WA','UNITED STATES','98665-1147','(503) 522-1961','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 17:29:34',0,NULL,3,1,1,1,NULL,NULL),(2268,601659232001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','bandaler0','alexanderkhan@rogers.com','Alexander T Khan','175 Goldenwood Crescent','Markham','ON','CANADA','L6E 1L8','(905) 554-3344','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 18:46:27',0,NULL,3,1,2,1,NULL,NULL),(2269,640464552002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','myabellasdesigns','myabellas@gmail.com','Mayra Rigual','739 Kenilworth Cir','Lake Mary','FL','UNITED STATES','32746-5556','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 19:15:09',0,NULL,3,1,1,1,NULL,'æ–°åœ°å€ï¼š\rMayra Rigual\r739 Kenilwoth cir. \rApt 205 Lake Mary \rFlorida 32746\rUNITED STATES'),(2270,640475547002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','123penniek','penniek@bresnan.net','Pennie Kittilson','2665 Valley Dr','East Helena','MT','UNITED STATES','59635-3132','(406) 227-7949','NoPaymentFailure','CheckoutComplete','Other','2010-12-01 19:29:55',0,NULL,3,1,1,1,NULL,'canon èƒŒå¿ƒ è€æ¬¾  L   1 '),(2271,683112967016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','linnelinn55','soa.svensson@hotmail.com','Sven Svensson','StÃ¶rÃ¥sen 139','FÃ¶llinge','','SWEDEN','83060','0645-61024','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-01 19:45:45',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\r50-70 æ£š  æ¬§æ ‡   2\r115w 220v   2\råŒ…    1 \rlighting kit  $32\rYW864143532CN'),(2272,601713712001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',3,'AC2401',65.82,'hermeshine','froggy2i','ebay@photoalex.ca','Alex Leblanc','C.C. Franco-Ouest<br>411 Seyton dr','Nepean','ON','CANADA','K2H 8X1','(613) 820-2920 ext.: 1306','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 20:15:10',0,NULL,3,1,3,1,NULL,'40cm æ£š   3 \rRR723017975CN\r'),(2273,640513368002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','1515kate','caitlin_sara_hogan@yahoo.com','Kate Hogan','2312 3rd Avenue<br>Apt 313','Seattle','WA','UNITED STATES','98121','(214) 632-4882','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 20:29:52',0,NULL,3,1,1,1,NULL,NULL),(2274,696720881015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','ukgadgetguy','graysteve@btinternet.com','Stephen Gray','32 Meadowgate Eston','Middlesbrough','Cleveland','UNITED KINGDOM','TS6 9JB','01642456019','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-01 22:12:42',0,NULL,3,1,2,1,NULL,NULL),(2275,640572079002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','rogercaldeira','rogeriocaldeira@gmail.com','Rogerio Caldeira','Rua Curruiras, 400','Florianopolis','Santa Catarina','BRAZIL','88063091','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 22:23:41',0,NULL,3,1,2,1,NULL,NULL),(2276,640589122002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','mafldemamafldema','fabridale@gmail.com','fabricio dalessandro','cachimayo 1324','buenos aires','capital federal','ARGENTINA','1424','49328403','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 23:07:52',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2277,601812223001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','lestebr','ivanleste@metacomsoft.com.br','Ivan Leste Ribeiro','Rua Sagitario, 81 - Apt. 501','Belo Horizonte','MG','BRAZIL','30360-230','55 31 3293-8926','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 00:03:56',0,NULL,3,1,2,1,NULL,NULL),(2278,601815694001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','jfreyesjr','rjj2jljr2@yahoo.com','JOSE REYES','10527 W Chautauga MTN','LITTLETON','CO','UNITED STATES','80127-3858','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 00:12:32',0,NULL,3,1,1,1,NULL,NULL),(2280,640632991002,120566694530,'Neoprene Protector Camera Cover  for Nikon Size: Large ',1,'AC1303',9.25,'hermeshine','teenyharris','teeny.harris@gmail.com','Teeny Harris','6211 Wrightsville Ave<br>Apt 157','Wilmington','NC','UNITED STATES','28403-3853','(704) 572-1042','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 01:36:07',0,NULL,3,1,1,1,NULL,'å¤§å·å†…èƒ†åŒ… nikon   1 '),(2281,696800455015,250692240760,'Wireless Remote Control Cord for Canon 500D/550D/450D',1,'',11.47,'hutongstore','completecqc','jason.litchfield@gmail.com','lauren pieri','42 ambrose rise wheatley','oxford','Oxfordshire','UNITED KINGDOM','ox33 1ye','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-02 01:42:40',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿  C1   1 '),(2282,640645620002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lieslkarbo','lkardatzke@comcast.net','Liesl Bohan','5580 MacDonald St','Lansing','MI','UNITED STATES','48911-7218','(517) 699-0884','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 02:20:53',0,NULL,3,1,1,1,NULL,NULL),(2283,640654471002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','mello021','rafael.calero@hotmail.com','Rafael Calero','Rua GirÃ£o Barroso 100<br>Bloco 3B apartamento 202 Alcantara','SÃ£o GonÃ§alo','Rio de Janeiro','BRAZIL','24711-160','55 21 87050724','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 02:51:32',0,NULL,3,1,2,1,NULL,NULL),(2284,601866226001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','tadichter','dichtert@charter.net','Terry Dichter','3525 Eddingham Ave','Calabasas','CA','UNITED STATES','91302-5828','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 03:24:44',0,NULL,3,1,1,1,NULL,NULL),(2285,601868264001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','discountjunkseller','discountjunk@yahoo.com','James McDonald','PO Box 1962','Rockingham','NC','UNITED STATES','28380-1962','(910) 273-8819','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-02 03:32:06',0,NULL,3,1,1,1,NULL,NULL),(2286,601868667001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','jackymf6','lhmarketing178@hotmail.com','Vu Kah Tshun@Jacky Leong','LH Marketing/Jacky\'s Fitness Club, Block D7, Lot 20,<br>Yee Shing Commercial Centre, Jalan Masak','Keningau','Sabah','MALAYSIA','89008','0168307935','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 03:44:39',0,NULL,3,1,2,1,NULL,NULL),(2287,696850500015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'',3.76,'hutongstore','peterrabbit1980','pompeysrabbit@yahoo.co.uk','Peter Lambeth','Flat 44, Copperfield House Wingfield Street','Portsmouth','Hampshire','UNITED KINGDOM','PO1 4NY','07784361945','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-02 04:26:04',0,NULL,3,1,2,1,NULL,NULL),(2288,640693499002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','rod5434','redge48034@aol.com','rodney edge','OPM-SANG NGS<br>Unit 61304','APO','AE','AA','09803-1304','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 05:42:48',0,NULL,3,1,1,1,NULL,' '),(2289,696885735015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','coussell','tom@botservice.net','Tom Coussell','20 Gainsborough Road','Bournemouth','Dorset','UNITED KINGDOM','BH7 7BD','01202394688','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-02 07:06:25',0,NULL,3,1,2,1,NULL,NULL),(2290,601921743001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2106',32,'hermeshine','777soln','mgg@777solution.net','M. Gastrock','2427 Nina St<br>Apt 2','West Covina','CA','UNITED STATES','91792','(626) 667-7346','NoPaymentFailure','CheckoutComplete','Other','2010-12-02 08:46:33',0,NULL,3,1,1,1,NULL,'è“è‰²èƒŒå¿ƒ æ— å­—  xxxl  1 '),(2291,696921410015,250599931689,'New TianYa Star 6 points filters for Cokin P Series',1,'',7.8,'hutongstore','tangosierraone','tn.watson@btinternet.com','Thomas Watson','\'Camusfearna\' 19 Sycamore Gardens','BLACKWOOD','Lanarkshire,Scotland','UNITED KINGDOM','ML11 9SX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-02 09:29:13',0,NULL,3,1,2,1,NULL,'star6 æ˜Ÿå…‰é•œ   1 '),(2292,640745119002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','timchen8653','timchen415@hotmail.com','Xie Tian Chen','5532 Geary Blvd<br>Apt B','San Francisco','CA','UNITED STATES','94121-2209','(415) 832-0521','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 10:08:59',0,NULL,3,1,1,1,NULL,NULL),(2293,600998261001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',153.68,'hermeshine','scar074','energosb@yandex.ru','Alexander Tihonov/Ð¢Ð¸Ñ…Ð¾Ð½Ð¾Ð²','Salutnay 10 - 22<br>Ð¡Ð°Ð»ÑŽÑ‚Ð½Ð°Ñ 10 - 22','Chelybinsk/Ð§ÐµÐ»ÑÐ±Ð¸Ð½ÑÐº','Ð§ÐµÐ»ÑÐ±Ð¸Ð½ÑÐºÐ°Ñ Ð¾Ð±Ð»Ð°ÑÑ‚ÑŒ','RUSSIAN FEDERATION','454071','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 10:12:10',0,NULL,3,1,5,1,NULL,' 2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡  2\råŒ…   1\r60cm æ£š  1\rä¸­å·å†…èƒ†åŒ…  æ— å­—   1\rCP212235114CN\r\rå€’å½±æ¿   1\r'),(2295,640753641002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','kbro7815','broumand@hotmail.com','Kamyar Broumand','Schavei 69','Overijse','','BELGIUM','3090','+3226876031','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 10:42:53',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  4 \rRR723014599CN'),(2296,601973048001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','iunux','desmondyee@iunuxstudio.com','Desmond Yee','Blk. 897A, Tampines St.81, #09-714','default','','SINGAPORE','521897','96465453','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 11:58:08',0,NULL,3,1,3,1,NULL,'717å¿«è£…æ¿  1 \rRR723014585CN'),(2297,601978738001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','szaborobert3','szaborobert8@gmail.com','Robert Szabo','PattantyÃºs Ã. u. 1. 1/4.','Miskolc','','HUNGARY','3529','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 12:17:12',0,NULL,3,1,2,1,NULL,NULL),(2298,602002958001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.3,'hermeshine','zellyzell','dzelikovitz@hotmail.com','David Zelikovitz','94 regal road','Toronto','ON','CANADA','M6h2k2','(416) 347-8688','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 13:37:04',0,NULL,3,1,2,1,NULL,NULL),(2299,602022687001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','chris_here','chrkuhn@gmail.com','Kuhn Christoph','Im Lee 15','Winterthur','','SWITZERLAND','8400','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 14:32:38',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚  1 \rYW864143521CN\r\rlight stand  $15'),(2300,602042275001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','rnd.ru','rnd@getek.ru','Ruslan Dvornikov','Solov\'inyj proezd, d.14, kv. 442','Moscow','Moscow','RUSSIAN FEDERATION','117593','+7 906 7140185','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 15:38:09',0,NULL,3,1,3,1,NULL,'çº¢ç›’ç¯æž¶  1 \rRR723014381CN'),(2301,602050555001,110583278393,'TianYa 58mm ND8 filter New 58 Neutral Density Grey NIB',1,'AA2303',6.7,'hermeshine','jorgeamoros','jorgeamorosd@gmail.com','Jorge AmorÃ³s PayÃ¡','Rio Segura 52','Torrellano - Elche','Comunidad Valenciana','SPAIN','03320','660660077','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 15:50:04',0,NULL,8,1,17,0,NULL,NULL),(2302,602048171001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3303',6.8,'hermeshine','jorgeamoros','jorgeamorosd@gmail.com','Jorge AmorÃ³s PayÃ¡','Rio Segura 52','Torrellano - Elche','Comunidad Valenciana','SPAIN','03320','660660077','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 15:51:30',0,NULL,8,1,17,0,NULL,NULL),(2303,602047696001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','jorgeamoros','jorgeamorosd@gmail.com','Jorge AmorÃ³s PayÃ¡','Rio Segura 52','Torrellano - Elche','Comunidad Valenciana','SPAIN','03320','660660077','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 15:51:30',0,NULL,3,1,4,1,NULL,'6662a   1\rå¤©æ¶¯ 58mm nd8  1\r58mm uv    2 \rYW864143554CN\r\rtripod   $15'),(2304,602053950001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','fipinha22','filipa.a.f.agostinho@gmail.com','Filipa Agostinho','PraÃ§a Gil Vicente nÂº 3 4ÂºEsq','Lisbon','Prior Velho','PORTUGAL','2685-404','00351913508319','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 16:01:15',0,NULL,3,1,2,1,NULL,NULL),(2305,640856242002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','slemmigahelge','slemhelge@gmail.com','Kenny Berglund','Karlfeldtsgatan 36 A','VÃ¤sterÃ¥s','VÃ¤stmanland','SWEDEN','72222','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 16:13:05',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143565CN\r'),(2306,640867735002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','*yoyo*69','cd.denis@gmail.com','Denis Cemazar','Breg ob Savi 22a','Mavcice','Kranj','SLOVENIA','4211','+38642332975','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 16:34:13',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(2307,602068751001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 16:41:29',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723014364CN'),(2308,640880868002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','ladysalsa514','marysetanguay@hotmail.fr','Maryse Tanguay','5230, 7e Avenue','Montreal','QC','CANADA','H1Y 2N3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 17:03:56',0,NULL,3,1,2,1,NULL,NULL),(2309,640539063002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','67jonasttt','tom.jira@o2active.cz','Tomas Jira','Machateho 682/8','Praha5','vÃ½chozÃ­','CZECH REPUBLIC','15200','00420725586863','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 17:19:32',0,NULL,8,1,17,0,NULL,NULL),(2310,602093745001,110583278219,'TianYa 62mm CPL filter New 62 Circular Polarizing C-PL',1,'AA2304',6.5,'hermeshine','67jonasttt','tom.jira@o2active.cz','Tomas Jira','Machateho 682/8','Praha5','vÃ½chozÃ­','CZECH REPUBLIC','15200','00420725586863','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 17:32:52',0,NULL,3,1,5,1,NULL,'å¤©æ¶¯ 62mm CPL   1 \r6662a   1\rCP212235105CN\r'),(2311,640901173002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','gerson0909','fotomota@hotmail.com','GERSON MOTA','RUA ALFREDO ROBERTO VELTEN<br>13/101 BAIRRO: JARDIM MAYLI','PIÃšMA','ESPIRITO SANTO','BRAZIL','29.285-000','28-3520-1041','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 17:49:36',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹   2 '),(2312,697133004015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','angelmiguel.a','dispar@dispar.es','Angel Miguel Albertos GÃ³mez','C/ PÃ­o Baroja nÂº 1, Bloque 1, 3Âº C','Boadilla del Monte','Madrid','SPAIN','28660','625098732','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-02 18:00:35',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å›› ç¯å¤´   1 '),(2313,640924077002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','lamzak','lamgagnon@yahoo.com','Lambert Gagnon','3033 Ziron Ave','Simi Valley','CA','UNITED STATES','93065-0507','(805) 452-9683','NoPaymentFailure','CheckoutComplete','Other','2010-12-02 18:34:13',0,NULL,3,1,1,1,NULL,'canonèƒŒå¿ƒ  L   1 æ—§æ¬¾ '),(2314,600881692001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',22.2,'hermeshine','3824alain','brod_alain@hotmail.com','Alain Brodeur','11762 26e avenue','St-Georges','QC','CANADA','G6A 1E8','(418) 221-7093','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 18:36:33',0,NULL,3,1,3,1,NULL,'77mm é•œå¤´ç›–  canon  9 \rRR723014404CN'),(2315,601588165001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',94.9,'hermeshine','shark_raph','shark.raph@gmail.com','Maksim Sarychau','Peterdy utca 5, 1/11','Budapest','Budapest','HUNGARY','1071','36207761177','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 18:45:52',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ ç»¿ çº¢ï¼‰   1 \rCP212150630CN\r'),(2316,696938695015,250643703886,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'',7.99,'hutongstore','1947gp','georgepender@btinternet.com','GEORGE PENDER','2 KILN FIELD STAXTON','SCARBOROUGH','NORTH YORKSHIRE','UNITED KINGDOM','YO12 4RX','01944710510','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-02 19:09:09',0,NULL,3,1,2,1,NULL,'1.6x2.1 ç»¿è‰²èƒŒæ™¯å¸ƒ   1 '),(2318,683665537016,260619309261,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'',24.99,'hutongstore','ibisabelle','isa.vgl@gmail.com','bertrand maquin','5 rue trieu maquette','sirault','','BELGIUM','7332','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-02 19:12:14',0,NULL,3,1,3,1,NULL,'115w 220v   2 \rRR723014395CN'),(2319,683692370016,260660056106,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',2.4,'hutongstore','lkh4717','lkh@stoneloose.dk','Lars Hansen','RÃ¸dkÃ¦lkevej 14','StenlÃ¸se','','DENMARK','DK-3660','004529808500','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-02 19:50:42',0,NULL,3,1,2,1,NULL,NULL),(2320,640965012002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','photos6288','ttocsm@gmail.com','Matt Scott','14 Cantonments Rd<br>Lyttelton Manor','Centurion','Gauteng','SOUTH AFRICA','0157','0732128584','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 19:59:04',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\r50-70 æ£š  2\r115w 220v   2\råŒ…   1 \rLighting kit  $58\rYW864143576CN\r'),(2321,640977031002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','imalooser','brucek@outhouseinc.com','Cassie Keesee','4711 Regency Dr','Durham','NC','UNITED STATES','27713','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 20:06:08',0,NULL,3,1,1,1,NULL,NULL),(2322,683734997016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','7544bmw','alanmc@hotmail.fr','ALAN  BRYANT','101 RUE DU FOUR A CHAUX','LA CERLANGUE','HAUTE NORMANDIE','FRANCE','76430','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-02 20:51:18',0,NULL,3,1,2,1,NULL,NULL),(2323,602211661001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','tayfun78','t_yildiz@msn.com','Tayfun Yildiz','Ortabayir Mahallesi Sarigol Caddesi<br>No.9 D.7','Istanbul','Kagithane','TURKEY','34413','+90 543 957 26 51','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 21:10:22',0,NULL,3,1,2,1,NULL,' '),(2324,602214345001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','jckaphotography','jaybass5@gmail.com','Jon Adjjahoe','6210 Belcrest Rd<br>Apt 1032','Hyattsville','MD','UNITED STATES','20782-2972','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 21:17:08',0,NULL,3,1,1,1,NULL,NULL),(2325,641029814002,120565901367,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','lutreolus','lutreolus@yahoo.com.au','ben griggs','6/1-3 McGrath Court<br>Richmond','Melbourne','Victoria','AUSTRALIA','3121','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 21:46:54',0,NULL,3,1,6,1,NULL,'717  135    1 \ræ–°åŠ å¡EMS\rEX000065338SG\r'),(2326,683772580016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'',7.52,'hutongstore','tullesfar','jens.nielsen45@gmail.com','Jens Peter Nielsen','Emdrupvej 137 st. th.','2400 KÃ¸benhavn NV','Denmark','DENMARK','0045','(0045) 50805538','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-02 21:50:05',0,NULL,3,1,2,1,NULL,'lenspen  2 '),(2327,602233870001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','bacoretajoseluis','jlyep@hotmail.com','JOSÃ‰ LUIS YEPES ALARCÃ“N','C/ OESTE, 4 URB. LOS VIENTOS','MOLINA DE SEGURA','Murcia','SPAIN','30500','968641656','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 22:09:27',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723014452CN'),(2328,641053840002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','pedro.soria','pedrojsoria@gmail.com','Pedro Soria','c/ Goleta 8','Velilla de San Antonio','Madrid','SPAIN','E-28891','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 22:36:11',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR723014378CN'),(2329,641060764002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','playtaf','playvision@ono.com','CRISTOBAL BELLES VIDAL','c/ SAN FEDERICO NÂº1 2Âºd','ALMASSORA','Comunidad Valenciana','SPAIN','12550','964563106','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 22:55:07',0,NULL,3,1,2,1,NULL,'6662a å¿«è£…æ¿   2 '),(2330,641082388002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','tusik123456','tusik12345@walla.com','Yishay Lamzin','P.O.BOX 44220<br>pisgat zehev','jerusalem','','ISRAEL','91441','972-52-3288889','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 00:04:48',0,NULL,3,1,2,1,NULL,NULL),(2331,641111220002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','stastlv','stas.peters@gmail.com','Stanislav Peters','Yesod Hamala<br>10/6','Tel Aviv','n/a','ISRAEL','66055','0544534881','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 01:54:07',0,NULL,3,1,3,1,NULL,'4ç¯å¤´æ£š  æ¬§æ ‡   2\råˆ†ä¸¤ç¥¨å‘\rRR723014262CN\rRR723014347CN'),(2332,602307293001,110566021597,'New YN Flash Battery Pack SF-17 Canon Flash 580EX CP-E4',1,'AB3313',41.99,'hermeshine','mcap1972','mario@avangardphoto.com','Mariusz Caputa','17 Gracefield Crt','Maple','ON','CANADA','L6A 1G5','(905) 417-9535','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 02:04:54',0,NULL,3,1,3,1,NULL,'sf17 canon   1 \rRR723010610CN'),(2333,602169326001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','thebiestsc','the_biest_sc@hotmail.com','Logan Biesterfeldt','2221, 19th ave south','Lethbridge','AB','CANADA','t1k1e7','(403) 795-3929','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 02:26:56',0,NULL,3,1,2,1,NULL,NULL),(2334,683912936016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','aquila_alba','stil@stilphoto.com','Martin Marcinkiewicz','73 Bryn Parc Morriston','Swansea','Swansea','UNITED KINGDOM','SA6 8ND','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-03 04:35:23',0,NULL,3,1,2,1,NULL,NULL),(2335,602364594001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','igorbb2010','biven-2001@mail.ru','Igor Baranov','Shirotnaya dom157 kv 109','Tyumen','','RUSSIAN FEDERATION','625028','+79044900222','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 06:35:40',0,NULL,3,1,5,1,NULL,' CP212150294CN\r'),(2336,602365607001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','coreylunsford','coreylunsfordphotography@yahoo.com','corey lunsford','10 Alta vista','Sylacauga','AL','UNITED STATES','35150','','NoPaymentFailure','CheckoutComplete','Other','2010-12-03 06:40:19',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143580CN\r'),(2337,601427340001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',54.05,'hermeshine','studio94ua','studio94spd@gmail.com','Punov-Drozdovsky Stanislav','Pavlenko 16/31, ap 21','Simferopol','Crimea','UKRAINE','95006','+380505680222','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 07:56:40',0,NULL,3,1,3,1,NULL,'æ¸å˜ç°  1\rND4  1\r72mm çŽ¯æž¶  1\rä¸€è½¬å››ç¯å¤´   1\rçƒ­é´ç›–   1\r40cm æ£š  1\rRR723014333CN\r\r '),(2338,602384024001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','speckledfrog','specklesphotography@hotmail.com','Rebecca Thompson','97 Burke Rd','Ferntree Gully','Victoria','AUSTRALIA','3156','0397586989','NoPaymentFailure','CheckoutComplete','AU_Other','2010-12-03 08:26:53',0,NULL,3,1,6,1,NULL,' èƒŒæ™¯æž¶( ç™½ é»‘ ç»¿)   1\rEX000046078SG\r'),(2339,683964215016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','mevijaynair','mailmevj@ymail.com','Vijay Nair','H.No.4, 54 RGL Bungalows, phase 1, Mugalivakam Porur.PO','Chennai','TN','INDIA','600116','00919952079708','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-03 08:37:10',0,NULL,3,1,2,1,NULL,NULL),(2340,602400958001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','hhp4595','penghh@yahoo.com','Honghong Peng','3845 Evangelho Cir','San Jose','CA','UNITED STATES','95148-4374','(585) 214-9157','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 09:43:40',0,NULL,8,1,17,0,NULL,NULL),(2341,602399966001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','hhp4595','penghh@yahoo.com','Honghong Peng','3845 Evangelho Cir','San Jose','CA','UNITED STATES','95148-4374','(585) 214-9157','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 09:43:41',0,NULL,8,1,17,0,NULL,NULL),(2342,641210464002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','hhp4595','penghh@yahoo.com','Honghong Peng','3845 Evangelho Cir','San Jose','CA','UNITED STATES','95148-4374','(585) 214-9157','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 09:43:42',0,NULL,8,1,17,0,NULL,NULL),(2343,641211517002,120564178566,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.77,'hermeshine','hhp4595','penghh@yahoo.com','Honghong Peng','3845 Evangelho Cir','San Jose','CA','UNITED STATES','95148-4374','(585) 214-9157','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 09:43:42',0,NULL,3,1,1,1,NULL,'Lenspen   1\r58mm é•œå¤´ç­’  canon  1\r58mm uv   1\r58mm æ©¡èƒ¶ç½©    1 '),(2344,692692656015,250620017234,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'',2.39,'hutongstore','ergheiz','carlos_dlux@hotmail.com','JosÃ© Piteira','Rua de Entrecampos NÂº 28 7Âº andar  Bloco C  Sala  7.10','Lisboa','Lisboa','PORTUGAL','1749-076','00351962639038','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-03 11:17:26',0,NULL,3,1,2,1,NULL,'49mm æŽ¥å£çŽ¯   1 '),(2346,602430655001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','bheka134','barrykusuma@gmail.com','To : Barry Kusuma','Pondok Kelapa Indah<br>Jl kelapa kuning Raya blok C1 no 7, Jakarta Timur.','DKI','Jakarta','INDONESIA','13450','62811928357622193672032','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 11:30:52',0,NULL,3,1,2,1,NULL,'Barry Kusuma\rPondok Kelapa Indah\rJl kelapa kuning Raya blok C1 no 7, Jakarta Timur.\rDKI Jakarta 13450\rIndonesia\r+62811928357 /+622193672032\rå°å·å†…èƒ†åŒ…  Nikon  1 \r'),(2347,641267421002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',87.8,'hermeshine','syl20n','syl20n@yahoo.fr','sylvain negro','15 rue gerbier','paris','ÃŽle-de-France','FRANCE','75011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 12:58:04',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\räº‘å°  2\ræŸ”å…‰ä¼ž   2 \rlight kit  $22\rYW864143672CN\r'),(2348,641274659002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','paorefon45','paorefon@yahoo.com.br','Fonseca Andre','Rua Domiciano Santana, 1239, Centro','Avare','Sao Paulo','BRAZIL','18700-080','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 13:28:29',0,NULL,3,1,3,1,NULL,'84cm ç¯æž¶  1 RR723014735CN'),(2349,684079032016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','berni9361','berni.gore7@fsmail.net','Bernadette McArthur','7 Gore Avenue','Salford','Greater Manchester','UNITED KINGDOM','M5 5LF','01617361324','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-03 14:04:08',0,NULL,8,1,17,0,NULL,NULL),(2350,684078728016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'',3.5,'hutongstore','berni9361','berni.gore7@fsmail.net','Bernadette McArthur','7 Gore Avenue','Salford','Greater Manchester','UNITED KINGDOM','M5 5LF','01617361324','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-03 14:04:09',0,NULL,3,1,2,1,NULL,'lenspen   1\ræ°”å¹+å¸ƒ   1 '),(2351,641294284002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','sunrayplaytime','rcrobson@cytanet.com.cy','Richard Campbell-Robson','PO Box 61185','Paphos','','CYPRUS','8131','26960665','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 14:15:56',0,NULL,3,1,2,1,NULL,' '),(2352,684092906016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','damianhose','damian@thefotografer.net','Damian Mizzi','The Foto Grafer. St.Thomas Street,','Fgura.','','MALTA','FGR 1605','+356 99253690','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-03 14:35:27',0,NULL,3,1,2,1,NULL,NULL),(2353,602488868001,110534332881,'CTR-301P Wireless Flash Trigger 2 Receiver SB800 580EX',1,'AKT001',41.9,'hermeshine','spfldcustomer33','bilyrocker33@gmail.com','Billy Jenkins','7880 N Prairie View Rd','Strafford','MO','UNITED STATES','65757-8879','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-03 14:40:43',0,NULL,3,1,1,1,NULL,'301p ä¸€æ‹–äºŒ  1 '),(2354,684096431016,260660056537,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'',2.4,'hutongstore','cankanbol','banner@firma.home.pl','Bartosz Wscisel','13 Glazebrook Close Dulwich','London','London','UNITED KINGDOM','SE218RP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-03 14:42:53',0,NULL,3,1,2,1,NULL,NULL),(2355,602495076001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','cgrytten','cgrytten@online.no','Cato Grytten','Motlandsmarka 118','NÃ¦rbÃ¸','','NORWAY','4365','(+47)40249502','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 15:01:17',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ nikon xxxl   1\rè€æ¬¾ RR723014727CN'),(2356,641321977002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2401',24.95,'hermeshine','sforzinda','galip.kurkcu@gmail.com','galip kurkcu','75. sokak (eski 15. sokak) no: 1/2<br>Bahcelievler','Ankara','Ankara','TURKEY','06500','903122210182','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 15:39:02',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£æ£š   1 RR723014744CN'),(2357,641340955002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','kostis123','karakiolis@gmail.com','Kostis Karakiolis','Mitropolitou Amvrosiou 17A','Larissa','GREECE','GREECE','41221','+306936479140','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 16:16:07',0,NULL,3,1,2,1,NULL,'ä½³èƒ½ä¸‰è§’åŒ…  1 '),(2358,697664235015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','rider76','goran76@abv.bg','Goran Manolov','jk.2A bl.76 vh.G et.2 ap.4','Kozlodui','Kozlodui   Vraca   Kozlodui','BULGARIA','3320','00359885555877','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-03 16:36:25',0,NULL,3,1,2,1,NULL,''),(2359,641351266002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','alexandrnikitin','alexandrnikitin11@yandex.ru','ALEKSANDR NIKITIN','Grazhdanskiy pr. Dom-36 Kv-289','Sankt-Peterburg','','RUSSIAN FEDERATION','195220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 16:38:53',0,NULL,3,1,2,1,NULL,'ä½³èƒ½ä¸‰è§’åŒ…  1   '),(2360,640234084002,120654560408,'for waelilas',1,'',135,'hermeshine','waelilas','cubafm2@yahoo.com','wael fouad','dubai media city<br>CNN building first floor 103 arabian radio network','dubai','','UNITED ARAB EMIRATES','502012','+971507969122','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 17:01:53',0,NULL,8,1,17,0,NULL,NULL),(2361,602547982001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','waelilas','cubafm2@yahoo.com','wael fouad','dubai media city<br>CNN building first floor 103 arabian radio network','dubai','','UNITED ARAB EMIRATES','502012','+971507969122','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 17:05:40',0,NULL,3,1,8,1,NULL,' 6662a   1\rWT600   1\rlenspen   1\r110cm 5in1 åå…‰æ¿   1\rä¸èƒ½åˆåœ¨ä¸€èµ·ï¼Œå°±æŠŠåå…‰æ¿å‘å›½å†…å°åŒ…æŒ‚å·\rCP212330971CN\rRR723010654CN\r'),(2362,602552376001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','10marvinc','mcascante.63@gmail.com','MARVIN CASCANTE','2976 SW 23rd St','MIAMI','FL','UNITED STATES','33145-3312','506 244 5717 1','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-03 17:15:33',0,NULL,3,1,1,1,NULL,NULL),(2363,641375443002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','shelmilkitmu','giro_cyborg@yahoo.com','mohd nazirul asyraf','nakaku nunohashi 2-4<br>karejjitaun wingu 402','hamamatsu','Shizuoka','JAPAN','4328012','(080)-3662-2242','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 17:30:42',0,NULL,3,1,6,1,NULL,'æ–°åŠ å¡EMS\r\r717AH  1 \rEX000290784SG\r'),(2364,602346524001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','blue-frog-boutique','volkswagenmom@yahoo.com','Tarrah Kjolby','816 Peace Portal Drive','Blaine','WA','UNITED STATES','98230','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 17:41:47',0,NULL,3,1,1,1,NULL,NULL),(2365,697734914015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'',6.95,'hutongstore','susanns1','susanns1@yahoo.co.uk','Susann Schmidt','Interactive Data - BDG 13-17 Epworth Street','London','London','UNITED KINGDOM','EC2A 4DL','07786135252','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-03 18:34:16',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2366,602604522001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','obaidah13','alzayeas@aramco.com','Abdullah Salman Al Zayer','14729 182nd St<br>DHA 7539','Springfield Gardens','NY','UNITED STATES','11413-4028','718 553 8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 19:01:54',0,NULL,8,1,17,0,NULL,NULL),(2367,602599589001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','obaidah13','alzayeas@aramco.com','Abdullah Salman Al Zayer','14729 182nd St<br>DHA 7539','Springfield Gardens','NY','UNITED STATES','11413-4028','718 553 8740','NoPaymentFailure','CheckoutComplete','Other','2010-12-03 19:01:55',0,NULL,3,1,4,1,NULL,'tripod  $15 \rç‡•æ–‡ ä¸€ç¥¨äºŒä»¶\r\rYW864143786CN\r'),(2368,602603718001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2106',32,'hermeshine','obaidah13','alzayeas@aramco.com','Abdullah Salman Al Zayer','14729 182nd St<br>DHA 7539','Springfield Gardens','NY','UNITED STATES','11413-4028','718 553 8740','NoPaymentFailure','CheckoutComplete','Other','2010-12-03 19:01:55',0,NULL,3,1,4,1,NULL,'æ‘„å½±èƒŒå¿ƒè–„æ¬¾é»‘è‰² canon XL 1\r80CM 5in1 åå…‰æ¿   1\rYW864143716CN\r\rç‡•æ–‡ ä¸€ç¥¨äºŒä»¶\r '),(2369,697757225015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'',24.95,'hutongstore','weshtie','jennrussell@ireland.com','Jennifer Russell Fulgosi','Ehrlichovea 9/5 Sopot','Zagreb','','CROATIA','10,020','0996801907','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-03 19:11:48',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR723014758CN'),(2370,641441068002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','jcarrio','julio.carrio@gmail.com','Julio Carrio','Av.Oswaldo Cruz, 90/711<br>Flamengo','Rio de Janeiro','RJ','BRAZIL','22250060','+55+21-25532270','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 19:38:03',0,NULL,3,1,3,1,NULL,'3m æ¨ªæ†   1 RR723014660CN'),(2371,601962938001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'',13.99,'hermeshine','petrs4321','svoboda@lmail.cz','Petr Svoboda','Budovcova 1149, -','Podebrady','-','CZECH REPUBLIC','29001','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 20:46:11',0,NULL,3,1,2,1,NULL,'nikon 90th é•œå¤´ç­’   1 '),(2372,602679478001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','narsuitus','narsuitus@hotmail.com','Dr. Harvey Cobb','9214 S King Dr','Chicago','IL','UNITED STATES','60619-7314','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 21:28:59',0,NULL,3,1,1,1,NULL,'åŒç¯å¤´   1 '),(2373,641516122002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','liardp66a','jikchan@shaw.ca','Jik C Chan','44 Varsity Estates Court N.W.','Calgary','AB','CANADA','T3B5B1','(403) 286-3759','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 22:02:19',0,NULL,3,1,2,1,NULL,'6662aå¿«è£…æ¿   1 '),(2374,602708555001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','dacamcam','davidcambero@yahoo.es','David Cambero Cambero','Avda. Burjasot 29 Esc. A Puerta 4','Valencia','Comunidad Valenciana','SPAIN','46009','659213721','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 22:39:02',0,NULL,3,1,2,1,NULL,NULL),(2375,602712496001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','anafantastika','ka-indb@online.no','Karianne IndbjÃ¸r','Etterstadsletta 7a','Oslo','Oslo','NORWAY','0660','4799470518','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 22:49:23',0,NULL,3,1,2,1,NULL,NULL),(2376,684388568016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',2,'',43,'hutongstore','damonjamesdriver','damonjamesdriver@yahoo.co.uk','Damon Driver','32 Blakeland Hill','Duxford','Cambridgeshire','UNITED KINGDOM','CB22 4RX','07515917469','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶  2 \rYW864143705CN\r'),(2377,602728728001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','yelenam27','yelenam27@yahoo.com','Yelena Melnikov','1706 Sheepshead Bay rd<br>Fl 2','Brooklyn','NY','UNITED STATES','11235-3605','(917) 628-6823','NoPaymentFailure','CheckoutComplete','Other','2010-12-03 23:37:05',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶  ï¼ˆ ç™½ ï¼‰ 1\r2mç¯æž¶  2\r50-70 æ£š   1\r115w 110v   2\råŒ…   1 \rlighting kit  $30\rYW864143742CN\r'),(2378,641567544002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','oahudogger','oahuray@earthlink.net','Ray Gress','581 Lancaster Dr SE<br># 259','Salem','OR','UNITED STATES','97317','(503) 689-7696','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 00:34:48',0,NULL,3,1,1,1,NULL,NULL),(2380,602772827001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',5,'AA3301',16.5,'hermeshine','msmim10','mimidorazio@bigpond.com','Emilia D\'Orazio','11 Irwin Road','Embleton','Western Australia','AUSTRALIA','6062','0892751143','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 02:29:07',0,NULL,3,1,3,1,NULL,'52mm uv   5 RR723014687CN'),(2381,602779950001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64.99,'hermeshine','tmaxwell_design','max-o-s@hotmail.com','T.Maxwell  Smith','9 Palmgrove Ct','Palmwoods','Queensland','AUSTRALIA','4555','0754763915','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 02:59:41',0,NULL,3,1,6,1,NULL,'çº¢å¤´ç¯   æ¾³æ ‡  1 \ræ–°åŠ å¡EMS\rEX000239952SG\r'),(2382,641607783002,120644812085,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0024',27.9,'hermeshine','snowdog0416','www.jeremysingleton.com@gmail.com','Jeremy Singleton','937 Blanche Dr','Miamisburg','OH','UNITED STATES','45342-2027','(937) 866-5550','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-04 03:02:31',0,NULL,3,1,1,1,NULL,'canon å•è‚©åŒ…  a1   1 '),(2383,602804482001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','waynej5227','wayne@epatant.com.au','wayne jaye (Ã©patant model management)','unit 1/12 ensign avenue','annerley','Queensland','AUSTRALIA','4103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 05:01:36',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1RR723014673CN '),(2384,697654529015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'',125,'hutongstore','2010villemuurinen','ville.muurinen@gmail.com','Ville Muurinen','Sahalahdentie 8','PiikkiÃ¶','','FINLAND','21500','+35840 5256749','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-04 07:18:05',0,NULL,3,1,4,1,NULL,'tripod $30 \rYW864143683CN\r'),(2385,602832885001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','drerkan20','mderkan@hotmail.com','ERKAN KAYGIN','Ã‡AMLARALTI MAH. DOÄžAN DEMÄ°RCÄ°OÄžLU CAD NO:2<br>FORUM Ã‡AMLIK AVM. DOUGLAS PARFÃœMERÄ°','DENÄ°ZLÄ°','MERKEZ','TURKEY','20070','+90 (555) 305 9607','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 07:56:06',0,NULL,3,1,5,1,NULL,'CP212330897CN\r '),(2386,641666474002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','plainamericanguy','grandbob@gmail.com','Robert Otey','3824 Virginia Avenue SE','Charleston','WV','UNITED STATES','25304-1508','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 08:11:13',0,NULL,3,1,1,1,NULL,NULL),(2387,641671958002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','chrys9429','ccygay@yahoo.com','Chrysostom Ygay','3151 S ST<br>Apt 350','SACRAMENTO','CA','UNITED STATES','95816-7076','(714) 757-8460','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 08:34:46',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(2388,641680523002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','goldopt','gold@goldopt.ru','Vladimir Birukov','Kirova 96-313','Volgograd','','RUSSIAN FEDERATION','400059','89275104547','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 09:12:07',0,NULL,3,1,2,1,NULL,' '),(2389,641691097002,120601698609,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','yoaninka','yoanina.borisova@gmail.com','Yoanina Borisova','Mladost Bl.119 et9 ap47','Varna','Varna','BULGARIA','9020','+359886768542','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 09:51:39',0,NULL,3,1,3,1,NULL,'wf1005  1 RR723014695CN'),(2390,602865346001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',9.8,'hermeshine','peroni_es','por@retemail.es','Pere Onieva','Av. Barcelona 108 6-2','IGUALADA','SPAIN','SPAIN','08700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 10:05:29',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹çƒå°   1\ré‡é‡ï¼Ÿ 232g'),(2391,684586236016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'',22,'hutongstore','chrisgosling23','chris@gosling.com','Chris Gosling','Carl Plougs Vej 6, st.th','Frederiksberg','','DENMARK','1913','+45 3379 0185','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-04 11:11:54',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 RR723014700CN'),(2392,698107222015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','up-north-ian','hello@ianmcmanus.com','Ian McManus','16 Langdale Road','Blackburn','England','UNITED KINGDOM','BB2 5DW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-04 11:18:01',0,NULL,3,1,2,1,NULL,NULL),(2393,602930070001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','caracolits','caro.contreras@gmail.com','Carolina Andrea Contreras Tapia','Maquehue 9250','Hualpen - VIII regiÃ³n','Region del Bio Bio','CHILE','4601980','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 13:21:47',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon  1 '),(2394,641770034002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','hector_python','teufeur_1987@hotmail.com','Meckes','79, rue principale','Leutenheim','Alsace','FRANCE','67480','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 13:48:11',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…canon   1 '),(2395,641774249002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','narsil06','dewiric@ebuyclub.com','David RICHARD','54 allÃ©e des Consuls','GUERANDE','Pays de la Loire','FRANCE','44350','0647886622','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 13:58:38',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR723014611CN'),(2396,641776404002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','davidammar','duduammar@gmail.com','david amar','coresh 1915','Afula','Israel','ISRAEL','18310','9720524687337','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 14:04:27',0,NULL,3,1,2,1,NULL,NULL),(2397,641782008002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','1103peterd','photojack5@gmail.com','Peter Damo','69 Wigram Rd<br>Glebe','Sydney','New South Wales','AUSTRALIA','2037','0296604194','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 14:36:39',0,NULL,8,1,17,0,NULL,NULL),(2398,602872723001,110532007244,'77mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1304',35.22,'hermeshine','1103peterd','photojack5@gmail.com','Peter Damo','69 Wigram Rd<br>Glebe','Sydney','New South Wales','AUSTRALIA','2037','0296604194','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 14:36:39',0,NULL,3,1,3,1,NULL,'RS-C3   1\r77mm é•œå¤´ç›–  canon   1\rå¤§å·ç°å¡    1\r40cm æ£š    1\rRR723014894CN\r '),(2399,602930477001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','jbenben09','johanbencker@gmail.com','johan bencker','segervÃ¤gen 204','Ã„lvsjÃ¶','Stockholm','SWEDEN','12534','+46708614662','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 14:41:59',0,NULL,3,1,2,1,NULL,'å°å·é•œå¤´ç­’   1 '),(2400,698204712015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','gtgaute','gtgaute@gmail.com','Gaute Thogersen','Skrenten 48 C','Larvik','Vestfold','NORWAY','3258','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-04 14:55:18',0,NULL,3,1,2,1,NULL,'45w   2 '),(2401,602834117001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',14.98,'hermeshine','scroc_fr','scroc@hotmail.com','Guillaume ALEXANDRE','68, les Casses Vivert','La Batie Neuve','Provence-Alpes-CÃ´te d\'Azur','FRANCE','05230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 15:09:50',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°   1\r77mm çŽ¯æž¶  1\rå¹¿è§’æ‰˜æž¶    1 '),(2402,641808768002,120454225464,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',1,'AE2308',5.8,'hermeshine','hosa87','hosacrew@seznam.cz','AXA CNC stroje, s.r.o.','Jan Hosek<br>Cintlovka 535','Horovice','','CZECH REPUBLIC','26801','00420604913394','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 15:18:15',0,NULL,3,1,2,1,NULL,NULL),(2403,698221827015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',2,'',6.76,'hutongstore','sookonn','indrek.polakes@mail.ee','Indrek Polakes','KÃ¤rberi 52-11','Tallinn','Harjumaa','ESTONIA','13919','56453066','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-04 15:27:26',0,NULL,3,1,2,1,NULL,NULL),(2405,641819609002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','reyabe','mycadipo.ventas@gmail.com','Carlos DÃ­az Polo','C/ Justina NÂº62','Yecla','Murcia','SPAIN','30510','617850603','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 15:40:54',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(2407,641824161002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',2,'AA2106',70,'hermeshine','conan80','tom@tomsig.de','Thomas Starke','Magnusweg 13 a','Gaimersheim','','GERMANY','85080','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 15:51:38',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ  canon L   2 è€æ¬¾ 1.292\rRR723010274CN\r'),(2408,641854005002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','magnet32','magnet32@hotmail.com','Jesus Neira Martel','Avenida Extremedura, 73C','Santiponce','Sevilla','SPAIN','41970','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 16:48:30',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1 \rRR723014625CN'),(2409,603047623001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.5,'hermeshine','will2fire','williec@pacific.net.sg','Willie Chan','Pearl Bank #14-10','default','','SINGAPORE','169016','96195688','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 17:50:59',0,NULL,3,1,11,1,NULL,NULL),(2410,684794239016,260660054946,'YongNuo SF-18 Flash Battery Pack 8*AA for Nikon SB800',1,'',32.99,'hutongstore','mau180161','ik3ord1@inwind.it','Maurizio Busato','Sant\'Antonio n.73','Teolo','PD','ITALY','35037','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-04 17:59:52',0,NULL,3,1,3,1,NULL,'sf18 nikon  sb800   1 RR723014639CN'),(2411,641900608002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','melktabares','msegbar@gmail.com','Miguel Angel Segura Barandalla','C/SebastiÃ¡n Machado, 40','TACORONTE','Canarias','SPAIN','38350','922560864','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 18:10:44',0,NULL,3,1,4,1,NULL,'tripod $15\rYW864143694CN\r '),(2412,641926601002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','omriamos','omriamos@gmail.com','Omri Amos','Levi Eshkol 3<br>Apartment 4','Kiryat Motzkin','Israel','ISRAEL','26397','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 19:07:28',0,NULL,3,1,3,1,NULL,' RR723014642CN'),(2413,641939339002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','arqhfernandes','arq.h.fernandes@gmail.com','Hugo Fernandes','RRCRS Arquitectos<br>Av. D. Joao II, lote 1.03.2.1B, 4ÂºA1','Lisboa','Lisboa','PORTUGAL','1990-092','(+351) 918151509','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 19:23:18',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR723014656CN'),(2414,603107661001,110533631413,'CTR-301P Flash Trigger Kit with 2 Receivers ctr301p',1,'AKT001',41.9,'hermeshine','mihocidavid','mihoci@gmail.com','David Mihoci','Preloska 66','Cakovec','Hrvatska','CROATIA','40000','098220252','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 19:26:54',0,NULL,3,1,3,1,NULL,'301p ä¸€æ‹–äºŒ   1 \rRR723014568CN'),(2415,698391954015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'',3.76,'hutongstore','tullichcroft','kevin.mcglynn@virgin.net','kevin mcglynn','tullich croft soroba','oban','Argyll and Bute','UNITED KINGDOM','pa34 4sb','01631563717','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-04 19:40:56',0,NULL,3,1,2,1,NULL,NULL),(2416,603121605001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','duametef2010','duametef@seznam.cz','Jiri Padour','Na Luzci 735/3','Lazne Bohdanec','Czech Republic','CZECH REPUBLIC','533 41','+420 606 619 602','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 19:42:15',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  Nikon   1 '),(2417,684906515016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'',7.56,'hutongstore','philbot24','psoliven_24@yahoo.com','MR PAUL SOLIVEN','#2 Laureston Terrace,','Douglas,Isle of Man','Isle of Man','UNITED KINGDOM','IM2 5DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-04 20:39:13',0,NULL,3,1,2,1,NULL,NULL),(2418,641989048002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','adeje_dario','dario_adeje@hotmail.com','Dario Bascones Carrodeguas','Residencial Los Abalos nÂº1 El Galeon','Adeje','Canarias','SPAIN','38670','617441150','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 20:46:27',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§  1\ræŸ”å…‰ä¼ž   1 \rRR723014903CN'),(2419,641992097002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','katzmeny77','katzmeny@gmail.com','meny  katz','moshe sharet 79/19 kyriat haim','haifa','israel','ISRAEL','26308','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 20:47:37',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§  1\ræŸ”å…‰ä¼ž   1  \rRR723014850CN'),(2420,603164935001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','lsloomie','lsloomie@hotmail.com','Leo Loomie','9 Hall Pl','Albany','NY','UNITED STATES','12210-2550','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 21:00:35',0,NULL,3,1,1,1,NULL,NULL),(2421,642016440002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','tingzhao1688','vincent82123@hotmail.com','Min Wong','10352 Stone Ave N<br>Apt 6','seattle','WA','UNITED STATES','98133-9494','(206) 605-3138','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 21:35:12',0,NULL,3,1,1,1,NULL,NULL),(2422,642019067002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','adamnguyen','shushilov3r@yahoo.com','Adam T. Nguyen','811 Seabrook ct','San Jose','CA','UNITED STATES','95111-1410','(408) 896-7794','NoPaymentFailure','CheckoutComplete','Other','2010-12-04 21:39:38',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRR723014761CN'),(2423,698508621015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'',13.9,'hutongstore','imflister','borut.komac@mangrt.com','Borut Komac','Reska ulica  25','Ljubljana','Slovenia','SLOVENIA','1000','051674764','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-04 22:48:57',0,NULL,3,1,2,1,NULL,'50cm æ£š  1 '),(2424,684981805016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','encl4ve','gummibear@rambler.ru','Vjaceslavs Sanins','Flat 11 190 Quarry Street','Hamilton','South Lanarkshire','UNITED KINGDOM','ML3 6QR','07791774216','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-04 22:52:18',0,NULL,3,1,2,1,NULL,'lenspen   1 '),(2425,642057662002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','eaglewomyn','eaglewomyn@aol.com','Stephanie Shore','242 Rutland Blvd','West Palm Beach','FL','UNITED STATES','33405-5034','(561) 585-3662','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 23:04:20',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ… Nikon   1 '),(2426,603240348001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','fredwidall','fwwidall@uwaterloo.ca','Fred Widall','544 Red River Drive','Waterloo','ON','CANADA','N2T 2B7','(519) 744-1478','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 00:01:12',0,NULL,3,1,2,1,NULL,NULL),(2427,642095550002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','rsg123','rsghuman@hotmail.com','RUPAUL GHUMAN','595 Gidda Loop','YUBA CITY','CA','UNITED STATES','95993-5000','(530) 218-1257','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-05 00:55:16',0,NULL,3,1,1,1,NULL,'canon ä¸‰è§’åŒ…  1 '),(2428,642110968002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','schwarzschild1924','philipcops@gmail.com','Winkin M.G.','Rue sur les Roches, 18','Namur','','BELGIUM','5004','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 01:45:04',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRR723014775CN'),(2429,642119656002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','ko_paints','ko_paints@hotmail.com','Eric McPherson','13439 County Road 339','Sidney','MT','UNITED STATES','59270-3554','(406) 798-3122','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 02:18:40',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡  1 '),(2430,642125194002,120644812085,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0024',27.9,'hermeshine','cozine','ari.ahlbom@gmail.com','Ari Ahlbom','Koskitie 12 a3','Huittinen','Satakunta','FINLAND','32700','0449449011','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 02:34:55',0,NULL,3,1,3,1,NULL,'canon å•è‚©åŒ… A1   1\rRR723014801CN '),(2431,642133632002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','lpaulw1','lpaulw@charter.net','L. PAUL WASSERMAN','2433 S Nadine St<br>Apt 2','WEST COVINA','CA','UNITED STATES','91792-3559','(818) 625-0947','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 03:03:28',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2432,642133328002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jimstack1942','jimsta1942@roadrunner.com','James Stack','2158 Langdon Rd','Ransomville','NY','UNITED STATES','14131-9704','(716) 791-3990','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 03:03:35',0,NULL,3,1,1,1,NULL,NULL),(2433,603309136001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','overkillweldingco','lokistink1@comcast.net','georgia eckert','2205 Three Mile Run Rd','perkasie','PA','UNITED STATES','18944-2037','(267) 354-1783','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 04:17:36',0,NULL,3,1,1,1,NULL,NULL),(2434,603314419001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','morenah1000','videoz@terra.com.br','Azevedo Zilah','Rua Cesar Zama, 74 Bl 2/303<br>Lins de Vasconcelos','Rio de Janeiro','Rio de Janeiro','BRAZIL','20725-090','02178132984','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 04:39:40',0,NULL,3,1,2,1,NULL,NULL),(2435,642173734002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','karakozov2010','rogers@yandex.ru','Vladimir Karakozov','Grajdanskiy prospect<br>122-4-287','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','195267','904-516-3517','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 05:54:57',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ canon L   1 è€æ¬¾ RR723014789CN'),(2436,642181036002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','sattastrin','sattas@inbox.com','Brad Semeniuk','Box 1244','Vernon','BC','CANADA','V1T6N6','(250) 558-8120','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 06:36:13',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\rbåº§  2\ræŸ”å…‰ä¼ž   2 CP212330883CN\r'),(2437,642184302002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','vintageboy69','nandgbsjeremy@hotmail.com','Jeremy Chuang','3251 Cardiff Ave<br>Apt 7','Los Angeles','CA','UNITED STATES','90034-2840','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 06:54:54',0,NULL,3,1,1,1,NULL,NULL),(2438,642220570002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','ostrenok','lostrenok@gmail.com','Leonid Ostrenok','Yunnatov street 3-28','Khimki','Moscow region','RUSSIAN FEDERATION','141400','7-985-773-9420','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 09:21:02',0,NULL,3,1,3,1,NULL,'115w 220v    2 RR723014792CN'),(2439,603378098001,110532006869,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.6,'hermeshine','8anos','8annos@gmail.com','Nikopoulos Thanasis','OGA Panepistimiou 168','Patra','','GREECE','26443','00306945718123','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 09:33:35',0,NULL,3,1,2,1,NULL,NULL),(2440,642235669002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','wayne.ck','wayne_underoath@hotmail.com','Wayne Devine','Unit 2/262 Lenah Valley Rd, Lenah Valley','Hobart','Tasmania','AUSTRALIA','7008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 09:58:51',0,NULL,3,1,2,1,NULL,'6662a å¿«è£…æ¿   1 '),(2441,603398645001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','jesabltd64','jeanette.edstrom@hotmail.com','jeanette edstrÃ¶m','illervÃ¤gen 7','Sundsvall','','SWEDEN','86232','0046702604435','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 10:23:01',0,NULL,3,1,2,1,NULL,''),(2442,642287562002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','ezavgorodniy','zavgorodniy@ymail.com','Eugene Zavgorodniy','Novoslobodskaya str. 73, gzt Kultura','Moscow','Moscow','RUSSIAN FEDERATION','127055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 11:49:49',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2443,642287437002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','nickybear0001','nickybear@internode.on.net','Michael Denholm','4 Meadowview Rise','Aberfoyle Park','South Australia','AUSTRALIA','5159','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 11:54:33',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ canon XL  1\rè€æ¬¾   RR723014713CN'),(2444,698810553015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'',29,'hutongstore','mickyblueeyes.ie','mickpcunningham@gmail.com','MicheÃ¡l Cunningham','N0 3 Riverchapel Place','Riverchapel / Courtown, Gorey, County Wexford','','IRELAND','0','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-05 12:26:32',0,NULL,3,1,3,1,NULL,'4ç¯å¤´æ£š   1   è‹±æ ‡RR723014571CN'),(2445,603462183001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','feelx100','brianleung1103@hotmail.com','Brian Leung','7451 Nevis Dr','Richmond','BC','CANADA','V7A 1J5','(778) 323-0032','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 12:32:13',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(2446,698869398015,250606688659,'New IR Remote Control for Pentax K10D K20D K100D',1,'',2.75,'hutongstore','anoi71','nevrotika@tiscali.it','IGNAZIO DE MAIO','VIA ACCADEMIA 36','SORRENTO','NA','ITALY','80067','0818073904','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-05 13:56:04',0,NULL,3,1,2,1,NULL,'çº¢å¤–5in1   1 '),(2447,698886429015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','shildon2','ericwhite@talktalk.net','Eric White','21 Dale Rd','Shildon','Durham','UNITED KINGDOM','DL4 2LB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-05 14:18:56',0,NULL,3,1,2,1,NULL,NULL),(2448,603532043001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','chadrundle','crundle@cargologistics.com','Chad Rundle','8761 Dorchester rd<br>Suite 205','North Charleston','SC','UNITED STATES','29420','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 14:38:52',0,NULL,3,1,1,1,NULL,NULL),(2449,603580807001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','mikhaelsinenko','cper34@gmail.com','Mikhael Sinenko','bakhchivandzhi 2a flat138','Shelkovo-3','Moscow','RUSSIAN FEDERATION','141103','+79265594371','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 15:56:18',0,NULL,3,1,5,1,NULL,'wt600   1 CP212330923CN\r'),(2450,699031881015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','dushkoivanko','dusanivanko@yahoo.co.uk','Mr Dusan Ivanko','Startide Limited, Unit 72, Mill Mead Business Centre Mill Mead Road','London','London','UNITED KINGDOM','N17 9QU','07958769188','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-05 17:08:42',0,NULL,3,1,2,1,NULL,NULL),(2451,699051150015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',2,'',3.76,'hutongstore','dkephalas','d_kephalas@kephalas.gr','Dimitris Kephalas','Tellou Agra 4','Volos','','GREECE','38333','6945802354','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-05 17:25:25',0,NULL,3,1,2,1,NULL,NULL),(2452,603678865001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1309',7.4,'hermeshine','allenchester4xo8','allenchester@comcast.net','Charles Allen Chester','3011 Lopez Rd','Jacksonville','FL','UNITED STATES','32216-3509','(904) 641-4672','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 17:46:53',0,NULL,3,1,1,1,NULL,NULL),(2453,603699805001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','alex.shishkin','shishkin.82@gmail.com','Alexey Shishkin','Pr. Mira 64-197','Nizhnekamsk','Tatarstan','RUSSIAN FEDERATION','423571','+7-904-675-3650','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 18:30:46',0,NULL,3,1,2,1,NULL,NULL),(2454,685602399016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','paulmeakings','paul@pmeakings.orangehome.co.uk','paul meakings','121 South Eastern Road','ramsgate','Kent','UNITED KINGDOM','CT11 9QD','01843851053','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-05 18:31:41',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\r50-70 æ£š  2 è‹±æ ‡\r115w 220v   2\råŒ…  1\rlight kit  $32 \rYW864143764CN\r'),(2455,603745591001,110519774429,'Pro FANCIER WF-531T Tripod with 593H 6662a Upgraded NEW',1,'AE1101',79,'hermeshine','maormuki','mukipe@gmail.com','maor peretz','× ×•×¨×“××• 52 ×§.××ª×','×§×¨×™×ª ××ª×','','ISRAEL','28000','0774010258','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 18:50:05',0,NULL,5,1,18,0,NULL,NULL),(2456,642628299002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',9.8,'hermeshine','chrispar76','chrisparsons76@sky.com','chris parsons','99 percival road','Eastbourne','East Sussex','UNITED KINGDOM','BN22 9JW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 19:08:50',0,NULL,3,1,2,1,NULL,NULL),(2457,603814386001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','wrongeway5','bjbrush@hotmail.com','Brian Brush','4282<br>WALTON WOODS ROAD','WALTON','NS','CANADA','B0N2R0','(902) 528-2716','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 19:38:16',0,NULL,3,1,2,1,NULL,NULL),(2458,699319025015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'',1.88,'hutongstore','canik1','sleeponit@dysonuk.com','Adrian Dyson','176 Meadfoot Road','Coventry','West Midlands','UNITED KINGDOM','CV3 3DS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-05 20:38:26',0,NULL,3,1,2,1,NULL,NULL),(2459,642731184002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ftir','fotis_tirokomos@yahoo.gr','Fotis Tirokomos','6-8, Agisilaou str.<br>OTEGLOBE, BlueLand building 3rd floor','Marousi','Athens - Attica','GREECE','15123','+306975869317','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 20:38:56',0,NULL,3,1,2,1,NULL,NULL),(2460,685821335016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','tntmah','tntmahar1@optusnet.com.au','Terrence Mahar','19 O\'Neill street','Coffs Harbour','New South Wales','AUSTRALIA','2450','0266519703','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-05 21:10:53',0,NULL,3,1,6,1,NULL,' 2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\r50-70 æ£š  2 æ¾³æ ‡\r115w 220v   2\råŒ…  1\ræ–°åŠ å¡EMS\rlight kit  $32 \rEX000290775SG\r'),(2461,642767835002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ozjohnbayid','texon@rogers.com','Oz John Tekson','2706 - 27 Sudbury Street','Toronto','ON','CANADA','M6J 3W6','(416) 837-3451','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 21:19:10',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 RR723014829CN'),(2462,685857759016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'',22,'hutongstore','sanglierolivier','ptitgomme@yahoo.fr','Olivier  Sanglier','Rue Bois Madame , 37','Mont-sur-Marchienne','','BELGIUM','6032','0472476951','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-05 21:52:26',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723014815CN'),(2463,603941179001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','eryka91','eryka91@hotmail.com','Eryka Garbutt','4 Rechner Place, Flynn','Canberra','Australian Capital Territory','AUSTRALIA','2615','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 22:03:44',0,NULL,3,1,2,1,NULL,'40cm æ£š   1 '),(2464,642805707002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','angelitofr','julietafraga@hotmail.com','Angel Fraga Rivera','C/ RÃ­a de Arousa NÂº 12 4ÂºB<br>Arteixo','A CoruÃ±a','Galicia','SPAIN','15142','607935537','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 22:12:13',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143775CN\r'),(2465,603950128001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','jlpe4837','jmloplin@yahoo.es','JosÃ© Manuel LÃ³pez Linares','Plaza JosÃ© RamÃ³n Aketxe, 8 - 5ÂºA','Leioa','PaÃ­s Vasco','SPAIN','48940','606 384 777','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 22:18:32',0,NULL,3,1,4,1,NULL,'tripod  $22 \rYW864143731CN\r'),(2466,642802233002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','co$mik','cosmik@mail.ru','Maxim Shepelev','Schelkovskoe Shosse<br>26-1-93','Moscow','','RUSSIAN FEDERATION','105425','+79265403810','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 22:20:33',0,NULL,3,1,2,1,NULL,NULL),(2467,685879844016,260687503075,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'',28.99,'hutongstore','insidecover','alec.kirkham@red5audio.com','Alec Kirkham','21 Dalmore Drive','Airdrie','North Lanarkshire','UNITED KINGDOM','ML6 9AH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-05 22:22:36',0,NULL,3,1,3,1,NULL,'3m æ¨ªæ†  1 RR723014832CN'),(2468,699416465015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','wobbegong1977','wesg77@hotmail.com','Wesley Gottliebsen','55 barfleur lane','london','London','UNITED KINGDOM','se8 3dd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-05 22:33:30',0,NULL,3,1,2,1,NULL,NULL),(2469,603964949001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','pierre50mm','hiboudejour@hotmail.com','Pierre Boucher','200, Fleury ouest','Montreal','QC','CANADA','H3L 1T7','(514) 858-7661','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 22:50:56',0,NULL,5,1,18,0,NULL,NULL),(2470,642825945002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','pierre50mm','hiboudejour@hotmail.com','Pierre Boucher','200, Fleury ouest','Montreal','QC','CANADA','H3L 1T7','(514) 858-7661','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 22:50:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rå•ç¯å¤´   1\råå…‰ä¼ž   1 \rRR723010433CN\r'),(2471,641441578002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','sick_cycles','paypal@sickcycles.com','Brian A Bailey','9 EDGEWOOD ST','CHELMSFORD','MA','UNITED STATES','01824-2509','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-05 22:59:41',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  2 '),(2472,642864122002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','carlos.pizarro','carlos.pizarro.bravo@gmail.com','Carlos Pizarro Bravo','Avda Maria Moliner 48','Leganes','Madrid','SPAIN','28919','675123042','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 00:14:44',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž   1 RR723014846CN'),(2474,603561555001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','nallurjeyam1971','nallurjeyam@yahoo.com','thirukulasingam jeyapalan','78,nayanmar road,nallur,jaffna,srilanka.','jaffna','noth','SRI LANKA','40000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 01:11:40',0,NULL,3,1,2,1,NULL,'45w   2 '),(2475,642886392002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','robyn9315','princezo7@aol.com','Robyn Parker','9845 Deepwoods Dr','Shreveport','LA','UNITED STATES','71118','(318) 687-2279','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 01:07:01',0,NULL,3,1,1,1,NULL,NULL),(2476,642894013002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','fsumsn98','penpie64@bellsouth.net','PENNYE AREHART','PO Box 600368','ST JOHNS','FL','UNITED STATES','32260-0368','(904) 287-4186','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 01:32:55',0,NULL,3,1,1,1,NULL,NULL),(2477,638583636002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','9965glee','greg@liservices.com.au','Greg Lee','10 McNae Street','Moonee Ponds','Victoria','AUSTRALIA','3039','0398197084','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 02:27:47',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2478,604058169001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','duane2210','duey2210@msn.com','Duane Gullard','5610 80th St E','Puyallup','WA','UNITED STATES','98371-5457','(253) 881-1448','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 02:49:07',0,NULL,3,1,1,1,NULL,'å°å·é•œå¤´ç­’   1 '),(2479,604076889001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','acm8ker','uchillin14@embarqmail.com','dave green','30 Apple Hill Holw','casselberry','FL','UNITED STATES','32707-4945','(407) 767-0755','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 03:42:02',0,NULL,3,1,1,1,NULL,NULL),(2480,604068726001,110531022936,'3ft Universal TTL Off camera Cord  Canon/Nikon/Pentax',1,'AB3319',18.5,'hermeshine','udarling1','udarling1@verizon.net','Ural Darling','202 40th St S','Saint Petersburg','FL','UNITED STATES','33711','(727) 327-6915','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 05:42:06',0,NULL,8,1,17,0,NULL,NULL),(2481,642953603002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','udarling1','udarling1@verizon.net','Ural Darling','202 40th St S','Saint Petersburg','FL','UNITED STATES','33711','(727) 327-6915','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 05:42:06',0,NULL,8,1,17,0,NULL,NULL),(2482,604067896001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','udarling1','udarling1@verizon.net','Ural Darling','202 40th St S','Saint Petersburg','FL','UNITED STATES','33711','(727) 327-6915','NoPaymentFailure','CheckoutComplete','Other','2010-12-06 05:42:05',0,NULL,8,1,17,0,NULL,NULL),(2483,604083612001,110544584989,'16chan Wireless  Control Cord for Canon 40D 50D 5D 5DII',1,'AA3204',18.5,'hermeshine','udarling1','udarling1@verizon.net','Ural Darling','202 40th St S','Saint Petersburg','FL','UNITED STATES','33711','(727) 327-6915','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 05:42:07',0,NULL,8,1,17,0,NULL,NULL),(2484,642955806002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','udarling1','udarling1@verizon.net','Ural Darling','202 40th St S','Saint Petersburg','FL','UNITED STATES','33711','(727) 327-6915','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-06 05:42:08',0,NULL,3,1,4,1,NULL,' 2m ç¯æž¶  2\ræ–œè‡‚   1\råå…‰æ¿æ”¯æž¶   1\r80cm 2in1 åå…‰æ¿   1\rçˆµå½±ttlçº¿ 1m   1\rçˆµå½±æ— çº¿ c3   1\rä¸€ç¥¨å¤šä»¶\rYW864143650CN\r\r\r'),(2485,642982906002,120654651653,'Pro Photo Vest Blue for Nikon D90 D300s D7000 D80  user',1,'AA2106',32,'hermeshine','countryboycreations','maurice@countryboycreations.com','Country Boy Creations LLC','300 Berkshire Dr<br>Ste E','Columbia','SC','UNITED STATES','29223-1859','(803) 600-6563','NoPaymentFailure','CheckoutComplete','Other','2010-12-06 05:46:45',0,NULL,3,1,1,1,NULL,'è–„æ¬¾ æ‘„å½±èƒŒå¿ƒ  NIkon  xxl   1 è“è‰²'),(2486,642991326002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','a_brooke2006','afordham06@yahoo.com','Amber Baldino','351 Clover Brook Dr','Locust Grove','GA','UNITED STATES','30248-3692','(678) 294-5675','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 06:32:29',0,NULL,3,1,1,1,NULL,'NG200   1 '),(2489,643009087002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','anbidian','azine@mm.st','Matthew Capowski','9 Fair Oaks Drive','St. Albert','AB','CANADA','t8n 1p7','(780) 964-1200','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 08:12:40',0,NULL,3,1,2,1,NULL,'NG200   1 '),(2490,604150265001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','agreis81','agreis@agreis.hu','Bela Forgo','FÃ³ti Ãºt 122','Budapest','Budapest','HUNGARY','H-1046','36704584638','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 09:34:26',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1  \rRR723010362CN\r'),(2491,643036564002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','spinebass','udu.wudu@gmail.com','Deniss Arsenins','Anninmuizas bulvaris 38/3-46C','Riga','Latvia','LATVIA','LV-1067','+371 26411374','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 10:02:34',0,NULL,3,1,3,1,NULL,'\rRR723010455CN\r'),(2492,604173161001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','uszkomatonta','don@tricon.hu','Szilard Pasztor','KaposvÃ¡r u. 14-18.','Budapest','Budapest','HUNGARY','1117','+3613727154','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 10:59:54',0,NULL,3,1,2,1,NULL,NULL),(2493,686154370016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','nimrod1937a','etootell@btinternet.com','Eric Tootell','14, Tennyson Avenue','Chorley','Lancashire','UNITED KINGDOM','PR7 3HX','01257231741','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-06 11:02:29',0,NULL,3,1,2,1,NULL,NULL),(2494,643053525002,120601698743,'Canon 52mm Reverse Adapter 450D 50mm 1.8 500D Macro',1,'AA1207',4.4,'hermeshine','lesterlem','lesterlem@hotmail.com','Justin Lem','1st Floor, 155 Wong Nai Chung Road, Happy Valley','default','','HONG KONG','default','(852) 983-4133 ext.: 7','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 11:02:44',0,NULL,3,1,2,1,NULL,'canon 52mm åæŽ¥çŽ¯  1 '),(2495,641812696002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',62.79,'hermeshine','greeneagle65','mike.bolcskey@gmail.com','Martin Domeny (Eltec)','Daimler str.13-15','Wernau','','GERMANY','73249','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 11:13:30',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  2 \r Mike Bolcskey\r Katona Jozsef u. 24. Budapest, 1194\r Hungary RR723010685CN'),(2496,604190456001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','ap.lv','andris.pilmanis@inbox.lv','Andris Pilmanis','M.Nometnu street 28 - 24A','Riga','','LATVIA','LV-1002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 11:59:52',0,NULL,3,1,2,1,NULL,NULL),(2497,643076515002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','litlestar','msracheljavila@aol.com','RACHEL AVILA','824 Pepperidge Road','Westbury','NY','UNITED STATES','11590','(917) 439-1408','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 12:22:55',0,NULL,3,1,1,1,NULL,NULL),(2498,643078141002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','c.diaz.c','cskyline@gmail.com','Carlos Diaz Canovas','Utrillas 8 5A','Madrid','Madrid','SPAIN','28043','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 12:26:11',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864143834CN\r'),(2499,643086246002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','veerawol','veerawol@innovate.co.th','Veerawong Lohayuenyongsook','1115/2 Itsaraparp Road<br>Wataroon','Bangkokyai','Bangkok','THAILAND','10600','66814979070','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 12:52:23',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2500,699735559015,250692237477,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'',7.75,'hutongstore','carnlough16','krzysztofosa@wp.pl','krzysztof ossowski','19 croft road','carnlough','Antrim','UNITED KINGDOM','bt44 0ex','02828885925','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-06 13:04:07',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ è‹±æ ‡   1 '),(2501,643092020002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','filmugamyba','info@filmugamyba.lt','Mindaugas Ciciunas','J.Basanaviciaus 17','Kretinga','','LITHUANIA','97125','+370 676 39744','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 13:09:59',0,NULL,8,1,17,0,NULL,''),(2502,604214727001,110414378946,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','filmugamyba','info@filmugamyba.lt','Mindaugas Ciciunas','J.Basanaviciaus 17','Kretinga','','LITHUANIA','97125','+370 676 39744','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 13:18:17',0,NULL,8,1,17,0,NULL,''),(2503,604218875001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',4,'AA1314',11.96,'hermeshine','ujangubed','ujangbidik@gmail.com','Ujang Hidayat / bidik photo','Jl Terusan Pasir Koja no .96B dan 96C','Bandung','Jawa Barat','INDONESIA','40232','081321 875152','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 13:31:21',0,NULL,3,1,2,1,NULL,'NIKON æœºèº«ç›–/é•œå¤´åŽç›–     4 '),(2505,604217901001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','tony_c77','tony_c@mail.ru','Cheremukhin Anton','Moravsky side str.  3-1-395','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','192289','+79216446366','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 13:36:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rRR723010963CN'),(2506,604226690001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','astralstar','astralstar2009@yandex.ru','Aleksander Udalov','Zavodskoe shosse, dom 56, kv. 29','Samara','Samarskaya oblast','RUSSIAN FEDERATION','443052','89171107322','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 13:54:27',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰   1 \rCP212330945CN\r'),(2507,699786480015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'',22,'hutongstore','filmugamyba','info@filmugamyba.lt','Mindaugas Ciciunas','J.Basanaviciaus 17','Kretinga','','LITHUANIA','97125','+370 676 39744','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-06 15:01:49',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \r 52mm çŽ¯æž¶   1 \rND8    1\rRR723010932CN'),(2508,604251852001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','mickekss','micke_kss@hotmail.com','Mikael Andersson','Sadelmakaregatan 9','Klippan','','SWEDEN','264 70','+46735615009','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 15:05:46',0,NULL,3,1,2,1,NULL,NULL),(2509,601952525001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','georgeting','georgetingfz@gmail.com','George Ting','1st Floor, Lot 8795 Pending Court<br>Jalan Kwong Lee Bank','Kuching','Sarawak','MALAYSIA','93450','0128861512','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 15:31:16',0,NULL,3,1,3,1,NULL,'ç”³æŠ¥ï¼š camera accessories \råå…‰æ¿æ”¯æž¶    1\rRR723010416CN\r'),(2510,604265421001,110591560700,'82mm 82 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','finsilop1','finsilop@gmail.com','Sergey Chupina','24, Polevaya Str.<br>Infopulse Ukraine LLC','Kiev','UA','UKRAINE','03056','380951891123','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 15:41:37',0,NULL,3,1,2,1,NULL,'82mm çŽ¯æž¶    1 '),(2512,642956936002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','vespagott','viva.zapata@arcor.de','Helmut Zapatka','Klapheckenhof 27a','Gelsenkirchen','','GERMANY','45883','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 16:05:48',0,NULL,8,1,17,0,NULL,NULL),(2514,642956662002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',2,'AO0024',18,'hermeshine','vespagott','viva.zapata@arcor.de','Helmut Zapatka','Klapheckenhof 27a','Gelsenkirchen','','GERMANY','45883','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 16:08:02',0,NULL,8,1,17,0,NULL,NULL),(2516,604082334001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2106',32,'hermeshine','vespagott','viva.zapata@arcor.de','Helmut Zapatka','Klapheckenhof 27a','Gelsenkirchen','','GERMANY','45883','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 16:10:01',0,NULL,3,1,4,1,NULL,'è–„æ¬¾æ‘„å½±èƒŒå¿ƒ  canon é»‘è‰² xxxl   1 \rè€æ¬¾æ‘„å½±èƒŒå¿ƒ canon  xxxl   1\rcanon ä¸‰è§’åŒ…   2\rYW863884296CN\r'),(2517,604277480001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','zinmen','lavazza1@freemail.hu','Gabriel Melaga','Stefanikova 40','Sturovo','','SLOVAK REPUBLIC','94301','+421907738943','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 16:11:19',0,NULL,3,1,2,1,NULL,NULL),(2518,604272765001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','toprcm','jevgenijs.kuh@toprcm.lv','Jevgenijs Kuhalskis','Skanstes 29a-10','Riga','Latvia','LATVIA','LV-1013','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 16:15:36',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚   1 RR723010668CN'),(2519,604295309001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','jobermesik','joberm01@yahoo.com','Jeffery Obermesik','10756 Larissa St','Orlando','FL','UNITED STATES','32821','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 16:51:01',0,NULL,3,1,1,1,NULL,NULL),(2520,604297740001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','kirgon','matthieu.fynes@lesplansj.com','Matthieu FYNES','12 rue des couvre-toits','FRELINGHIEN','Nord-Pas-de-Calais','FRANCE','59236','0699039033','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 16:59:22',0,NULL,3,1,4,1,NULL,'tripod $22 \rYW864143823CN\r'),(2521,643189233002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','virgmayjune','ififig@gmail.com','Phill Yendt','114 Dalgleish Ave','Kingston','ON','CANADA','K7K 7E3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 17:08:05',0,NULL,3,1,2,1,NULL,NULL),(2522,643188765002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','mmlowe2005','misty.dlowe@gmail.com','Misty Lowe','14030 Merseyside Dr','Pflugerville','TX','UNITED STATES','78660-8808','(512) 820-3624','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 17:15:48',0,NULL,3,1,1,1,NULL,NULL),(2523,604310451001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0024',20.99,'hermeshine','blinkyblinkyusa','blinky1@blinkyblinky.com','C Wilson','4405 Candlewood Pl<br>Wilson-Devoronoff Apt 103','Rapid City','SD','UNITED STATES','57702-0183','(605) 718-7494','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-06 17:22:12',0,NULL,3,1,3,1,NULL,'Nikon å•è‚©åŒ…  æ–°æ¬¾  1 \rRR723010420CN\r'),(2524,699866498015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'',51,'hutongstore','dale_ee','megake@gmail.com','Mihhail Maslakov','Vilde 6-5','Kohtla-JÃ¤rve','Estonia','ESTONIA','30321','+372 5123739','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-06 17:31:02',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½  é»‘ï¼‰   1 \rCP212330937CN\r'),(2526,604320180001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.95,'hermeshine','darkwater308','dougy308@verizon.net','DOUG YOUNG','308 Quarry St<br>Apt 501','QUINCY','MA','UNITED STATES','02169-4135','(617) 471-2740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-06 17:45:15',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹   1 '),(2527,643246532002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','dstaton','2co@bloomingtononline.net','BloomingtonOnline.NET','101 W Kirkwood Ave<br>Ste 008A','Bloomington','IN','UNITED STATES','47404-6130','(812) 961-0630','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 18:55:02',0,NULL,3,1,1,1,NULL,NULL),(2528,604378118001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7Âº 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 19:21:52',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶   1\rND2/4/8    1 '),(2529,643270595002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','lom41','me@albertzak.com','Theresa Zak','GerasdorferstraÃŸe 153/167','Wien','','AUSTRIA','A-1210','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 19:28:54',0,NULL,3,1,4,1,NULL,'BALLHEAD  $18 \rYW864143790CN\r'),(2530,641852965002,120598267827,'Camera shoulder bag with raincover for Canon 550D 40D',1,'AO0021',28.99,'hermeshine','rocknroller2009','ginji.amano@voila.fr','Romuald Bavarin','79 rue de Patay','PARIS','Ile-de-France','FRANCE','75013','Invalid Request','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'CANan å•è‚©åŒ…  R2   1 \rRR723010393CN\r'),(2531,604414950001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','onyxander','tom.dekock@gmail.com','Tom','Leurschans 44','Steenbergen','','NETHERLANDS','4651 WJ','0167500853','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 20:17:36',0,NULL,3,1,2,1,NULL,NULL),(2532,604424144001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','moti_malul','mm18@zahav.net.il','MORDEHAI MALUL','Hativat Givati 10/9','yavne','ISRAEL','ISRAEL','81205','97289493116','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 20:32:12',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723010380CN\r'),(2533,699994611015,250599408294,'Green.L 77mm 77 Neutral Density ND4 Filter ND 4 New',1,'',4.8,'hutongstore','1esadmf','paul10downingstreet@hotmail.com','paul white','10 burn road','scunthorpe','Lincolnshire','UNITED KINGDOM','dn15 8ax','01724344651','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-06 21:18:06',0,NULL,3,1,2,1,NULL,NULL),(2534,604462975001,110566021597,'New YN Flash Battery Pack SF-17 Canon Flash 580EX CP-E4',1,'AB3313',41.99,'hermeshine','jighairy','frucgiu@comcast.net','Giuseppe Fruci','840 Michigan Ave<br>Apt 3','Evanston','IL','UNITED STATES','60202-2588','','NoPaymentFailure','CheckoutComplete','Other','2010-12-06 21:40:21',0,NULL,5,1,18,0,NULL,'sf17  canon   1 '),(2535,643347698002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','rzanini','zureta@gmail.com','Romulo Zanini de Gouveia Pinto','Rua Quintino Bocaiuva 131 ap. 61','Curitiba','PR','BRAZIL','80035090','55 41 33523731','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 21:53:59',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶   1 \rRR723010376CN\r'),(2536,643375768002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','dragon011','dragon011@worldnet.att.net','Hipolito R Gonzales','6606 Sherman St','Houston','TX','UNITED STATES','77011-3524','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 22:23:04',0,NULL,3,1,1,1,NULL,'90th é•œå¤´ç­’   1 '),(2537,643380230002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','lasseskive','ln@netip.dk','Lars Nielsen','Skolevej 24','HÃ¸jslev','DK','DENMARK','7840','+4551386610','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 22:36:04',0,NULL,3,1,2,1,NULL,NULL),(2538,643386549002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','biasa84','salonnebiancamaria@yahoo.it','BIANCAMARIA SALONNE','VIA BALDARI, 12','LATIANO','BR','ITALY','72022','3403706565','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 22:48:11',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2539,604501261001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','the-intercessor','heytoddman@msn.com','Todd  Almquist','1093-143rd Ave NW','Andover','MN','UNITED STATES','55304','(763) 434-1423','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 23:06:55',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ…   1 '),(2540,604512344001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','pddl2010','uy.pablo@gmail.com','Javier Larramendy','Calle Mozart  Manzana M Solar 28','Villa Foresti, Las Piedras','Canelones','URUGUAY','90200','099639597','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 23:38:41',0,NULL,3,1,3,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ  è€æ¬¾   xxl  1\rRR723010402CN\r'),(2541,604514007001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 23:44:08',0,NULL,8,1,17,0,NULL,NULL),(2542,643409118002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 23:46:13',0,NULL,8,1,17,0,NULL,NULL),(2543,642961056002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','zinabra','mls_so@hotmail.com','Milles GonÃ§alves','Rua AmbirÃ© Cavalcanti 496<br>Rio Comprido','Rio De Janeiro','Rio de janeiro','BRAZIL','20250-490','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 23:49:20',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž    1\rç”³æŠ¥ï¼š gift  $37.9\rRR723010328CN\r'),(2544,604515974001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 23:53:53',0,NULL,8,1,17,0,NULL,NULL),(2545,643410162002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 23:53:54',0,NULL,8,1,17,0,NULL,NULL),(2546,604515432001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 23:53:54',0,NULL,3,1,3,1,NULL,' 77mm çŽ¯æž¶   2\r67mm çŽ¯æž¶  1\r52mm çŽ¯æž¶  1\rCPL    1\rND2/4/8    1\ræ¸å˜ç°   1\rRR723010314CN\r'),(2547,604519572001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','juanan.ramirez','juan-antonio.ramirez@vodafone.com','Juan Antonio Ramirez Quintero','San Bartolome 9, 3 B','Malaga','Andalucia Ceuta y Melilla','SPAIN','29013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 00:02:38',0,NULL,3,1,2,1,NULL,NULL),(2548,604531997001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','mafiacream','lord@eakom.com','Mabanza Ma-luvuezo','Route de Chavannes 123','Lausanne','','SWITZERLAND','1007','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 00:42:41',0,NULL,3,1,4,1,NULL,'tripod dolly  $20 \rYW864143801CN\r\r'),(2549,604550712001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',3.79,'hermeshine','jorge-o','ochavo-57@gmx.es','jorge ochavo muÃ±oz','avda badalona 8 atico 2<br>mollet del valles','barcelona','CataluÃ±a','SPAIN','08100','935935899','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 01:45:50',0,NULL,3,1,2,1,NULL,NULL),(2550,603472463001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',61.68,'hermeshine','marz520','mmarziotto@gmail.com','Michael Marziotto','The Financial Center At Woodbury<br>80 Crossways Park Dr W','Woodbury','NY','UNITED STATES','11797-2000','(516) 677-6270','NoPaymentFailure','CheckoutComplete','Other','2010-12-07 02:14:47',0,NULL,3,1,4,1,NULL,'æ–œè‡‚  1\råå…‰æ¿æ”¯æž¶   1 \r77mm æ©¡èƒ¶ç½©   1\rYW864143646CN\rboom arm  $18'),(2551,602803449001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','wavesonstn','rdrstnrit1945@yahoo.com','Stanley Ritterbach','20763 Syracuse Ave','Warren','MI','UNITED STATES','48091-2820','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 02:38:05',0,NULL,3,1,1,1,NULL,NULL),(2552,643468385002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','michelle_rk','michelle_rk@hotmail.com','Michelle Keith','2 E Walnut St','Washington','IN','UNITED STATES','47501-2785','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 02:45:56',0,NULL,3,1,1,1,NULL,NULL),(2553,700183741015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'',5.88,'hutongstore','sharonk100','skelly100@live.co.uk','Sharon Kelly','100 Glenrandel','Eglinton','Londonderry','UNITED KINGDOM','BT47 3XW','02871812068','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-07 02:51:57',0,NULL,3,1,2,1,NULL,'60cm 2in1   åå…‰æ¿   1 '),(2554,604599820001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','c-photo','cphoto@gmail.com','Christophe Testi','1048 Petie Way','Mountain View','CA','UNITED STATES','94040-3128','(650) 823-2706','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 04:44:26',0,NULL,3,1,1,1,NULL,NULL),(2555,604602240001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','spacec21','spacec21@hotmail.com','Shanon Hong','Unit B - 4th street nw<br>PO Box 1143','Nakusp','BC','CANADA','V0G 1R0','(250) 265-4354','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 04:53:31',0,NULL,3,1,2,1,NULL,NULL),(2556,643504037002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','spacec21','spacec21@hotmail.com','Shanon Hong','Unit B - 4th street nw<br>PO Box 1143','Nakusp','BC','CANADA','V0G 1R0','(250) 265-4354','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 04:53:31',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ… nikon   1\réº‚çš®   1 '),(2557,604606725001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','gotdane','c_james3@hotmail.com','Christy Saint','2924 Canna St','thousand Oaks','CA','UNITED STATES','91360','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 05:17:56',0,NULL,3,1,1,1,NULL,NULL),(2558,643511446002,120605577790,'New thicken Non Woven Fabric Backdrop 3m x 2m(10 x7 ft)',1,'AO0018',35,'hermeshine','leclick','misscream@live.com','Rebecca Cream','147 St. Mary\'s Street','Fredericton','NB','CANADA','E3A2S1','(506) 260-3414','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 05:31:18',0,NULL,3,1,3,1,NULL,'ç™½è‰²ï¼ŒåŽšçš„èƒŒæ™¯å¸ƒ  3mx2m  1 RR723010699CN'),(2559,604617827001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',2,'AA2101',70,'hermeshine','fun2vy10','fun2vy@hotmail.com','Vy Mac','9203 39th Ave S','Seattle','WA','UNITED STATES','98118-4826','(206) 992-5886','NoPaymentFailure','CheckoutComplete','Other','2010-12-07 06:24:45',0,NULL,3,1,3,1,NULL,'è€æ¬¾èƒŒå¿ƒ  nikon  L   2 \rRR723010637CN\r'),(2560,643524861002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','pau1600','au.pinky@gmail.com','Pinky Au','1118 West 48th Ave','Vancouver','BC','CANADA','V6M 2N5','(604) 760-6889','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 06:46:00',0,NULL,3,1,2,1,NULL,NULL),(2561,643530975002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','phongd','phongacn@gmail.com','Phong Dang','11624 SE 223rd Dr','Kent','WA','UNITED STATES','98031-2398','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 07:22:35',0,NULL,3,1,1,1,NULL,NULL),(2562,604636574001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',3,'AE1301',29.4,'hermeshine','balbirrichi','balbirsinghrishi@hotmail.com','Balbir Singh Rishi','218  Richvale Dr. South,','Brampton','ON','CANADA','L6Z 4W2','(905) 495-0321','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 08:10:01',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹äº‘å°   3 \rRR723010645CN\r'),(2563,643466703002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','ludolilian','labouillette42@hotmail.fr','ludovic pivot','16 rue de l hotel de ville','le donjon','Auvergne','FRANCE','03130','0470995357','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 08:34:20',0,NULL,8,1,17,0,NULL,' '),(2564,604542197001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','ludolilian','labouillette42@hotmail.fr','ludovic pivot','16 rue de l hotel de ville','le donjon','Auvergne','FRANCE','03130','0470995357','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 08:34:21',0,NULL,8,1,17,0,NULL,NULL),(2565,643438528002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',87.8,'hermeshine','ludolilian','labouillette42@hotmail.fr','ludovic pivot','16 rue de l hotel de ville','le donjon','Auvergne','FRANCE','03130','0470995357','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 08:34:21',0,NULL,8,1,17,0,NULL,NULL),(2566,604542948001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','ludolilian','labouillette42@hotmail.fr','ludovic pivot','16 rue de l hotel de ville','le donjon','Auvergne','FRANCE','03130','0470995357','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 08:34:22',0,NULL,3,1,4,1,NULL,'301p ä¸€æ‹–ä¸‰   1\r 2m ç¯æž¶  3\räº‘å°   3\ræŸ”å…‰ä¼ž   3\r\r2mx3m èƒŒæ™¯æž¶    1\rlight kit  $25\rYW864143613CN\r'),(2567,643546250002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','arvin2k','arvin@nissan.com.sa','Arvin Biscarra','Alhamrani Trading & Import Co. - Nissan<br>Al Ahsa St., PO Box 2745','Riyadh','Malaz','SAUDI ARABIA','11461','0532124561','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 08:42:44',0,NULL,3,1,2,1,NULL,NULL),(2568,604645027001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','adamnguyen','shushilov3r@gmail.com','Adam T. Nguyen','811 Seabrook ct','San Jose','CA','UNITED STATES','95111-1410','(408) 896-7794','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 08:54:58',0,NULL,3,1,1,1,NULL,NULL),(2569,604666527001,110583278199,'TianYa 58mm CPL filter New 58 Circular Polarizing C-PL',1,'AA2303',5.9,'hermeshine','marovilya','ilyamarov@gmail.com','Ilya Marov','Matrosova str, 6, 18','Nekrasovskoe','Yaroslavskaya oblast','RUSSIAN FEDERATION','152260','+79159857562','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 10:19:34',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯ 58mm cpl   1 '),(2570,604749472001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','mloup','mirek.loup@gmail.com','Miroslav Loup','Reklama Kubicek, spol. s r.o.<br>Francouzska 81','Brno','','CZECH REPUBLIC','602 00','00420739229010','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 15:00:14',0,NULL,3,1,2,1,NULL,NULL),(2571,643660435002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dest6001ad59981','dest6001ad@gmail.com','Mohamed Yusri  Abdul Wahab','Blk 805 yishun ring road<br>#08-4279','Singapore','Singapore','SINGAPORE','760805','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 15:13:41',0,NULL,3,1,11,1,NULL,NULL),(2572,604755664001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','jabr9677','real3550@gmail.com','joao abreu','15, ivatt place<br>west kensington','london','London','UNITED KINGDOM','w149nq','07939664372','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 15:19:56',0,NULL,3,1,3,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ  M   1 RR723010671CN'),(2573,700435832015,250619800184,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'',39,'hutongstore','atieayus','yatie_musm02@yahoo.com','Mohd Fairus Ahmad','18th Floor, Menara Boustead 69, Jalan Raja Chulan','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','50200','0169274852','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-07 15:50:37',0,NULL,3,1,6,1,NULL,'æ–°åŠ å¡EMS\rEX000344200SG'),(2574,686878334016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'',2.52,'hutongstore','krolis007','svetlank@post.skynet.lt','Rolandas Kubilinskas','Staneviciaus 4-48','Vilnius','','LITHUANIA','LT-07129','(370)60029277','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-07 15:56:17',0,NULL,3,1,2,1,NULL,NULL),(2575,643702793002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.5,'hermeshine','photomanglen','glensphotos@webtv.net','Glen Lipton','7929 Nagle Ave','North Hollywood','CA','UNITED STATES','91605-1708','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 16:49:18',0,NULL,3,1,1,1,NULL,NULL),(2576,643704397002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','wlfranz','wlfranz@aol.com','William L. Franz','17 Lonsdale Ave','Dayton','OH','UNITED STATES','45419-3143','(937) 298-9780','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 16:59:57',0,NULL,3,1,1,1,NULL,NULL),(2577,643730746002,120500417599,'62mm CPL Circular Polarizing Filter 62 CPL Green.L ',10,'AA3311',56,'hermeshine','1imagen','imaklos@hotmail.com','Manuel','Avenida Derechos Humanos 28 - Rdcia.Los sauces 10','Laredo','Cantabria','SPAIN','39770','942611010','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 17:47:10',0,NULL,3,1,3,1,NULL,'RR723010708CN '),(2578,643739991002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','clemen2002','find_ir@hotmail.com','Clement Auo','25 Kovan Road #12-21<br>Kovan Melody','Singapore','','SINGAPORE','545024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 18:04:26',0,NULL,3,1,11,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2580,700526157015,250634555406,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'',2.75,'hutongstore','nikiforosgt','nikiforosgt@yahoo.gr','NIKIFOROS MANOLAS','BOMOY 13, KYPSELI, KYPSELI KYPSELI','ATHENS','','GREECE','11364','6972740952','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-07 18:27:10',0,NULL,3,1,2,1,NULL,'sonyçº¢å¤–   1 '),(2581,686992368016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',38,'hutongstore','benbammens','ben.bammens@telenet.be','Ben Bammens','Bosstraat 51','Hasselt','','BELGIUM','3500','0485730363','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-07 19:14:46',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶   1 \rreflector holder  $18\rYW864143635CN\r'),(2582,643780524002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','liongkoen','koen.liem@hccnet.nl','Koen Liem','Engelenburg 277','HAARLEM','','NETHERLANDS','2036RJ','0638515333','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 19:15:38',0,NULL,3,1,2,1,NULL,'6662a å¿«è£…æ¿   1 '),(2583,700564409015,250692237477,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'',15.5,'hutongstore','thecuestick','kelsey_colin@yahoo.co.uk','colin kelsey','8 orchard grove','diss','norfolk','UNITED KINGDOM','ip224lx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-07 19:19:05',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´  è‹±æ ‡   2 '),(2584,643783791002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','topcat999','tcip@att.net','Thomas D. Cipriano','3527 Oleander Ave','Alameda','CA','UNITED STATES','94502','(510) 865-2133','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 19:21:32',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2586,604903857001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','anton.kovalev','aykovalev@gmail.com','Anton Kovalev','Yubileynaya str. 12 apartment 206','Serpukhov','Moscow','RUSSIAN FEDERATION','142204','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 20:15:01',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ï¼ˆç™½ï¼‰1\r2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡   2\r115w 220v   2\råŒ…    1 \rCP212330985CN\r'),(2587,643771299002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','osmanoz26','osman.ufukecz@gmail.com','osman oz','sair fuzuli cad.no:27/a ufuk eczanesi','eskisehir','eskisehir','TURKEY','26010','+90 532 2710892','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 21:17:41',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶  ï¼ˆ ç™½ï¼‰   1\rCP212330999CN '),(2588,643904755002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','heliogas17','helio_rogerio@hotmail.com','HÃ©lio Lopes','Rua Padre AntÃ³nio Vieira nÂº12 1Âº andar','Rio Tinto','Rio Tinto/Gondomar/Porto','PORTUGAL','4435-370','+351916699358','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 23:19:09',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2589,643909444002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','nickip911','nperi816@gmail.com','Nick Peri','PO Box 233<br>2749 Chestnut St.','York','NY','UNITED STATES','14592-0233','(585) 991-9880','NoPaymentFailure','CheckoutComplete','Other','2010-12-07 23:25:00',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 RR723010756CN'),(2590,643910344002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','carloslzf','carlosliu913@gmail.com','Zhifeng Liu','54 Compton Street<br>Hillcrest','Auckland','','NEW ZEALAND','0627','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 23:25:03',0,NULL,8,1,17,0,NULL,NULL),(2591,643910334002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',3.55,'hermeshine','carloslzf','carlosliu913@gmail.com','Zhifeng Liu','54 Compton Street<br>Hillcrest','Auckland','','NEW ZEALAND','0627','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 23:25:04',0,NULL,3,1,2,1,NULL,'72mm æŽ¥å£çŽ¯  1\rå¹¿è§’æ‰˜æž¶    1 '),(2592,605009114001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1309',7.4,'hermeshine','mirare202','mariana_harsan@yahoo.com','Mariana Harsan','7717 rowan ct','annandale','VA','UNITED STATES','22003','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 00:11:48',0,NULL,3,1,1,1,NULL,NULL),(2593,643938729002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','ralphsworldtour','worldcup2006@verizon.net','Ralph Rodriguez','12654 Izetta Ave','downey','CA','UNITED STATES','90242-4942','(562) 382-7240','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 00:57:57',0,NULL,3,1,1,1,NULL,NULL),(2594,643956963002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','jakubch88','info@jakubchrudina.eu','Jakub Chrudina','Matuskova<br>8','Havirov','Okres Karvina, Moravskoslezsky kraj','CZECH REPUBLIC','73601','608447543','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 01:51:02',0,NULL,8,1,17,0,NULL,NULL),(2595,605036726001,110486687213,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','jakubch88','info@jakubchrudina.eu','Jakub Chrudina','Matuskova<br>8','Havirov','Okres Karvina, Moravskoslezsky kraj','CZECH REPUBLIC','73601','608447543','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 01:51:02',0,NULL,8,1,17,0,NULL,NULL),(2596,605033511001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','jakubch88','info@jakubchrudina.eu','Jakub Chrudina','Matuskova<br>8','Havirov','Okres Karvina, Moravskoslezsky kraj','CZECH REPUBLIC','73601','608447543','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 01:51:03',0,NULL,8,1,17,0,NULL,' '),(2597,605033753001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','jakubch88','info@jakubchrudina.eu','Jakub Chrudina','Matuskova<br>8','Havirov','Okres Karvina, Moravskoslezsky kraj','CZECH REPUBLIC','73601','608447543','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 01:51:03',0,NULL,8,1,17,0,NULL,NULL),(2598,605036805001,110531023633,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','jakubch88','info@jakubchrudina.eu','Jakub Chrudina','Matuskova<br>8','Havirov','Okres Karvina, Moravskoslezsky kraj','CZECH REPUBLIC','73601','608447543','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 01:51:04',0,NULL,3,1,3,1,NULL,'58mm çŽ¯æž¶   2\ræ¸å˜è“  1\ræ¸å˜æ£•   1\ræ¸å˜ç°   1RR723010739CN\r '),(2599,643961275002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','u8ey','adsl9lyi@tpg.com.au','Dave Tease','9 Boundary rd','Windang','New South Wales','AUSTRALIA','2528','0242954140','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 02:02:46',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 RR723010742CN'),(2600,605047356001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','rchall23','rchall242@hotmail.com','Robert Hall','3421 W Village Grove Pl<br>Apt 4','Memphis','TN','UNITED STATES','38115','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 02:29:25',0,NULL,3,1,1,1,NULL,NULL),(2601,643972991002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','roshan517','patelro@msu.edu','Roshan patel','6532 spring brook road<br>apt302','rockford','IL','UNITED STATES','61114','(517) 388-0895','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 02:41:50',0,NULL,3,1,1,1,NULL,NULL),(2602,643978284002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','605ranger','stevie605@hotmail.com','steven ontaneda','349 NE 33rd St<br>Apt 1','miami','FL','UNITED STATES','33137-4047','(954) 593-7837','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 02:55:08',0,NULL,3,1,1,1,NULL,NULL),(2603,643978767002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','dooglestar88','laetitia@songololochildren.com','Laetitia H Casta c/o Liam O\'Prey','Plaza Lesseps 11<br>6Âº 1Âª','Barcelona','CataluÃ±a','SPAIN','08023','670357375','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 02:57:15',0,NULL,3,1,4,1,NULL,'ballhead $20 \rYW864143370CN'),(2604,605056745001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','wilsonpazos','wilsonpazos@hotmail.com','Wilson Pazos','Ekkodalen 16 2.tv','Aarhus','Danmark','DENMARK','8210','004528814877','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,NULL),(2605,643628026002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','kingzazza','sizolee@gmail.com','SisÃ¡k ZoltÃ¡n','KecskemÃ©ti Ã. u. 2. 1/1','MakÃ³','','HUNGARY','6900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 06:50:02',0,NULL,3,1,2,1,NULL,NULL),(2606,644034026002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','amstel00','ndongo@gmail.com','ANA VERONICA NDONGO BINDANG','C/SIERRA DE LOS FILABRES 48<br>1Âº A','MADRID','Madrid','SPAIN','28038','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 07:11:33',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´  æ¬§æ ‡   1 '),(2607,604936725001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',709.17,'hermeshine','mr0mer','tuzakk@gmail.com','Ã–MER GÃœNGÃ–R','Zumrutevler Mh. Ugral Sk. Altinsoy Is Merkezi No:14/3 Maltepe','Istanbul','','TURKEY','34852','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 07:27:39',0,NULL,3,1,6,1,NULL,'800w çº¢å¤´ç¯   2\rçº¢ç›’ç¯æž¶  2\r800w 220v ç¯æ³¡   5\r6663a   1\rwt600   1\r2mx3m èƒŒæ™¯æž¶   1\r2m ç¯æž¶  2\råŒç¯å¤´  æ¬§æ ‡   2\råå…‰ä¼ž   2\r10ç‰‡è£…  + 58mm çŽ¯æž¶   1\ré˜²é›¨ç½©   1\r115w  220v   2\r110cm 5in1 åå…‰æ¿  1\rEX000344213SG'),(2609,605111000001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','topcat999','tcip@att.net','Thomas D. Cipriano','3527 Oleander Ave','Alameda','CA','UNITED STATES','94502','(510) 865-2133','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 07:34:35',0,NULL,3,1,1,1,NULL,NULL),(2610,605117600001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',4,'AA1204',6.46,'hermeshine','strafel67','strafel@cox.net','Robert Strafeldas','85 Northern Pine Loop','Aliso Viejo','CA','UNITED STATES','92656','(949) 215-9145','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 08:08:46',0,NULL,3,1,1,1,NULL,NULL),(2611,605131489001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',9.8,'hermeshine','liveoakbob','bobyount@sbcglobal.net','Robert Yount','3400 Portola Dr<br>Apt 9','Santa Cruz','CA','UNITED STATES','95062-5137','(831) 479-4734','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-08 09:13:52',0,NULL,3,1,1,1,NULL,' '),(2612,605132400001,110469599322,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',24.99,'hermeshine','alien5651','allan5651@hotmail.com','Allan Bailey','18 Pioneer Drive<br>Narangba','Brisbane','Queensland','AUSTRALIA','4504','0733856654','NoPaymentFailure','CheckoutComplete','AU_Regular','2010-12-08 09:18:27',0,NULL,8,1,17,0,NULL,NULL),(2613,605132217001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','alien5651','allan5651@hotmail.com','Allan Bailey','18 Pioneer Drive<br>Narangba','Brisbane','Queensland','AUSTRALIA','4504','0733856654','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 09:27:56',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´   æ¾³æ ‡  1\r45w   2 \rRR723010929CN'),(2615,604839908001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',4,'AE1302',43.2,'hermeshine','luizprettif','luizprettif@gmail.com','Luiz Pretti Filho','Estrada do Limoeiro, 500<br>Limoeiro','Aruja','SÃ£o Paulo','BRAZIL','07400-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 10:08:07',0,NULL,3,1,3,1,NULL,'å•ç¯å¤´ 4 \rRR723015078CN'),(2616,644085101002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','slartiii','ofer.maor@gmail.com','Ofer Maor','1 Moshe Vilensky St.','Tel Aviv','','ISRAEL','69623','054-6545406','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 10:52:34',0,NULL,3,1,2,1,NULL,NULL),(2617,687357169016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','dfleed74','harlock.arcadia@tin.it','Giuseppe Mirabile','Via Roma 283','Barcellona Pozzo di Gotto','ME','ITALY','98051','3490069162','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 10:59:23',0,NULL,8,1,17,0,NULL,NULL),(2618,687358369016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'',3.5,'hutongstore','dfleed74','harlock.arcadia@tin.it','Giuseppe Mirabile','Via Roma 283','Barcellona Pozzo di Gotto','ME','ITALY','98051','3490069162','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 11:02:22',0,NULL,3,1,2,1,NULL,'Lenspen  1\ræ°”å¹+å¸ƒ   1 '),(2619,644133919002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','mtbguy','anhvudo@hotmail.com','Anhvu Do','5761 Lake Melrose Dr','Orlando','FL','UNITED STATES','32829-7690','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-08 13:30:59',0,NULL,3,1,1,1,NULL,NULL),(2620,605178631001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',20.99,'hermeshine','jalanen','jani.alanen@pp.inet.fi','Jani Alanen','Possilanrinne 6 B','Tampere','','FINLAND','33400','+358400867241','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 13:37:56',0,NULL,3,1,3,1,NULL,'RR723015081CN '),(2621,605249495001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','veraz7','veraz7@hotmail.com','Juan RamÃ³n Reina Vera','c/ Camino Nuevo, 23','MÃ¡laga','AndalucÃ­a Ceuta y Melilla','SPAIN','29500','669335742','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 15:36:50',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723015095CN'),(2622,605246053001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','oles771','ovsjak@ukr.net','Oleksandr Ovsjak','Skrypnika 31a/49','Lviv','ua','UKRAINE','79049','380971101090','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 15:37:57',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723015104CN'),(2623,605256559001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','veraz7','veraz7@hotmail.com','Juan RamÃ³n Reina Vera','c/ Camino Nuevo, 23','MÃ¡laga','AndalucÃ­a Ceuta y Melilla','SPAIN','29500','669335742','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 15:55:07',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚   1 \rlight stand  $18\rYW863884753CN\r'),(2624,644188667002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','rocter1963','razvodovskij@gmail.com','Sergej Razvodovskij','Cialkovska 14-41','Daugavpils','','LATVIA','LV-5410','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 15:55:09',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´æ£š   2 æ¬§æ ‡  \r45w  8\råŒ…   1 \rCP212331005CN\r'),(2625,644209987002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','om-mariam','zbon_draz@yahoo.com','Fatemah Alhusayni','446 Blue Course Dr<br>Apt 1001','State College','PA','UNITED STATES','16803-2872','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 16:43:28',0,NULL,3,1,1,1,NULL,NULL),(2626,644220044002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','zara.warthog','robin.lake@mbnl.co.uk','Robin lake','44 Knox Road','Guildford','Surrey','UNITED KINGDOM','GU2 9AH','01483826827','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 17:01:35',0,NULL,3,1,2,1,NULL,NULL),(2627,605290079001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11,'hermeshine','mikey-fisher','michael.madio@gmail.com','Michael Madio','40 SPRUCE BLVD','ACTON','ON','CANADA','L7J 2Y2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 17:07:49',0,NULL,3,1,2,1,NULL,NULL),(2628,701110317015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','flpicuser072009','flfonseca.pro@gmail.com','Fernando Fonseca','970 Cumbernauld Road','Riddrie','Glasgow (City of)','UNITED KINGDOM','G33 2QR','01417701651','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-08 17:36:55',0,NULL,3,1,2,1,NULL,NULL),(2629,699987787015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','shellysherring','shelly_harrell@msn.com','Shelly Herring','8245 Sawyer Mill Cv','Arlington','TN','UNITED STATES','38002-8361','(901) 734-3676','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-08 17:48:40',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\r50-70æ£š   2\r115w 110v   2\råŒ…    1 \rlighting kit  $32\rYW863884764CN\r'),(2630,687547354016,260660056537,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'',2.4,'hutongstore','slhpokey69','pokey69@hotmail.co.uk','Stacey Hughes','18 Ripon Road','Stevenage','Hertfordshire','UNITED KINGDOM','SG1 4LY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-08 18:02:50',0,NULL,3,1,2,1,NULL,NULL),(2631,701133643015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','nedproductions','s_ebay@nedproductions.biz','ned Productions Limited','12 Woodlands','Kerry Pike','Cork','IRELAND','default','0214872739','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 18:21:34',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å›› ç¯å¤´   1 '),(2632,644263869002,120601698401,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','fredy_declercq','fredy_declercq@uol.com.br','Frederic Declercq','Rua Doutor JosÃ© Gustavo Bush 155<br>apart.: 101-A  bairro:Morumbi','SÃ£o Paulo','SP','BRAZIL','05705-190','+55-11-96257763','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 18:25:11',0,NULL,3,1,2,1,NULL,NULL),(2633,605207878001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','thomthomtreasures','cultho@yahoo.com','Thomas Cullum','2348 Hillcrest Rd','York','SC','UNITED STATES','29745-9309','(803) 684-5530','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 18:44:10',0,NULL,3,1,1,1,NULL,NULL),(2634,701108504015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'',26.56,'hutongstore','pea11','fotomalheiros@gmail.com','vitor malheiros','rua do ouro 11 Atouguia da baleia','Atouguia da Baleia','Penicha','PORTUGAL','2525-058','00351938360399','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 18:54:57',0,NULL,8,1,17,0,NULL,NULL),(2635,701112799015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'',22,'hutongstore','pea11','fotomalheiros@gmail.com','vitor malheiros','rua do ouro 11 Atouguia da baleia','Atouguia da Baleia','Penicha','PORTUGAL','2525-058','00351938360399','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 18:54:58',0,NULL,8,1,17,0,NULL,NULL),(2636,687537922016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'',43.8,'hutongstore','pea11','fotomalheiros@gmail.com','vitor malheiros','rua do ouro 11 Atouguia da baleia','Atouguia da Baleia','Penicha','PORTUGAL','2525-058','00351938360399','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 18:54:57',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶   1\ræ–œè‡‚   1\r100-150 5in1 åå…‰æ¿   1\rä¸€ç¥¨ä¸¤ä»¶ \rlight kit $25\rYW863884775CN\r\r'),(2637,605407103001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','bolty1969','adambolt@hotmail.com','Adam Bolt','7 Georgia St','Coombabah','Queensland','AUSTRALIA','4216','0755015159','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 20:37:18',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR723015016CN'),(2638,605445023001,110562231928,'Camera shoulder bag nova 4 with raincover 4 D300s D700',1,'AO0025',40.99,'hermeshine','jumiroc','jumiroc@gmail.com','Juan M.  Roca Ripoll','Av. Argentina, 8, 1Âº, A','Palma de Mallorca','Baleares','SPAIN','07011','971288891','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 21:39:13',0,NULL,3,1,3,1,NULL,'nikon å•è‚©åŒ…  n4   1 \rRR723015020CN'),(2639,644384211002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','bogopolsky1','bog.vadim@gmail.com','vad bogopolsky','motzkin 21 ap 10','netanya','israel','ISRAEL','42460','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 21:40:43',0,NULL,5,1,18,0,NULL,NULL),(2640,602314900001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','buycouture4less','sincityphotography@yahoo.com','Leah Seguin','8734 Haviland Rd','Las Vegas','NV','UNITED STATES','89123-0188','(702) 581-1075','NoPaymentFailure','CheckoutComplete','Other','2010-12-08 21:55:08',0,NULL,3,1,4,1,NULL,' 2mx3m èƒŒæ™¯æž¶  1\r3m x 6m ç™½è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š   2\r115w 110v   2\råŒ…   1\rlighting kit  $40\rYW864143753CN'),(2641,605460279001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','sabbatha190987','sabbathabali@hotmail.com','Julia Danilenko','Raketnyi Bulvar dom 9, korp. 2, kv. 113','Moscow','Moscow','RUSSIAN FEDERATION','129366','+79100020090','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 22:12:45',0,NULL,3,1,2,1,NULL,NULL),(2642,605469500001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','tresudek','todd@tr1design.net','Todd Resudek','7166 W Custer Ave<br>C423','Lakewood','CO','UNITED STATES','80226','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 22:35:48',0,NULL,3,1,1,1,NULL,NULL),(2643,644404458002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','geeugenia','eugeniaapaula@gmail.com','Eugenia Paula','R aquilino Ribeiro n31  3esq<br>carnaxide','carnaxide','','PORTUGAL','2790-028','00351962054955','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 22:36:58',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ… 1 '),(2644,644412729002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','stgod2010','playwithebay2@gmail.com','Oleg Kirillov','39 Kosmonavtov Street, Apt.90','Korolev','Moskovskaya oblast','RUSSIAN FEDERATION','141080','+79162242040','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 22:45:40',0,NULL,3,1,3,1,NULL,'2mç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1\rRR723015033CN'),(2645,605485494001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','reznik.andrei','reznikandrew@gmail.com','Andrei Reznik','Avshalom Haviv 7/15','Ashqelon','Hadarom','ISRAEL','78642','+972545828707','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 23:19:03',0,NULL,3,1,2,1,NULL,NULL),(2646,605489949001,110534332901,'New Flash Hot Shoe Adapter YN-H3 for Alpha and Minolta',1,'AKT002',7.9,'hermeshine','hugojesussanchez','hugo_jesus2000@yahoo.com.mx','Hugo Jesus','Av. Norte # 100 Edificio 17 Departamento 402 Colonia Pantitlan<br>Delegacion Iztacalco','Mexico','Distrito Federal','MEXICO','08100','01525557006691','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 23:39:24',0,NULL,3,1,2,1,NULL,'sonyçƒ­é´è½¬æ¢å™¨  1 '),(2647,701382462015,250599924001,'New Circular Polarizing C-PL CPL Filters for Cokin P ',1,'',10.99,'hutongstore','pike990_1','miles51@btinternet.com','miles ferrari','14 Quebec Close Cringleford','Norwich','Norfolk','UNITED KINGDOM','NR4 6XU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-09 01:59:05',0,NULL,8,1,17,0,NULL,NULL),(2648,701381913015,250692237994,'New 55mm 55 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','pike990_1','miles51@btinternet.com','miles ferrari','14 Quebec Close Cringleford','Norwich','Norfolk','UNITED KINGDOM','NR4 6XU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-09 01:59:06',0,NULL,3,1,2,1,NULL,'55mm çŽ¯æž¶   1\rcpl    1 '),(2649,644499824002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','tribemark','josephamey@gmail.com','Joe Amey','223 Royal Arms Way','Glen Burnie','MD','UNITED STATES','21061-6249','(410) 977-7132','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-09 03:24:14',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…  1 \rRR723015047CN'),(2650,605559273001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','myrvan_21','djmyrvan_21@hotmail.com','Ivan Urzua','5334 S Laramie Ave','Chicago','IL','UNITED STATES','60638-3044','(773) 251-6010','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 03:46:11',0,NULL,3,1,1,1,NULL,' '),(2651,687862192016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','jwiebe44','jeffwiebe@yahoo.ca','Jeff Wiebe','44 Limetree Cove','Winnipeg','MB','CANADA','R2J 4B4','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 04:36:25',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(2652,644522710002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','sipooh68','linda.mongrain@hotmail.com','Linda Mongrain','9150 de Lunenburg','QuÃ©bec','QC','CANADA','G2B 5R8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 04:43:44',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(2653,605572926001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','brendad1977','brendper@gmail.com','Brenda Dahlseide','Rural Route 3','Barrhead','AB','CANADA','T7N 1N4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 05:14:41',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†nikon   1 '),(2654,701495961015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'',1.88,'hutongstore','maris0007','kosnel@wp.pl','MARIUSZ KOS','56 HAZEL GROVE','WREXHAM','Wrexham','UNITED KINGDOM','LL12 7HA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-09 08:25:00',0,NULL,3,1,2,1,NULL,NULL),(2655,687912624016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','nenad5044','nenad@helpers.hu','Nenad Ignjatovic','Helpers Hungary Kft. RÃ¡day u. 8 I/5  (buzzer/csengÅ‘: 20)','Budapest','Hungary','HUNGARY','1092','+36705926994','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 08:32:00',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(2656,644583313002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','juanjose5593','pernildeldols@hotmail.com','juan jose escortell ibaÃ±ez','marina alta 186, 2Âº piso puerta 4','gata de gorgos (Alicante)','Comunidad Valenciana','SPAIN','03740','653935203','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 09:55:11',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°   1 '),(2657,644595928002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','linusmic','ebay@magnic.com','Linus Mickelsson','Bymossavagen 1a5','Helsingfors','FI','FINLAND','00320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 10:45:04',0,NULL,8,1,17,0,NULL,' '),(2658,644569322002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','guderian233vladimir','guderian233@gmail.com','Vladimir MandiÄ‡','Vilima Korajca 2','PoÅ¾ega','','CROATIA','34000','0038534622389','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 10:47:35',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§    1\ræŸ”å…‰ä¼ž   1 \rRR723015943CN\r'),(2659,605646292001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','linusmic','ebay@magnic.com','Linus Mickelsson','Bymossavagen 1a5','Helsingfors','FI','FINLAND','00320','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 10:58:01',0,NULL,3,1,4,1,NULL,'3m æ¨ªæ†   1\råå…‰æ¿æ”¯æž¶   1 \rYW863884230CN\r\r'),(2660,605602688001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','ellenandedgar','ellerrn@msn.com','Ellen Arkinstall','34 Longboard Circuit','Kingscliff','New South Wales','AUSTRALIA','2487','0266742402','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 11:06:08',0,NULL,3,1,6,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶   2\råŒç¯å¤´  2  æ¾³æ ‡  \råå…‰ä¼ž   2\r45w   4\råŒ…    1\ræ–°åŠ å¡EMS\r EX000334675SG'),(2661,605649755001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',2,'AB1204',34,'hermeshine','thargjunior','algood@iinet.net.au','A L Goodland','P O Box 117<br>North Perth','Perth','Western Australia','AUSTRALIA','6906','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 11:13:13',0,NULL,3,1,3,1,NULL,'717å¿«è£…æ¿   2\rRR723015869CN\r'),(2663,644604850002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','evalara','eva.lcc@gmail.com','EVA MILLAN VALLDEPERAS','ETSI INFORMATICA, BOULEVARD LOUIS PASTEUR 35. CAMPUS DE TEATINOS','Malaga','AndalucÃ­a Ceuta y Melilla','SPAIN','29002','625585032','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 11:20:05',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW863884731CN\r'),(2664,687968595016,260661685518,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'',9.2,'hutongstore','kukomakijuha','juhakari@nic.fi','Juha Kari','Vuorikatu 30 b','Uusikaupunki','Oletus','FINLAND','23500','0443332912','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 11:43:08',0,NULL,3,1,2,1,NULL,'canon å¯¹ç„¦çŽ¯   1 '),(2665,644611983002,120560203215,'Nikon 52mm Reverse Adapter Combined shipping discounts',1,'AA1210',4.4,'hermeshine','jdolan16','jamesrdolan_1992@yahoo.co.uk','James Dolan','11 St Annes Terrace','Bradford, Shipley','West Yorkshire','UNITED KINGDOM','BD176PR','01274597358','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 11:44:55',0,NULL,3,1,2,1,NULL,'nikon 52mm åæŽ¥çŽ¯   1 '),(2666,644613895002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','t_baunkjaer','t_baunkjaer@hotmail.com','Thomas BaunkjÃ¦r','MatthÃ¦usgade 48c, 4., 418','Copenhagen V','Denmark','DENMARK','1666','51262819','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 11:52:02',0,NULL,3,1,2,1,NULL,NULL),(2667,644613991002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','michaelesh8u43','michaelesh@comcast.net','Michael Esh','631 Springville Rd','New Holland','PA','UNITED STATES','17557-9561','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 11:52:42',0,NULL,3,1,1,1,NULL,NULL),(2668,605664441001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',3,'AA1311',12.57,'hermeshine','pinto.35','sales@vault35.com','Pontus Perhamn','Adelgatan 3','Nybro','Sweden','SWEDEN','382 32','0738437559','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 12:04:49',0,NULL,3,1,2,1,NULL,'æ°”å¹+å¸ƒ    3 '),(2670,701571581015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','ashallen1','ashallen@gmx.com','Ash Allen','746 Fishponds Road Fishponds','Bristol','Avon','UNITED KINGDOM','bs163ua','07545216767','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-09 12:28:38',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon    1 '),(2671,644236103002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 13:13:08',0,NULL,8,1,17,0,NULL,NULL),(2672,644669712002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 14:46:27',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\rbåº§   2\ræŸ”å…‰ä¼ž    2 \rlight stand  $22\rYW863884241CN\r'),(2673,605729066001,110533631413,'CTR-301P Flash Trigger Kit with 2 Receivers ctr301p',1,'AKT001',41.9,'hermeshine','dsch1085','dschank9200@att.net','Donna Schank','653 Silver Fox Ct','Indianapolis','IN','UNITED STATES','46217','(317) 362-9200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-09 15:27:21',0,NULL,3,1,1,1,NULL,'301p ä¸€æ‹–äºŒ   1 '),(2674,701639713015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','xsnicholas','xsnicholas@hotmail.com','Nicholas J K Ang','Blk 107,Tampines St 11, #05-355','Singapore','Singapore','SINGAPORE','521107','+65 93898481','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 15:29:16',0,NULL,8,1,17,0,NULL,NULL),(2675,701638676015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'',1.88,'hutongstore','xsnicholas','xsnicholas@hotmail.com','Nicholas J K Ang','Blk 107,Tampines St 11, #05-355','Singapore','Singapore','SINGAPORE','521107','+65 93898481','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 15:29:17',0,NULL,3,1,11,1,NULL,'77mm é•œå¤´ç›–  canon  1\r67mm é•œå¤´ç›–   canon   1 '),(2677,644693456002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','motonany','pasha70@comcast.net','Shaul Anbinder','317 Timber Hill rd','Buffalo Grove','IL','UNITED STATES','60089','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 15:50:07',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡   1 '),(2678,644484923002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','oncatca','oncatca@hotmail.com','NAMJONG LEE','2911 BAYVIEW AVE. 117E','NORTH YORK','ON','CANADA','M2K 1E8','(416) 886-8860','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 16:38:25',0,NULL,3,1,3,1,NULL,'717æ‰‹æŸ„   1 \rRR723015957CN\r'),(2679,644724501002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','xb0129','xb0129@gmail.com','XU BIN','PTE.150 No.842<br>COL.INDUSTRIAL VALLEJO','AZCAPOTZALCO','Distrito Federal','MEXICO','02300','0052-5557377208','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 17:00:53',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2680,605784665001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','hiflyer2007','ebay2007@prointernet.ca','Jim Whitesell','c/o McBain Camera<br>1982 - 8882 170 ST','Edmonton','AB','CANADA','T8N 5E9','(780) 690-5615','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 17:42:37',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´   1 '),(2681,701714407015,250599932668,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'',41,'hutongstore','suprat_7m','jcause@live.com','James Cause','Unit  2 / 5  Flinders Street','Taree','New South Wales','AUSTRALIA','2430','0265538332','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 17:47:23',0,NULL,3,1,3,1,NULL,'10ç‰‡è£…   +58mm çŽ¯æž¶   1 \rRR723015529CN'),(2682,644753373002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','compilog','iromeo77@ya.ru','Roman Ivlev','Kronverskiy pr., d.59, kv.30','Saint-Petersburg','','RUSSIAN FEDERATION','197198','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 18:11:06',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2683,605807949001,110566020134,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',3.55,'hermeshine','adro3429','alland@pacific.net','Allan Droyan','445 N Harold St','Fort Bragg','CA','UNITED STATES','95437-3305','(707) 964-2130','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 18:31:17',0,NULL,8,1,17,0,NULL,NULL),(2684,644770252002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','adro3429','alland@pacific.net','Allan Droyan','445 N Harold St','Fort Bragg','CA','UNITED STATES','95437-3305','(707) 964-2130','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 18:34:38',0,NULL,3,1,1,1,NULL,'72mm æŽ¥å£çŽ¯   1\rå¹¿è§’æ‰˜æž¶    1 '),(2685,605813570001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','bmeeler','bmeeler@gmail.com','Brock Meeler','339 Rhine Avenue','Wynne','AR','UNITED STATES','72396','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 18:51:00',0,NULL,3,1,1,1,NULL,'ä¸€è½¬å››ç¯å¤´   1 '),(2686,688211051016,260646700576,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'',54.5,'hutongstore','cfb700','cuentadecarlos@yahoo.es','Carlos Fernandez','Fernando el Catolico, 55-4Âº izda','Zaragoza','Zaragoza','SPAIN','50006','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-09 19:56:11',0,NULL,3,1,4,1,NULL,'tripod  $22 \rYW863884263CN\r'),(2687,644854649002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','iamtorpe','manuelhigueras@gmail.com','manuel higueras garcia','reina sofia, 10','los villares, jaen','AndalucÃ­a Ceuta y Melilla','SPAIN','23160','953323199','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 21:01:50',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW863884274CN\r'),(2688,701865712015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','ibisabelle','isa.vgl@gmail.com','bertrand maquin','5 rue trieu maquette','sirault','','BELGIUM','7332','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 21:29:42',0,NULL,3,1,2,1,NULL,NULL),(2689,603083511001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',35.2,'hermeshine','ursadoc','galb1@bellsouth.net','paulette L. Foster-galbraith','4806 Jefferson Ave','Gulfport','MS','UNITED STATES','39507','(228) 831-1988','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 22:06:51',0,NULL,3,1,1,1,NULL,'52mm é•œå¤´ç›–   nikon   10\rlenspen    2 '),(2690,605931125001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','mkkknana','bay_666@hotmail.com','Helena Maria GonÃ§alves','Av Angelo Rivelli 820<br>Jardim da Fonte','Jundiai','SÃ£o Paulo','BRAZIL','13216300','45873121','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 22:23:32',0,NULL,3,1,2,1,NULL,'nikon 52mm åæŽ¥çŽ¯   1 '),(2691,644907584002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','gromov.a','post.gromov@gmail.com','Alexey Gromov','Kolomenskaya naberezhnaya, dom 6, kv 938','Moscow','','RUSSIAN FEDERATION','115142','(495)9435600','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 22:54:18',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ N1   1 '),(2692,644911191002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','zinabra','mls_so@hotmail.com','Milles GonÃ§alves','Rua AmbirÃ© Cavalcanti 496<br>Rio Comprido','Rio De Janeiro','Rio de janeiro','BRAZIL','20250-490','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 23:11:32',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR723015930CN\r'),(2693,605953490001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','cmilitao','celsomilito@yahoo.com.br','Celso MilitÃ£o dos Santos','Rua PanamÃ¡, 59<br>Vila Brasil','Londrina','ParanÃ¡','BRAZIL','86010300','43 3321-5495','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 23:25:30',0,NULL,3,1,2,1,NULL,NULL),(2694,644920563002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','photofan66','photofan66@hotmail.com','Blane Becker','302 E Oak St','Algona','IA','UNITED STATES','50511','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 23:29:55',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2695,644922467002,120560203167,'77mm Lens lenscap for Canon Combined shipping discounts',2,'AA1304',5,'hermeshine','09klaasjan','kjschraa@gmail.com','Klaas Jan Schraa','Slingerbeek 21','ZWARTSLUIS','','NETHERLANDS','8064JE','06-10657474','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 23:40:25',0,NULL,8,1,17,0,NULL,NULL),(2696,605957420001,110523102217,'67mm Lens lenscap for Canon Combined shipping discounts',1,'AA1302',2.6,'hermeshine','09klaasjan','kjschraa@gmail.com','Klaas Jan Schraa','Slingerbeek 21','ZWARTSLUIS','','NETHERLANDS','8064JE','06-10657474','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 23:40:27',0,NULL,3,1,2,1,NULL,'77mm é•œå¤´ç›–  canon   2\r67mm é•œå¤´ç›–  canon   1 '),(2697,605415531001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','momx3black','jdtrblack4@aol.com','Jami Black','21032 Al Highway 10','Thomasville','AL','UNITED STATES','36784-3948','(334) 992-5979','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 00:07:36',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(2698,605967783001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','gerty-dreamer','h_ohtsu@ma.net3-tv.net','Kouhei Ohtsu','513, Kami-Umesawa','Namerikawa-shi','Toyama','JAPAN','936-0853','(090)8094-1071','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 00:11:57',0,NULL,3,1,2,1,NULL,NULL),(2699,642889662002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','sanlah','sandra.lahna@hotmail.com','Sandra Lahnalampi','Gustaf bergs vÃ¤g 17A','TÃ¤by','SD','SWEDEN','18370','+46738064469','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 01:07:21',0,NULL,3,1,2,1,NULL,NULL),(2700,605988476001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',2,'AB1303',6.68,'hermeshine','neilljm','neill.mathieson@telus.net','Neill Mathieson','16 Abbercove Rd. S.E.','Calgary','AB','CANADA','T2A6Z2','(403) 248-4328','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 01:36:16',0,NULL,3,1,2,1,NULL,NULL),(2701,605987763001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','littlemattkid','zoltansship@hotmail.com','matthew clinesmith','PSC 251 Box 337','APO','AP','AA','96542','6716852177','NoPaymentFailure','CheckoutComplete','Other','2010-12-10 01:40:56',0,NULL,3,1,6,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š   2\råŒ…    1 \rEX000334689SG\rlighting kit   $25'),(2702,605587613001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','andromedasweetie','basicblack25@gmail.com','Piper Black','970 Milner Avenue','Victoria','BC','CANADA','V8X 3N4','(250) 248-2477','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 01:48:14',0,NULL,3,1,2,1,NULL,NULL),(2703,605603262001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',9.8,'hermeshine','gliderpilot2002','bdandress@aol.com','Brent Andress','26341 Alcott Union Dr.','Murrieta','CA','UNITED STATES','92563','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 01:55:02',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›–  canon   1 \r67mm é•œå¤´ç›–  canon   1 \r72mm é•œå¤´ç›–  canon   1 \r77mm é•œå¤´ç›–  canon   1 '),(2704,605993121001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','brenda.hammel','bhammel@shaw.ca','Brenda Hammel','96 Sunrise Rd SW','Medicine Hat ','AB','CANADA','T1B 4S2','(403) 526-8830','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 01:56:23',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR723015926CN\r'),(2705,605867155001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','gmen87','mgm6704@hotmail.com','Mike McCormick','114 S Manchester St','West Union','OH','UNITED STATES','45693-1221','(937) 544-9722','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 02:05:26',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ…   æ— å­—   1 '),(2706,644980567002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bburton88','bburton@berklee.net','brian burton','404 Potts St','Davidson','NC','UNITED STATES','28036','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 02:50:34',0,NULL,3,1,1,1,NULL,NULL),(2707,606029501001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','iaorana7577','note4ken@skyviewmail.com','Ken Summerhays','715 W Mariposa Dr','Washington','UT','UNITED STATES','84780-2198','(435) 652-1950','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 04:08:13',0,NULL,3,1,1,1,NULL,NULL),(2708,645004986002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','chadstoolbox-knipextools','email@chadstoolbox.com','ChadsToolbox.com Inc','PO BOX 876084','Wasilla','AK','UNITED STATES','99687','(877) 456-4739','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 04:25:52',0,NULL,3,1,1,1,NULL,NULL),(2709,606039577001,110533631166,'62mm 3-Stage Rubber Lens Hood for D80 D90 450D 500D',1,'AB1304',3.79,'hermeshine','irandut','hammer_fll@yahoo.com','nana haroen','1075 E Stuart Dr','galax','VA','UNITED STATES','24333-2638','(336) 244-4449','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 05:00:18',0,NULL,3,1,1,1,NULL,NULL),(2710,645020777002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','akarae','genchildren@hotmail.com','Teo   Hong Joo',' Block 426 Serangoon Avenue 1 #11-203','Singapore','Singapore','SINGAPORE','550426','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 05:47:06',0,NULL,3,1,11,1,NULL,NULL),(2711,644604553002,120560203032,'58mm Lens lenscap for Canon Combined shipping discounts',1,'AA1301',23.59,'hermeshine','mohdfaxyl','faxyl@me.com','Mohamed Fazeel','M.Light view<br>Blookiya Magu','Male','','MALDIVES','20340','009607977978','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 05:59:19',0,NULL,3,1,3,1,NULL,'canon å•è‚©åŒ…   1\r58mm é•œå¤´ç›– canon    1 \rRR723015719CN\r'),(2712,645027713002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',2,'AA1302',5,'hermeshine','chalyk','chaly_k@hotmail.com','chaly khoeun','19903 13th ave s','seatac','WA','UNITED STATES','98148','(206) 422-4701','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 06:28:02',0,NULL,8,1,17,1,NULL,NULL),(2713,645027437002,120560203127,'72mm Lens lenscap for Canon Combined shipping discounts',2,'AA1303',5,'hermeshine','chalyk','chaly_k@hotmail.com','chaly khoeun','19903 13th ave s','seatac','WA','UNITED STATES','98148','(206) 422-4701','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 06:28:03',0,NULL,3,1,1,1,NULL,'72mm canon é•œå¤´ç›–  2\r67mm canon é•œå¤´ç›–  2\r '),(2714,645030799002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','sdibao10','sdibao@gmail.com','Serge  Dibao','15000 W Airport Blvd<br>Apt 1822','sugar land','TX','UNITED STATES','77498-7278','','NoPaymentFailure','CheckoutComplete','Other','2010-12-10 06:45:28',0,NULL,3,1,3,1,NULL,'RR723015722CN'),(2715,606067747001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','shahlesnoit101','shahlesnoit@hotmail.com','Selamat Shahridzuan','Blk 827 Woodlands Street 81 #02-90','Singapore','','SINGAPORE','730827','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 07:47:10',0,NULL,8,1,17,0,NULL,' '),(2716,606067746001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','shahlesnoit101','shahlesnoit@hotmail.com','Selamat Shahridzuan','Blk 827 Woodlands Street 81 #02-90','Singapore','','SINGAPORE','730827','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 07:47:11',0,NULL,3,1,11,1,NULL,'52mm æ©¡èƒ¶ç½©   1\r58mm æ©¡èƒ¶ç½©    1 '),(2717,688476389016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','artwizdean','dean@artwiz.co.uk','Dean Williams','11 Somerset Drive, Glenfield','Leicester','Leicestershire','UNITED KINGDOM','LE3 8QW','01162912374','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-10 08:06:55',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶   2\r50-70 æ£š  è‹±æ ‡   2\r115w 220v   2\råŒ…   1\r lighting kit  $32 \rYW863884285CN\r'),(2718,605674596001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting Ã—2',1,'AKT031',108.9,'hermeshine','jeve398','jeve398@hotmail.com','Joris Vermeylen','Leuvensesteenweg 398','Kortenberg','Vlaams-Brabant','BELGIUM','3070','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 08:55:28',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£šé€šç”¨å¡å£   2\rlight stand  $22\rYW863884322CN'),(2719,645061727002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','toma_graphics','marco@archeologiasperimentale.it','Marco Tomaselli','via L. D\'Aragona 266','pistoia','PT','ITALY','51100','0573-545284','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 09:23:37',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´æ£š   2\r45w  8\råŒ…    1 \rlighting kit    $28\rYW863884300CN\r'),(2721,606105063001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','yasamehmet','mehmetyasa@yahoo.com','MEHMET YASA','G. M. K. BULVARI NO: 128/C<br>TANDOGAN','ANKARA','TURKEY','TURKEY','06470','905333548487','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 10:35:37',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´   æ¬§æ ‡   1 '),(2722,645088941002,120564178566,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11.54,'hermeshine','612150','oln07@mail.ru','Oleg Nikitenkov','Ð Ñ‹Ð»ÐµÐ½ÐºÐ¾Ð²Ð° 42-15','Ð¡Ð¼Ð¾Ð»ÐµÐ½ÑÐº','Smolensk','RUSSIAN FEDERATION','214036','+79190494900','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 11:09:49',0,NULL,3,1,2,1,NULL,'lenspen   2 '),(2723,702145853015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','blacknegr57','negr.black@gmail.com','Martin Cerny','Daskova 3081','Praha','','CZECH REPUBLIC','143 00','+420604911140','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-10 12:00:16',0,NULL,8,1,17,0,NULL,NULL),(2724,702145851015,250599364553,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',2.1,'hutongstore','blacknegr57','negr.black@gmail.com','Martin Cerny','Daskova 3081','Praha','','CZECH REPUBLIC','143 00','+420604911140','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-10 12:00:15',0,NULL,3,1,2,1,NULL,'RS-S1   1\r55mm uv   1 '),(2726,645117936002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','bet2100','bet@mainpage.ddo.jp','Kengo Mohri','2192-3<br>Yachikusa','Fukusaki-Cho Kanzaki-Gun','Hyogo','JAPAN','679-2202','081-790-22-6302','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 12:51:14',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1åå…‰ä¼ž   1å•ç¯å¤´RR723015395CN'),(2727,702166701015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','mpen5877','mauricepenn@ntlworld.com','Maurice Penn','70 Moran Road','Newcastle under Lyme','Staffordshire','UNITED KINGDOM','ST5 6EX','01782253051','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-10 12:58:39',0,NULL,3,1,2,1,NULL,NULL),(2728,645129661002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0014',18,'hermeshine','paulogris','paulo.gris@gmail.com','Harita Chotalal','Rua Nossa Sra da Nazare nÂº16 1Âº Esq','Loures','Lisboa','PORTUGAL','2660-316','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 13:31:17',0,NULL,3,1,3,1,NULL,'1.6x3m ç™½è‰²èƒŒæ™¯å¸ƒ   1 \rRR815345035CN\r'),(2729,606156095001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','hadar123','orhadar@gmail.com','or Hadar','1 Gibstain st','Rishon le Zion','','ISRAEL','75313','0578170438','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 13:35:23',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³çŽ¯   1 '),(2731,645157933002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','saaliya2010','saaliya.thilakarathna@gmail.com','Saaliya Thilakarathna','No.34,DeLaSalleStreet,<br>Modara,','Colombo','Western','SRI LANKA','15','+94777413739','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 14:51:50',0,NULL,3,1,3,1,NULL,'åå…‰æ¿ RR723015400CN'),(2732,645160342002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','stl.sportsman','mktrrnc@hotmail.com','mike torrence','14477 Eddington Dr','chesterfield','MO','UNITED STATES','63017-2541','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 14:55:14',0,NULL,3,1,1,1,NULL,'nikon 90th è‚©å¸¦   1 '),(2733,606200506001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','iuly_yo','pandy.iuly@yahoo.com','Iulian Pandele','Str. Dragos Mladinovici nr. 2-4 Bloc R11 apartament 46 sector 4<br>Post office nr. 82','Bucharest','RO','ROMANIA','041783','+4 0727899848','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 15:40:36',0,NULL,8,1,17,0,NULL,NULL),(2734,606197263001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','iuly_yo','pandy.iuly@yahoo.com','Iulian Pandele','Str. Dragos Mladinovici nr. 2-4 Bloc R11 apartament 46 sector 4<br>Post office nr. 82','Bucharest','RO','ROMANIA','041783','+4 0727899848','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 15:40:37',0,NULL,3,1,2,1,NULL,'52-52 åŒé˜³çŽ¯   1\r52-58 åŒé˜³çŽ¯   1 '),(2735,702264914015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'',51,'hutongstore','primozkrze2009','primoz.krze@szdl.si','PrimoÅ¾ KrÅ¾e','horjulska 225','Dobrova','','SLOVENIA','1356','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-10 16:36:08',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½  é»‘ ï¼‰   1 \rCP212331075CN\r'),(2736,606232662001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3401',2.6,'hermeshine','burs','bursey3@cogeco.ca','paul e. bursey','2153 sunnyvale Dr','Oakville','ON','CANADA','l6l1w6','(905) 847-9573','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 16:55:23',0,NULL,3,1,2,1,NULL,'è‚¥çš‚ç›’æŸ”å…‰ç½©   430ex   1 '),(2737,606240260001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','grosfaters','serpovs@mail.ru','Serpov Sergey','Shagabudinova 116/120, 2','Almaty','Almaty','KAZAKHSTAN','050012','+77772494350','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 17:12:33',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³çŽ¯   1 '),(2738,645227533002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','guanavi','jllahumada@hotmail.com','Jose Luis Lopez de Ahumada','Lira,5 G','Sevilla','AndalucÃ­a Ceuta y Melilla','SPAIN','41003','618052614','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 17:35:54',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW863884366CN\r'),(2739,606252644001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','alonluft','imwaiting23@gmail.com','alon luft','yanush korchak 31','hertzliya','hertzliya','ISRAEL','46309','+972 546743447','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 17:51:50',0,NULL,3,1,11,1,NULL,NULL),(2740,645240648002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','jontrotta1022','jontrotta1022@yahoo.com','jonathan trotta','140 picturesque dr','rochester','NY','UNITED STATES','14616','(585) 278-4040','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 17:59:47',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2741,645251407002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',61.99,'hermeshine','dusanvlajic','dusanvlajic@hotmail.com','Dusan Vlajic','250 Christie St. Apt. #2','Toronto','ON','CANADA','M6G 3B8','(647) 827-9767','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 18:20:22',0,NULL,3,1,5,1,NULL,'6662a  1 \rCP212331067CN\r'),(2742,645257702002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','victav33','victav33@verizon.net','Victor Taveras','6 Merrick CT','Middletown','NJ','UNITED STATES','07748-1209','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 18:32:02',0,NULL,3,1,1,1,NULL,NULL),(2743,702329862015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'',13.9,'hutongstore','foralgebra','info@rexware.fr','Mickael Nicotera','95 rue Jean Zay','St Jean de Braye','Centre','FRANCE','45800','0238215985','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-10 18:34:21',0,NULL,3,1,2,1,NULL,'50cm æ£š   1 '),(2744,606285886001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','relbix','wildworld@bk.ru','Vladimir Nikulkin','Shcherbakovskaya Str., 57/20, 194','Moscow','','RUSSIAN FEDERATION','105187','(919) 100-4190','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 18:46:22',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 RR723015342CN'),(2745,702337637015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','kazyy','katja.kaipainen@kotiposti.net','Katja Kaipainen','KÃ¤rrykuja 2-4 as 23','Imatra','Oletus','FINLAND','55100','0505414111','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-10 18:47:48',0,NULL,3,1,2,1,NULL,NULL),(2746,606301182001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','helenio1','britzka@gmail.com','HELENIO GRECH','\'ACUSHLA\'<br>CAPUCCHINS STREET','KALKARA','','MALTA','KKR 1033','(356) 9946 6363','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 19:14:59',0,NULL,3,1,3,1,NULL,'ä¸€è½¬å›› ç¯å¤´  2 \rRR815345027CN\r474'),(2747,702381937015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'',7.5,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-10 19:53:17',0,NULL,8,1,17,0,NULL,NULL),(2748,702380106015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'',127,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-10 19:53:18',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆç™½ï¼‰   1\r2mç¯æž¶  2\råŒç¯å¤´ æ¬§æ ‡   2\råå…‰ä¼ž  2\ræŸ”å…‰ä¼ž  1\r115w 220v   4\r åŒ…   1\rlighting kit  $29 YW863884355CN\r\r'),(2749,645022412002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','chev3936','silverado3936@att.net','Kevin Brock','3936 Griffith Rd','Pace','FL','UNITED STATES','32571-9357','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-10 20:25:28',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹   1 '),(2750,606339829001,110531023204,'JJC Leather Hand Strap Grip comfort stable D700 5DII',1,'AB3402',14.99,'hermeshine','sniper_stan','mepsy@yandex.ru','Ð¡Ñ‚Ð°Ð½Ð¸ÑÐ»Ð°Ð² Ð“ÑƒÐ´Ð·Ð¾Ð²ÑÐºÐ¸Ð¹','Ð¿Ñ€. Ðš.ÐœÐ°Ñ€ÐºÑÐ°, 268, 17','Ð¡Ð°Ð¼Ð°Ñ€Ð°','Ð¡Ð°Ð¼Ð°Ñ€ÑÐºÐ°Ñ','RUSSIAN FEDERATION','443081','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 20:32:54',0,NULL,3,1,2,1,NULL,'jjc-2  è…•å¸¦   1 '),(2751,688807374016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','ickle_pigeon_1337','russie_the_stokie@hotmail.co.uk','Rebecca Ruscoe','Halfway House Slindon','Eccleshall','Staffordshire','UNITED KINGDOM','ST216QP','01782791350','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-10 20:48:29',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(2752,606364064001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','tanqueton','ramnoel66@yahoo.com','jose ramon fernandez gonzalez','avenida benidorm 34-4 d','arnedo','La Rioja','SPAIN','26580','600322941','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 21:23:18',0,NULL,3,1,2,1,NULL,NULL),(2753,606373319001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','pddl2010','uy.pablo@gmail.com','Javier Larramendy','Calle Mozart  Manzana M Solar 28','Villa Foresti, Las Piedras','Canelones','URUGUAY','90200','099639597','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 21:44:41',0,NULL,3,1,3,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ xxl    1 RR723015325CN'),(2754,606410994001,110533631226,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','hemant_07047','hemant_07047@yahoo.com','Hemant Shah','1225 81st Street','North Bergen','NJ','UNITED STATES','07047','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 23:27:26',0,NULL,3,1,1,1,NULL,'72mm æ©¡èƒ¶ç½©   1 '),(2755,606413215001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','jh-project','honzikhanak@seznam.cz','Jan HanÃ¡k','Bohunova 10','Brno','','CZECH REPUBLIC','62500','+4207244444157','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 23:33:58',0,NULL,3,1,2,1,NULL,'nikon 52mm åæŽ¥çŽ¯   1 '),(2756,606428384001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','wookie_with_a_beer','otoolepiece@yahoo.com','Jason Beck','12300 Apache Ave<br>Apt 1609','Savannah','GA','UNITED STATES','31419-2337','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 00:29:39',0,NULL,3,1,1,1,NULL,NULL),(2757,645441787002,120564178467,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','kccims','sgingras@tbs.toshiba.ca','Serge Gingras','23 du Cantonnier','Levis','QC','CANADA','g6v8m3','(418) 837-9399','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 02:05:19',0,NULL,3,1,2,1,NULL,NULL),(2758,688938338016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','nboey','noelboey@yahoo.com.sg','Noel Boey','Blk 441A Fernvale Road #03-307 S(791441)','default','','SINGAPORE','791441','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-11 02:10:59',0,NULL,3,1,11,1,NULL,NULL),(2759,606169111001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',104.6,'hermeshine','bandphotographer','vincenzo_pistritto@msn.com','Vincenzo Pistritto Photography','C21 939 Western rd<br>BUZZER CODE 021','London','ON','CANADA','N1G1g3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-11 03:15:39',0,NULL,3,1,5,1,NULL,'æ–œè‡‚  2\råå…‰æ¿æ”¯æž¶   1\rå¤§åŠ›å¤¹   2 \rCP212331053CN\r'),(2760,606467612001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','ml3330577','boo1.1ood@hotmail.com','zihao Li','425 S Los Angeles St<br>Ste D','Los Angeles','CA','UNITED STATES','90013-1434','(909) 827-5220','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 03:21:40',0,NULL,3,1,1,1,NULL,NULL),(2761,645461652002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','cheetah2005','lanz_cbr@yahoo.com.sg','Nor Zailan Jalaludin','Panglima Power Sdn Bhd<br>Teluk Gong Power Station','Kuala Sungai Baru','Melaka','MALAYSIA','78200','0126160085','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 03:25:13',0,NULL,3,1,3,1,NULL,'é˜²å¯’ç½©    1 \rRR815345013CN\r'),(2762,606472629001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','bogolisk','dang.linh@gmail.com','Linh Dang','39 Rodeo Drive','Ottawa','ON','CANADA','K2J4Z5','(613) 825-8716','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 03:44:49',0,NULL,3,1,2,1,NULL,' '),(2763,606481263001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','nickf6549','awesomenick@gmail.com','nick fish','6549 Longmeadow Cir','west jordan','UT','UNITED STATES','84084-5801','(801) 635-3982','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-11 04:26:59',0,NULL,3,1,1,1,NULL,'ctr301p  ä¸€æ‹–ä¸‰   1 '),(2764,606495454001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','elenka-elenka','work-adress@mail.ru','Elena Fokina','ul.Svyazistov d.5 kv.233','Novosibirsk','Novosibirskaya oblast','RUSSIAN FEDERATION','630120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 05:54:17',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2765,645494763002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','abdullahjun09','abdullahjun@yahoo.com','Abdullah Jun Palma','Security Forces Hospital, Sitteen Street<br>PO Box 3643','Riyadh','','SAUDI ARABIA','11481','0567568050','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-11 06:18:17',0,NULL,3,1,3,1,NULL,'RR723015311CN '),(2766,606512683001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','perrier79','vformuzal@yahoo.com','Vyacheslav Formuzal','10559 Birch Ranch Dr','Sacramento','CA','UNITED STATES','95830','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 07:44:15',0,NULL,3,1,1,1,NULL,NULL),(2767,645510227002,120581410894,'16chan Wireless Remote Control Cord for Canon RS-80N3',1,'AA3204',18.5,'hermeshine','jeb5','jandmbaumann@bigpond.com','John Baumann','8 Visser Court','Rochedale','Queensland','AUSTRALIA','4123','0733411072','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 07:57:46',0,NULL,8,1,17,0,NULL,NULL),(2768,606513584001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','jeb5','jandmbaumann@bigpond.com','John Baumann','8 Visser Court','Rochedale','Queensland','AUSTRALIA','4123','0733411072','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 07:57:46',0,NULL,8,1,17,0,NULL,NULL),(2769,606514034001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','jeb5','jandmbaumann@bigpond.com','John Baumann','8 Visser Court','Rochedale','Queensland','AUSTRALIA','4123','0733411072','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 07:57:47',0,NULL,8,1,17,0,NULL,NULL),(2770,606513324001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','jeb5','jandmbaumann@bigpond.com','John Baumann','8 Visser Court','Rochedale','Queensland','AUSTRALIA','4123','0733411072','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 07:57:47',0,NULL,8,1,17,0,NULL,' '),(2771,645509495002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','jeb5','jandmbaumann@bigpond.com','John Baumann','8 Visser Court','Rochedale','Queensland','AUSTRALIA','4123','0733411072','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 07:57:48',0,NULL,3,1,3,1,NULL,'77mm æ©¡èƒ¶ç½©   1\r58mm æ©¡èƒ¶ç½©   2\rå“èƒœ 3.0 è†œ   1\rçƒ­é´ç›–   1\rçˆµå½±æ— çº¿  C3   1RR723015373CN\r '),(2772,606520150001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'',35,'hermeshine','nosnetto','nosnetto@hotmail.com','Nathan Ottenson','15 Marquis cr.','Regina','SK','CANADA','s4s6j8','(306) 584-3179','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 08:24:09',0,NULL,3,1,3,1,NULL,'800w 110v   5 \rRR815345662CN\r'),(2773,645521028002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','bouvierlab','kdobi@shaw.ca','Kim Dobischok','21379 126th ave','Maple Ridge','BC','CANADA','V4R 2K1','(604) 466-9936','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-11 08:53:29',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…  1 RR723015339CN'),(2774,606540759001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',2,'AB1303',6.68,'hermeshine','turquoise-web','turquoise.web@gmail.com','GURSOY HAFIZOGLU','HURRIYET MAH. 276 SOK. NO:7/3<br>GAZIOSMANPASA','ISTANBUL','IST','TURKEY','34240','(212) 537 6390','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 09:55:38',0,NULL,3,1,2,1,NULL,' '),(2775,645545988002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','theartharindra','harindranishshanka@gmail.com','Harindra Nishshanka','30/1, Godellawaththa,<br>Mahawila','Panadura','Western','SRI LANKA','12500','0094773040696','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 10:21:53',0,NULL,3,1,2,1,NULL,NULL),(2776,645547323002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','toanvle','toantech@gmail.com','Toan Le','3117 SE 136th Ave','Portland','OR','UNITED STATES','97236-2813','(503) 593-0307','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 10:27:33',0,NULL,3,1,1,1,NULL,NULL),(2777,702683825015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'',3.82,'hutongstore','noz_90','traffic_@live.co.uk','Nolan Galea','23, Triq il Gammar','Attard','','MALTA','ATD 2640','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-11 10:40:35',0,NULL,3,1,2,1,NULL,NULL),(2778,645555600002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','trilby990','tony-wright@tpg.com.au','Tony Wright','3 / 306 Victoria Avenue','Redcliffe','Queensland','AUSTRALIA','4020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 10:54:20',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶   1  RR723015268CN'),(2779,645565030002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','gybp','gybp@yahoo.com','Glennford B Perez','Avda Boulevard Edificio Primavera portal 7 apt 3-A Benalmadena<br>Benalmadena','Malaga','AndalucÃ­a Ceuta y Melilla','SPAIN','29631','617588950','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-11 11:24:51',0,NULL,8,1,17,0,NULL,''),(2780,645582177002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','gybp','gybp@yahoo.com','Glennford B Perez','Avda Boulevard Edificio Primavera portal 7 apt 3-A Benalmadena<br>Benalmadena','Malaga','AndalucÃ­a Ceuta y Melilla','SPAIN','29631','617588950','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 12:18:45',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \r52mm çŽ¯æž¶  1 RR723015356CN'),(2781,606595666001,110296333346,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',6.99,'hermeshine','miodas07','miodas007@hotmail.com','Mateusz Stawicki','20 Rosemount Drive','Cahir','Tipperary','IRELAND','052','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-11 12:49:23',0,NULL,3,1,2,1,NULL,'NG128   1 '),(2782,689156876016,260660056537,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'',2.4,'hutongstore','xyponob75','xyponob@interia.eu','Robert Sroga','8 Pellew Close','Padstow','Cornwall','UNITED KINGDOM','PL28 8EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-11 14:23:22',0,NULL,3,1,2,1,NULL,NULL),(2783,645632426002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bestrashny','gregorygur@gmail.com','gregory gurevich','nahal tzvi 32/16','migdal haemek','','ISRAEL','23049','972-0544831155','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 14:33:19',0,NULL,3,1,2,1,NULL,NULL),(2784,606677049001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','halloo9','auction@macnews.de','Christian Eischer','Ferdinand Fleischmanngasse 4/2','MÃ¶dling','','AUSTRIA','2340','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 16:26:55',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—   1 '),(2785,606706275001,110566018983,'Flash Softbox Diffuser for internal flash of D40 D60',1,'AB3304',11.34,'hermeshine','jlastuni','juha.lastuniemi@gmail.com','Juha Lastuniemi','Napaturunkatu 3b12','Turku','','FINLAND','20610','(358) 504835026','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 17:11:04',0,NULL,3,1,2,1,NULL,'NG128   1 '),(2786,606760532001,110566020134,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',3.55,'hermeshine','mtorraufv','marctorra@hotmail.com','Marc Torra i Ferrer','Ronda Paraires nÂº11 baixos','Olot','CataluÃ±a','SPAIN','17800','699698620','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 18:51:41',0,NULL,8,1,17,0,NULL,NULL),(2787,645764385002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','mtorraufv','marctorra@hotmail.com','Marc Torra i Ferrer','Ronda Paraires nÂº11 baixos','Olot','CataluÃ±a','SPAIN','17800','699698620','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 18:53:55',0,NULL,3,1,2,1,NULL,'72mm æŽ¥å£çŽ¯   1\rå¹¿è§’æ‰˜æž¶   1 '),(2788,645763806002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','adnankalkan65','adnankalkan@gmail.com','Adnan Kalkan','1. Ana Bakim Merkezi Lojmanlari','Sakarya','','TURKEY','54580','02642765570','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 18:54:31',0,NULL,8,1,17,0,NULL,NULL),(2789,645763496002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','adnankalkan65','adnankalkan@gmail.com','Adnan Kalkan','1. Ana Bakim Merkezi Lojmanlari','Sakarya','','TURKEY','54580','02642765570','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 18:54:31',0,NULL,3,1,2,1,NULL,'67mm æŽ¥å£çŽ¯   1\rå¹¿è§’æ‰˜æž¶   1 '),(2790,645770042002,120571007530,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','cooldudz23aeronpaul','aeronpaulm@yahoo.com','Aeron Paul Mendoza, Estimating Department','P.O.box 991<br>M.S. Al-Suwaidi Industrial Services Co. Ltd.','Jubail Industrial City','Eastern Region','SAUDI ARABIA','31951','033411148','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 19:08:42',0,NULL,3,1,2,1,NULL,'æ¸å˜è“   1 '),(2791,702993315015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'',1.88,'hutongstore','klausnjules','kanj@blueyonder.co.uk','David Harrison','43 Runshaw Avenue Appley Bridge','Wigan','Lancashire','UNITED KINGDOM','WN6 9JP','01257253157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-11 20:11:08',0,NULL,3,1,2,1,NULL,NULL),(2792,645817419002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','nnik01','niklasnilsen@getmail.no','Niklas Nilsen','Olaf Bulls vei 3a','Oslo','','NORWAY','0765','+4799282427','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 20:26:54',0,NULL,3,1,2,1,NULL,NULL),(2793,645822763002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','andreiphotografy','photomaestro@mail.ru','Andrei Aksenov','str. Vologodskaya 25-74','Arhangelsk','Arhangelsk region','RUSSIAN FEDERATION','163001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 20:38:05',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´ æ¬§æ ‡   1 '),(2794,703029603015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','choang2603','choang263@gmail.com','Duc Hoang','47 Casby House','Dickens Estate','London','UNITED KINGDOM','SE16-4SX','02072376252','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-11 21:10:22',0,NULL,3,1,2,1,NULL,NULL),(2795,606843200001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3401',2.6,'hermeshine','eladsega','eladsega@gmail.com','elad segal','hirshfeld 12','rishon lezion','','ISRAEL','75244','+972525459977','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 21:26:34',0,NULL,3,1,2,1,NULL,'è‚¥çš‚ç›’æŸ”å…‰ç½©  sb800   1 '),(2796,606859652001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','brandondsp','brandon@dreamsoftproductions.com','Brandon Christensen','2821 Shayla Bay Ave','North Las Vegas','NV','UNITED STATES','89086-1431','(702) 278-9373','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 22:04:10',0,NULL,3,1,1,1,NULL,'çƒ­é´ç›–   1 \rBrandon Christensen\r1101 E Tropicana Ave # 2202\rLas Vegas, NV 89119\rUSA\r'),(2797,645868375002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','vicenteml25','vicenteml25@hotmail.com','Vicente MuÃ±oz Losada','Doctor Angel Pascual Megias, nÂº4 - 5ÂºA','Alicante','Comunidad Valenciana','SPAIN','03015','607800743','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 22:10:10',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(2798,606863123001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','andreiphotografy','photomaestro@mail.ru','Andrei Aksenov','str. Vologodskaya 25-74','Arhangelsk','Arhangelsk region','RUSSIAN FEDERATION','163001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 22:14:42',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´   1 '),(2799,645728471002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','urtrapbud','jerrym@wellingtonatm.com','Jerry Magnuson','1560 Sandstone Bluffs View St','Mesquite','NV','UNITED STATES','89034','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 22:14:54',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(2800,645885417002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','frogbro','richfrye@comcast.net','Rich Frye','7637 W Catalpa Ave','Chicago','IL','UNITED STATES','60656','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 22:50:33',0,NULL,3,1,1,1,NULL,NULL),(2801,645890022002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','dlehouillier','davel@vacautomation.com','Dave Lehouillier','21 Gower Rd','Georgetown','ON','CANADA','L7G 1E6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 23:04:25',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶   1 \rCP212331040CN\r'),(2802,645895297002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','blackwidow1128','ecwright_28@yahoo.com','Elaine Wright','3490 Quail Lake Rd<br>Apt 280','Colorado Springs','CO','UNITED STATES','80906','(513) 405-1221','NoPaymentFailure','CheckoutComplete','Other','2010-12-11 23:16:06',0,NULL,8,1,17,0,NULL,''),(2803,645896308002,120571007466,'New Umbrella in Silver 85cm / 33.5\" Photo Studio Light',1,'AD1401',9.9,'hermeshine','blackwidow1128','ecwright_28@yahoo.com','Elaine Wright','3490 Quail Lake Rd<br>Apt 280','Colorado Springs','CO','UNITED STATES','80906','(513) 405-1221','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 23:18:20',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž   1 \råå…‰ä¼ž   1RR723015299CN'),(2804,645927213002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','diamondcutter47','gblasberg@gmail.com','Gary Blasberg','1610 Murphy Pkwy','Eagan','MN','UNITED STATES','55122','(651) 688-9075','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 00:54:19',0,NULL,3,1,1,1,NULL,NULL),(2806,646003122002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0024',20.99,'hermeshine','bintang1972','bintang68@hotmail.com','Bin Tang','5842 Aline','Brossard','QC','CANADA','J4Z1R5','(514) 574-0638','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 06:12:19',0,NULL,3,1,3,1,NULL,'æ–°æ¬¾å•è‚©åŒ… D1 canon   1 RR723015387CN'),(2807,606992826001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',9.8,'hermeshine','epochphoto','bvishneski@msn.com','Robert J Vishneski','107 Glen David Dr','Pittsburgh','PA','UNITED STATES','15238','(412) 656-7001','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-12 06:26:43',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹äº‘å°  1 '),(2808,606998896001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','joneff51','desmo450@hotmail.com','John Farrell','12 Light Place<br>Colonel Light Gardens','Adelaide','South Australia','AUSTRALIA','5041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 07:06:00',0,NULL,3,1,2,1,NULL,'45w   2 '),(2809,703261166015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',1,'',2.2,'hutongstore','dougacteach','douglas.lunnlunn@btinternet.com','Doug Lunn','34, D\'Eyncourt Lighton Avenue','Kirton','Lincolnshire','UNITED KINGDOM','PE20 1HP','01205725065','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 08:42:56',0,NULL,3,1,2,1,NULL,'nikon æœºèº«ç›–/é•œå¤´åŽç›–  1 '),(2810,646064716002,120581161644,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','eqzoo_com','zookeeper@eqzoo.com','Christopher Fowler','2261 Edsel ln','Modesto','CA','UNITED STATES','95358-9524','(209) 622-8214','PayPalPaymentInProcess','CheckoutComplete','Other','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'ç¢—ç½© P1   1 eé‚®å®æ”¹ä¸€ä¸ªLK012653203CN'),(2811,606984199001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',2,'AA1311',8.38,'hermeshine','spartanof84','matthew_alderdice@yahoo.com.au','Matthew Alderdice','46 Middle St Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0293981243','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 10:27:12',0,NULL,8,1,17,0,NULL,NULL),(2812,645994853002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','spartanof84','matthew_alderdice@yahoo.com.au','Matthew Alderdice','46 Middle St Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0293981243','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 10:27:12',0,NULL,3,1,3,1,NULL,'æ°”å¹+ å¸ƒ   2\rå¤§åŠ›å¤¹    2 \rRR723015285CN'),(2813,646082875002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','tollarp1-2007','tollar.peter@t-online.hu','Peter Tollar','Berenyi u. 3/b','Budapest','','HUNGARY','H-1016','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 10:52:49',0,NULL,3,1,2,1,NULL,' '),(2814,646085828002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','tatiana.nefedova','tatiana.nefyodova@gmail.com','Tatiana Nefedova','Shkolniy bulvar, dom 20, kv 25','Chernogolovka','Moscow district','RUSSIAN FEDERATION','142432','007-9057481744','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-12 11:00:07',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723015271CN'),(2815,607072342001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',52.99,'hermeshine','harioe','harioe2002@yahoo.com.au','Hari Oetomo','5 Bordeaux Crescent, Castle Hill','Sydney','New South Wales','AUSTRALIA','2154','0288501729','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2010-12-12 11:06:50',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°   1\ræŸ”å…‰ä¼ž   1 RR723015308CN'),(2816,703260440015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'',1.88,'hutongstore','learn-and-master','dan-made@hotmail.co.uk','DANIEL KENNY','2 jamaica street Apartment 51','liverpool','Merseyside','UNITED KINGDOM','L1 0AF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 11:09:52',0,NULL,3,1,2,1,NULL,NULL),(2817,689702379016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','moondustgold','geoffmartin@fsmail.net','Geoffrey Martin','174 Selwyn Street Hillstown,  Bolsover','Chesterfield','Derbyshire','UNITED KINGDOM','S44 6LT','01246824065','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 11:17:50',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(2819,606609999001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',86.9,'hermeshine','ewinwins','ewinwins@hotmail.com','M. Eid','58 Ironbark Drive Templestowe Lower','Melbourne','Victoria','AUSTRALIA','3107','61419001270','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-12 12:43:44',0,NULL,3,1,6,1,NULL,'\rèƒŒæ™¯æž¶ï¼ˆ ç™½ é»‘ ç²‰ï¼‰   1 \r\ræ–°åŠ å¡ems\rEX000237316SG\r'),(2820,646151978002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','tzvili','tsl999@gmail.com','tzvi lin','mevo dotan','mevo dotan ','dn tzfon hashomron','ISRAEL','44890','052-3115948','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 13:18:17',0,NULL,3,1,11,1,NULL,'cåž‹å¤§åŠ›å¤¹  2 '),(2821,646164163002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',5,'AA1302',12.2,'hermeshine','kajanakis','al.petrov@live.se','Alexander Petrov','ValhallavÃ¤gen 57, 2 tr','Stockholm','','SWEDEN','11422','+46762728172','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 13:41:19',0,NULL,8,1,17,0,NULL,' '),(2822,607102146001,110414472986,'Remote Cord Shutter Release for Nikon D200 D3 = MC-30',1,'AA3207',59.83,'hermeshine','ayukov','asv@ayukov.com','Sergey Ayukov','ul. Krzhizhanovskogo, d.5, korp.1, kv.54','Moscow','','RUSSIAN FEDERATION','117292','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 14:06:28',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž  1\rçˆµå½±æ— çº¿  N1   1 \rrs-n1    1\rRR815345747CN\r'),(2823,606935976001,110414374077,'55mm 55 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT019',4.87,'hermeshine','cjeremynoir','cjeremy1@hotmail.fr','crestey','9 allee leon jouhaux<br>chez breard loic','st sebastien de morsent','Haute-Normandie','FRANCE','27180','0659814559','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 14:39:22',0,NULL,3,1,2,1,NULL,'55mm çŽ¯æž¶   1 '),(2824,607141373001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',4.4,'hermeshine','tigerwho6','andreas.sleipnes@gmail.com','Andreas Sleipnes','BjÃ¸rnestien 13 B','Horten','Vestfold','NORWAY','3188','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 14:52:04',0,NULL,3,1,2,1,NULL,'canon 52mm åæŽ¥çŽ¯  1 '),(2825,646220812002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','acuglass','ac.uygongco@gmail.com','Albert Uygongco','Block 2 Lot 8 Ledesco Village, Lapaz','Iloilo City','Iloilo','PHILIPPINES','5000','6333209396','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 15:19:02',0,NULL,8,1,17,0,NULL,NULL),(2826,607220792001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','acuglass','ac.uygongco@gmail.com','Albert Uygongco','Block 2 Lot 8 Ledesco Village, Lapaz','Iloilo City','Iloilo','PHILIPPINES','5000','6333209396','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 15:50:30',0,NULL,8,1,17,0,NULL,NULL),(2827,646247878002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6,'hermeshine','acuglass','ac.uygongco@gmail.com','Albert Uygongco','Block 2 Lot 8 Ledesco Village, Lapaz','Iloilo City','Iloilo','PHILIPPINES','5000','6333209396','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 16:01:47',0,NULL,3,1,2,1,NULL,'67mm  cpl    1\r67mm uv    1\r67mm é•œå¤´ç›–  canon   1 '),(2828,703561702015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','colinn5393','colinjn@talktalk.net','colin nunn','18 moors way','woodbridge','Suffolk','UNITED KINGDOM','ip124hq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 16:48:19',0,NULL,3,1,2,1,NULL,NULL),(2829,646303555002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','spongebobparker','heidi@olypen.com','Heidi Hansen','40 Park Ln','Sequim','WA','UNITED STATES','98382-9505','(360) 683-1404','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 17:07:37',0,NULL,8,1,17,0,NULL,NULL),(2830,646302782002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','spongebobparker','heidi@olypen.com','Heidi Hansen','40 Park Ln','Sequim','WA','UNITED STATES','98382-9505','(360) 683-1404','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 17:07:38',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›–  canon   2 '),(2831,606833342001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','oreskovic1970dino','oreskovic1970@gmail.com','Dino Oreskovic','Pljesivicka 6','Zagreb','Dubrava','CROATIA','10040','00385915183412','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-12 17:14:17',0,NULL,3,1,5,1,NULL,'wt600   1 \rCP212331036CN\r'),(2832,607337437001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','jnoble2k','jnoble2k@yahoo.com','judith noble','3030 N Spaulding Ave','chicago','IL','UNITED STATES','60618-6809','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 18:07:01',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ…  nikon   1 '),(2833,646373911002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE1301',23.67,'hermeshine','hellofrankcom','info@hellofrank.com','Frank Bongers','Maaltebruggestraat 194','Gent','','BELGIUM','9000','0496558558','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 18:19:06',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  3 RR723015210CN'),(2834,703678508015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','dgs_tomek','td145@vp.pl','Tomasz Dobrzanski','12 castle walk','didcot','Oxfordshire','UNITED KINGDOM','ox117pd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 18:30:40',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´   1 '),(2835,606378265001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','totty61','slalves@hotmail.com','Suzanne Alves','61 Tulip Tree Close','Tonbridge','Kent','UNITED KINGDOM','TN9 2SJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 18:48:08',0,NULL,3,1,2,1,NULL,NULL),(2836,607484147001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','patrickvanderhorst','mail@patrickvanderhorst.nl','Patrick van der Horst','Onlandhorst 20','Enschede','','NETHERLANDS','7531 KX','+31-53-4317431','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 20:13:03',0,NULL,3,1,2,1,NULL,NULL),(2837,607504915001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','yetifvr','yetifvr@yahoo.com','Tony Tortolano','1003 E Avenue J3','Lancaster','CA','UNITED STATES','93535-3848','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 20:48:18',0,NULL,3,1,1,1,NULL,NULL),(2838,607525372001,110529627209,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','chrisdanielsnz','chris@chrisdaniels.co.nz','Chris Daniels','76 Clear View Lane<br>RD 5','Rangiora 7475','Canterbury','NEW ZEALAND','7475','+64 22 621 4900','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 20:57:42',0,NULL,3,1,2,1,NULL,'cpl   1 '),(2839,607523001001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11,'hermeshine','mpjsalazar','mpjsalazar@yahoo.com','Patricia Salazar','10848 Scripps Ranch Blvd<br>Apt 204','San Diego','CA','UNITED STATES','92131-6026','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 21:00:39',0,NULL,3,1,1,1,NULL,NULL),(2841,703869931015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','yogarosedog','briank8@blueyonder.co.uk','carole keenan','50 northmount rd north park est','liverpool','Merseyside','UNITED KINGDOM','L322AZ','01515480892','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 20:45:34',0,NULL,3,1,2,1,NULL,NULL),(2842,646609996002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','kajanakis','al.petrov@live.se','Alexander Petrov','ValhallavÃ¤gen 57, 2 tr','Stockholm','','SWEDEN','11422','+46762728172','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 22:16:25',0,NULL,3,1,3,1,NULL,' NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap  5RR723015360CN'),(2843,607589340001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','120897','jacobson68@yahoo.com','marti m jacobson','490 Bucheit St','Mount Angel','OR','UNITED STATES','97362','','NoPaymentFailure','CheckoutComplete','Other','2010-12-12 22:36:04',0,NULL,3,1,3,1,NULL,'è‚©æž¶RR723015223CN'),(2844,607608694001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','guiguigd','g.debizet@free.fr','Guillaume DEBIZET','6 avenue de la Gare','BIEVRES','ÃŽle-de-France','FRANCE','91570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 23:18:00',0,NULL,3,1,2,1,NULL,'star4 æ˜Ÿå…‰é•œ   1 '),(2845,703953935015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','paranoid73','seventy_three@hotmail.co.uk','Karl Fennell','Mill Cottage Norwich Road','Chedgrave','Norwich','UNITED KINGDOM','NR14 6ND','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 22:20:53',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(2846,607635875001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',10,'AA1309',24.2,'hermeshine','janvaaga','jevaaga@online.no','Jan Erik Vaaga','Strandg. 54','Haugesund','','NORWAY','5528','4795435497','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 00:36:08',0,NULL,3,1,3,1,NULL,' RR723015427CN'),(2847,646711307002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',2,'AB1402',27.8,'hermeshine','netniaga','paklongm@gmail.com','mohd akmal yahaya','No. 11 Jalan 3/18<br>bangi perdana','bandar baru bangi','selangor','MALAYSIA','43650','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 02:01:52',0,NULL,3,1,3,1,NULL,'90th è‚©å¸¦  2 RR723015435CN'),(2848,646719649002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','ilgas72','tommaz1972@sbcglobal.net','Tomas Mazeika','2389 McBride Ln<br>Apt 40','Santa Rosa','CA','UNITED STATES','95403-2942','(707) 545-8515','NoPaymentFailure','CheckoutComplete','Other','2010-12-13 02:19:15',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR723015444CN'),(2849,646719457002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','hiedz10','hmalig@gmail.com','Hiedie Malig c/o Green Harvest','8 Buntun Highway<br>Luna Extension','Tuguegarao City','Cagayan','PHILIPPINES','3500','0788462804','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 02:50:06',0,NULL,3,1,6,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ ï¼‰  1 \rEX000237320SG\r'),(2850,646756994002,120581555566,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','eeow45','eeow007@hotmail.com','ladaphan iamsriurai','970/44  Sukhumvit103 rd.','bangna','BKK','THAILAND','10260','0865563730','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 03:55:22',0,NULL,8,1,17,0,NULL,NULL),(2851,646753202002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','eeow45','eeow007@hotmail.com','ladaphan iamsriurai','970/44  Sukhumvit103 rd.','bangna','BKK','THAILAND','10260','0865563730','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 03:55:22',0,NULL,3,1,2,1,NULL,' '),(2852,646776147002,120601698567,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','primetym22','primetym22@aol.com','Dale Meyer','6668 Drake Dr','Anderson','CA','UNITED STATES','96007','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 05:25:59',0,NULL,3,1,3,1,NULL,'1007wf  1 RR723015458CN'),(2853,607739021001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','highborn_talon','highborntalon@gmail.com','Dave Arsenault','4324 Glencanyon Drive','North Vancouver','BC','CANADA','V7N 4B3','(778) 839-3308','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 05:58:42',0,NULL,3,1,2,1,NULL,NULL),(2854,607738787001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','pa4credit','willpa4credit@gmail.com','Rob Rhodes','203 Harbor Lndg','Braidwood','IL','UNITED STATES','60408-1763','(630) 935-7945','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 05:58:58',0,NULL,3,1,1,1,NULL,NULL),(2855,607742149001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','svmonterrosa','robtslucy@yahoo.com','Sandra Monterrosa','266 W Linden Ave<br>Apt D','Burbank','CA','UNITED STATES','91502','(818) 435-2218','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 06:23:56',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ…æ— å­—  1 '),(2857,646805610002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','rawbeansta','robin.ong.87@gmail.com','Robin Ong','Block 533 Woodlands Drive 14<br>#10-581 S(730533)','default','Singapore','SINGAPORE','730533','92255105','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 07:41:54',0,NULL,3,1,11,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2856,704164780015,250692240254,'Remote Control Cord Shutter Nikon D300/D200/D700â€‹ MC-30',1,'',2.98,'hutongstore','lundemann77','mch@datea.dk','Martin Lundemann Christensen','Henrik Nielsens Vej 19','Roskilde','Roskilde','DENMARK','4000','+45 51319182','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-13 07:09:37',0,NULL,3,1,2,1,NULL,'RS-N1  1 '),(2858,607763258001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','mjigz','minojigz@gmail.com','mino jegalian','1939 N Berendo st','los angeles','CA','UNITED STATES','90027-1801','(323) 717-5513','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 08:20:15',0,NULL,3,1,1,1,NULL,' '),(2859,646842797002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','rk20-2008','javidelope@terra.es','Javier de lope sanchez','C/ Mario Vargas Llosa NÂº34, 4Âº A','AlcalÃ¡ de Henares','Madrid','SPAIN','28806','615053293','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 10:31:06',0,NULL,8,1,17,0,NULL,NULL),(2860,607792028001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','rk20-2008','javidelope@terra.es','Javier de lope sanchez','C/ Mario Vargas Llosa NÂº34, 4Âº A','AlcalÃ¡ de Henares','Madrid','SPAIN','28806','615053293','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 10:31:06',0,NULL,3,1,3,1,NULL,'å°å·ç°å¡   1\r40cm æ£š   1\rRR815345101CN\r '),(2861,601088042001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','leah007leah','007leah@walla.com','LEAH MOSE','ALUFY ZAHAL 2/12<br>HOLON','HOLON','ISRAEL','ISRAEL','58417','0508511678','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 11:55:35',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815345225CN\r'),(2862,607821125001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','rmar2238','rosamdej@hotmail.com','Rosa MartÃ­n de Jorge','Rambla de catalunya 6, 5Âª planta','Barcelona','CataluÃ±a','SPAIN','08007','649844788','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 12:12:02',0,NULL,3,1,4,1,NULL,'tripod $22 \rYW863884392CN'),(2864,646886869002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',3,'AKT014',109.45,'hermeshine','inphernomassacro','giuliano.froio@gmail.com','Giuliano Froio','c/o SKY Italia srl<br>via Salaria 1021','ROMA','Roma','ITALY','00138','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 13:12:08',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   3\rbåº§   3\ræŸ”å…‰ä¼ž   3 \rlight stand $25\rYW863884414CN'),(2865,646122284002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','marcusfilmproducer','marcus.sassi@gmail.com','Marcus Sassi','BlidvÃ¤dersgatan 35A','Gothenburg','','SWEDEN','41830','0722-322-159','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 13:26:53',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶   1 \rreflector holder   $20\rYW863884425CN'),(2866,646909361002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','danrhomem','mortenris@hotmail.com','Morten Risberg','GrÃ¸nlandsgutua 1','Elverum','','NORWAY','2408','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 14:11:31',0,NULL,3,1,2,1,NULL,NULL),(2867,607857900001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tonybonekhang1','tonybonekhang@gmail.com','Tony Khang','318 S 8th Ave<br>Apt A','Wausau','WI','UNITED STATES','54401','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 14:20:19',0,NULL,3,1,1,1,NULL,NULL),(2868,646918257002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3302',55.99,'hermeshine','aristidetor','aristide.torrelli@telecomitalia.it','Aristide Torrelli','Via Luigi Magrini 19','Roma','RM','ITALY','00146','3357510069','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 14:36:07',0,NULL,3,1,3,1,NULL,'60cm é—ªå…‰ç¯æŸ”å…‰ç½©   1\rRR815345234CN\r '),(2869,704321592015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'',51,'hutongstore','darek.s.241271','darek.s.24@wp.pl','darek sikorski','13sherwood avenue','Boston','Lincolnshire','UNITED KINGDOM','pe21 9lg','01205358136','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-13 15:05:18',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰   1 \rbackground support $20\rYW863884436CN'),(2870,607900058001,110320736753,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','2deset','i.gledam@gmail.com','Damir Rister','Rakitje, Novacka cesta 18','Bestovje','','CROATIA','10437','0038598569776','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 16:11:46',0,NULL,3,1,2,1,NULL,NULL),(2871,704370928015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'',7.48,'hutongstore','skilgast','stephaniekilgast@yahoo.fr','Stephanie Kilgast','chez MARION 28 rue des Manouvriers','Savigny-le-Temple','ÃŽle-de-France','FRANCE','77176','0164684893','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-13 16:44:13',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡   1 '),(2872,607914757001,110320736753,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','tomasg1010','tomasg10@yahoo.es','TomÃ¡s Gabriel Carretero Ajo','Las Cruces casa 2<br>AlajerÃ³','Tenerife','Canarias','SPAIN','38812','628782598','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 16:47:48',0,NULL,3,1,2,1,NULL,NULL),(2875,646999688002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','trsilva23','trsilva_photo@hotmail.com','TÃ¡ssio Ribeiro Da Silva','Rua Benjamin Constant, 972 - Alecrim','Natal','Rio Grande do Norte','BRAZIL','5904030','8432012330','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 17:47:11',0,NULL,8,1,17,0,NULL,' '),(2876,646999127002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','trsilva23','trsilva_photo@hotmail.com','TÃ¡ssio Ribeiro Da Silva','Rua Benjamin Constant, 972 - Alecrim','Natal','Rio Grande do Norte','BRAZIL','5904030','8432012330','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 17:47:12',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\ræŸ”å…‰ä¼ž  2\rbåº§     1 \rRR815345251CN\r'),(2877,646219155002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','r-db','rdb@r-db.net','C.PERRIN - R. DEBIAUNE','LE TRELOD<br>15 RUE ARMAND AUBRY','ALBERTVILLE','RhÃ´ne-Alpes','FRANCE','73200','0608092092','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 17:20:32',0,NULL,3,1,3,1,NULL,'canon æ‘„å½±èƒŒå¿ƒxl  1\rRR815345305CN\r'),(2878,600521757001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','v.starshinov','starshinov.vn@gmail.com','Viatcheslav Starshinov','Gidromontazhnikov 9','Kazan','Tatarstan','RUSSIAN FEDERATION','420088','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 18:05:13',0,NULL,3,1,2,1,NULL,NULL),(2879,607906156001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','basell3','basell@omnicityusa.com','Beth Sell','9207 W 800 N','Huntington','IN','UNITED STATES','46750','(260) 344-3191','NoPaymentFailure','CheckoutComplete','Other','2010-12-13 18:12:47',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\r50-70 æ£š   2\råŒ…   1 \rlighting kit  $25\rYW863884440CN'),(2880,607960459001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',2,'AA2326',21.6,'hermeshine','jtyl6390','capt.john.tyler@gmail.com','John Tyler','465 Rush Green Road','Romford','Essex','UNITED KINGDOM','RM70NH','07719342148','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2010-12-13 18:17:09',0,NULL,3,1,2,1,NULL,'cpl   2 '),(2881,704432440015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'',4.5,'hutongstore','daydreamerswindows123','daydreamerswindows@live.com','Hayley Riordan','14 St michaels ave bishops cleeve','cheltenham','Gloucestershire','UNITED KINGDOM','gl52 8nx','01242671092','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-13 18:22:49',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… canon   1 '),(2882,646909129002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','icevace1982','icevace@mail.ru','Marsel Valiullin','Zarechnaya ulitsa<br>dom 7, kvartira 132','Moscow','Moscow','RUSSIAN FEDERATION','121087','79031599999','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 18:36:27',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rå•ç¯å¤´ æ¬§æ ‡  1\råå…‰ä¼ž   1 \rRR815345248CN\r'),(2883,646974256002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','omi0002','fredjhawkins@yahoo.com','Frederick J Hawkins','347 Overcup Ct','Millersville','MD','UNITED STATES','21108-2410','(410) 987-3063','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 18:31:50',0,NULL,3,1,1,1,NULL,NULL),(2884,647050937002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','terminator9210','ssalie@mweb.co.za','Shaheed Salie','59 Pinehurst Road<br>Kenwyn','Cape Town','','SOUTH AFRICA','7780','+27836776634','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 19:12:38',0,NULL,3,1,2,1,NULL,NULL),(2885,684385254016,260677592103,'Continuous Light Redhead 800w with bulb Red Head Light',1,'',49.99,'hutongstore','damonjamesdriver','damonjamesdriver@yahoo.co.uk','Damon Driver','32 Blakeland Hill','Duxford','Cambridgeshire','UNITED KINGDOM','CB22 4RX','07515917469','PayPalPaymentInProcess','CheckoutComplete','UK_StandardShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,4,1,NULL,'çº¢å¤´ç¯  è‹±æ ‡   1\r800w 220v   1\rlight  $16 \rYW863884451CN'),(2886,608020672001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.3,'hermeshine','brkstrtrcr757','brkstrtrcr@aol.com','Chris Young','439 Marion Rd','Hampton','VA','UNITED STATES','23663-1311','(757) 602-7844','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 19:55:21',0,NULL,3,1,1,1,NULL,NULL),(2888,704533801015,250599966664,'Aluminium Ultra Lightweight 71\" Camera Monopod 3wayhead',1,'',21.99,'hutongstore','siegmond2009','siegmondmarsden@yahoo.co.uk','siegmond marsden','10 oak tree road','thatcham','Berkshire','UNITED KINGDOM','rg194qp','01635862676','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-13 20:45:52',0,NULL,3,1,3,1,NULL,'wf1005   1 \rRR815345163CN\r'),(2889,704547305015,250693634352,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'',4.4,'hutongstore','hpeake666','helenpeake666@yahoo.co.uk','H Peake','Flat 4 105 Cliff Road','Crigglestone','West Yorkshire','UNITED KINGDOM','WF4 3EJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-13 20:49:42',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯ 52mm cpl   1 '),(2890,608053160001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','koen20102010','koenvanderjagt@upcmail.nl','Koen van der Jagt','Buitenweg 21','Krimpen aan de Lek','','NETHERLANDS','2931AC','0031180521022','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 20:51:44',0,NULL,8,1,17,0,NULL,NULL),(2891,647111371002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','koen20102010','koenvanderjagt@upcmail.nl','Koen van der Jagt','Buitenweg 21','Krimpen aan de Lek','','NETHERLANDS','2931AC','0031180521022','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 20:51:44',0,NULL,8,1,17,0,NULL,NULL),(2892,608053336001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','koen20102010','koenvanderjagt@upcmail.nl','Koen van der Jagt','Buitenweg 21','Krimpen aan de Lek','','NETHERLANDS','2931AC','0031180521022','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 20:51:45',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\rå•ç¯å¤´  æ¬§æ ‡   2\råå…‰ä¼ž   1\r45w   2 \rYW863884462CN\r'),(2893,704340829015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','jpersson2','gomikael@hotmail.com','Jan Persson','2 Stuttle House Buxton Street','London','London','UNITED KINGDOM','E1 5EJ','02072477448','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-13 21:33:39',0,NULL,3,1,2,1,NULL,NULL),(2894,608088245001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','epkpern','per.norlander@telia.com','Per Norlander','Vikingagatan 2','Vikingstad','','SWEDEN','59049','+461381041','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 21:53:51',0,NULL,3,1,2,1,NULL,NULL),(2895,704595861015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','asaliamirka','asalia35@wp.pl','Mirka Zakrzewska','2 Mon desir apartm. Grouville','Jersey','Channel Islands','JE','JE39DJ','07700744639','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-13 22:00:26',0,NULL,5,1,18,0,NULL,NULL),(2896,647151329002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','zoommr09','zmmr12@goldmail.etsu.edu','Michelle Ramsaran','1123 Cedar Pl','Johnson City','TN','UNITED STATES','37604-6533','(423) 434-0375','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 22:03:25',0,NULL,3,1,1,1,NULL,NULL),(2897,608092983001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','fashionmystiquespa','fashionmystique2@verizon.net','Dawn Lackner','6406 Chelton Ave','Harrisburg','PA','UNITED STATES','17112-2389','(717) 695-4244','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 22:04:17',0,NULL,3,1,1,1,NULL,NULL),(2898,647117604002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','seashore1444','watpat@comcast.net','John Watson','7 N Rumson Ave','Margate City','NJ','UNITED STATES','08402-1341','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 22:10:03',0,NULL,3,1,1,1,NULL,NULL),(2899,608097688001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','herbeapuce','stef@videotron.ca','Stephane Bigras','744 Graham Blvd.','Dorval','QC','CANADA','H9P2B6','(514) 636-2746','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 22:14:28',0,NULL,3,1,2,1,NULL,NULL),(2900,608099987001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',2,'AA1314',5.98,'hermeshine','woopz86','woopz@hot.ee','Eduard Jashin','Sopruse 250-8','Tallinn','Estonia / Harjumaa','ESTONIA','13412','(+372)55604952','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 22:20:52',0,NULL,3,1,2,1,NULL,'æœºèº«ç›–/é•œå¤´åŽç›–  Nikon   2 '),(2902,704628416015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','jumanjitim','tlb8000@aol.com','Tim Bateman','Eagle Print, Unit 5 Manor Way Business Centre Fairview Estate, Marsh Way','Rainham','Essex','UNITED KINGDOM','RM13 8UG','07940038843','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-13 23:04:05',0,NULL,3,1,2,1,NULL,' '),(2903,608126851001,110529627255,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','starslite80','jpearson@videotron.qc.ca','jacques pearson','431-audouart','quÃ©bec','QC','CANADA','g1c6m3','(418) 667-6972','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 23:33:49',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2904,647192746002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','shushumna555','robertocavarra@gmail.com','roberto cavarra','17 Jarvie st<br>Brunswick East','Melbourne','Victoria','AUSTRALIA','3057','0414904462','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 23:43:48',0,NULL,3,1,2,1,NULL,'cåž‹å¤§åŠ›å¤¹   2 '),(2905,608133138001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',4,'hermeshine','pjsm787','pjsm01@msn.com','Pedro Strazzara','G10 Calle Leon<br>Villa del Rey 1','Caguas','Puerto Rico','PUERTO RICO','00725-6262','(787) 360-9723','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 23:54:44',0,NULL,8,1,17,0,NULL,NULL),(2906,647195097002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','pjsm787','pjsm01@msn.com','Pedro Strazzara','G10 Calle Leon<br>Villa del Rey 1','Caguas','Puerto Rico','PUERTO RICO','00725-6262','(787) 360-9723','NoPaymentFailure','CheckoutComplete','Other','2010-12-13 23:54:44',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\räº‘å°   1\ræŸ”å…‰ä¼ž   1\r450d çœ¼ç½©     1 \rRR815345203CN\r'),(2907,646647459002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','katriena88','concealed_one07@yahoo.com','katriena greco','1862 17th ave','Kenosha','WI','UNITED STATES','53140-1628','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-14 00:46:02',0,NULL,3,1,1,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2908,647213375002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','gerbenzomp','rommelhok@zonnet.nl','Gerben Schmidt','Acaciastraat 35 bis','UTRECHT','','NETHERLANDS','3551 BE','030-2332533','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 00:51:53',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815345194CN\r'),(2909,647224894002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','georgegowan','georgegowan_69@hotmail.com','George Gowan','5/7 Teemangum Street','Tugun','Queensland','AUSTRALIA','4224','0755595142','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2910,647226208002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.9,'hermeshine','shehzadsadiq','princeshad@gmail.com','Shehzad Sadiq','KDB IT, Orica House, Level 2<br>123 Carlton Gore Road, New Market','Auckland','','NEW ZEALAND','1023','006421570070','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 01:34:21',0,NULL,3,1,3,1,NULL,'301p ä¸€æ‹–äºŒ   1 \rRR815345217CN\r'),(2911,647234844002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','soccerhong','centurydentalcare@msn.com','james hong','13011 century blvd','garden grove','CA','UNITED STATES','92843','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 02:01:55',0,NULL,3,1,1,1,NULL,NULL),(2912,607881103001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','saigon74vietnam','susantran77@hotmail.com','Susan Tran','118 Jackson Ave','Madison','AL','UNITED STATES','35758-2324','(256) 457-3393','NoPaymentFailure','CheckoutComplete','Other','2010-12-14 02:03:47',0,NULL,3,1,4,1,NULL,'tripod\r$25\rYW863884532CN\r'),(2913,647235850002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE1301',29.04,'hermeshine','paradebh','paravideo@gmail.com','Thiago Cordeiro','Av Carandai n:362 ap:1402<br>Bairro Funcionarios','Belo Horizonte','MG','BRAZIL','30130-060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 02:08:08',0,NULL,3,1,2,1,NULL,'cåž‹å¤§åŠ›å¤¹   3 \r725'),(2914,608180356001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','naomisabelle88','naomisabelle@gmail.com','Naomi Lee','16 Leedon Heights<br>#11-05','Singapore','','SINGAPORE','267937','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 03:02:49',0,NULL,3,1,11,1,NULL,NULL),(2915,647263642002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','thimn123','mitnak@gmail.com','thim naccache','50 av charles floquet code 159A','paris','ÃŽle-de-France','FRANCE','75007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 03:36:23',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   1 '),(2916,647274940002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE1301',29.04,'hermeshine','deeptech1','delsey@deeptech.com','Doug Elsey','6382 Coachford Way','Mississauga','ON','CANADA','L5N 3V8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 04:21:46',0,NULL,3,1,3,1,NULL,' RR815345115CN\r'),(2917,647274732002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2401',24.95,'hermeshine','apples452010','davidandsuewinnett@bigpond.com.au','Sue Winnett','120 Albury Street','Holbrook','New South Wales','AUSTRALIA','2644','0260632075','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 04:23:08',0,NULL,3,1,3,1,NULL,'RR815345177CN \r'),(2918,608213125001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','raquelkg_jewelry','raquelkg@terra.com.br','Raquel Guimaraes','4246 Village Dr<br>Apt E','Chino Hills','CA','UNITED STATES','91709-3719','(909) 644-0688','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 04:53:54',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ† nikon   1 '),(2919,647296686002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','priitk111','pkralla@gmail.com','priit kralla','Rooli tn 1 (AU Rool 12)<br>(phone. +3725183483)','Luige kyla, Kiili vald','Harju maakond','ESTONIA','75404','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 06:18:08',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   1 '),(2920,704786204015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','bonnydj','emanuele.bonaldo@gmail.com','emanuele bonaldo','via tor tre ponti nÂ°14','latina','latina','ITALY','04013','3283016028','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-14 07:39:40',0,NULL,3,1,2,1,NULL,' '),(2921,608244779001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','bbrigi80','atti73@freemail.hu','Brigitta Brocsko','FÃ¼lÃ¶ke u. 212/1.','Budapest','','HUNGARY','1112','+36-30-240-8694','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 08:05:20',0,NULL,3,1,2,1,NULL,NULL),(2922,647319042002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','c411','dbp@clara.net','David Butler','25 Pinewood Ave','Leigh on sea','Essex','UNITED KINGDOM','SS9 5PH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 08:26:51',0,NULL,3,1,2,1,NULL,NULL),(2923,608250446001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','dieseltommy','diesel_1964@hotmail.com','Tommy Berglund','Fargarevagen 3','Roknas','','SWEDEN','94631','+46911240041','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 08:35:19',0,NULL,3,1,2,1,NULL,NULL),(2924,608272323001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cyr_est','jyri@pixel.ee','JÃ¼ri Muhhin','Linnupesa 6','KÃµrvekÃ¼la','Tartu vald','ESTONIA','60512','+372 5112218','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 10:13:43',0,NULL,3,1,2,1,NULL,NULL),(2925,647345616002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','eurocrystal','buzasuk@hotmail.com','Jae-young Suk','Junggyegreen @115-508<br>Jung-Gye Dong,Nown-gu','seoul','','KOREA,REPUBLIC OF','139-785','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 10:26:56',0,NULL,3,1,2,1,NULL,NULL),(2927,608237619001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',46.19,'hermeshine','tarikyavuz','o.tarikyavuz@gmail.com','TarÄ±k Yavuz','HacÄ± KÃ¼Ã§Ã¼k Camii Sokak<br>No : 19 Sultanhamam - EminÃ¶nÃ¼','Ä°stanbul','','TURKEY','34120','05327036573','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 11:06:37',0,NULL,3,1,3,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon  1\rå¤§åŠ›å¤¹ çƒå°   2\råŒç¯å¤´  æ¬§æ ‡   1\r RR815345375CN\r'),(2929,608285256001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','resonance*','gokceelhan@yahoo.com','Mehmet Gokce Elhan','ENKA ENERJI SANTRALLERI<br>Taskisigi Mh. Cayirtarla Mevkii PK:225','ADAPAZARI','SAKARYA','TURKEY','54100','0902642890140','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 11:26:03',0,NULL,3,1,3,1,NULL,' RR815345322CN\r'),(2930,704861919015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','lowflyer3','iancturner@btconnect.com','Ian Turner','11 The Broadway','Swindon','Wiltshire','UNITED KINGDOM','SN25 3BN','01793523661','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-14 12:04:23',0,NULL,3,1,2,1,NULL,NULL),(2931,608312983001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',4,'AA1208',17.6,'hermeshine','aville1210','saccharine_babie@yahoo.com','dona ville rabago','hirose higashi 4-34-1<br>junes sayama 102','sayamashi','Saitama','JAPAN','3501320','0429467729','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 12:52:19',0,NULL,3,1,3,1,NULL,'canon 58mm åæŽ¥çŽ¯   4 \rRR815345455CN\r'),(2932,691214782016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','dav_es','andrewldavies@gmail.com','Attn: Andrew Davies - Best Buy UK','1 Portal Way Acton','London','London','UNITED KINGDOM','W36RS','07717266957','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-14 13:05:52',0,NULL,3,1,2,1,NULL,'å°å·æ— å­—å†…èƒ†åŒ…   1 '),(2933,704908034015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','jake496','mailjasonpaul@yahoo.co.uk','Jason Paul','496 Upper Newtownards Road','Belfast','Down','UNITED KINGDOM','BT4 3HB','02890290517','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-14 14:09:56',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š   2 è‹±æ ‡   \r115w 220v   2\råŒ…   1 \rlighting kit  $28\rYW864143366CN\r'),(2934,691242438016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'',43.8,'hutongstore','ze-photographer','6161207@inbox.lv','Valerijs Zemisevs','Anninmuizas bulv. 38/3-74c','Riga','','LATVIA','LV-1067','26161207','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-14 14:17:37',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚   1 \rRR815345319CN\r'),(2935,647418545002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','love668','stephen.rao@gmail.com','Stephen Rao','3918 Misty Morn Ln','Sugar Land','TX','UNITED STATES','77479-3205','(713) 854-6372','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 14:49:18',0,NULL,3,1,1,1,NULL,NULL),(2936,608351084001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','gcc_20050','kep_numberg@yahoo.com','Gunes Can Capanoglu','566. sok 3/1 erek apt<br>Akincilar Mah. Sirinyer Buca','Ä°zmir','','TURKEY','35380','905367739884','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 14:53:00',0,NULL,8,1,17,0,NULL,NULL),(2938,608351491001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3301',6.6,'hermeshine','gcc_20050','kep_numberg@yahoo.com','Gunes Can Capanoglu','566. sok 3/1 erek apt<br>Akincilar Mah. Sirinyer Buca','Ä°zmir','','TURKEY','35380','905367739884','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 14:53:56',0,NULL,3,1,2,1,NULL,'52mm uv   2\r58mm uv   1 '),(2940,704937063015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','pandorastyle2010','stylepandora@live.com','Adam  Hinchcliffe','23 Pensham Hill pershore','worcester','Worcestershire','UNITED KINGDOM','WR10 3HA','01386554940','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-14 15:21:53',0,NULL,3,1,2,1,NULL,NULL),(2941,608365838001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','mbbdesign','mboarman@gmail.com','Mark Boarman','7755 Freedom Ave NW','North Canton','OH','UNITED STATES','44720-6905','(330) 492-1338','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 15:37:23',0,NULL,3,1,1,1,NULL,NULL),(2942,704946164015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','mattserati','fatal@westnet.com.au','Matthew Tillotson','135 West Parade','Mt Lawley','Western Australia','AUSTRALIA','6050','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-14 15:42:19',0,NULL,3,1,2,1,NULL,NULL),(2943,647443072002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','fortunato190905','mway1@rambler.ru','Nina Sevastyanova','ispitateley av. 15-1, flat: 310','Saint-Petersburg','','RUSSIAN FEDERATION','197341','+7 (921) 937 - 0681','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 15:49:18',0,NULL,3,1,2,1,NULL,'éº‚çš®  1 '),(2944,647450302002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','bigfun28','lionel-gourdy@wanadoo.fr','lionel gourdy','63 av de saint ouen',' paris','ÃŽle-de-France','FRANCE','75017','0142262498','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 16:09:29',0,NULL,3,1,4,1,NULL,'ballhead  $20 \rYW864143355CN\r 退件 需要联系客户 从法国仓库取0141845515'),(2945,647455384002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','stor9560','suzietorre@aol.com','Suzie Torre','2381 Whittier Avenue','Scotch Plains','NJ','UNITED STATES','07076','(908) 202-2135','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 16:20:05',0,NULL,3,1,1,1,NULL,NULL),(2946,647478686002,120560203012,'52mm Lens lenscap for Nikon Combined shipping discounts',4,'AA1305',9.8,'hermeshine','varanasi','christopher.m.perez@tek.com','Christopher Perez','3532 SE Franklin St','Portland','OR','UNITED STATES','97202-1829','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 17:14:14',0,NULL,3,1,1,1,NULL,NULL),(2947,608405716001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.95,'hermeshine','kilincs99','r.miska@gmail.com','MihÃ ly RadvÃ nyi','NyÃ¹l utca 7','Budapest','','HUNGARY','1024','+36-20-823-46-98','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 17:18:46',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹   1 '),(2948,647486469002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','niteskie','jweedop@gmail.com','Jade Weedop','756 E 60 S','American Fork','UT','UNITED STATES','84003-2247','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-14 17:37:31',0,NULL,3,1,1,1,NULL,'cåž‹å¤§åŠ›å¤¹   1 '),(2949,705058813015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'',8.99,'hutongstore','itsnew2u2010','davespeedyrecovery@yahoo.co.uk','Dave Barrett','51 Chatham Place Curry Rivel','Langport','Somerset','UNITED KINGDOM','TA10 0HS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-14 18:59:49',0,NULL,3,1,2,1,NULL,'é˜²é›¨ç½©   1 '),(2950,647465852002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','kilin02','pokupka02@mail.ru','ÐÐ½Ð´Ñ€ÐµÐ¹ ÐšÐ¸Ð»Ð¸Ð½','Ð¢Ð°Ñ‚ÑŒÑÐ½Ñ‹ Ð‘Ð°Ñ€Ð°Ð¼Ð·Ð¸Ð½Ð¾Ð¹, 14, 8','Ð˜Ð¶ÐµÐ²ÑÐº','Ð£Ð´Ð¼ÑƒÑ€Ñ‚cÐºÐ°Ñ Ð ÐµÑÐ¿ÑƒÐ±Ð»Ð¸ÐºÐ°','RUSSIAN FEDERATION','426067','+79043127847','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 19:01:57',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815345407CN\r'),(2951,608476316001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','tyncho78','tyncho_78@fibertel.com.ar','Martin Gardeazabal','Bolivia 95 9no F','Capital Federal','Buenos Aires','ARGENTINA','1406','5411-4612-3368','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 19:32:39',0,NULL,3,1,2,1,NULL,NULL),(2952,691408768016,260660052497,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'',2.39,'hutongstore','noz_90','traffic_@live.co.uk','Nolan Galea','23, Triq il Gammar','Attard','','MALTA','ATD 2640','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-14 19:34:19',0,NULL,3,1,2,1,NULL,'77mm æŽ¥å£çŽ¯   1 '),(2953,647560832002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','robertbookshop','robert@neco.cz','Robert Tichy','Hrbitovni 33','Pilsen','West Bohemia','CZECH REPUBLIC','31200','00420-608826881','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 19:47:28',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹    2 '),(2954,647564059002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','ezrage12','ezrage@gmail.com','Ezra Genuth','Tarshish 77','Modiin','Israel','ISRAEL','71725','972-50-8918239','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 19:52:28',0,NULL,3,1,3,1,NULL,'cåž‹å¤¹    2  \rRR815345367CN\r'),(2955,646874440002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT014',71.3,'hermeshine','ruuuka','ruukachan@gmail.com','Ruuka Huang','9165 Rollin','Brossard','QC','CANADA','J4X 2P7','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 21:01:45',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\rå•ç¯å¤´   2\råå…‰ä¼ž   2 \rCP219437408CN\r'),(2956,608534235001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','jeloul76','jalalkhaldi@gmail.com','Jalal KHALDI','4 avenue san fernando','Montigny le bretonneux','ÃŽle-de-France','FRANCE','78180','0686568711','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 21:15:18',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ï¼‰   1\r2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡  2\r115w 220v   3 \råŒ…   1\rlighting kit  $30\rYW864143392CN\r'),(2957,647610352002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','jeloul76','jalalkhaldi@gmail.com','Jalal KHALDI','4 avenue san fernando','Montigny le bretonneux','ÃŽle-de-France','FRANCE','78180','0686568711','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 21:15:18',0,NULL,8,1,17,0,NULL,''),(2958,647622247002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 21:37:26',0,NULL,8,1,17,0,NULL,NULL),(2959,608543529001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 21:37:26',0,NULL,8,1,17,0,NULL,NULL),(2960,608544120001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 21:37:27',0,NULL,3,1,2,1,NULL,'58mm æ©¡èƒ¶ç½©   2\r67mm æ©¡èƒ¶ç½©   1 '),(2961,608552686001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0024',6.99,'hermeshine','romanelcuore2010','sheila86_b@hotmail.it','G.Pischedda c/o B.Sardegna','p.zza cavour 32','livorno','LI','ITALY','57126','0586836117','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 21:56:32',0,NULL,3,1,2,1,NULL,'canon å°åŒ…   1 '),(2962,647641880002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','diablots3','paradiss@telefonica.net','JORDI PARADIS MULERO','Urb.San BartolomÃ©, 23','Umbrete','AndalucÃ­a Ceuta y Melilla','SPAIN','41806','692641007','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 22:18:30',0,NULL,3,1,4,1,NULL,'tripod $16 \rYW864143381CN\r'),(2963,705193959015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','olppax','ollitee@wippies.fi','olli teelmÃ¤ki','paaskunnankatu 1 d 41','turku','lÃ¤nsi-suomen lÃ¤Ã¤ni','FINLAND','20540','0442584862','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-14 22:23:11',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´  1 '),(2964,608575734001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','marina_lima','marinadfl@hotmail.com','marina dubourcq fonseca lima','rua leonardo bezerra cavalcanti<br>300/702','recife','pernambuco','BRAZIL','52060030','558132682766','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 22:53:17',0,NULL,3,1,2,1,NULL,NULL),(2965,647664198002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','tetuve','fabtetard@free.fr','Fabrice TETARD','28 rue du lieutenant Fiancey','St EGREVE','RhÃ´ne-Alpes','FRANCE','38120','+33621490622','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 23:18:37',0,NULL,8,1,17,0,NULL,''),(2966,647655235002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','oncarf','castellari.franco@libero.it','Franco Castellari/Laura Leccese','Via Romita NÂ°42','Serravalle Scrivia','AL','ITALY','15069','3474786382','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 23:35:37',0,NULL,3,1,3,1,NULL,'sony æ‘„å½±èƒŒå¿ƒ  xl  é»‘è‰² åŽš   1 \rRR815345441CN\r'),(2967,608594939001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','big_dolt','dtlockard@gmail.com','David  Lockard','PO Box 240147','Douglas','AK','UNITED STATES','99824-0147','(907) 364-2965','NoPaymentFailure','CheckoutComplete','Other','2010-12-14 23:57:12',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚   1 \rlight stand $18\rYW863884543CN\rRR764990593CN\r'),(2968,705236202015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','edel3597','miskis82@hotmail.com','edel bertram','33 gateacre walk, brooklands','sale','Greater Manchester','UNITED KINGDOM','m23 9ba','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-14 23:57:31',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(2969,608606027001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','moca2100','prasush@hotmail.com','Pramod Puri','12688 CHAPMAN AVE<br>Unit 3211','GARDEN GROVE','CA','UNITED STATES','92840-4043','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 00:38:49',0,NULL,3,1,1,1,NULL,NULL),(2970,608587914001,110529627209,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','tetuve','fabtetard@free.fr','Fabrice TETARD','28 rue du lieutenant Fiancey','St EGREVE','RhÃ´ne-Alpes','FRANCE','38120','+33621490622','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 00:56:09',0,NULL,8,1,17,0,NULL,NULL),(2971,647666973002,120601699795,'New 3 filters & Ring holder set 4 Cokin System P Series',1,'AKT026',22.8,'hermeshine','tetuve','fabtetard@free.fr','Fabrice TETARD','28 rue du lieutenant Fiancey','St EGREVE','RhÃ´ne-Alpes','FRANCE','38120','+33621490622','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 00:56:10',0,NULL,8,1,17,0,NULL,NULL),(2972,608589441001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','tetuve','fabtetard@free.fr','Fabrice TETARD','28 rue du lieutenant Fiancey','St EGREVE','RhÃ´ne-Alpes','FRANCE','38120','+33621490622','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 00:56:11',0,NULL,3,1,4,1,NULL,' 717 180    1 \r52mm çŽ¯æž¶  1\r58mm çŽ¯æž¶  1\rND2/4/8   1\ræ¸å˜ç°   1\rcpl   1\rtripod $30\rYW863884591CN\r\r'),(2973,608609597001,110523102217,'67mm Lens lenscap for Canon Combined shipping discounts',1,'AA1302',2.6,'hermeshine','kaimeischke_2007','kai@meischke.net','Kai Meischke','308/15 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0420769443','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 01:02:58',0,NULL,8,1,17,0,NULL,NULL),(2974,608609427001,110531023440,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',4,'hermeshine','kaimeischke_2007','kai@meischke.net','Kai Meischke','308/15 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0420769443','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 01:02:58',0,NULL,3,1,2,1,NULL,'450d çœ¼ç½©  1\r67mm é•œå¤´ç›–  canon   1 '),(2975,600759322001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',2,'AC2301',14.5,'hermeshine','goldorak-----go','myspace@hot-bike.ch','chris mettraux','pontaise 41','lausanne','','SWITZERLAND','1018','0041763482041','NoPaymentFailure','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,' 2x lenscase (s),\r 2x lenscase(m)\rRR815345438CN\r'),(2976,608635015001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',2,'AE1502',164,'hermeshine','jumpby','juanmaasecas@hotmail.com','juan manuel herrera marin','c/Palacios ValdÃ©s 6, p1-2','Linares','AndalucÃ­a Ceuta y Melilla','SPAIN','23700','648754551','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 02:32:56',0,NULL,3,1,4,1,NULL,'tripod $30 \rYW863884484CN\r'),(2977,608662172001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','bogopolsky1','bog.vadim@gmail.com','vad bogopolsky','motzkin 21 ap 10','netanya','israel','ISRAEL','42460','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 04:14:38',0,NULL,3,1,3,1,NULL,'åˆ†ä¸¤ç¥¨å‘ \rRR815345398CN\rRR815345384CN\r\r'),(2978,608662482001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','kobble','kolbein.svensson@gmail.com','Kolbein Svensson','Geitastrandveien 21','Orkanger','','NORWAY','7300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 04:16:12',0,NULL,3,1,2,1,NULL,NULL),(2979,608686556001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','cz3221','cezeez@yahoo.com','Cesar Brito','2248 W 233rd St','Torrance','CA','UNITED STATES','90501-5726','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 06:38:46',0,NULL,3,1,1,1,NULL,NULL),(2980,647776718002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','pixoid','mra@pixar.com','Mark R. Adams','1838 Heather Ln','Petaluma','CA','UNITED STATES','94954-8591','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 06:41:57',0,NULL,3,1,1,1,NULL,NULL),(2981,608692713001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','iamdiva007','angela@angelacalderon.com','Angela Calderon','1029 Chatsworth Ln','Woodstock','GA','UNITED STATES','30189-6683','(770) 653-7116','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 07:16:40',0,NULL,3,1,1,1,NULL,NULL),(2982,647794147002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','chernov_da','cdastudio@mail.ru','Dmitry Chernov','Ulyanovskaya 2-60<br>Ruza','Ruza / Moscow','','RUSSIAN FEDERATION','143103','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 08:21:13',0,NULL,8,1,17,0,NULL,NULL),(2983,647793714002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',2,'AA2106',70,'hermeshine','chernov_da','cdastudio@mail.ru','Dmitry Chernov','Ulyanovskaya 2-60<br>Ruza','Ruza / Moscow','','RUSSIAN FEDERATION','143103','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 08:21:14',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ xxl   2\rcanon èƒŒå¿ƒ xxxl  1 \rRR815345954CN\r'),(2984,705378165015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'',27,'hutongstore','ziimbabve','abra-kadabra@bk.ru','Yakov Sakhan','Gromova street, 15-117','Rubtsovsk','Altay region','RUSSIAN FEDERATION','658213','+79132796620','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-15 08:31:17',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815345923CN\r'),(2985,608707691001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','giulix99','sy99@hotmail.it','VIALARDI ANDREA','VIA DELLE GINESTRE 16/16','GENOVA','GE','ITALY','16137','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 08:41:56',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815345866CN\r'),(2986,608729283001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','kobble','kolbein.svensson@gmail.com','Kolbein Svensson','Geitastrandveien 21','Orkanger','','NORWAY','7300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 10:18:15',0,NULL,3,1,2,1,NULL,'å€’å½±æ¿  1 '),(2987,647831476002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','yskunto','kunto_ys@peter.petra.ac.id','Yohanes Sondang Kunto','Blimbing Indah Tama C2/50','Malang','East Java','INDONESIA','65126','+62 341 496491','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 11:06:36',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRR815345945CN\r'),(2988,647827940002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','bushutte','vautinsh@gmail.com','Valdis Krumins','Skolas iela 3-100','Salaspils','','LATVIA','LV-2121','+371 29239141','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 10:53:07',0,NULL,8,1,17,0,NULL,NULL),(2989,608737494001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','bushutte','vautinsh@gmail.com','Valdis Krumins','Skolas iela 3-100','Salaspils','','LATVIA','LV-2121','+371 29239141','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 10:53:07',0,NULL,3,1,3,1,NULL,'å•ç¯å¤´ æ¬§æ ‡   1\r115w 220v ç¯æ³¡   1 \rRR815346005CN\r'),(2990,647839279002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','ifel79','ifelmail@gmail.com','Igor Kanjuka','N. Uzhvij, building 72<br>flat 236','Kharkov','','UKRAINE','61195','380(66)7805537','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 11:35:07',0,NULL,3,1,2,1,NULL,' '),(2991,647833045002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','simonepuma80','21tiger1@aliceposta.it','Simone Zanni','via al fiume<br>1','Cambiasca','VB','ITALY','28814','3488185038','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 12:29:23',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶  ï¼ˆ ç™½ ï¼‰ 1\r2m ç¯æž¶  2\råŒç¯å¤´ æ¬§æ ‡  2\r115w 220v   4\råå…‰ä¼ž   2\råŒ…    1\rlighting kit  $30\r\r'),(2992,691778593016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'',26.5,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-15 13:27:48',0,NULL,8,1,17,0,NULL,NULL),(2993,705467618015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-15 13:27:47',0,NULL,8,1,17,0,NULL,' '),(2994,691778103016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-15 13:27:48',0,NULL,3,1,4,1,NULL,'2m x 3m èƒŒæ™¯æž¶   1\r3m x6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡   2\r115w 220v   2\råŒ…   1\rä¸€è½¬å››ç¯å¤´  1\r100-150 åå…‰æ¿    1 \rä¸€ç¥¨ä¸¤ä»¶å§ï¼Œåå…‰æ¿ä¸å¥½åŒ…çš„è¯\rlighting kit  $32\rYW863884506CN\r'),(2995,608792114001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','imstaeb','dovy@bezeqint.net','Dov Yassky','13, Sderot Chen','Tel Aviv','--','ISRAEL','64071','97236209031','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 14:10:27',0,NULL,3,1,2,1,NULL,'52-52 åŒé˜³çŽ¯   1 '),(2996,647930993002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','arturbaikov','abaikov@yandex.ru','Artur Baikov','Kyivskaya 25-29','Zhytomyr','','UKRAINE','10014','380-412-471753','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 16:19:17',0,NULL,3,1,2,1,NULL,NULL),(2997,608495971001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',5.94,'hermeshine','0440.literatboris','literatboris@gmail.com','Boris Literat','Hayogev -- 15','Ofaqim','','ISRAEL','87613','+97289960440','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 16:27:04',0,NULL,3,1,2,1,NULL,'58mm é•œå¤´ç›–  canon  1\r58mm æ©¡èƒ¶ç½©    1 '),(2998,705542597015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'',18.3,'hutongstore','dgs_tomek','td145@vp.pl','Tomasz Dobrzanski','12 castle walk','didcot','Oxfordshire','UNITED KINGDOM','ox117pd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-15 17:05:32',0,NULL,3,1,3,1,NULL,'ä¸€è½¬å››ç¯å¤´   2 \rRR815345910CN\r'),(2999,648017670002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','punchihewa','manojpunchihewa@yahoo.com','Manoj Punchihewa','1145 Wintergreen Cv','Cordova','TN','UNITED STATES','38018-8828','(901) 921-1196','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 19:17:08',0,NULL,3,1,1,1,NULL,NULL),(3000,648048663002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',8,'AA1301',19.4,'hermeshine','houndqueen','topalov5@optusnet.com.au','HELEN TOPALOV','6 CURLEW CAMP ROAD','MOSMAN','New South Wales','AUSTRALIA','2088','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 20:11:25',0,NULL,3,1,3,1,NULL,'RR815345659CN\r'),(3001,648057487002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','lelodani','re_nato@yahoo.com','Renato F De Araujo','75 Pierrepont St<br>Apt 6E','Brooklyn','NY','UNITED STATES','11201','(718) 855-4235','NoPaymentFailure','CheckoutComplete','Other','2010-12-15 20:31:32',0,NULL,8,1,17,0,NULL,NULL),(3002,648054929002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','lelodani','re_nato@yahoo.com','Renato F De Araujo','75 Pierrepont St<br>Apt 6E','Brooklyn','NY','UNITED STATES','11201','(718) 855-4235','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 20:31:33',0,NULL,3,1,1,1,NULL,'é˜²å¯’ç½©   1\rç¢—ç½© p1    1 '),(3003,648084065002,120568071807,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',4.4,'hermeshine','bestrashny','gregorygur@gmail.com','gregory gurevich','nahal tzvi 32/16','migdal haemek','','ISRAEL','23049','972-0544831155','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 21:15:12',0,NULL,3,1,2,1,NULL,'canon-52 åæŽ¥çŽ¯   1 '),(3004,608711449001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','asterixbcn','benfranklinfu@yahoo.de','Ricard Riel Cabrera','ConcÃ²rdia 14, 2-2','Barcelona','CataluÃ±a','SPAIN','08004','675733555','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 21:19:37',0,NULL,8,1,17,0,NULL,NULL),(3005,608709201001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','asterixbcn','benfranklinfu@yahoo.de','Ricard Riel Cabrera','ConcÃ²rdia 14, 2-2','Barcelona','CataluÃ±a','SPAIN','08004','675733555','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 21:19:38',0,NULL,8,1,17,0,NULL,' '),(3006,608710881001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.3,'hermeshine','asterixbcn','benfranklinfu@yahoo.de','Ricard Riel Cabrera','ConcÃ²rdia 14, 2-2','Barcelona','CataluÃ±a','SPAIN','08004','675733555','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 21:19:38',0,NULL,3,1,2,1,NULL,'\r52mm é•œå¤´ç›– nikon   1\rå°å·å†…èƒ†åŒ… nikon   1 '),(3007,692050293016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'',26.5,'hutongstore','dougoudoum','demoulinfabrice@gmail.com','demoulin fabrice','pta carlos manito torres nÂº1, 4f','setubal','setubal','PORTUGAL','2900','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-15 21:38:02',0,NULL,3,1,3,1,NULL,'100-150 åå…‰æ¿    1\rRR815345999CN\r  '),(3008,648103307002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT014',73.3,'hermeshine','james7007_123','jakub.snabl@seznam.cz','Jakub Å nÃ¡bl','Pod MÃ½tem 60','Å ternberk','Czech Republic','CZECH REPUBLIC','78501','00420777012130','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 21:54:53',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\rå•ç¯å¤´  æ¬§æ ‡   2\råå…‰ä¼ž   2 \rCP219437442CN\r'),(3009,648120701002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','s.himanshu09','s.himanshu9@gmail.com','Himanshu','408 Joseph Ct','Oswego','IL','UNITED STATES','60543-7315','(312) 203-0413','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 22:39:21',0,NULL,3,1,1,1,NULL,NULL),(3012,609065003001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','shipsforsail','mkdavies@shaw.ca','Ken Davies','582 Hawthorne Rise','Parksville','BC','CANADA','v9p 2k3','(250) 752-4480','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 01:22:25',0,NULL,8,1,17,0,NULL,NULL),(3013,648170356002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','shipsforsail','mkdavies@shaw.ca','Ken Davies','582 Hawthorne Rise','Parksville','BC','CANADA','v9p 2k3','(250) 752-4480','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 01:22:26',0,NULL,3,1,2,1,NULL,'EW-73B   1\rET-65B    1 '),(3014,609073207001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','moreiralm','lmiguelmoreira@gmail.com','Luis Moreira','Rua Pedras da MarÃ©, nÂº 794 3Âº DT sul<br>S. Felix Marinha','V.N.Gaia','S Felix Marinha','PORTUGAL','4410-129','+351919946667','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 01:53:18',0,NULL,3,1,2,1,NULL,NULL),(3015,609074925001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','tazy1115','al-fadh1511@hotmail.com','Fadillah Ali','No.8, spg. 806-13, Kg. Jangsak<br>Jalan Gadong','Bandar Seri Begawan','Brunei Muara','BRUNEI DARUSSALAM','BF 2720','+6738839039','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 02:00:20',0,NULL,3,1,3,1,NULL,' RR815345971CN\r'),(3016,609075602001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','mkalogios','deppytefaa@yahoo.gr','KALOGYIOS EMMANOUHL','MOUSSON 98B','ATHENS','NIKAIA,NEAPOLH','GREECE','18452','6976613475','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 02:01:37',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR815345937CN\r'),(3017,609075756001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','garym165','smclean31@cogeco.ca','Gary','McLean<br>123 Kingham Road','Acton','ON','CANADA','L7J1S3','(519) 929-9255','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 02:02:36',0,NULL,3,1,2,1,NULL,'éº‚çš®  2 '),(3018,609067269001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','lucasdjone','lucasdjone@hotmail.com','lucas haedo','barrio smata 1 , manzana O lote 12<br>12','cordoba','cordoba','ARGENTINA','5016','4622004','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 02:08:03',0,NULL,3,1,2,1,NULL,''),(3019,609087318001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','jw12ang','jwang@wideopenwest.com','Jimmy Wang','511 Gateshead Dr','Naperville','IL','UNITED STATES','60565-3186','(630) 548-9812','NoPaymentFailure','CheckoutComplete','Other','2010-12-16 02:52:29',0,NULL,3,1,1,1,NULL,' '),(3020,648205985002,120568071854,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','hiwave','ksh5-2@hanmail.net','soohyun kim','Life Apt.3-1406, Hang-dong 7-ga, Jung-gu, Incheon, Korea','Incheon','Incheon','KOREA,REPUBLIC OF','400-751','82-32-889-6439','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 03:30:51',0,NULL,3,1,6,1,NULL,'2m ç¯æž¶   2\råŒç¯å¤´  2\råå…‰ä¼ž   2\r åŒ…    1 \ræ–°åŠ å¡ems\rEX000273287SG\r'),(3021,609129019001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','tommeo','tommeo@sympatico.ca','Thomas Brezinski','783A  Apt. 3 Danforth Ave','Toronto','ON','CANADA','m4j1l2','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 06:17:03',0,NULL,8,1,17,0,NULL,NULL),(3022,648237740002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','tommeo','tommeo@sympatico.ca','Thomas Brezinski','783A  Apt. 3 Danforth Ave','Toronto','ON','CANADA','m4j1l2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 06:17:03',0,NULL,8,1,17,0,NULL,NULL),(3023,648235923002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','tommeo','tommeo@sympatico.ca','Thomas Brezinski','783A  Apt. 3 Danforth Ave','Toronto','ON','CANADA','m4j1l2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 06:17:04',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1\rcåž‹å¤¹  1\réº‚çš®    1 \rRR815345778CN\r'),(3024,648240010002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','ymliew2','ymliew@hotmail.com','Liew Yien Mau','182, Taman Genesis,<br>Jln Matang Batu Kawa','Kuching','Sarawak','MALAYSIA','93050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 06:32:06',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(3025,648247287002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','platinumz','platinum_ong@hotmail.com','Platinum Ong Choon Yen','42-G, GROUND FLOOR, JALAN DINAR, F U3/F,<br>TAMAN SUBANG PERDANA, SEK U3,','SHAH ALAM','SELANGOR,MALAYSIA','MALAYSIA','40150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 07:18:12',0,NULL,3,1,2,1,NULL,NULL),(3026,608902466001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3401',23.45,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7Âº 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 08:05:09',0,NULL,3,1,3,1,NULL,' 6662a å¿«è£…æ¿   2\r77mm çŽ¯æž¶  1\r430è‚¥çš‚ç›’    1\rRR815345680CN\r\r\r'),(3027,609162484001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','tatiana.nefedova','tatiana.nefyodova@gmail.com','Tatiana Nefedova','Shkolniy bulvar, dom 20, kv 25','Chernogolovka','Moscow district','RUSSIAN FEDERATION','142432','007-9057481744','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 09:33:23',0,NULL,3,1,2,1,NULL,NULL),(3028,692256524016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'',22,'hutongstore','photographer1506','edwarddullard@gmail.com','EDWARD DULLARD','13 DE LA SALLE PLACE','KILKENNY CITY','COUNTY KILKENNY','IRELAND','056','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-16 09:35:39',0,NULL,3,1,3,1,NULL,' RR815345755CN\r'),(3029,609173111001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','zheyu321','zhe1984@hotmail.com','Thor Yu Zhe','2, Jalan Indah 1/28,<br>Taman Universiti Indah,','Seri Kembangan','Selangor Darul Ehsan','MALAYSIA','43300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 10:22:36',0,NULL,3,1,2,1,NULL,NULL),(3030,705984993015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','gerardm5368','f63photos@eircom.net','Gerard Murphy','Lavally Lower, Mallow','Cork','Cork','IRELAND','default','00353851740738','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-16 12:10:49',0,NULL,3,1,2,1,NULL,NULL),(3031,648309188002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','guscupra','guscupra@hotmail.com','GUSTAVO VALVERDE MUÃ‘OZ','BABOR NÂº40','ALHAURIN DE LA TORRE (MALAGA)','AndalucÃ­a Ceuta y Melilla','SPAIN','29130','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 12:15:45',0,NULL,3,1,3,1,NULL,'sony èƒŒå¿ƒ é»‘è‰²   xxl    1 \rRR815345693CN\r'),(3032,647503439002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','tilberien','herzog.pavel@gmail.com','Pavel Herzog','Fujikoki Czech s.r.o.<br>Prumyslova 386','Louny','CZ','CZECH REPUBLIC','44001','415652918','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 12:27:22',0,NULL,3,1,2,1,NULL,' '),(3033,648317237002,120454246029,'4 way Macro Slider for CANON NIKON SONY Olympus PENTAX',1,'AE3102',51.9,'hermeshine','digiser','prodjs@teleline.es','Jose Luis Solar PeÃ±a','Av/ Carmen Miranda 6','Pravia','Asturias','SPAIN','33120','985000000','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 12:45:09',0,NULL,3,1,3,1,NULL,'å¾®è·æž¶  1 \rRR815345702CN\r'),(3034,609206678001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','gizmofr77','tnshop@tiet.net','Trung Nghi TIET','30 Thurlow Street','Redfern','New South Wales','AUSTRALIA','2016','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 12:45:31',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rlight stand  $20\rYW863884580CN\r\r'),(3035,609213461001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','falcorner','pdelalastra@wanadoo.es','Pablo de la Lastra Marcos','Velarde nÂº 2 - 3Âº C','Sevilla','AndalucÃ­a Ceuta y Melilla','SPAIN','41001','652926047','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 13:07:48',0,NULL,8,1,17,0,NULL,NULL),(3036,648322470002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','falcorner','pdelalastra@wanadoo.es','Pablo de la Lastra Marcos','Velarde nÂº 2 - 3Âº C','Sevilla','AndalucÃ­a Ceuta y Melilla','SPAIN','41001','652926047','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 13:07:49',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž   1\r110cm 5in 1  åå…‰æ¿   1\rYW863884576CN\r\rç‡•æ–‡ä¸€ç¥¨ä¸¤ä»¶'),(3037,692322331016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',38,'hutongstore','iancook458','iancook@ijcphotography.co.uk','Ian Cook','647 Monnow Way Bettws','Newport','Gwent','UNITED KINGDOM','NP20 7DN','01633855280','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-16 13:16:10',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶   1\rreflector holder  $18\rYW863884565CN\r\r'),(3038,648332648002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','roma1414','romabeg@hotmail.com','Roman Beglarov','Aviakonstruktorov d.36, kv90','Sankt-Petersburg','','RUSSIAN FEDERATION','197373','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 13:41:18',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…  1'),(3039,648338944002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','rrobbiefcb','robert@limesmodel.hu','Robert Racz','Sas Militaria - Szinvonal<br>Sas u. 5.','Budapest','Hungary','HUNGARY','1051','+36209228474','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 14:00:57',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶   2\r4ç¯å¤´ æ£š   2  æ¬§æ ‡   \r45w  8\r åŒ…    1\rCP219437411CN\r\r '),(3040,692328179016,260660053270,'New Neoprene Reversible Cover for Nikon D300S D700 L',1,'',6.1,'hutongstore','ant-eater','koziel@tlen.pl','Opus-B, Tomasz KozieÅ‚','Pijarska 9','KrakÃ³w','maÅ‚opolskie','POLAND','31-015','507 260707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-16 14:22:58',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ… nikon   1 '),(3041,692356446016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'',5.9,'hutongstore','fotoboy64','fotoboy@apollo.lv','Maris J IK','Darzu 60-22','Rezekne','','LATVIA','LV-4601','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-16 14:50:28',0,NULL,3,1,2,1,NULL,''),(3042,646345024002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ratinha40','vladyszimba@hotmail.com','vladys cargnin','6073 Boca Colony Dr<br>Apt 1211','Boca Raton','FL','UNITED STATES','33433','(954) 562-0679','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 15:00:05',0,NULL,3,1,1,1,NULL,NULL),(3043,706059301015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','copelinter','ricoplin@googlemail.com','Richard Copeland','69 Delamere RD Bedworth','Nuneaton','Warwickshire','UNITED KINGDOM','CV12 8SG','02476314961','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-16 15:06:21',0,NULL,3,1,2,1,NULL,'45w   2 '),(3044,706063170015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','vincelotte','autenzio@hotmail.com','antonio autenzio','171 rue saint denis','paris','ÃŽle-de-France','FRANCE','75002','0622706868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-16 15:16:15',0,NULL,3,1,2,1,NULL,NULL),(3045,609257099001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','kenclimber','ken_noyce@hotmail.com','Kenneth Noyce','2245 Nice Ave<br>Apt A2','Mentone','CA','UNITED STATES','92359-9757','(801) 735-8697','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 15:30:37',0,NULL,3,1,1,1,NULL,''),(3046,609255474001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','blancaportanet','blancasc@gmail.com','BLANCA SANCHEZ CARRERA','PRINCIPE DE VERGARA 58 4Âº C-I','MADRID','Madrid','SPAIN','28006','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 15:32:19',0,NULL,3,1,4,1,NULL,'tripod   $15 \rYW863884554CN\r'),(3047,706074036015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','profclimb','prandy@waitrose.com','Kenneth Prandy','School House Llangattock Lingoed','Abergavenny','Monmouthshire','UNITED KINGDOM','NP7 8RR','01873821758','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-16 15:42:19',0,NULL,3,1,2,1,NULL,NULL),(3048,648377423002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.2,'hermeshine','akilles4','akilles@pacinfo.com','John C. Rowland','637 7th St','Springfield','OR','UNITED STATES','97477-4631','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 15:56:45',0,NULL,3,1,1,1,NULL,NULL),(3049,609270552001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','davidof4','davidbalick@gmail.com','David Balick','765 Bunker Hill Rd','King of Prussia','PA','UNITED STATES','19406-1553','(610) 354-0115','NoPaymentFailure','CheckoutComplete','Other','2010-12-16 16:09:11',0,NULL,3,1,1,1,NULL,'sf18-canon   1 '),(3050,648386285002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2401',49.9,'hermeshine','eniacservice','o.belishta@eniac-services.com','Olsi Belishta','Klinika Ikeda<br>Rr. Kongresi i Manastirit','Tirane','Tirane','ALBANIA','1015','+355672066378','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 16:18:16',0,NULL,3,1,3,1,NULL,'50-70 æ£š é€šç”¨å¡å£  2 \rRR815345614CN\r'),(3051,648390726002,120601699795,'New 3 filters & Ring holder set 4 Cokin System P Series',1,'AKT026',22.8,'hermeshine','joachimwiig','joachimwiig@hotmail.com','joachim wiig raak','kvamstrÃ¸a 10','steinkjer','','NORWAY','7715','(+47) 97756510','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 16:31:05',0,NULL,8,1,17,0,NULL,''),(3052,648392161002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','joachimwiig','joachimwiig@hotmail.com','joachim wiig raak','kvamstrÃ¸a 10','steinkjer','','NORWAY','7715','(+47) 97756510','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 16:33:02',0,NULL,3,1,3,1,NULL,' ND4/ 8  æ¸å˜ç°  58mm çŽ¯æž¶   1 \r77mm æŽ¥å£çŽ¯   1\rRR815345628CN\r'),(3054,648409395002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','doubleview','yausser@usa.net','Richard Yaussi','1622 W Longhill Dr','Monterey Park','CA','UNITED STATES','91754-4523','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 17:16:12',0,NULL,3,1,1,1,NULL,NULL),(3055,609297236001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','enigma505','enigma505@email.com','Patrick Blake II','DynCorp International<br>Unit 42119','APO','AE','AA','09342','(702) 325-4379','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 17:18:03',0,NULL,3,1,1,1,NULL,NULL),(3056,648418991002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','pwakefield71','wakefieldfx@hotmail.com','Patrick Wakefield','77 Masters Dr','Barrie','ON','CANADA','L4M6W9','(705) 734-0909','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 17:37:29',0,NULL,3,1,2,1,NULL,'cåž‹å¤§åŠ›å¤¹   2 '),(3057,648427883002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','hotcorner4jeff','jeffabctv@yahoo.com','Jeff Caldwell','10061 Riverside Dr<br># 210','Toluca Lake','CA','UNITED STATES','91602','(818) 231-3702','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 18:09:32',0,NULL,3,1,1,1,NULL,'canon å°å·å†…èƒ†åŒ…   1 '),(3058,609331580001,110533631226,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','najort-perm','alexandr.abramenkov@gmail.com','Alexandr Abramenkov','M. Gorkogo Street<br>64-145','Perm','Permskiy Kray','RUSSIAN FEDERATION','614007','8-902-7918020','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 18:33:55',0,NULL,3,1,2,1,NULL,'72mm æ©¡èƒ¶ç½©   1 '),(3059,609335184001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','inafih','knaphih@gmail.com','Ibrahim Nafih','46/1<br>Rathnawali Road','Kalubowila','Western Province','SRI LANKA','94','+94779449789','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 18:41:37',0,NULL,3,1,2,1,NULL,'58mm uv   1 '),(3060,648450497002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','hadijoyce','hadij@hotmail.com','Hadi Joyce','1588 Boulder Walk Dr SE','Atlanta','GA','UNITED STATES','30316','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 18:43:09',0,NULL,3,1,1,1,NULL,NULL),(3061,706158929015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'',6.1,'hutongstore','ex-dylan-dog','ex_dylan_dog@yahoo.it','Luca Radatti','Via B. Croce, 16','Paese','TV','ITALY','31038','3286645016','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-16 18:57:41',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon   1 '),(3062,692487786016,260660052780,'New Circular Polarizing C-PL CPL Filters for Cokin P',1,'',10.99,'hutongstore','agajuce','agnieszka.lewin@yahoo.co.uk','agnieszka lewin','139 anson road','crickelwood','London','UNITED KINGDOM','nw2 4ah','07766640925','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-16 19:18:22',0,NULL,3,1,2,1,NULL,'cpl   1 '),(3063,648510540002,120593060982,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1101',22.9,'hermeshine','ggcan','gg@primus.ca','Glane Gorveatt','171 Hages Lane','Prospect','NS','CANADA','B3T 2A4','(902) 852-4201','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 20:39:06',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ å¤å­£  L   1 \rRR815345631CN\r'),(3064,648515679002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','bobbyddixon117','bobbyddixon@hotmail.com','Bobby D. Dixon','1617 Country Meadows Dr','Sevierville','TN','UNITED STATES','37862-9335','(865) 441-1859','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 20:46:13',0,NULL,3,1,1,1,NULL,NULL),(3065,648526431002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','pedoviejo59','jellynoel@yahoo.com','joel w kaufmann','1023 N Bishop Ave','dallas','TX','UNITED STATES','75208-4112','(214) 300-5840','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 21:08:25',0,NULL,8,1,17,0,NULL,NULL),(3066,648527721002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','pedoviejo59','jellynoel@yahoo.com','joel w kaufmann','1023 N Bishop Ave','dallas','TX','UNITED STATES','75208-4112','(214) 300-5840','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 21:10:13',0,NULL,3,1,1,1,NULL,'67mm é•œå¤´ç›–   canon   1\r67mm æ©¡èƒ¶ç½©    1 '),(3067,609411022001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','wiserhoffwiserhoff','wiserhoff@gmail.com','Dinar Burnashev','Kolomenskaya street, 15-2-612','Moscow','','RUSSIAN FEDERATION','115142','(964)-5373272','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 21:13:47',0,NULL,8,1,17,0,NULL,NULL),(3068,648530875002,120454221534,'Green.L 77mm Neutral Density ND4 Filter ND 4 77',1,'AE2307',8.2,'hermeshine','wiserhoffwiserhoff','wiserhoff@gmail.com','Dinar Burnashev','Kolomenskaya street, 15-2-612','Moscow','','RUSSIAN FEDERATION','115142','(964)-5373272','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 21:17:16',0,NULL,3,1,2,1,NULL,'110cm 5in1  åå…‰æ¿  1\r77mm ND4   1 '),(3069,648530918002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','cktechguy13','saigonohato@gmail.com','Chris  King','2446 Taylor Ave','corona','CA','UNITED STATES','92882','(951) 310-0796','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 21:18:51',0,NULL,3,1,1,1,NULL,NULL),(3070,609431191001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','epkpern','per.norlander@telia.com','Per Norlander','Vikingagatan 2','Vikingstad','','SWEDEN','59049','+461381041','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 21:58:39',0,NULL,3,1,2,1,NULL,NULL),(3071,609435264001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',2,'AC2301',14.5,'hermeshine','chrisxx178','csengel.krisztian@chello.hu','KrisztiÃ¡n Csengel','Kisfaludy u. 32.','Budapest','','HUNGARY','1047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 22:10:27',0,NULL,8,1,17,0,NULL,''),(3072,648554735002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',2,'AC1302',18.5,'hermeshine','chrisxx178','csengel.krisztian@chello.hu','KrisztiÃ¡n Csengel','Kisfaludy u. 32.','Budapest','','HUNGARY','1047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 22:13:06',0,NULL,3,1,3,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—  2\rå¤§å·å†…èƒ†åŒ… nikon   2\rRR815345645CN\r'),(3073,647269007002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','nickball982009','nickball98@yahoo.com','Nick Ball','2217 Lafayette Ter','Clinton','IA','UNITED STATES','52732-6647','(563) 243-4120','NoPaymentFailure','CheckoutComplete','Other','2010-12-16 22:29:05',0,NULL,3,1,1,1,NULL,'sony èƒŒå¿ƒ é»‘è‰²  xxl  1 '),(3075,609480042001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','luizweb','luizantoniogsimoes@gmail.com','Luiz Simoes','Rua Olavo de Paula Borges, 83<br>ap. 23-B','Santos','SÃ£o Paulo','BRAZIL','11035-130','13-3236-8826','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 00:44:50',0,NULL,3,1,2,1,NULL,NULL),(3077,609530525001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','lliatep','zhitenko77@yandex.ru','Ivan Zhitenko','Kurchatova,23A,40','Chelyabinsk','Chelyabinskaya oblast','RUSSIAN FEDERATION','454092','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 04:22:33',0,NULL,3,1,2,1,NULL,NULL),(3078,648656858002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','jrbegalli','raphael.begalli@yahoo.com.br','JoÃ£o Raphael Grazia Begali','Av. Dr. Sylvio de Aguiar Maya, 268<br>Centro','Pedreira','SP','BRAZIL','13920-000','55 19 3893 5319','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 04:23:55',0,NULL,8,1,17,0,NULL,NULL),(3079,609529230001,110532007517,'Male-Male 58mm-58mm Macro Combined shipping discounts',1,'AA1213',3.8,'hermeshine','jrbegalli','raphael.begalli@yahoo.com.br','JoÃ£o Raphael Grazia Begali','Av. Dr. Sylvio de Aguiar Maya, 268<br>Centro','Pedreira','SP','BRAZIL','13920-000','55 19 3893 5319','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 04:23:56',0,NULL,3,1,2,1,NULL,'58-58 åŒé˜³çŽ¯  1\ræœºèº«ç›–/é•œå¤´åŽç›–  canon   1 '),(3080,609537402001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','tom4038525','tom.march.ca@gmail.com','Tom March','710 Earl Grey Cres SW','Calgary','AB','CANADA','T2S0N7','(403) 245-8435','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 05:01:29',0,NULL,3,1,2,1,NULL,NULL),(3081,706412734015,250692237866,'New 3 filters & Ring holder for Cokin System P Series',1,'',18.9,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 05:01:58',0,NULL,3,1,2,1,NULL,'ND2/4/8  72mm çŽ¯æž¶  1 '),(3082,706417842015,250692237866,'New 3 filters & Ring holder for Cokin System P Series',1,'',18.9,'hutongstore','waixmonkey','frank@protrader.com.au','Frank Watkins','13 Klem Ave','Redcliff','Western Australia','AUSTRALIA','6104','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 05:11:44',0,NULL,3,1,2,1,NULL,'ND2/4/8  58mm çŽ¯æž¶  1 '),(3083,609542910001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','salteefish','laijason@msn.com','Jason Lai','30 Gentry','Irvine','CA','UNITED STATES','92620-2836','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-17 05:35:05',0,NULL,3,1,1,1,NULL,' '),(3084,648680655002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','telezini','studio1@telezini.com','Sergio Marranzino','45 Gramercy Ave','Yonkers','NY','UNITED STATES','10701-5123','(914) 424-1066','NoPaymentFailure','CheckoutComplete','Other','2010-12-17 06:36:43',0,NULL,3,1,1,1,NULL,'canon èƒŒå¿ƒ L   1 '),(3085,648681637002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','casperus','casperus67@gmail.com','Casper Mickwitz','Vironkatu 5C 39','Helsinki','Uusimaa','FINLAND','00170','358405294422','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 06:42:58',0,NULL,3,1,4,1,NULL,'ballhead  $18 \rYW863884602CN\r'),(3086,609559013001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',2,'AA2217',17.98,'hermeshine','jirin_ol','jnol@seznam.cz','Jiri Novacek','Vosmikovych 36','PRAHA 8 -  Liben','','CZECH REPUBLIC','18000','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 07:25:54',0,NULL,3,1,2,1,NULL,NULL),(3087,609566330001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','tmichael_br','brnstin@zahav.net.il','Michael Bernstein','12/6 Sivan street','Ashqelon','Israel','ISRAEL','78726','+972 (0) 528669438','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 08:08:54',0,NULL,3,1,2,1,NULL,NULL),(3088,648716510002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','yngvillsalvesen90','yngvillsalvesen@hotmail.com','Yngvill JÃ¸lstad Salvesen','Konsul Christiansens vei 3','Kristiansand','','NORWAY','4616','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 09:53:43',0,NULL,3,1,2,1,NULL,NULL),(3089,648318853002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',5,'AE1301',48.4,'hermeshine','hellofrankcom','info@hellofrank.com','Frank Bongers','Maaltebruggestraat 194','Gent','','BELGIUM','9000','0496558558','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 10:30:53',0,NULL,3,1,3,1,NULL,'cåž‹å¤¹  5 RR815347076CN'),(3090,648724797002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','biohazardaj','anyeloj@hotmail.com','Anyelo JimÃ©nez Boguier','Carretera General del Sur Nro. 59 2Âº Apto. 8<br>San Miguel de Abona','Santa Cruz de Tenerife','Canarias','SPAIN','38620','609166224','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 10:31:25',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž   1RR815347062CN\r'),(3091,648734342002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','vaskada','arhivo@yandex.ru','Vas Panov','19/4 Novoyasenevsky Str. App. 512','Moscow','','RUSSIAN FEDERATION','117593','+79266507819','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 11:14:22',0,NULL,3,1,5,1,NULL,'4ç¯å¤´ æ£š  2  æ¬§æ ‡\rCP219437425CN\r   '),(3093,706513320015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'',3.5,'hutongstore','szentandras','ambrus@szarvasnet.hu','GyÃ¶rgy Ambrus','Kisfaludy.u.17','BÃ©kÃ©sszentandrÃ¡s','BÃ©kÃ©s','HUNGARY','5561','36304594558','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 12:09:19',0,NULL,3,1,2,1,NULL,NULL),(3095,648709966002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kohav_sheifa','sheifa@ukr.net','Zhuravskaya Tatyana','Rokosovsky 10a, kv 6','Kiev','','UKRAINE','04201','0938752729','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 12:39:00',0,NULL,3,1,2,1,NULL,NULL),(3096,648766534002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','shakpitz','zilberlicht@gmail.com','Shai Zilberlicht','Yehuda Hamaccabi 2','Nahariyya','Israel','ISRAEL','22291','972-04-9825662','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 13:20:36',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR815347155CN'),(3097,648773692002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ronggurmh','ronggur.mh@gmail.com','Ronggur Hutasuhut','Jl. Pualam Raya No.80 Rt 006/04 Kec. Kemayoran, Kel. Sumur Batu','Jakarta','Jakarta Pusat','INDONESIA','10640','081314191552','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 13:48:15',0,NULL,3,1,2,1,NULL,NULL),(3098,648774503002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','fredfmart','fredericoferreiramartins@hotmail.com','Frederico Martins','fiais','fiais','campia','PORTUGAL','3670-059','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 13:59:01',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ  L   1 RR815347147CN\r'),(3099,692846064016,260660056022,'64-LED Universal Camera Camcorder Video Light & Bracket',1,'',23.95,'hutongstore','31mirage31','fwangprc@gmail.com','Frank Wang','Van Polanenlaan 11','Capelle aan den IJssel','','NETHERLANDS','2902BX','(010) 7440494','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 14:02:33',0,NULL,3,1,3,1,NULL,'64LED   1 \rRR815346455CN\r'),(3100,648783806002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','photoman19632zcg','photoman1963@hotmail.com','ryan walsh','8 chestnut lane<br>kingsnorth','ashford','Kent','UNITED KINGDOM','tn233lr','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 14:18:05',0,NULL,3,1,3,1,NULL,'ç¢—ç½©  P4  1 RR815347133CN\r'),(3103,609663002001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','razshwaizer','shwaizer@yahoo.com','Raz Shwaizer','Azar 18/9','Haifa','ID','ISRAEL','32767','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 15:01:36',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³  1 '),(3104,609664535001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','inertialsensors','htatlau@gmail.com','Marcella Sunanto Laut','15 Scotts Road<br>#04-10 Thong Teck Building','default','','SINGAPORE','228218','(+65)96962956','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 15:07:52',0,NULL,3,1,3,1,NULL,'60cm æ£š   1 RR815347120CN'),(3105,648823403002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','memitoe21','guillermoe21@yahoo.com','Guillermo Jimenez','7979 NW 21st St<br># SJO-71781','Doral','FL','UNITED STATES','33122-1630','(305) 592-7754','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-17 16:17:29',0,NULL,3,1,1,1,NULL,'canon ä¸‰è§’åŒ…  1 '),(3106,647959317002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','alexx_gsm','alexx-gsm@yandex.ru','ÐÐ»ÐµÐºÑÐµÐ¹ Ð›ÑƒÐºÑŒÑÐ½Ñ‡ÐµÐ½ÐºÐ¾','Ð¡Ð²ÐµÑ‚Ð»Ð°Ñ, 9<br>Ñ€.Ð¿. Ð®Ð¶Ð½Ñ‹Ð¹','Ð‘Ð°Ñ€Ð½Ð°ÑƒÐ»','ÐÐ»Ñ‚Ð°Ð¹ÑÐºÐ¸Ð¹ ÐºÑ€Ð°Ð¹','RUSSIAN FEDERATION','656906','(3852)687555','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 16:12:17',0,NULL,3,1,2,1,NULL,NULL),(3107,648850716002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','ruslanl','ruslanla@ukr.net','Ruslan Lyulya','11 Dudykina<br>108','Zaporizhzhya','Zaporizhzhya','UKRAINE','69065','38-050-6610745','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 17:31:51',0,NULL,3,1,3,1,NULL,'3m æ¨ªæ†   1 RR815347337CN\r'),(3108,609718371001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3401',2.6,'hermeshine','hanei2010','hanei@walla.co.il','Hanan Pinchevsky','Amitsur Shimshon 23/7','Beer Sheva','Negev','ISRAEL','84717','0525815258','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 17:32:18',0,NULL,3,1,2,1,NULL,'430 è‚¥çš‚ç›’æŸ”å…‰ç½©   1 '),(3109,648862918002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','tropicalstormcc','christianstrevy@gmail.com','Christian Strevy','945 Castlemaine Dr','Birmingham','AL','UNITED STATES','35226-5913','(205) 447-8266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-17 17:55:57',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹  1 '),(3110,609734591001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','guibeloto','guimaemcasa@gmail.com','Guilherme Beloto','Rua Tutoia 839 ap. 12','Sao Paulo','SP','BRAZIL','04007-004','+55 (11) 8114-8190','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 18:15:02',0,NULL,3,1,2,1,NULL,NULL),(3111,609737845001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',3,'',23.7,'hermeshine','teeasin','cappucup@hotmail.com','Thawatchai Changesom','4/4 Loikroh Rd. Lane 3 T.Changklan','MuangChiangmai','ChiangMai','THAILAND','50100','+66818817931','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 18:18:03',0,NULL,3,1,3,1,NULL,'800w 220v ç¯æ³¡   3RR815347354CN\r '),(3112,706677285015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'',26,'hutongstore','matiashalme','orders@halme.info','Matias Halme','Onkimiehenpolku 3','Valkeakoski','','FINLAND','37600','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-17 18:43:24',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 RR815347116CN\r'),(3113,706698796015,250692239254,'New Neoprene Reversible Cover for Canon 5D II 7D L',1,'',6.1,'hutongstore','5346roberto','roberto.om@libero.it','Roberto Borsoi','via Don lucchinetti 10','sondrio','SO','ITALY','23100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 19:20:14',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon   1 '),(3114,648903453002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','jabollo','stundex@hotmail.com','Martin Jablonski','Dreieichstr. 21','Dietzenbach','','GERMANY','63128','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 19:23:13',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   1 '),(3115,706739523015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'',24.95,'hutongstore','stressferdinand','nannyfilipe@gmail.com','ferdinand Filipe','9 levmoss Park the gallops','sandyford','Dublin','IRELAND','18','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 20:34:22',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815347204CN'),(3116,609798154001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',18.19,'hermeshine','falcon_112','peter.sjoback@yahoo.se','Peter Sjoback','Sodralanggatan 21B','Oskarshamn','','SWEDEN','572 55','0491769497','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 20:35:18',0,NULL,3,1,3,1,NULL,'wf1003    1 RR815347195CN'),(3117,648941858002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',6,'AE1301',47.34,'hermeshine','emmity','michaelleadbetter@me.com','Michael Leadbetter','271 King Street','Newtown','New South Wales','AUSTRALIA','2042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 20:50:39',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹   6 RR815347181CN'),(3118,648952368002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','puncaz','puncaz@yahoo.com','Pankaj Singh Negi','Microsoft India(R&D) Pvt Ltd<br>Microsoft campus Building 2 Gachibowli','hyderabad','Andhra Pradesh','INDIA','500032','09701649997','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 21:21:05',0,NULL,8,1,17,0,NULL,''),(3119,648956255002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','puncaz','puncaz@yahoo.com','Pankaj Singh Negi','Microsoft India(R&D) Pvt Ltd<br>Microsoft campus Building 2 Gachibowli','hyderabad','Andhra Pradesh','INDIA','500032','09701649997','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 21:28:41',0,NULL,8,1,17,0,NULL,NULL),(3120,648957415002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','alexbro_1','alex.broniewicz@swipnet.se','Alexander Broniewicz','KnektevÃ¤gen 38','SÃ¤vedalen','','SWEDEN','43369','+46-31-268669','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 21:29:14',0,NULL,3,1,2,1,NULL,NULL),(3121,648958724002,120448645643,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','puncaz','puncaz@yahoo.com','Pankaj Singh Negi','Microsoft India(R&D) Pvt Ltd<br>Microsoft campus Building 2 Gachibowli','hyderabad','Andhra Pradesh','INDIA','500032','09701649997','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 21:34:01',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°   1\ræ¸å˜è“   1\ræ¸å˜æ©™   1 '),(3122,609824853001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','koboley','ioannis.lelakis@gmail.com','Ioannis Lelakis','Prestelandet 25a','1632 Gamle Fredrikstad','','NORWAY','1632','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 21:43:11',0,NULL,3,1,4,1,NULL,'2m x 3m èƒŒæ™¯æž¶   1 \rbackground support  $30\rYW863884661CN\r'),(3123,648952277002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','mattclarkemedia','matt@mattclarkemedia.com.au','Matthew Clarke Media','Office 109, 48 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0299013339','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 22:25:58',0,NULL,8,1,17,0,NULL,NULL),(3124,609819277001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'',35,'hermeshine','mattclarkemedia','matt@mattclarkemedia.com.au','Matthew Clarke Media','Office 109, 48 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0299013339','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 22:25:58',0,NULL,8,1,17,0,NULL,NULL),(3125,648955576002,120560330004,'64pcs LED Light Flash Camcorder/Camera Photo Light ',1,'AB3317',36.99,'hermeshine','mattclarkemedia','matt@mattclarkemedia.com.au','Matthew Clarke Media','Office 109, 48 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0299013339','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 22:25:59',0,NULL,8,1,17,0,NULL,''),(3126,609817519001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',99,'hermeshine','mattclarkemedia','matt@mattclarkemedia.com.au','Matthew Clarke Media','Office 109, 48 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0299013339','NoPaymentFailure','CheckoutComplete','AU_Express','2010-12-17 22:27:56',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶ 4\råŒç¯å¤´  æ¾³æ ‡  2\råå…‰ä¼ž   2\r50-70 æ£š  æ¾³æ ‡  2\r115w 220v  2\råŒ…   2\r64LED ç¯    1\r800w 220v  ç¯æ³¡  5 \rlighting kit   $40\rYW863884705CN\r\r'),(3127,609843977001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.8,'hermeshine','superpac1974','fcifuentes@iberdrola.es','IBERDROLA - FRANCISCO CIFUENTES FDEZ.','PARQUE EMPRES. CRISTALIA. EDIF.9<br>VIA DE LOS POBLADOS, 3','MADRID','Madrid','SPAIN','28033','639401224','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 22:43:30',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´  æ¬§æ ‡   2 RR815347178CN'),(3128,609005102001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','juutaa2010','juutaa@yahoo.com','Agne Gudziunaite','Molainiu 66-12','Panevezys','LT','LITHUANIA','37149','37060743307','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 23:00:14',0,NULL,3,1,2,1,NULL,' '),(3129,649029889002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rvaleriano','rudolphvaleriano@yahoo.com','rudolph valeriano','20929 Parthenia St<br>Apt 23','canoga park','CA','UNITED STATES','91304-6221','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 01:47:39',0,NULL,3,1,1,1,NULL,NULL),(3130,649039033002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','kdou8331','kdoubt@gmail.com','Keith Doubt','626 Omar Cir','Yellow Springs','OH','UNITED STATES','45387-1420','(937) 767-1540','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 02:24:11',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡   1 '),(3131,649066555002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','randy1982d','randy82@att.net','Randy Singleton','4351 Heron Pt','Portsmouth','VA','UNITED STATES','23703-5376','(757) 681-0221','NoPaymentFailure','CheckoutComplete','Other','2010-12-18 04:39:56',0,NULL,8,1,17,0,NULL,''),(3132,609925131001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 05:20:37',0,NULL,8,1,17,0,NULL,NULL),(3133,609922610001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.6,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 05:20:38',0,NULL,8,1,17,0,NULL,' '),(3134,609924133001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 05:20:38',0,NULL,8,1,17,0,NULL,NULL),(3135,609923496001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 05:20:38',0,NULL,8,1,17,0,NULL,NULL),(3136,649072085002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 05:20:39',0,NULL,3,1,5,1,NULL,'58mm cpl   1\rèƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ ï¼‰   1\ré˜²å¯’ç½©    1\rNikon æ‘„å½±èƒŒå¿ƒ è€æ¬¾ L    1\rsal\rCP219437310CN\r\r\r110cm 5in1   1\rng200  \rè¿™ä¸¤ä¸ªæ˜¯æŒ‚å·å°åŒ…\r\r\r '),(3137,609931472001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','vassilygr','vassily@gmx.at','Vassily Bekrodimitris','Diakou 26','Athens','','GREECE','11743','00306944362403','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 06:07:41',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815347164CN'),(3138,649085471002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','sarusalvadoralfredo','mattahitori@hotmail.com','SALVADOR ALFREDO DIAZ MATSUDA','NAKAGAWA-KU<br>SHOMEICHO 4-40-1','NAGOYA-SHI','Aichi','JAPAN','454-0854','08036593770','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 06:49:47',0,NULL,3,1,3,1,NULL,' RR815347252CN'),(3139,649093033002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','jvarod','mix1@inter.net.il','Moshe Aron','1 Harechev street','Tel-Aviv','Israel','ISRAEL','67771','(003)537-4111','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 07:43:10',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 RR815347249CN\r'),(3140,609946534001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','icyxwindz','icyxwindz@gmail.com','Wilson Tang','543 E Arrow Hwy<br>Apt 48','Azusa','CA','UNITED STATES','91702-5774','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 07:57:43',0,NULL,3,1,1,1,NULL,NULL),(3141,649100742002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','ashley86uf','ashley86@ufl.edu','Ashley Marie Reed','640 Navarre Ave','Coral Gables','FL','UNITED STATES','33134-3761','','NoPaymentFailure','CheckoutComplete','Other','2010-12-18 08:43:24',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rå®¢æˆ·ç€æ€¥ï¼Œç­‰é‚®ä»¶çœ‹å‘ä»€ä¹ˆ\rRR815346022CN\r\r'),(3142,609957711001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','mustafamaluka','maluka@gmail.com','Amina Maluka','KASTUNTIE 46','Turku','','FINLAND','20300','+358 404821614','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 09:02:30',0,NULL,8,1,17,0,NULL,NULL),(3143,609958601001,110533631226,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','mustafamaluka','maluka@gmail.com','Amina Maluka','KASTUNTIE 46','Turku','','FINLAND','20300','+358 404821614','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 09:06:43',0,NULL,3,1,2,1,NULL,'72mm æ©¡èƒ¶ç½©    1\r52mm æ©¡èƒ¶ç½©    1 '),(3144,706975454015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'',24.95,'hutongstore','maskare','teemu.p.saarinen@gmail.com','Teemu Saarinen','Lahdensivuntie 31 A 11','HÃ¤meenlinna','Oletus','FINLAND','13100','+358415076144','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-18 11:10:25',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815347235CN'),(3145,706986325015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',2,'',7,'hutongstore','sookonn','indrek.polakes@mail.ee','Indrek Polakes','KÃ¤rberi 52-11','Tallinn','Harjumaa','ESTONIA','13919','56453066','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-18 11:41:42',0,NULL,3,1,2,1,NULL,NULL),(3146,609993225001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','matteaster','measterby@msn.com','Matt Easterby','MS L9, Waterfront Place<br>1 Eagle Street','Brisbane','Queensland','AUSTRALIA','4000','0732187044','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 11:45:32',0,NULL,8,1,17,0,NULL,NULL),(3147,609996750001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','matteaster','measterby@msn.com','Matt Easterby','MS L9, Waterfront Place<br>1 Eagle Street','Brisbane','Queensland','AUSTRALIA','4000','0732187044','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 11:45:32',0,NULL,8,1,17,0,NULL,NULL),(3148,609993479001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'',35,'hermeshine','matteaster','measterby@msn.com','Matt Easterby','MS L9, Waterfront Place<br>1 Eagle Street','Brisbane','Queensland','AUSTRALIA','4000','0732187044','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 11:45:33',0,NULL,3,1,3,1,NULL,'40cm æ£š   1\rå€’å½±æ¿   1\r800w 220v  ç¯æ³¡  5 RR815347345CN\r'),(3149,609999557001,110296333346,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',6.99,'hermeshine','julian-starr','julian@minervafilm.dk','Julian Andersen','Baldersgade 6','Copenhagen N','','DENMARK','2200','35821133','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-18 11:56:09',0,NULL,3,1,2,1,NULL,'NG128   1 '),(3150,649144248002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 12:02:01',0,NULL,8,1,17,0,NULL,''),(3151,649152427002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','phantomphoto1983','phantom-tv@mail.ru','Andrey Kozlov','Boicovaia ulica, dom 6, korpus 1, kv. 9','Moskva','Moskovskaia oblast','RUSSIAN FEDERATION','107370','+79264316069','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 12:14:16',0,NULL,3,1,2,1,NULL,'3pcs æ»¤é•œè¢‹   1 '),(3152,649152075002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 12:18:12',0,NULL,8,1,17,0,NULL,'\r'),(3153,610011586001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','knetebol','knetebol@hotmail.com','M.Gerritsen','Castorweg 298','Hengelo ov','','NETHERLANDS','7557KS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 12:44:07',0,NULL,8,1,17,0,NULL,NULL),(3154,610011499001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','knetebol','knetebol@hotmail.com','M.Gerritsen','Castorweg 298','Hengelo ov','','NETHERLANDS','7557KS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 12:44:08',0,NULL,3,1,2,1,NULL,'77mm é•œå¤´ç›–  canon   2 '),(3155,649161775002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','brda1986','hrvoje.bakovic@gmail.com','hrvoje bakoviÄ‡','dracevac 80b','split','','CROATIA','21000','+385 95 9106383','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 12:49:44',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3156,707020891015,250692240898,'Wireless Remote Shutter Release for Sony A900/A200/â€‹A10',1,'',11.47,'hutongstore','grahamslist','doorcare.systems@ntlworld.com','graham smith','4.saffron close','barrowford','Lancashire','UNITED KINGDOM','bb9 6dl','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-18 13:20:50',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿  S1   1 '),(3157,610043823001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','enlisette','lis1_svensson@hotmail.com','Lisette Svensson','EksjÃ¶gatan 31','JÃ¶nkÃ¶ping','JÃ¶nkÃ¶ping','SWEDEN','554 54','0046704489953','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 14:28:33',0,NULL,3,1,2,1,NULL,' '),(3158,647002932002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','klaudiapolec88','klaudiapolec@interia.pl','Klaudia Stawiarska','Apt.1 Chapel Court,<br>Cathedral Place','Limerick','Limerick','IRELAND','061','873211433','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 14:41:42',0,NULL,3,1,2,1,NULL,'ä¸‰è§’åŒ…  canon  1 '),(3159,610050494001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','yamila02','irvisp@gmail.com','Irvis Y PagÃ¡n','319 Calle Tampa<br>San Gerardo','San Juan','PR','PUERTO RICO','00926-3433','','NoPaymentFailure','CheckoutComplete','Other','2010-12-18 14:48:23',0,NULL,3,1,3,1,NULL,'RR815347986CN\r'),(3160,649200596002,120339084231,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',8.99,'hermeshine','3080stewart','djstewart01@tiscali.co.uk','derek stewart','50 acredales<br>haddington','east lothain','East Lothian','UNITED KINGDOM','eh41 4nu','01620825416','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2010-12-18 14:49:03',0,NULL,3,1,2,1,NULL,'90th è‚©å¸¦  1 '),(3161,609943438001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',9,'AA1204',13.91,'hermeshine','go6maidee','go6maidee_k@hotmail.com','Supakit  Jirawanidchakorn','949/137  Sathu58  Bangpongpang  yannawa','Bangkok','Bangkok','THAILAND','10120','66855059444','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 14:55:56',0,NULL,3,1,3,1,NULL,'çƒ­é´ç›–   9 \rRR815346331CN\r'),(3162,610052372001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','emil_akhmadi','akhmadistudio@gmail.com','Emil Akhmadeev','Khimikov, dom 27, kv. 59','Kazan','Tatarstan','RUSSIAN FEDERATION','420085','+79046668659','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 14:57:21',0,NULL,3,1,2,1,NULL,NULL),(3163,609941553001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','auchorhing','we168168@hotmail.com','Albert Chor Hing Au','21 Drawbridge Drive','Markham','ON','CANADA','L6C 2B3','(416) 618-1588','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 15:09:35',0,NULL,8,1,17,0,NULL,NULL),(3164,609940344001,110609032219,'Redhead Red head 800w w bulb + Spring Cushioned Stand ',1,'AKT007',130,'hermeshine','auchorhing','we168168@hotmail.com','Albert Chor Hing Au','21 Drawbridge Drive','Markham','ON','CANADA','L6C 2B3','(416) 618-1588','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 15:09:35',0,NULL,3,1,5,1,NULL,'800w çº¢å¤´ç¯   1\r800w 110v ç¯æ³¡   1\r2.8m å¼¹ç°§ ç¯æž¶   1 \r2m ç¯æž¶  1\ræ–œè‡‚   1\rCP219437354CN\rCP219437345CN\r\r'),(3165,707068437015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'',26.56,'hutongstore','25bell25','ebell@anglianwater.co.uk','Emma Bell','219 Four Chimneys Crescent','Peterborough','Cambridgeshire','UNITED KINGDOM','Pe7 8JQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-18 15:17:45',0,NULL,3,1,3,1,NULL,'RR815347221CN '),(3166,649245180002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','macgarys','macgary@gmail.com','Edgar Pedroza','435 Hackberry Dr','Rockwall','Tx','UNITED STATES','75087-6778','(214) 228-1807','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 16:47:25',0,NULL,8,1,17,0,NULL,NULL),(3167,610095110001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','macgarys','macgary@gmail.com','Edgar Pedroza','435 Hackberry Dr','Rockwall','Tx','UNITED STATES','75087-6778','(214) 228-1807','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 16:47:25',0,NULL,3,1,1,1,NULL,'77mm é•œå¤´ç›–  canon  1\r58mm é•œå¤´ç›– canon   1 '),(3168,649268304002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','sw-cheif','dmack1974@gmail.com','Dennis McDowell','26360 Girard St','Hemet','CA','UNITED STATES','92544','(951) 658-1743','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 17:38:16',0,NULL,3,1,1,1,NULL,NULL),(3169,649285183002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bhaskar1020','bhaskar1020@yahoo.com','Bhaskar Pandya','300 hartwell st','Fall RIver','MA','UNITED STATES','02721-2912','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 18:15:41',0,NULL,3,1,1,1,NULL,NULL),(3170,649356409002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','jken7958','kennedymary@rogers.com','John Kennedy','219 Tamarac Trail','Aurora','ON','CANADA','L4G 5W2','(905) 727-3027','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 20:42:05',0,NULL,3,1,2,1,NULL,NULL),(3171,610244667001,110451012922,'Adjustable Padded Camera Neck shoulder Strap for Canon',1,'AB1404',8.9,'hermeshine','madcom1138','alexdumani@gmail.com','alex dumani','Cdla. Los Almendros Mz. A Villa 18','Guayaquil','Guayas','ECUADOR','EC090114','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 22:35:28',0,NULL,3,1,2,1,NULL,'canon è‚©å¸¦  çº¢å­— logo   1 '),(3172,649401381002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','reywas92','dlsmorgan@att.net','David Morgan','10846 Hamilton Pass','Fishers','IN','UNITED STATES','46037-9494','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 22:41:54',0,NULL,3,1,1,1,NULL,NULL),(3173,610248035001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting Ã—2',1,'AKT031',59,'hermeshine','bahrialtay10','altaybahri@hotmail.com','Bahri Altay','Veliefendi mah. Saha Yolu No:22 Celik apt. k:2 d:4<br>zeytinburnu','istanbul','','TURKEY','34025','0212 547 59 01','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 22:52:09',0,NULL,8,1,17,0,NULL,NULL),(3174,649403646002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','bahrialtay10','altaybahri@hotmail.com','Bahri Altay','Veliefendi mah. Saha Yolu No:22 Celik apt. k:2 d:4<br>zeytinburnu','istanbul','','TURKEY','34025','0212 547 59 01','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 22:52:09',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶   2\r4ç¯å¤´ æ£š   æ¬§æ ‡   2 \r4338\rCP219437385CN\r'),(3176,649409863002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','randy1982d','randy82@att.net','Randy Singleton','4351 Heron Pt','Portsmouth','VA','UNITED STATES','23703-5376','(757) 681-0221','NoPaymentFailure','CheckoutComplete','Other','2010-12-18 23:08:05',0,NULL,3,1,4,1,NULL,'sony èƒŒå¿ƒ xxxl   1 \rsony èƒŒå¿ƒ xxl   1 \rphoto vest  $22\rYW863884650CN\r'),(3177,649419492002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','lenaokh','lena.okhman@gmail.com','Yelena Okhman','5750 Olohena Rd<br># M','Kapaa','HI','UNITED STATES','96746-8808','(949) 395-1871','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-18 23:40:13',0,NULL,8,1,17,0,NULL,NULL),(3178,610262201001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','lenaokh','lena.okhman@gmail.com','Yelena Okhman','5750 Olohena Rd<br># M','Kapaa','HI','UNITED STATES','96746-8808','(949) 395-1871','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 23:47:04',0,NULL,3,1,1,1,NULL,' 77mm CPL+ND8+Macro+8 +Gradual grey+filter case 1\r52mm æ©¡èƒ¶ç½©   1'),(3179,649427627002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','franconialocal','franconialocal@hotmail.com','Chris Fowler','PO Box 151','Franconia','NH','UNITED STATES','03580-0151','(603) 616-7171','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 00:10:30',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡   1 '),(3180,649431044002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jeannie16452','stevenson519@comcast.net','JEANNIE STEVENSON','16452 Lakeside Dr','LOCKPORT','IL','UNITED STATES','60441-7024','(815) 325-4750','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 00:25:12',0,NULL,3,1,1,1,NULL,NULL),(3181,693612210016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','mumby33','graham.mumby-croft@ntlworld.com','Graham Mumby-Croft','15 Thirsk Drive, North Hykeham','Lincoln','Lincolnshire','UNITED KINGDOM','LN68SZ','01522889993','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-19 00:30:58',0,NULL,3,1,2,1,NULL,'canon æœºèº«ç›–/é•œå¤´åŽç›–   1 '),(3182,610276898001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','taras2376','taras.ebay@glek.net','Taras Glek','411 NW 231st Ave','Hillsboro','OR','UNITED STATES','97124','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 00:37:25',0,NULL,3,1,1,1,NULL,NULL),(3183,649460860002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dede0301','tardif.saulnier@videotron.ca','Andre Tardif','1345 Place du Titanic','Ville Sainte-Catherine','QC','CANADA','J5C 1T8','(450) 632-8713','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 02:40:53',0,NULL,3,1,2,1,NULL,NULL),(3184,609766693001,110523102158,'62mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1306',2.6,'hermeshine','richandranda','rich@rt2inc.com','Richard Taylor','10 Briarwood Ct','Warrenton','MO','UNITED STATES','63383-1056','(702) 239-1656','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 03:06:22',0,NULL,3,1,1,1,NULL,NULL),(3185,610328369001,110566021597,'New YN Flash Battery Pack SF-17 Canon Flash 580EX CP-E4',2,'AB3313',82.98,'hermeshine','dewiedbw','dewiedbw@yahoo.com','Bennie Watson','5010 Interstate 10 E','San Antonio','TX','UNITED STATES','78219','(210) 216-4865','NoPaymentFailure','CheckoutComplete','Other','2010-12-19 04:56:49',0,NULL,3,1,1,1,NULL,'sf17 canon   2 '),(3186,649507498002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','campster456','leecam@internode.on.net','Mrs Lee Camporeale','8 Inverness Avenue','St Georges','South Australia','AUSTRALIA','5064','0883795838','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 07:01:54',0,NULL,3,1,4,1,NULL,'717 180cm    1\rtripod $30 \rYW863884646CN\r'),(3187,649512793002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',3,'AKT049',105,'hermeshine','ostrenok','lostrenok@gmail.com','Leonid Ostrenok','Yunnatov street 3-28','Khimki','Moscow region','RUSSIAN FEDERATION','141400','7-985-773-9420','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 07:38:50',0,NULL,3,1,5,1,NULL,'115w 220v   6 \r2111g\rCP219437399CN\r'),(3188,610378983001,110533632545,'New Timer Remote Control for Sony a100 a200 a300 a350',1,'AA3223',48,'hermeshine','dmitryv43','dmitry_v43@mail.ru','Dmitry Vikharev','36 Drelevsky street, app.29','Kirov','Kirovskaya oblast','RUSSIAN FEDERATION','610020','+7(922)6621400','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 09:55:12',0,NULL,8,1,17,0,NULL,NULL),(3189,649541913002,120454219798,'Green.L 55mm Neutral Density ND4 Filter ND 4 55',1,'AE2302',6.5,'hermeshine','dmitryv43','dmitry_v43@mail.ru','Dmitry Vikharev','36 Drelevsky street, app.29','Kirov','Kirovskaya oblast','RUSSIAN FEDERATION','610020','+7(922)6621400','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 09:55:12',0,NULL,8,1,17,0,NULL,NULL),(3190,649541840002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',6.2,'hermeshine','dmitryv43','dmitry_v43@mail.ru','Dmitry Vikharev','36 Drelevsky street, app.29','Kirov','Kirovskaya oblast','RUSSIAN FEDERATION','610020','+7(922)6621400','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 09:55:13',0,NULL,3,1,3,1,NULL,'MC-S1   1\r55mm ND4   1\r58mm ND8   1 \rRR815346464CN\r'),(3191,610385798001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','to_dimitry','dimitry.p@hotmail.com','Dmitry Pishchagin','Boitsovaya str, 18-12, kv. 59','Moscow','','RUSSIAN FEDERATION','107150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 10:06:32',0,NULL,3,1,2,1,NULL,NULL),(3192,610408399001,110464615814,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',8.69,'hermeshine','mlc15','kossowsk@math.sc.edu','marek b. kossowski','103 Bruton Dr','chapel hill','NC','UNITED STATES','27516-9222','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 11:13:56',0,NULL,8,1,17,0,NULL,NULL),(3193,610408171001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','mlc15','kossowsk@math.sc.edu','marek b. kossowski','103 Bruton Dr','chapel hill','NC','UNITED STATES','27516-9222','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 11:13:57',0,NULL,8,1,17,0,NULL,NULL),(3194,649571356002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',2,'AA1305',5,'hermeshine','mlc15','kossowsk@math.sc.edu','marek b. kossowski','103 Bruton Dr','chapel hill','NC','UNITED STATES','27516-9222','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 11:13:56',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1\rä¸­å·å†…èƒ†åŒ…  æ— å­—  1\r52mm é•œå¤´ç›– NIkon   2 '),(3195,649575230002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ceb997','felisabros@yahoo.com','Felisa Brothers','7457 Gallant Road','Gallant','AL','UNITED STATES','35972','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 11:22:50',0,NULL,8,1,17,0,NULL,NULL),(3196,649574876002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ceb997','felisabros@yahoo.com','Felisa Brothers','7457 Gallant Road','Gallant','AL','UNITED STATES','35972','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 11:22:51',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›– canon   2 '),(3197,649559425002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','robertbookshop','robert@neco.cz','Robert Tichy','Hrbitovni 33','Pilsen','West Bohemia','CZECH REPUBLIC','31200','00420-608826881','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 11:26:56',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹  1 '),(3198,649581119002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','misterohlsson','mistero@live.se','Anders Ohlsson','AnanasvÃ¤gen 5','JÃ¤rfÃ¤lla','Stockholm','SWEDEN','175 49','+4687391691','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 11:49:08',0,NULL,8,1,17,0,NULL,''),(3199,649582345002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','misterohlsson','mistero@live.se','Anders Ohlsson','AnanasvÃ¤gen 5','JÃ¤rfÃ¤lla','Stockholm','SWEDEN','175 49','+4687391691','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 11:49:09',0,NULL,3,1,4,1,NULL,'80cm 2in1  åå…‰æ¿   1 \r2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rä¸€ç¥¨ä¸¤ä»¶   light stand  $22\rYW863884635CN\r'),(3200,649588511002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','ripleycats','m_brewis@sky.com','Michelle Brewis','20 Allchurch Drive','Ashington','Northumberland','UNITED KINGDOM','NE63 9EQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 11:59:08',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°   1 '),(3201,648573797002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','floy.123','floysele@floysele.jazztel.es','Fernando Loysele Gomez','Laguna Negra  13 Portal G 2ÂºA','Madrid','Madrid','SPAIN','28030','608604749','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-19 12:03:06',0,NULL,3,1,4,1,NULL,'6662a   1 \rtripod  $15\rYW864144103CN\r'),(3202,610433994001,110499652243,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','ramcoror1989','ramcoror89@gmail.com','Î¡Î±Î¼Î±Î´Î¬Î½ ÎŸÎ³Î»Î¿Ï Î¡Î±Î¼Î±Î´Î¬Î½','Î£Î±Ï€Î±Î¯Ï‰Î½ 42, Î . Î§ÏÏÏƒÎ±','ÎžÎ¬Î½Î¸Î·','GU','GREECE','67100','00306979437839','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 12:21:41',0,NULL,3,1,2,1,NULL,'æŸ”å…‰ä¼ž  2 '),(3203,610446342001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','vonkuba','jakub.dabrowski@gmail.com','Jakub Dabrowski','Zeeburgerkade 762','Amsterdam','','NETHERLANDS','1019HT','+31614870495','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 12:53:18',0,NULL,3,1,2,1,NULL,NULL),(3205,649617981002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','hemeroskopion','ewi@telefonica.net','Olaf Speier','Avenida 9 de Octubre, 9, 1Âº B<br>Residencial El Tossalet','Polop de la Marina','Comunidad Valenciana','SPAIN','03520','637101199','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 13:15:17',0,NULL,3,1,3,1,NULL,'cåž‹å¤¹   2 RR815347218CN\r'),(3206,610461312001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','siriwatj','siriwatj@gmail.com','Siriwat Jithunsa','116 Soi. Moo Baan Suannakarin 1<br>Srinakarin Road, Nongborn','Pravej','Bangkok','THAILAND','10250','+668 1619 1976','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 13:30:02',0,NULL,3,1,11,1,NULL,'\r'),(3207,649634363002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','mr2004','cmohanr@hotmail.com','Mohan Chennareddy','167 Rockview','Irvine','CA','UNITED STATES','92612-3239','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 13:57:58',0,NULL,3,1,1,1,NULL,NULL),(3244,650121869002,120564178883,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','jaimeluanco','nico1967@ymail.com','JAIME GONZALEZ FERNANDEZ','LA CRUZ  37 BAJO A','LUANCO','Asturias','SPAIN','33440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 09:33:15',0,NULL,8,1,17,0,NULL,NULL),(3208,610477766001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','ikupi','ivan@inode.nl','Ivan Kupi','2e octaviolaan 36','Capelle aan den IJssel','','NETHERLANDS','2909 RC','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 14:08:45',0,NULL,3,1,3,1,NULL,'1.6m x 2.1m èƒŒæ™¯å¸ƒ  2\ré»‘è‰²ï¼Œ è“è‰²  RR815347323CN\r'),(3209,649649413002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','boerkejos','bjorn.pira@skynet.be','Pira BjÃ¶rn','Nieuwstraat 33<br>3071 Erps-Kwerps','Erps-Kwerps','','BELGIUM','3071','0496743055','NoPaymentFailure','CheckoutIncomplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR815347306CN\r'),(3211,649670925002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ffhend26','bwh02@hotmail.com','Brian Harris','1142 Spottswoode St','Henderson','NV','UNITED STATES','89002-3387','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 15:13:06',0,NULL,3,1,1,1,NULL,NULL),(3212,610385380001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',148.2,'hermeshine','trivantan','trivan_tan@hotmail.com','Tan Kian Wee','Blk 484 Admiralty Link #10-65','default','','SINGAPORE','750484','97697369','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 15:13:13',0,NULL,3,1,6,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ é»„ ç™½  ï¼‰   1 \r2m ç¯æž¶  2\rå•ç¯å¤´  è‹±æ ‡   2\råå…‰ä¼ž   2\ræ–°åŠ å¡EMS\rEX000455038SG\r'),(3213,649699994002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','paulonorton','paulonorton@hotmail.com','antonio severino lopes paulo','rua ricardo espirito santo lt 9 3Âº dt<br>2615-677 sobralinho','vila franca de xira','lisboa','PORTUGAL','2615-677','0031934357900','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 16:09:27',0,NULL,3,1,4,1,NULL,'tripod  $15 \ræ–°åœ°å€ï¼š \rAntonio Severino Lopes Paulo\rSaint-Gobain. PAM\restrada nacional 1 km 38\r2580-381-Alenquer\rPortugal\r0031934357900\rYW863600142CN\r\r'),(3214,610555813001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',9.9,'hermeshine','lifishort','cookcarol52@aol.com','Carol Cook','6 S Laflin St<br>Apt 803','chicago','IL','UNITED STATES','60607-2443','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 16:44:23',0,NULL,3,1,1,1,NULL,'nikon è‚©å¸¦   1\ré»„å­—   '),(3215,649746558002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 17:21:12',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  3\rbåº§   3\ræŸ”å…‰ä¼ž   3 \rlight stand   $30\rYW863884672CN\r'),(3216,649763841002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0024',20.99,'hermeshine','alisss54','gamal4ml@yahoo.com','Ali','Pbox:22162,Sana\'a,Yemen','Sana\'a','sheraton/sana\'a/sana\'a','YEMEN (REPUBLIC OF)','YEM','+967-711553355','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 17:46:25',0,NULL,3,1,3,1,NULL,'canon d1 å•è‚©åŒ…    1 RR815347297CN'),(3217,610618836001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','manateepup','onthelargesideofaverage@hotmail.com','neil tadman','12 Hillmore Court<br>32 Belmont Hill','London','London','UNITED KINGDOM','SE13 5AZ','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 18:12:25',0,NULL,3,1,2,1,NULL,'717å¿«è£…æ¿   1 '),(3218,610667832001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','snakeke','marek.janicko@gmail.com','Marek Janicko','Wurmova 6','Kosice','','SLOVAK REPUBLIC','04023','+421905181816','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 19:07:45',0,NULL,3,1,2,1,NULL,' '),(3219,610664564001,110486687213,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','joancarm','joamac@gmail.com','JUAN MASSEGUR CASANOVA','C/TILÂ·LER NÂº11','OLOT','CataluÃ±a','SPAIN','17800','972272527','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 19:11:05',0,NULL,3,1,2,1,NULL,'æ¸å˜è“   1 '),(3220,610675957001,110454864267,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',7.89,'hermeshine','kobiavr69','kobiavraham69@yahoo.com','kobi avraham','Ben Hur 4/12<br>Em Hamoshavot','Petach Tikva','','ISRAEL','49063','+972578124269','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 19:17:04',0,NULL,3,1,3,1,NULL,'æ— å­—è‚©å¸¦   1 RR815347283CN'),(3221,649870594002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','factorandrey','anpetrov2@gmail.com','Andrey Petrov','Mayskiy bulvar 28, Apt.7','Kursk','','RUSSIAN FEDERATION','305038','7 471 2515545','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 19:50:45',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR815347270CN\r'),(3222,707874623015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'',12,'hutongstore','psvehv82','teunehv@kunen.nl','Ton Kunen','Boschdijk 275','EINDHOVEN','','NETHERLANDS','5612HD','0647312898','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-19 19:57:27',0,NULL,3,1,3,1,NULL,'1.6x3m èƒŒæ™¯å¸ƒ   ç™½è‰²   1 \r484\rRR815347782CN\r'),(3223,707882781015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'',24.99,'hutongstore','170jazmin','bobnield@aol.com','Robert Nield','5 Belle Vue Road','Exmouth','Devon','UNITED KINGDOM','EX8 3DR','01395279537','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-19 20:05:16',0,NULL,3,1,3,1,NULL,'115w 220v    2 RR815347266CN\r'),(3224,610741331001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','jimmilligan1','jimmilligan1@aol.com','Jim Milligan','10 ROWANBANK GARDENS<br>BROUGHTY FERRY','DUNDEE','ANGUS','UNITED KINGDOM','DD5 2JW','07540839018','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 20:46:18',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°  1\r58mm çŽ¯æž¶   1 '),(3225,610758035001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','truhlar_enterprise','truhlardc@sbcglobal.net','Jonathan A. Truhlar','1413 Sherborn Court South','Minooka','IL','UNITED STATES','60447-4569','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 21:13:21',0,NULL,3,1,1,1,NULL,'å“èƒœ 3.0   1 '),(3227,610761426001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',3.3,'hermeshine','gcc_20050','kep_numberg@yahoo.com','Kompusel Bilgisayar','Talatpasa Blv. No: 66 Palandoken Apt. Daire: 1<br>Alsancak','Izmir','','TURKEY','35220','905367739884','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 21:22:21',0,NULL,3,1,2,1,NULL,'55mm uv    1 \r '),(3229,649794127002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','juancodo','jic@codoneralonso.com','Juan Ignacio CodoÃ±er','C/ Colombia, 14','Majadahonda','Madrid','SPAIN','28220','678246037','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 22:33:29',0,NULL,3,1,2,1,NULL,NULL),(3230,610800409001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','domins-tigra','domins_1723@hotmail.com','Domingo Javier LÃ³pez HernÃ¡ndez','C/ Arrieros NÂº5, Albox','AlmerÃ­a','AndalucÃ­a Ceuta y Melilla','SPAIN','04800','669083058','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 22:55:55',0,NULL,3,1,2,1,NULL,' '),(3231,610802564001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','darrensbabe','dhollis0510@san.rr.com','Brandi Hollis','13333 Caminito Ciera<br>Unit 100','San Diego','CA','UNITED STATES','92129-4048','(858) 484-8461','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 23:01:44',0,NULL,3,1,1,1,NULL,' '),(3232,610829860001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',75,'hermeshine','zskyejb','zoe_sjb@hotmail.com','Zoe Barton','8 Wragge Pl','Florey','Australian Capital Territory','AUSTRALIA','2615','0403506520','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2010-12-20 00:38:30',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶  1 \rreflector holder   $20\rYW863884624CN\r'),(3233,650018001002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','mirsec','harvestcreations@hotmail.com','Miranda Mirsec','4301 E 3rd St','Long Beach','CA','UNITED STATES','90814-2920','(562) 706-0032','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 01:16:20',0,NULL,3,1,1,1,NULL,NULL),(3234,650025180002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','klynch315','kalynch315@aol.com','Kristina Lynch','5116 Leon St','Oceanside','CA','UNITED STATES','92057-3647','(760) 721-2580','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 01:40:17',0,NULL,3,1,1,1,NULL,NULL),(3235,649171171002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',74.3,'hermeshine','m_jodie1984','m_jodie@hotmail.com','jodie mills','3 Silvabank Drive<br>varsity lakes','Gold Coast','Queensland','AUSTRALIA','4227','0755753698','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 01:55:24',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\rbåº§   2\ræŸ”å…‰ä¼ž   2 \rlight kit  $22\rYW863884613CN\r'),(3236,650034769002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','bolla6772','bollaj85@hotmail.com','Jerry Bolla','1416 Broadway','highland','IL','UNITED STATES','62249','(618) 580-9867','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-20 02:06:34',0,NULL,3,1,1,1,NULL,NULL),(3237,650039671002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','lonelobo13','amoellendorf@gvtc.com','Joe Moellendorf','206 Live Oak Pass','Boerne','TX','UNITED STATES','78006-8533','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 02:22:06',0,NULL,3,1,1,1,NULL,NULL),(3238,650044964002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',9.25,'hermeshine','bredb71','bre_7171@yahoo.com','bryan balzomo','6925 Haskell Ave<br>Apt 109','van nuys','CA','UNITED STATES','91406-5076','(818) 300-7523','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 02:39:17',0,NULL,3,1,1,1,NULL,'å¤§å·å†…èƒ†åŒ… æ— å­—   1 '),(3239,650050223002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','claudiasa17','claudia_saucedo17@yahoo.com','claudia saucedo','406 Laurie Ln','billings','MT','UNITED STATES','59105-3924','(406) 208-4170','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 02:58:32',0,NULL,3,1,1,1,NULL,NULL),(3240,694339835016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','glamboyitalia','info@glamboy.com','BRIGNOLI LUCA','GARIBALDI,22','MORENGO','BG','ITALY','24050','3887437467','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-20 03:07:03',0,NULL,8,1,17,0,NULL,'\r'),(3241,708081020015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'',12,'hutongstore','glamboyitalia','info@glamboy.com','BRIGNOLI LUCA','GARIBALDI,22','MORENGO','BG','ITALY','24050','3887437467','NoPaymentFailure','CheckoutIncomplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,3,1,4,1,NULL,' 2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r1.6m x 3m ç™½è‰²èƒŒæ™¯å¸ƒ\r2mç¯æž¶  2\r50-70æ£š   2 æ¬§æ ‡  \r115w 220v  2\råŒ…   1 \rlighting kit  $32\rYW863884694CN\r'),(3242,650067402002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','wabenet73','wabenet@yahoo.com','Joe Wabe','Buk-gu, Young Bong Dong<br>1350-4 Young Bong Parkville #202','Gwangju','Jeollanamdo','KOREA,REPUBLIC OF','500-845','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 03:59:17',0,NULL,3,1,2,1,NULL,NULL),(3243,610911719001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','holoboss','office@holograms.bc.ca','Derek Galon','887 Walfred Rd.','Victoria','BC','CANADA','v9c2p1','(250) 380-2031','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 06:44:17',0,NULL,3,1,2,1,NULL,' '),(3245,610935172001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','jaimeluanco','nico1967@ymail.com','JAIME GONZALEZ FERNANDEZ','LA CRUZ  37 BAJO A','LUANCO','Asturias','SPAIN','33440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 09:33:16',0,NULL,3,1,2,1,NULL,'52mm æ©¡èƒ¶ç½©   1\rND8   1 '),(3246,610935943001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',3,'',23.7,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Kazankov Valery','Rokossovskogo avenue, 115-3','Minsk','','BELARUS','220085','+375447127692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 09:34:54',0,NULL,8,1,17,0,NULL,NULL),(3247,650122644002,120601698609,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Kazankov Valery','Rokossovskogo avenue, 115-3','Minsk','','BELARUS','220085','+375447127692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 09:37:18',0,NULL,3,1,3,1,NULL,'wf1005   1\r800w  220v   3 \rRR815347779CN\r'),(3248,650123247002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AE2301',8.55,'hermeshine','corypelican','corypelican@gmail.com','Cory Morris','P.O. Box 437 Annerley','Brisbane','Queensland','AUSTRALIA','4103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 09:45:16',0,NULL,3,1,2,1,NULL,'ç»¿å¶çš„ 72mm æ¸å˜ç°   1 '),(3249,694426320016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','standford26','gberbielae@hotmail.com','Guillermo Berbiela Esteve','Paseo de Lazkano, nÂº 14','Donostia - San Sebastian','Guipuzcoa','SPAIN','20009','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 10:10:58',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(3250,650129611002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','holistichealth','drnyvlt@hotmail.com','Pavel Nyvlt','Masarykovo nam.175','Podivin','','CZECH REPUBLIC','69145','(420) 739-4428 ext.: 66','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 10:16:08',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž   1 \rRR815347853CN\r'),(3251,650131157002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3302',55.99,'hermeshine','vess1vis2','chichkow@yahoo.com.au','Vesselin Chichkov','Unit 2  Block 1    50 Belomorski Prohod St<br>Lozenec','SOFIA','','BULGARIA','1407','35929672642','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 10:23:03',0,NULL,3,1,3,1,NULL,'60cm é—ªå…‰ç¯ æŸ”å…‰æ£š   1\rRR815346053CN\r '),(3253,708181941015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','the_hippo14','ray.sievey@ntlworld.com','Ray Sievey','10 Belcroft Close','Bromley','Kent','UNITED KINGDOM','BR1 3TL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-20 11:10:20',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³ 1 '),(3256,708196357015,250692240760,'Wireless Remote Control Cord for Canon 500D/550D/450D',1,'',11.47,'hutongstore','ferrierknight','bbarnett@fsmail.net','Bill Barnett','47 Oakleigh Drive','Swaffham','Norfolk','UNITED KINGDOM','PE37 7AJ','01760336076','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-20 12:06:32',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿  c1   1 '),(3257,610968034001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','greenbongo','rdcw@comcast.net','Robert Wynn','36 Windmill Dr','Clementon','NJ','UNITED STATES','08021-5821','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 12:18:08',0,NULL,3,1,1,1,NULL,NULL),(3258,650164356002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','joseluis9131','afrogm@gmail.com','Jose Luis Ruiz Gonzalez','Villa de Marin, 3 (8-1)','MADRID','Madrid','SPAIN','28029','913140971','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 13:03:10',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(3259,610988211001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','central_bay','kolodin@gmail.com','Oleg Kolodin','1200 N Queen St<br>Apt 339','Arlington','VA','UNITED STATES','22209-3312','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 13:51:34',0,NULL,3,1,1,1,NULL,NULL),(3261,650184394002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','bootje1974','corne@agrios.nl','Corne Boogaard','Zandbergsestraat 5','Graauw','','NETHERLANDS','4569TC','(06)55190592','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 14:26:13',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§  1\ræŸ”å…‰ä¼ž    RR815347765CN\r'),(3262,611001284001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','svejnozka','spcomposit@centrum.cz','Patrik Svejnoha','Elektrarenska 9','Prague 10','Czech Republic','CZECH REPUBLIC','101 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 14:43:49',0,NULL,8,1,17,0,NULL,NULL),(3263,611001296001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','svejnozka','spcomposit@centrum.cz','Patrik Svejnoha','Elektrarenska 9','Prague 10','Czech Republic','CZECH REPUBLIC','101 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 14:43:49',0,NULL,3,1,2,1,NULL,'52mm æ©¡èƒ¶ç½©   1\r58mm æ©¡èƒ¶ç½©   1 '),(3264,611005614001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','evelintamm','evelintamm@hot.ee','Evelin Tamm','Suurevalja tee 3','Saue','HARJUMAA','ESTONIA','76506','3725064557','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 15:10:26',0,NULL,3,1,2,1,NULL,' 803g'),(3265,694512914016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'',32.99,'hutongstore','lovezri','loryas@yahoo.com','Carlos Rivera','Urb. San Luis 500 Calle Valcarcel Apt. 17-H','San Juan','PR','UNITED STATES','00923','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 15:37:38',0,NULL,3,1,1,1,NULL,'sf18- canon   1 '),(3267,650202973002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','chicago1924','peter@kadisnet.se','Peter BodÃ©n','Kaddisvagen 42','905 92 Umea','Vasterbottens Lan','SWEDEN','....','4690148050','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 16:06:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rå•ç¯å¤´   æ¬§æ ‡   1\råå…‰ä¼ž   1 \rRR815347840CN\r'),(3268,650219833002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64,'hermeshine','pampolo','valerio.vella@email.it','valerio vella','Via S.Andrea Avellino n.15','MESSINA','ME','ITALY','98122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 16:33:04',0,NULL,3,1,4,1,NULL,'çº¢å¤´ç¯  1\r800w  220v ç¯æ³¡   1\rlight  $22 \rYW864143845CN\r'),(3269,611030264001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','alkhwaaa','ali.alkhwaldi@gmail.com','Ali Alkhwaildi','Alkatib Street<br>P.O Box 936','Safwa','Eastern Province','SAUDI ARABIA','31921','00966504815264','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 16:34:41',0,NULL,5,1,18,0,NULL,''),(3271,650217397002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','travellikesound','andreathornton@gmail.com','Andrea Thornton','1750 S 900 W<br>Ste A','Salt Lake City','UT','UNITED STATES','84104-1715','(801) 230-7108','NoPaymentFailure','CheckoutComplete','Other','2010-12-20 16:44:34',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚   1\r50-70 æ£š   1 \rlight kit  $22\rYW863884716CN\r'),(3272,648753666002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','bugy051','bugy111@net.hr','Matija Mavrinac','Kostrenskih boraca 19','kostrena','Kostrena','CROATIA','51221','0959059782','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 18:06:06',0,NULL,3,1,2,1,NULL,NULL),(3273,694580723016,260660051651,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D S',1,'',5.5,'hutongstore','jackpot68','marinaqb@hotmail.com','Marina Queralto Bartres','Mejia Lequerica 18, ent-4a','Barcelona','CataluÃ±a','SPAIN','08028','696808928','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 18:36:56',0,NULL,3,1,2,1,NULL,'CANON ä¸­å·å†…èƒ†åŒ…   1 '),(3274,611077212001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','domnicmicallef','micallefdomnic@gmail.com','Domnic Micallef','Villa Sandrigam,Sir Ugo Mifsud Strt.','Ta Xbiex','','MALTA','0000','77438995','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 18:40:49',0,NULL,3,1,2,1,NULL,'éº‚çš®   1 '),(3275,650268506002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','marzocchi_man','hurdj@rogers.com','Wendy Hurd','1180 Ewart Street','Lefroy','ON','CANADA','L0L 1W0','(705) 456-4707','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 18:47:01',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815347822CN\r'),(3276,650275380002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','simon182','simon.roseblade@fallon.com','SIMON ROSEBLADE','1772 Dupont Ave S','MINNEAPOLIS','MN','UNITED STATES','55403-3065','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 19:02:45',0,NULL,3,1,1,1,NULL,NULL),(3277,610939507001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','erkangunes39','erkangunes@sabanciuniv.edu','Erkan Gunes','Sabanci University<br>Orhanli Beldesi, Tuzla','Ä°stanbul','','TURKEY','34956','+90 535 599 7639','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 19:55:21',0,NULL,3,1,3,1,NULL,'tripod  $15 \rYW864144092CN\ræ¢æˆå°åŒ…æŒ‚å·\rRA014139322CN\r'),(3278,650299444002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','usafchick14','amber.scaife@yahoo.com','amber scaife','1730a dodson st','kailua','HI','UNITED STATES','96734-5127','(386) 503-5183','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 19:56:06',0,NULL,3,1,1,1,NULL,NULL),(3279,611088651001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','ucoome','mfsebuktekin@gmail.com','FURKAN SEBUKTEKIN','LIMAN MAH.CAMGUZELI SK.<br>DAMLA AP.1623','SAMSUN','TR','TURKEY','55100','+905333091749','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 20:40:50',0,NULL,3,1,2,1,NULL,' '),(3280,708403133015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'',3,'hutongstore','tamaradarko','darknula@gmail.com','Tamara Jurca','Zoology department Trinity college Dublin','Dublin','Dublin','IRELAND','2','0861622773','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 20:51:52',0,NULL,8,1,17,0,NULL,''),(3281,708404653015,250599414645,'Green.L 77mm 77 Neutral Density ND8 Filter ND 8 New',1,'',4.8,'hutongstore','tamaradarko','darknula@gmail.com','Tamara Jurca','Zoology department Trinity college Dublin','Dublin','Dublin','IRELAND','2','0861622773','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 20:57:13',0,NULL,3,1,2,1,NULL,'77mm nd8   1 \r450D çœ¼ç½©   1 '),(3282,650329648002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','primulaed','primula@i.ua','Marina Senchenko','Bulvar Perova 23, 72','Kiev','','UKRAINE','02218','0969393100','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 21:10:24',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…  1 '),(3283,611144367001,110471764884,'i-TTL Flash for Nikon D60 D90 D5000 D3000 D300s D700 D3',1,'AB3301',80,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 21:25:03',0,NULL,3,1,3,1,NULL,'æ°¸è¯º YN465  Nikon   1 \rRR815347972CN\r'),(3284,708424029015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',3,'',5.64,'hutongstore','cookie_yum','ninjabat@hotmail.com','Andrew Steele','7 Bridle Close','St. Albans','herts','UNITED KINGDOM','AL3 5HX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-20 21:34:58',0,NULL,3,1,2,1,NULL,NULL),(3285,708163958015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','chucky210503','chucky210503@mailcan.com','Ken Griffin','114 Monvoy Valley Tramore','Co.','Waterford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 21:41:26',0,NULL,3,1,2,1,NULL,NULL),(3286,650357324002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','enyuco','joanvendrell@gmail.com','Joan Vendrell Marce (Estanco)','Passeig Esglesia, 3-5','Begues','CataluÃ±a','SPAIN','08859','615574197','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 22:31:17',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   1 '),(3287,650366146002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','quarter8','sheerecstasy@gmail.com','Yuinping C','Block 114 #03-696<br>Teck Whye Lane','default','Singapore','SINGAPORE','680114','8222 9318','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 23:04:11',0,NULL,3,1,11,1,NULL,NULL),(3288,650376956002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','thrais','valentinkelemen@rogers.com','Valentin Kelemen','50 Cedarhurst Drive','Richmond Hill','ON','CANADA','L4S 1B5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 23:45:45',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRR815347836CN\r'),(3289,650382042002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','gabriel4688','gabrielgalarza007@hotmail.com','gabriel galarza','4 Columbus Pl<br>Fl 2','bound brook','NJ','UNITED STATES','08805-1902','','NoPaymentFailure','CheckoutComplete','Other','2010-12-21 00:09:00',0,NULL,3,1,1,1,NULL,'canon èƒŒå¿ƒ m   1 '),(3290,611193094001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','autumn_mi','autumn_bagley@yahoo.com','Autumn Bagley','3322 W Stanley Rd','Mount Morris','MI','UNITED STATES','48458-9408','(810) 964-7533','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 00:29:25',0,NULL,3,1,1,1,NULL,NULL),(3291,611193768001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','pinkabilly','crespyration@yahoo.com','Temi Surya','Jalan Terong No. 9A','Bandung','','INDONESIA','40262','+62811590095','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 00:36:07',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon  1 '),(3292,650402053002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',9.8,'hermeshine','rickhuntr','rsims20770@aol.com','Richard Sims','2 Metroplex Dr<br>Ste 200','BIRMINGHAM','AL','UNITED STATES','35209-6843','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 01:36:35',0,NULL,3,1,1,1,NULL,NULL),(3293,650406086002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',2,'AC1302',18.5,'hermeshine','jlocatell','jlocatell@gmail.com','Julio Locatelli','Lima 1261<br>Sistemas San Juan','Buenos Aires','CABA','ARGENTINA','1138','5411 43701153','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 01:55:44',0,NULL,8,1,17,0,NULL,NULL),(3294,611210026001,110566019774,'Neoprene Protector Camera Cover  for Nikon Size: Large ',2,'AC1303',18.5,'hermeshine','jlocatell','jlocatell@gmail.com','Julio Locatelli','Lima 1261<br>Sistemas San Juan','Buenos Aires','CABA','ARGENTINA','1138','5411 43701153','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 01:55:43',0,NULL,3,1,3,1,NULL,'å¤§å·å†…èƒ†åŒ…   2  æ— å­—  \rå¤§å·å†…èƒ†åŒ…   2  nikon\rRR815346040CN\r'),(3295,611231196001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','rexosa','xosa@msn.com','Renold Gennosa','4315 205th St','Bayside','NY','UNITED STATES','11361-2610','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 03:42:22',0,NULL,3,1,1,1,NULL,NULL),(3296,650430237002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','photomarvin10','marvel623@hotmail.com','Marvin Schwartz','15125 88th St<br>Apt 6K','Howard Beach','NY','UNITED STATES','11414-2014','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 03:47:31',0,NULL,3,1,1,1,NULL,NULL),(3297,611234046001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','juanam2754','juanmarrero2005@yahoo.com','Juan Marrero','PO Box 0982','Miami','FL','UNITED STATES','33101','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 03:58:57',0,NULL,3,1,1,1,NULL,NULL),(3298,611236051001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','jtbone68','jtbone68@iwon.com','Joseph Resi','21 Orchard Ln','Cold Spring','NY','UNITED STATES','10516-3727','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 04:10:21',0,NULL,8,1,17,0,NULL,' '),(3299,611236320001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','jtbone68','jtbone68@iwon.com','Joseph Resi','21 Orchard Ln','Cold Spring','NY','UNITED STATES','10516-3727','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 04:12:04',0,NULL,8,1,17,0,NULL,NULL),(3300,650435144002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','jtbone68','jtbone68@iwon.com','Joseph Resi','21 Orchard Ln','Cold Spring','NY','UNITED STATES','10516-3727','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 04:14:29',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›–  canon   2\r58mm rubber   æ©¡èƒ¶ç½©   1 \ret-65b    1'),(3301,611243667001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','gregorx2001','gregory@incessant.com','Gregory Pruden','2761 Dale Ave','Bexley','OH','UNITED STATES','43209','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 05:50:42',0,NULL,3,1,1,1,NULL,'å•ç¯å¤´  2 \r\r'),(3302,611250446001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',4,'AA3302',13.2,'hermeshine','msmim10','mimidorazio@bigpond.com','Emilia D\'Orazio','11 Irwin Road','Embleton','Western Australia','AUSTRALIA','6062','0892751143','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 05:57:30',0,NULL,3,1,2,1,NULL,'55mm uv   4 '),(3303,650461665002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lohner3','lohner3@hotmail.com','Ashlie Lohner','1803 Lantana Court','Southlake','TX','UNITED STATES','76092','(817) 488-7818','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 07:33:43',0,NULL,3,1,1,1,NULL,' '),(3304,610903989001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','thomajo2','thoma@edge.net','Thoma   Parker','618 Boscobel St','Nashville','TN','UNITED STATES','37206-4141','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 07:52:18',0,NULL,3,1,1,1,NULL,' '),(3305,650464703002,120560330004,'64pcs LED Light Flash Camcorder/Camera Photo Light ',1,'AB3317',36.99,'hermeshine','sky3910michal','sky3910@yahoo.com.sg','Michal Lim','Blk 762 Pasir Ris St 71 #04-228<br>(S)510762','default','','SINGAPORE','510762','6590236398','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 07:56:11',0,NULL,3,1,3,1,NULL,'RR815346504CN\r '),(3306,650474676002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','nahumzax','zook89@gmail.com','nahum zax','90teena st\'','moshav hemed','ISRAEL','ISRAEL','50295','972-50-8267563','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 09:07:55',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(3307,611276148001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','robiem72','tremk@triera.net','Emersic Robert','Rospoh 31b','Maribor','','SLOVENIA','SI2000','+38670899750','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 09:15:43',0,NULL,8,1,17,0,NULL,NULL),(3308,611276010001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','robiem72','tremk@triera.net','Emersic Robert','Rospoh 31b','Maribor','','SLOVENIA','SI2000','+38670899750','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 09:15:43',0,NULL,8,1,17,0,NULL,NULL),(3309,650475242002,120601700533,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','robiem72','tremk@triera.net','Emersic Robert','Rospoh 31b','Maribor','','SLOVENIA','SI2000','+38670899750','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 09:15:44',0,NULL,8,1,17,0,NULL,NULL),(3310,650475583002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','robiem72','tremk@triera.net','Emersic Robert','Rospoh 31b','Maribor','','SLOVENIA','SI2000','+38670899750','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 09:15:44',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡  2\råŒ…  1\r115w  220v   2\rå€’å½±æ¿   1\r60cm æ£š   1 \rCP219437323CN\ræ–°å•å·æ¢æˆï¼š CP179509855CN\r'),(3311,611273742001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','ilos9179','ivanlos@yahoo.com','IVAN LOSADA','AGASTIA 35 2 C','MADRID','Madrid','SPAIN','28027','646542166','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 10:13:48',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  ç™½ç›’  1 \rRR815346190CN\r'),(3312,611303044001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','timay554v','timay@hotmail.com','Sylvain Guimond','2850, des Hirondelles','BÃ©cancour','QC','CANADA','G9H 4M5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 11:53:52',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815346138CN\r'),(3313,611305422001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','philipnz20','philip@smartchat.net.au','Philip Cheng','Unit 2405<br>7 Riverside Quay','Southbank','Victoria','AUSTRALIA','3006','0422717535','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 12:07:29',0,NULL,3,1,2,1,NULL,NULL),(3314,708618787015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'',12,'hutongstore','zoumi1959','king1kty007@hotmail.fr','BONNETAUD Jeffrey','56 rue de lagrange','Manom','Lorraine','FRANCE','57100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-21 12:18:08',0,NULL,3,1,3,1,NULL,'1.6x3m ç™½è‰²èƒŒæ™¯å¸ƒ   1\rRR815346362CN\r '),(3315,694865587016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','pete0303','pete@zoapz.com','Peter marshall','Admiraal de Ruyterweg 3','amsterdam','','NETHERLANDS','1057 jt','0621874282','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-21 12:35:57',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶   2\r50-70 æ£š æ¬§æ ‡  2\r115w 220v   2\råŒ…   1\r110cm 5in1   1\rYW863600116CN\r\r '),(3316,650509102002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ariel.sharhabi','ariels.h@012.net.il','ariel sharhabi','or haganooz','or haganooz','marom hagalil','ISRAEL','13909','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 12:40:07',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRR815346186CN\r'),(3317,650511388002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','gtgaute','gtgaute@gmail.com','Gaute Thogersen','Skrenten 48 C','Larvik','Vestfold','NORWAY','3258','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 12:46:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´ æ¬§æ ‡   1\råå…‰ä¼ž   1 \rRR815346067CN\r'),(3318,650512341002,120553897299,'Wireless Flash Sync Trigger Receiver NEW pt-04tm ',1,'AB3322',19.99,'hermeshine','spinebass','udu.wudu@gmail.com','Deniss Arsenins','Anninmuizas bulvaris 38/3-46C','Riga','Latvia','LATVIA','LV-1067','+371 26411374','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 12:51:46',0,NULL,3,1,2,1,NULL,NULL),(3319,611314370001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','palagorn2006','plgorn@hotmail.com','Palagorn Raybumrung','888/104 Panuch Village<br>Pracharajbumpen Road,Samseannok,','Huaikhang','Bangkok','THAILAND','10320','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 12:57:07',0,NULL,3,1,3,1,NULL,'æ¸å˜ç°ï¼Œæ¸å˜çº¢ï¼Œ æ¸å˜è“ \rND2  ND4  ND8   \r6ç‰‡è£… æ»¤é•œè¢‹   1 \ré•œç‰‡ä¸è¦ç›’å­\rRR815346107CN\r'),(3320,694874525016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'',9.78,'hutongstore','pete0303','pete@zoapz.com','Peter marshall','Admiraal de Ruyterweg 3','amsterdam','','NETHERLANDS','1057 jt','0621874282','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-21 13:12:42',0,NULL,8,1,17,0,NULL,NULL),(3322,650533706002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','ernestfigueras','ernest.figueras@gmail.com','Ernest Figueras','Corcega 180, bajos derecha, CIBERehd','Barcelona','CataluÃ±a','SPAIN','08036','656348675','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 14:42:55',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW863600131CN\r'),(3323,708657669015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','simongorin61','simongorin@yahoo.co.uk','simon gorin','21 St Andrews Road st helier','Jersey','Channel Islands','UNITED KINGDOM','JE2 3JF','07797727359','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-21 14:57:30',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶  1 '),(3324,611340435001,110583278297,'TianYa 77mm CPL filter New 77 Circular Polarizing C-PL',1,'AA2307',7.1,'hermeshine','ogoxsam','sam.ogox@gmail.com','Ha Sam Vinh Hao','Blk 717 #22-105<br>Clementi West St 2','default','','SINGAPORE','120717','90941910','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 15:02:15',0,NULL,3,1,11,1,NULL,'å¤©æ¶¯  77mm cpl  1 '),(3327,611355048001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','harald0344','haraldbonke@hotmail.com','Harald Bonke','Veertien Hond 16','TIEL','','NETHERLANDS','4003GK','0344 633341','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 16:07:20',0,NULL,8,1,17,0,NULL,NULL),(3328,650554507002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','harald0344','haraldbonke@hotmail.com','Harald Bonke','Veertien Hond 16','TIEL','','NETHERLANDS','4003GK','0344 633341','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 16:07:21',0,NULL,3,1,3,1,NULL,'å°å·ç°å¡   1\rå€’å½±æ¿   1 \rRR815346141CN\r'),(3329,611160940001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','greels','mgreels@yahoo.com','MATTHEW GREELEY','320 16th St NE','MENOMONIE','WI','UNITED STATES','54751-2062','(715) 233-3059','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 16:14:59',0,NULL,3,1,1,1,NULL,NULL),(3330,708700504015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'',127,'hutongstore','slabrocker','kivilarmola@gmail.com','Kivi Larmola','70 Tootal Drive','Salford','Lancashire','UNITED KINGDOM','M5 5ER','01617377663','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-21 17:20:59',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ï¼‰   1\r2m ç¯æž¶  2\råŒç¯å¤´  è‹±æ ‡   2\råå…‰ä¼ž  2\r115w 220v   4\rlighting kit   $30\råŒ…    1\rYW863600120CN\r\r '),(3331,611377523001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','victor16554','vs_drammen@hotmail.com','Victor Pedersen','Dueveien 25','Hokksund','Hokksund','NORWAY','3300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 17:26:55',0,NULL,3,1,2,1,NULL,'éº‚çš®   1 '),(3332,611379408001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','serg70_2009','sergyuzhakov@gmail.com','Sergey Yuzhakov','19/43,Ul.Arkhangelskaya','Cherepovets','Vologodskaya obl','RUSSIAN FEDERATION','162603','78202623941','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 17:34:00',0,NULL,3,1,2,1,NULL,' '),(3333,611209837001,110532007471,'HB-7 HB7 Lens Hood for Nikon AF 80mm-200mm f/2.8D NEW',1,'AA3403',9.8,'hermeshine','jlocatell','jlocatell@gmail.com','Julio Locatelli','Lima 1261<br>Sistemas San Juan','Buenos Aires','CABA','ARGENTINA','1138','5411 43701153','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 18:37:02',0,NULL,3,1,2,1,NULL,NULL),(3334,611409951001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','wlad2318','wladneto@uol.com.br','Wladimir Nequesaurt Pereira Neto','Rua Lucio Vitorino de Souza 186','Florianopolis','Santa Catarina','BRAZIL','88035060','48-32346911','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 19:08:22',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶   1 '),(3335,649417321002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jeffreyhuntfish','hotfish@comcast.net','jeffrey lester','4301 NW 12th Way','pompano beach','FL','UNITED STATES','33064-1178','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 18:59:55',0,NULL,3,1,1,1,NULL,NULL),(3338,695029870016,260660053640,'New TianYa Star 4 points filters for Cokin P Series',1,'',7.8,'hutongstore','smithdw1','dereksmith60@hotmail.com','Derek Smith','10 Overstand Close','Beckenham','Kent','UNITED KINGDOM','BR3 3JY','02086586794','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-21 20:52:45',0,NULL,3,1,2,1,NULL,'æ˜Ÿå…‰é•œ   star4    1 '),(3339,650635519002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','se25itamar','se25@inter.net.il','itamar saida','box 2574','shoam','','ISRAEL','60850','972528898677','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 20:18:57',0,NULL,3,1,3,1,NULL,' æ–œè‡‚  1\rRR815346115CN\r'),(3340,650650722002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','max_d_solomko','max_solomko@bigmir.net','Max Solomko','Viljamsa st. home 15 corpus 3 ap. 63','Kiev','Kiev','UKRAINE','03191','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 21:07:17',0,NULL,3,1,2,1,NULL,NULL),(3342,650670879002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','tomi10090','t_balija@yahoo.com','tomislav balija','banski vinogradi 44a','zagreb','CA','CROATIA','10090','0918811883','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 22:11:33',0,NULL,3,1,3,1,NULL,' RR815346075CN\r'),(3344,610845110001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','jchi2889','jimmystu102@tds.net','james chiarella','12744 Kingston Pike<br>Ste 102','Knoxville','TN','UNITED STATES','37934-0941','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 22:13:30',0,NULL,3,1,1,1,NULL,NULL),(3345,611470056001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','omerpiposh','hfg666@bezeqint.net','Omer Yaari','The Galil 34','Kfar Saba','Sharon','ISRAEL','44233','972 52 4507156','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 22:15:03',0,NULL,3,1,3,1,NULL,' RR815346124CN\r'),(3346,611471078001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','omerpiposh','hfg666@bezeqint.net','Omer Yaari','The Galil 34','Kfar Saba','Sharon','ISRAEL','44233','972 52 4507156','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 22:20:41',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR815346155CN\r'),(3347,650677178002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','omerpiposh','hfg666@bezeqint.net','Omer Yaari','The Galil 34','Kfar Saba','Sharon','ISRAEL','44233','972 52 4507156','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 22:36:03',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815346084CN\r'),(3348,650677507002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','omerpiposh','hfg666@bezeqint.net','Omer Yaari','The Galil 34','Kfar Saba','Sharon','ISRAEL','44233','972 52 4507156','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 22:37:43',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815346098CN\r'),(3349,611480259001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','siretorre','asaad@me.com','RÃ©jean Harvey','496 Boniface','Le Gardeur','QC','CANADA','J5Z4K6','(450) 654-2636','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 23:01:11',0,NULL,3,1,2,1,NULL,NULL),(3351,611497736001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','prepaee','kayjet64@gmail.com','Mitchell Wolfrom','PO BOX 1362','Vieques','PR','UNITED STATES','00765-1362','(787) 435-9252','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 00:28:42',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(3352,708857911015,250600489459,'New Hairlight photostudio boom arm ',1,'',20.9,'hutongstore','dpssy42','antoinedurivaux@gmail.com','antoine durivaux','13 rue destienne dorves','chatillon','ÃŽle-de-France','FRANCE','92320','0625650644','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-22 00:39:37',0,NULL,8,1,17,0,NULL,NULL),(3353,695095620016,260619309261,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'',24.99,'hutongstore','dpssy42','antoinedurivaux@gmail.com','antoine durivaux','13 rue destienne dorves','chatillon','ÃŽle-de-France','FRANCE','92320','0625650644','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-22 00:39:36',0,NULL,8,1,17,0,NULL,''),(3354,708858417015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'',25,'hutongstore','dpssy42','antoinedurivaux@gmail.com','antoine durivaux','13 rue destienne dorves','chatillon','ÃŽle-de-France','FRANCE','92320','0625650644','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-22 00:39:37',0,NULL,3,1,4,1,NULL,'æ–œè‡‚  1\r50-70 æ£š  æ¬§æ ‡   1\r115w 220v   2\rlighting kit  $25\rYW863600175CN\r\r '),(3355,650711966002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2401',49.9,'hermeshine','koseofthewest','westkose@frontier.com','Cheryl Kose','7470 SW 140th Ave','Beaverton','OR','UNITED STATES','97008-8652','(503) 526-1322','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-22 01:24:58',0,NULL,3,1,1,1,NULL,'50-70 æŸ”å…‰æ£š é€šç”¨å¡å£   2\rå…ˆå‘ä¸€ä¸ªLK014121366CN\rè¿˜å·®ä¸€ä¸ªLK014380119CN'),(3357,611515709001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','lungfishman','ebaytrade@netscape.net','Robert Willmore','163 S John St','Crown Point','IN','UNITED STATES','46307-4157','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 02:04:59',0,NULL,3,1,1,1,NULL,NULL),(3358,650717760002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','typhoon220','sgagne2@midco.net','Sarah Gagne','2883 Highway 11 S','Loman','MN','UNITED STATES','56654-8009','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 01:54:29',0,NULL,3,1,1,1,NULL,NULL),(3360,611518929001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','darare','davidrafael@gmail.com','David Reyes','7801 NW 37th St<br># DO80Q22750N','DORAL','FL','UNITED STATES','33166-6503','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 02:22:57',0,NULL,3,1,1,1,NULL,' '),(3361,650725705002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','mnncoop','mnncoop@verizon.net','Filomena Cooper','24 Sesame St','Kings Park','NY','UNITED STATES','11754-2836','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'LK014374665CN'),(3362,708893420015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','jazzrena','jazzrena@yahoo.com','Renatas Fominichas','103 Hurworth Avenue','Slough','Berkshire','UNITED KINGDOM','SL3 7FG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-22 03:26:04',0,NULL,3,1,2,1,NULL,NULL),(3363,611540891001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','sn74','support@creograf.ru','Anastasiya Deeva','Solnechnaya street 12A-34','Chelyabinsk','','RUSSIAN FEDERATION','454014','+7 909-746-6433','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 04:39:29',0,NULL,3,1,2,1,NULL,NULL),(3364,650748359002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','tuoc22gh7','tuoc2@juno.com','Joseph Nguyen','2309 Gaylord St','Denver','CO','UNITED STATES','80205-5627','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 04:55:32',0,NULL,3,1,1,1,NULL,NULL),(3365,611544040001,110534333216,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',2,'AA1201',8,'hermeshine','truesharp','fond@radiolink.ru','Andrey Smirnov','Zelenograd, kor. 1606, kv. 392','Moscow','','RUSSIAN FEDERATION','124365','+7(903)726-1110','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 05:05:34',0,NULL,8,1,17,0,NULL,NULL),(3366,611541482001,110529627255,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','truesharp','fond@radiolink.ru','Andrey Smirnov','Zelenograd, kor. 1606, kv. 392','Moscow','','RUSSIAN FEDERATION','124365','+7(903)726-1110','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 05:05:35',0,NULL,3,1,2,1,NULL,'450dçœ¼ç½©  2\rå¤§å·ç°å¡   1 '),(3368,611547254001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','1pslabo1','pslabo@gmail.com','Pavel Slabodkin','ul. Dekabristov d.34 kv.6','Moscow','','RUSSIAN FEDERATION','127273','+79036185228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 05:31:03',0,NULL,3,1,2,1,NULL,' '),(3370,650769046002,120601700210,' New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',30.9,'hermeshine','spartanof84','matthew_alderdice@yahoo.com.au','Matthew Alderdice','46 Middle St Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0293981243','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 07:45:36',0,NULL,3,1,3,1,NULL,'æ¡Œé¢ç¯   1 \rRR815346481CN\r'),(3371,649072524002,120499333257,'Flash Softbox Diffuser for external flash SB800 580EX',1,'AB3302',8.8,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-22 07:21:23',0,NULL,8,1,17,1,NULL,NULL),(3372,611576169001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',2,'AB3321',53.98,'hermeshine','mizer357','mizer357@yahoo.com','Henry Cho','610 W 42nd St<br>Apt 53G','New York','NY','UNITED STATES','10036-1997','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 09:36:57',0,NULL,3,1,1,1,NULL,'ttlçº¿  1m   2 '),(3373,611581118001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','wellingtonrlimawellington','wellingtonrlima@gmail.com','Wellington Rodrigues Lima','PraÃ§a Carlos Chagas, 49Âº / 10Âº andar<br>Lourdes','Belo Horizonte','Minas Gerais','BRAZIL','30170-913','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 10:13:29',0,NULL,3,1,2,1,NULL,NULL),(3374,650789817002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','tomash_15','toms.element@gmail.com','tomer ifrach','yehuda halevi 21','herzelia','il','ISRAEL','46480','(972)544443223','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-22 10:24:34',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815346420CN\r'),(3375,695207137016,260660052146,'New 62mm 62 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','franziska4532','franzi-leo@web.de','Franziska Leonhardi','48 Carnock Road','Dunfermline','Fife','UNITED KINGDOM','ky 129nt','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-22 11:07:42',0,NULL,3,1,2,1,NULL,'62mm çŽ¯æž¶   1 '),(3376,611624362001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','dhwteb','dhwieringa@planet.nl','derk  wieringa','ludgerstraat 12','bedum','','NETHERLANDS','9781GG','0648563412','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 14:26:02',0,NULL,3,1,2,1,NULL,NULL),(3377,611615301001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',94.9,'hermeshine','perhan195','per@phpwebtech.com','Per Hanson','Urb. Terrazas del Rodeo<br>Bloque 6-1C','Nueva Andalucia','AndalucÃ­a Ceuta y Melilla','SPAIN','29660','600012841','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-22 15:26:19',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ ï¼‰ \rä¸¤ä¸ªèƒŒæ™¯å¸ƒéƒ½æ˜¯1.6x3m   1\rbackground support   1\rYW863684575CN'),(3378,650859802002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',8,'AA1310',43.92,'hermeshine','lolica007','rcararo@ig.com.br','LOURDES LISE CARARO','RUA BORTOLO ZANI, 97<br>SALA 1','CAXIAS DO SUL','RIO GRANDE DO SUL','BRAZIL','95072-000','054 3228 5664','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 16:27:54',0,NULL,3,1,3,1,NULL,' RR815346447CN\r'),(3379,611652981001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','pisnou','fc888@club-internet.fr','Francois CARREZ','17 rue JEAN JACQUES ROUSSEAU<br>App 122','CORBEIL ESSONNES','ÃŽle-de-France','FRANCE','91100','0675085353','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 16:36:38',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°   1\r77mm çŽ¯æž¶   1 '),(3380,650863662002,120560203215,'Nikon 52mm Reverse Adapter Combined shipping discounts',1,'AA1210',4.4,'hermeshine','hansasd.eb','hansasd@gmail.com','Hansa Dharmapriya','10<br>Araliya Mawatha','Sirimal Uyana','Ratmalana','SRI LANKA','10370','+94776256383','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 16:40:13',0,NULL,3,1,2,1,NULL,'nikon-52mm åæŽ¥çŽ¯  1 '),(3381,709110110015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','kriginasm','kriginas.marius@gmail.com','Mar Kriginas','Ziedu 4 Pajiesmeniai','Pasvalio raj','','LITHUANIA','39449','+37061592593','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-22 19:21:01',0,NULL,3,1,2,1,NULL,'1è½¬4 ç¯å¤´   1 '),(3382,650913923002,120601698401,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','itzikelisha','iel8@walla.com','itzik elisha','yarkon 34<br>isrel','baer yakov','MD','ISRAEL','70300','0506537779','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 19:34:15',0,NULL,3,1,2,1,NULL,NULL),(3383,611712787001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',4,'AA1309',9.8,'hermeshine','swingfishnut','marksebay@verizon.net','Mark J. Gucker','1525 5th PL','Kirkland','WA','UNITED STATES','98033','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 19:57:19',0,NULL,3,1,1,1,NULL,NULL),(3384,611717611001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','dimaster7','dimasmotta@yahoo.com','DIMAS MOTTA','3235 30th Street Apt D1','Astoria','NY','UNITED STATES','11106','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 20:12:34',0,NULL,3,1,1,1,NULL,NULL),(3385,611721838001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','concept-tango','concept-tango@hotmail.com','Claudia Gherzetich','Colectora AU Ricchieri, Barrio Autopista,<br>Torre 8, 10Â° C','Tapiales','Buenos Aires','ARGENTINA','1770','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 20:26:16',0,NULL,3,1,2,1,NULL,NULL),(3386,650955136002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','stephaniejeansouthard','stephaniejeansouthard@gmail.com','Stephanie Southard','2163 N Brandywine St','Arlington','VA','UNITED STATES','22207-2225','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 21:43:39',0,NULL,3,1,1,1,NULL,NULL),(3387,650960518002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0014',18,'hermeshine','ruslanl','ruslanla@ukr.net','Ruslan Lyulya','11 Dudykina<br>108','Zaporizhzhya','Zaporizhzhya','UKRAINE','69065','38-050-6610745','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 22:06:51',0,NULL,3,1,3,1,NULL,'1.6x3m èƒŒæ™¯å¸ƒ   é»‘è‰² RR815346570CN\r'),(3388,611752214001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','hands2u','ray@hands2u.com','Raymond Stover','69 W Anchor Dr','Little Egg Harbor','NJ','UNITED STATES','08087-1626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 22:16:59',0,NULL,3,1,1,1,NULL,NULL),(3389,611754648001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','cuemeister','tekdiver@metrocast.net','Daniel Butler','70 Dalton Dr','Center Barnstead','NH','UNITED STATES','03225','(603) 509-2885','NoPaymentFailure','CheckoutComplete','Other','2010-12-22 22:30:14',0,NULL,3,1,3,1,NULL,'RR815346478CN\r '),(3390,650967639002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','litobocon','miguelginermg@gmail.com','miguel giner','polo y peyrolon n5 pta 19','valencia','Comunidad Valenciana','SPAIN','46021','963695436','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 22:35:34',0,NULL,8,1,17,0,NULL,' '),(3391,695408414016,260687503075,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'',28.99,'hutongstore','litobocon','miguelginermg@gmail.com','miguel giner','polo y peyrolon n5 pta 19','valencia','Comunidad Valenciana','SPAIN','46021','963695436','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-22 22:41:39',0,NULL,3,1,4,1,NULL,'3m æ¨ªæ†   1 \rCåž‹å¤¹  2\rYW863684623CN'),(3392,611754534001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','acwaits','andrew.waits@gmail.com','Andrew Waits','725 15th Ave','Seattle','WA','UNITED STATES','98122','(206) 931-2221','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 22:49:14',0,NULL,3,1,1,1,NULL,NULL),(3393,611768707001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1304',12.99,'hermeshine','rozzikat','marzi@q.com','Marlene Romuar','2500 S Broadway<br>Trlr 13','Cortez','CO','UNITED STATES','81321-8502','(970) 564-9360','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 23:38:41',0,NULL,3,1,1,1,NULL,'æ–°æ¬¾å†…èƒ†åŒ…   1 '),(3395,650989369002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','smkhan57','skhan511@hotmail.com','Saad Khan','11 Municipal Square','Clarenville','NL','CANADA','A5A1T4','(709) 466-2659','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 00:24:14',0,NULL,3,1,2,1,NULL,NULL),(3396,611777394001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','graham186','grahamrobson@talktalk.net','Graham Robson','186 Inchbonnie Road','South Woodham Ferrers','Essex','UNITED KINGDOM','CM3  5WU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 00:30:21',0,NULL,3,1,2,1,NULL,'6663aå¿«è£…æ¿  1 '),(3397,650992552002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','fisheggie','vian.c@hotmail.com','Vian Cheng','#86-3260 E58th Ave','Vancouver','BC','CANADA','V5S 3T3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 00:38:27',0,NULL,3,1,2,1,NULL,NULL),(3398,651002805002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ivanebeoulve','ivane.beoulve@hotmail.com','Ivan Negrete','317 Heffernan Ave<br>PMB 10918','Calexico','CA','UNITED STATES','92231-2739','(020) 234-2342','NoPaymentFailure','CheckoutComplete','Other','2010-12-23 01:37:50',0,NULL,3,1,3,1,NULL,' RR815346433CN\r'),(3399,695453393016,260619309261,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'',24.99,'hutongstore','chrissie_n02','lanxxoo@yahoo.com.au','Lan Nguyen','8 Border Close','Hinchinbrook','New South Wales','AUSTRALIA','2168','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-23 02:13:29',0,NULL,3,1,3,1,NULL,'115w 220v   2 \rRR815346495CN\r'),(3400,611796289001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','pitukmercerago','mercerago@hotmail.com','PITUK KARNYOO','104 Moo 12 Soi Tanasit Teparak Rd. Bangpla','Bangplee','Samutprakarn','THAILAND','10540','086-233-8407','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 02:32:39',0,NULL,3,1,11,1,NULL,NULL),(3401,611801130001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',28.99,'hermeshine','seratolvinyl','seratovinyl@gmail.com','Paul Vollmer','2720 S Highland Ave<br>Apt 750','Lombard','IL','UNITED STATES','60148-7156','(815) 557-7746','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-23 02:57:29',0,NULL,3,1,1,1,NULL,'ttl çº¿  canon   3m   1 '),(3402,651022235002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','henrckw001','henrckw001@yahoo.com','Ket Wai Chu','No. 53A, Jln Apollo U5/187,<br>Bandar Pinggiran Subang','Shah Alam','Selangor Darul Ehsan','MALAYSIA','40150','0122375800','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 03:30:39',0,NULL,3,1,2,1,NULL,NULL),(3403,610869274001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','andrelorente','andrelorente@ig.com.br','Helio Bressan','Rua Dr. Candido Espinheira, 396<br>Terreo','Sao Paulo','SP','BRAZIL','05004000','(551) 199-2691 ext.: 14','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 04:50:32',0,NULL,3,1,5,1,NULL,'\rCP219437283CN'),(3404,611823716001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','econspiracydesign','econ@econ.net','Brian Walls','255 4th St<br>Ste 104','Oakland','CA','UNITED STATES','94607-4389','(510) 836-0683','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-23 05:52:20',0,NULL,3,1,1,1,NULL,NULL),(3405,651041950002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','cowgirl4040','cowboy44@shaw.ca','Wendy Sherlock','#202 - 8830 Montcalm Street','Vancouver','BC','CANADA','V6P 4R3','(604) 267-0057','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 06:02:56',0,NULL,3,1,2,1,NULL,NULL),(3406,611828852001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.8,'hermeshine','farinhasbr','digite@hotmail.com','Mauricio Farias','Av Governador Valadares 54','Monte Santo de Minas','Minas gerais','BRAZIL','37958000','513535912535','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 06:39:52',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´   2 '),(3407,611834470001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','liongld','lion_dg@mail.ru','Gabaraev Levan','Sverdlova 22 - 59','Tyumen','Tyumen Region','RUSSIAN FEDERATION','625002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 07:32:11',0,NULL,3,1,2,1,NULL,NULL),(3408,611582638001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','theblueman','bluemanchurian@gmail.com','Mark H Hopper','1740 Chopin Dr','Charlottesville','VA','UNITED STATES','22903','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-23 08:30:47',0,NULL,3,1,1,1,NULL,NULL),(3410,709284226015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','rasjep09','peterpbo@gmail.com','Peter Bornaes','Soparken 97','Roskilde','SjÃ¦lland','DENMARK','4000','+45 23232323','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 08:32:07',0,NULL,3,1,2,1,NULL,NULL),(3411,651075141002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','onmyaeroplane','michele@myaeroplane.it','michele piazza','via a. volta 24','chiampo','VI','ITALY','36072','0444625776','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 10:48:23',0,NULL,3,1,3,1,NULL,'2mç¯æž¶  1\rå•ç¯å¤´ æ¬§æ ‡  1\råå…‰ä¼ž   1 \rRR815346671CN\r'),(3412,611884383001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','gustavof','gustavoguantay@gmail.com','Gustavo Guantay','Tomas Cabrera 623','Salta','Salta','ARGENTINA','4400','4340961','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 13:42:34',0,NULL,3,1,2,1,NULL,'å“èƒœ3.0è†œ   1 '),(3413,611885365001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','iraklis05','kesidisi@hotmail.com','Mr. Iraklis Kesidis','Kirkis 3 flat 102','Paphos','Paphos','CYPRUS','8049','+35799783602','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 13:46:07',0,NULL,3,1,2,1,NULL,NULL),(3414,709343072015,250599932668,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'',40,'hutongstore','greymancyclist','graham.fielder@gmail.com','Graham Fielder','4 THORNESS CLOSE MILLBROOK','SOUTHAMPTON','Hampshire','UNITED KINGDOM','SO16 9JE','02380579524','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-23 14:01:22',0,NULL,3,1,3,1,NULL,' RR815346711CN\r'),(3415,611888186001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','robalo8k','mons@mundo-r.com','Mauricio Bechler','CXG VIAXES<br>SÃ¡nchez Bregua, 5-3Âº','A CORUÃ‘A','Galicia','SPAIN','15004','902116882','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 14:01:42',0,NULL,3,1,2,1,NULL,NULL),(3416,709308411015,250619797712,'Photo Studio Background Support (2mÃ—2m)+ Free Backdrop',1,'',51.9,'hutongstore','chi26zach','chiarazach@btopenworld.com','Chiara Zachary','37 Westdale Drive','Moodiesburn','North Lanarkshire','UNITED KINGDOM','G69 0NP','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-23 14:23:38',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰ 1\ré•¿çš„ \rbackground support  $20\rYW863684553CN\ræ¢æˆsaläº†ï¼šCP219637024CN \r'),(3417,709346876015,250692236297,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',3,'hutongstore','aldo1052','eelcpo@tin.it','Aldo Porretta','Le Quadra ,3','Castelliri','Frosinone','ITALY','03030','3287160778','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 14:53:22',0,NULL,8,1,17,0,NULL,NULL),(3418,709348379015,250692242462,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',3.5,'hutongstore','aldo1052','eelcpo@tin.it','Aldo Porretta','Le Quadra ,3','Castelliri','Frosinone','ITALY','03030','3287160778','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 14:53:22',0,NULL,3,1,2,1,NULL,'67mm uv   1\r77mm uv    1 '),(3419,709363642015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','soares197150','fsfotosoares@gmail.com','Francisco Soares','Largoda Barreira nÂº2','Vilarandelo','ValpaÃ§os','PORTUGAL','5430-635','252419575','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 15:32:29',0,NULL,3,1,2,1,NULL,'1è½¬4 ç¯å¤´   1 '),(3420,611906940001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','talat417','talat_417@hotmail.com','talat arslan','82 evler 3122 sok. no:14<br>berdan ogrenci yurdu tarsus','mersin','','TURKEY','33460','905425942912','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 15:40:21',0,NULL,3,1,2,1,NULL,'éº‚çš®   1 '),(3421,611908661001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','soloaki','robobby@ymail.com','Roberto Guadarrama','Reforma # 7','Iguala de la independencia','guerrero','MEXICO','40000','557333337193','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,NULL),(3422,651128488002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bbemis5150','bbemis@san.rr.com','Bryan Bemis','9584 Via Pereza','San Diego','CA','UNITED STATES','92129-2730','(858) 414-5898','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-23 16:03:18',0,NULL,3,1,1,1,NULL,NULL),(3423,709372732015,250692238780,'New Desktop Photography light Stand 10-15\" Tall',2,'',41.8,'hutongstore','thebrontelife','buysomeflowers@gmail.com','Rebeca Santamaria Bretones','C/ Mesena NÂº 18, bloque b, escalera b-1, piso 2Âº A','Madrid','Madrid','SPAIN','28033','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 16:07:33',0,NULL,3,1,4,1,NULL,'æ¡Œé¢ç¯   2 \rlight  $26\rYW863684590CN\r'),(3424,651132878002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','mohabdellah','abdellah21211@yahoo.com','Mohamed Aly Abdellah','Riqqa Street , Deria , Dubai','Dubai','','UNITED ARAB EMIRATES','14568','00971558229325','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 16:21:19',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rå•ç¯å¤´   1  è‹±æ ‡\råå…‰ä¼ž   1 \rRR815346685CN\r'),(3425,651133511002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2401',24.95,'hermeshine','mohabdellah','abdellah21211@yahoo.com','Mohamed Aly Abdellah','Riqqa Street , Deria , Dubai','Dubai','','UNITED ARAB EMIRATES','14568','00971558229325','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 16:22:52',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£  1 \rRR815346950CN\r'),(3426,651146911002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','rufat_abas','rufatabas@gmail.com','Rufat Abas','2942A Mahammad Hadi street, apt 74','Baku','','AZERBAIJAN','AZ1129','(99450)2222809','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 17:24:05',0,NULL,3,1,2,1,NULL,'60cm 2in1   1 '),(3427,651151362002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lemeilleurencherisseurcmoa','francois.pavee@free.fr','Thibault PAVEE','42 rue de Dantzig','Paris','ÃŽle-de-France','FRANCE','75015','08.30.70.18.33','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 17:41:02',0,NULL,3,1,2,1,NULL,NULL),(3428,611899035001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','nudawest','dolbit@list.ru','Denis Moskvin','prospekt Karla Marksa 324-10',' Samara','','RUSSIAN FEDERATION','443016','+7 927-608-80-10','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 18:01:08',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m èƒŒæ™¯å¸ƒ  ç™½è‰²   1\r2mç¯æž¶   2\r50-70 æ£š æ¬§æ ‡  2\r115w 220v   1\råŒ…   1\r CP219436985CN\r'),(3429,611943435001,110566021441,'TianYa ND4 Filter for Cokin P Series Neutral Density',1,'AA2324',7.2,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:16',0,NULL,8,1,17,0,NULL,NULL),(3430,651159700002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:15',0,NULL,8,1,17,0,NULL,NULL),(3431,651158340002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:15',0,NULL,8,1,17,0,NULL,NULL),(3432,611943935001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:14',0,NULL,8,1,17,0,NULL,NULL),(3433,651159067002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:16',0,NULL,8,1,17,0,NULL,NULL),(3434,611942738001,110531023633,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:17',0,NULL,3,1,3,1,NULL,'æ¸å˜æ£•   1\r77mm æŽ¥å£çŽ¯  1\réº‚çš®   1\rå¹¿è§’æ‰˜æž¶   1\ræ¸å˜ç°    1\rND4    1 \rRR815346739CN\r'),(3435,611981118001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2101',59,'hermeshine','jojodel1','luc@execphoto.ca','Luc St-Amour','15 des Poiriers','Cantley','QC','CANADA','J8V3R5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 20:44:00',0,NULL,3,1,3,1,NULL,'nikon åŽŸè£…èƒŒå¿ƒ  XL   1 \rRR815346725CN\r'),(3436,695677392016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'',3,'hutongstore','blues-riff','pals@lyra.cc','Stephen Morton','548 Avenue Andre Gide','Cabris','Alpes Maritime','FRANCE','06530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 20:55:11',0,NULL,3,1,2,1,NULL,'450D  çœ¼ç½©  1 '),(3437,695680235016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','rszulia','rszulia@wp.pl','Ryszard Szulia','18 Glebe Road','Stratford upon Avon','Warwickshire','UNITED KINGDOM','CV37 9JU','07756939620','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-23 21:04:36',0,NULL,3,1,2,1,NULL,'67mm çŽ¯æž¶    1 '),(3438,611990102001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','lufox77','desenhado@gmail.com','Luciano Alves','Rua Rego Freitas, 355 ap64','Sao Paulo','Sao Paulo','BRAZIL','01220010','55 11 9400-3437','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 21:24:44',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR815346668CN\r'),(3439,709476742015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','jekas69','joel.pereira@iol.pt','Joel Pereira','Tv dos Unidos, 2','Tamel S. Verissimo','Barcelos','PORTUGAL','4750-726','+351 918904656','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 21:49:49',0,NULL,3,1,2,1,NULL,'RS-S1   1 '),(3440,695557457016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','raonipz','raoniz@hotmail.com','Raoni Zopolato','29 Grendon House/ Shore Place','London','London','UNITED KINGDOM','E9 7qg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-23 21:55:09',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—  1 '),(3441,651217221002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','johnnyalves75','alvesjohnny@sapo.pt','Johnny Alves','Rua 12 - nr.936 - 3Âºesq.Âº','Espinho','PA','PORTUGAL','4500','917774940','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 22:01:21',0,NULL,3,1,2,1,NULL,'lenspen   2 '),(3442,612006231001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','smartpoppoppop','baysmartpop@hotmail.com','Mr.Teeraphon Sunteeraparp (POP)','465 Plubplachai Road Tambon Pom-Parp<br>Pom-parp-sattru-phai District','Bangkok','à¸›à¸£à¸°à¹€à¸—à¸¨à¹„à¸—à¸¢','THAILAND','10100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 22:44:33',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR815346742CN\r'),(3443,651229320002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','thetawaves','vinhboi28@yahoo.com','Vinh-Boi Nguyen','1149 Mountain Gate Rd','Upland','CA','UNITED STATES','91786-2668','(909) 451-1225','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-23 23:01:57',0,NULL,3,1,1,1,NULL,' '),(3444,651270538002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','lottiemcdottie1','lottie_mcdottie@hotmail.com','Charlotte Bell','103-1915 E Georgia Street','Vancouver','BC','CANADA','V5L 2B7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 03:22:21',0,NULL,3,1,2,1,NULL,''),(3445,651181733002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',185,'hermeshine','soulsoothe','jrweaver@gmail.com','James Weaver','6201 Chapel Hill Blvd<br>Apt 2113','Plano','TX','UNITED STATES','75093-8887','(972) 971-2156','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-24 04:05:08',0,NULL,3,1,4,1,NULL,'çº¢å¤´ç¯  3\r800w110v   3\rç‡•æ–‡  light $30 \rYW863684601CN\r'),(3446,612054427001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'',13.99,'hermeshine','fujiyamasensei','robert.arbour@cgocable.ca','Robert Arbour','4510 Papineau','Trois-RiviÃ¨res','QC','CANADA','G8Y 1R1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 04:14:43',0,NULL,3,1,3,1,NULL,'90th é•œå¤´ç­’    1 \rRR815346875CN\r'),(3447,709549696015,250600489459,'New Hairlight photostudio boom arm ',1,'',20.9,'hutongstore','janberg','janfal@gmail.com','Jan F. Stetzelberg','58 Queens Gate Terrace Flat 5','London','London','UNITED KINGDOM','SW7 5PJ','07510304157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-24 04:15:25',0,NULL,3,1,3,1,NULL,' RR815346889CN\r'),(3448,612057628001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','got2ebuyitnow','tlambrou100@hotmail.com','Anthony C Lambrou','Calle 49 No 519 x 62 y 64<br>Centro','Merida','Yucatan','MEXICO','C.P. 97000','011-999-52-928-6694','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 04:37:48',0,NULL,3,1,2,1,NULL,NULL),(3449,651278083002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','wencam1225','wencam318i@usa.com','Wendell Campbell','PO Box 1164<br>807 Fox St','Elizabethtown','NC','UNITED STATES','28337-1164','(910) 876-3106','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 04:56:22',0,NULL,3,1,1,1,NULL,NULL),(3450,695796552016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'',5.5,'hutongstore','angonzi','angonzi@gmail.com','Ana GONZÃLEZ','Francisco de Quevedo 9, 3Âª F','LogroÃ±o','La Rioja','SPAIN','26006','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 08:46:49',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(3451,612083458001,110583709805,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',25,'hermeshine','jacek3210','jacek.dojnikowski@jaswily.pl','JACEK DOJNIKOWSKI','JAÅšWIÅY 71A/17, JAÅšWIÅY','JAÅšWIÅY','podlaskie','POLAND','19-124','606 655441','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 09:09:25',0,NULL,3,1,3,1,NULL,'58mm cpl, nd8, +4, æ¸å˜ç° æ”¾åœ¨4pcs æ»¤é•œè¢‹é‡Œ \rRR815340064CN'),(3452,612085785001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','cekk81','andreacekk@libero.it','andrea cecchetti','via maresciallo diaz 55','marcellina','RM','ITALY','00010','339-8655240','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 10:04:03',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶ 1\r æ–œè‡‚   1 \r\rlight stand  $20\rYW863684704CN\r'),(3453,695825385016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','hoogy4','a_hoogy@yahoo.co.uk','Alwyn Hoogwerf','59 Cumberland Road','Hanwell','London','UNITED KINGDOM','W7 2EH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-24 11:56:51',0,NULL,3,1,2,1,NULL,'67mm çŽ¯æž¶   1 '),(3454,651336178002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','diamond196406','diamond2000@sympatico.ca','DANIEL DIAMOND','7815, 55 iÃ¨me AVENUE','LAVAL','QC','CANADA','H7R 4E3','(450) 962-7325','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 12:51:00',0,NULL,3,1,2,1,NULL,NULL),(3455,709625138015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'',22,'hutongstore','wockerjabb','genieysjp2@hotmail.com','Jean-Philippe Genieys','27 rue Haxo','Paris','IDF','FRANCE','75020','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 13:06:57',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 RA022498106CN'),(3456,695844199016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','numbo-boss','nortel@nm.ru','Boris Bolotin','Novinskiy bulvar,15-35','Moscow','Russia','RUSSIAN FEDERATION','121099','79851309697','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 13:41:03',0,NULL,3,1,2,1,NULL,' '),(3457,695851276016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',38,'hutongstore','28330042','kenneth.barr@virgin.net','kenneth barr','105 tottenham crescent kingstanding','birmingham','West Midlands','UNITED KINGDOM','B44 0ST','01213555245','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-24 14:18:04',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶  1\r2m ç¯æž¶   1 \rreflector holder   $20\rYW863684693CN\r'),(3458,612126677001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',5,'AB1305',18.95,'hermeshine','moppersmurfje1971','mario@redeker.nl','Mario Redeker','Elise van Calcarstraat 66','Den Haag','','NETHERLANDS','2522MD','0622929989','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 14:26:53',0,NULL,3,1,3,1,NULL,'67mm æ©¡èƒ¶ç½©    5 RA022498083CN'),(3459,612128114001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','ecosvit','mv68@yandex.ru','Vyacheslav Makogon or Oleksandra Makogon','vul.E.Konovaltsa, b.14, kv.19.','Rivne','Rivne','UKRAINE','33016','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 14:37:05',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶   1 \rCP219437031CN\r'),(3460,651364834002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','rs2783','robert.sideserf@btinternet.com','Robert Sideserf','46 Randall Road, Chandlers Ford','Eastleigh','Hampshire','UNITED KINGDOM','SO535AL','02380267193','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 15:36:28',0,NULL,3,1,4,1,NULL,'717AH   1 \rBallhead  $20\rYW863684682CN\r'),(3461,612139831001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 15:38:07',0,NULL,8,1,17,0,NULL,''),(3462,612141997001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 15:49:16',0,NULL,3,1,2,1,NULL,' 58mm çŽ¯æž¶   1 \r67mm uv    1'),(3465,709671507015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'',1.88,'hutongstore','kimberley5954','kimberleydewar@hotmail.co.uk','Kimberley Dewar','The Old School Ancroft','BERWICK-UPON-TWEED','Northumberland','UNITED KINGDOM','TD151TE','07825604566','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-24 16:41:36',0,NULL,3,1,2,1,NULL,NULL),(3466,651378116002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','konischev','paraidey@yandex.ru','Maxim Konischev','N. Ostrovskogo St.<br>162/1, 104','Astrakhan','','RUSSIAN FEDERATION','414022','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 16:44:49',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´ æ£š  æ¬§æ ‡   2\r45w  8\råŒ…  1 \rCP219437028CN\r'),(3467,709677699015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',8,'',28.96,'hutongstore','1imagen','imaklos@hotmail.com','Manuel','Avenida Derechos Humanos 28 - Rdcia.Los sauces 10','Laredo','Cantabria','SPAIN','39770','942611010','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 17:11:00',0,NULL,8,1,17,0,NULL,''),(3468,695889928016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',9,'',32.22,'hutongstore','1imagen','imaklos@hotmail.com','Manuel','Avenida Derechos Humanos 28 - Rdcia.Los sauces 10','Laredo','Cantabria','SPAIN','39770','942611010','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 17:18:07',0,NULL,3,1,3,1,NULL,'67mm cpl   9\r72mm cpl  8 RA022498097CN'),(3469,651364234002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','nexcellpower','lynn@skycom.com.sg','Yee Chiang Yin','84 Flora Road #04-16','Singapore','','SINGAPORE','507001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 17:19:38',0,NULL,3,1,11,1,NULL,NULL),(3470,695890511016,260660051378,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'',2.75,'hutongstore','spamkil','deusexmachina@bk.ru','Igor Shatochin','str. Stavropolskaj haus 1331 apartment 46','Krasnodar','Krasnodarskij kraj','RUSSIAN FEDERATION','350040','+79286606285','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 17:21:07',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§ sony   1 '),(3471,612178261001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','dimitrina2010','photodim@walla.com','Dima Noff','7 Kikar Magness','Jerusalem','','ISRAEL','92304','972-545-791720','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 19:13:28',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RA022498018CN'),(3472,612179969001,110513729693,'Remote Control Wireless Shutter Release Canon 40D 5DII ',1,'AA3228',35.5,'hermeshine','jmaysen','john@maysen.com','John Maysenhoelder','2845 ch Glenday','Sherbrooke','QC','CANADA','J1M0C2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 19:24:00',0,NULL,3,1,3,1,NULL,'yn126 - c3  1 \rRR815340444CN'),(3473,651410174002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','fardochepq','dominicfortier@videotron.ca','Fortier Dominic','264 Place de Blois','Ste-Julie','QC','CANADA','J3E 2P1','(450) 338-0973','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 19:40:51',0,NULL,8,1,17,0,NULL,NULL),(3474,612182709001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','fardochepq','dominicfortier@videotron.ca','Fortier Dominic','264 Place de Blois','Ste-Julie','QC','CANADA','J3E 2P1','(450) 338-0973','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 19:40:51',0,NULL,3,1,2,1,NULL,'72mm é•œå¤´ç›–   canon 1\r77mm é•œå¤´ç›–  canon  1 '),(3475,651411551002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','87outlawracer','ronshubin@skinnerautoplex.com','Ron Shubin','2177 S Pacific Hwy','Medford','OR','UNITED STATES','97501','(541) 826-9267','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 20:02:36',0,NULL,8,1,17,0,NULL,NULL),(3476,651407650002,120564178624,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','87outlawracer','ronshubin@skinnerautoplex.com','Ron Shubin','2177 S Pacific Hwy','Medford','OR','UNITED STATES','97501','(541) 826-9267','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 20:02:36',0,NULL,8,1,17,0,NULL,NULL),(3477,651411420002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','87outlawracer','ronshubin@skinnerautoplex.com','Ron Shubin','2177 S Pacific Hwy','Medford','OR','UNITED STATES','97501','(541) 826-9267','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 20:02:37',0,NULL,8,1,17,0,NULL,NULL),(3478,651407542002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3306',8.4,'hermeshine','87outlawracer','ronshubin@skinnerautoplex.com','Ron Shubin','2177 S Pacific Hwy','Medford','OR','UNITED STATES','97501','(541) 826-9267','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 20:02:38',0,NULL,8,1,17,0,NULL,' '),(3479,651411489002,120566694399,'Brand New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','87outlawracer','ronshubin@skinnerautoplex.com','Ron Shubin','2177 S Pacific Hwy','Medford','OR','UNITED STATES','97501','(541) 826-9267','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 20:02:38',0,NULL,3,1,1,1,NULL,'æ˜Ÿå…‰é•œ star6    1\r72mm uv      2\r58mm é•œå¤´ç›–   canon   1\rcpl    1\ræ¸å˜è“   + æ¸å˜æ©™  + nd4 + 72mm çŽ¯æž¶   1\r '),(3480,695926172016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','bussyness-martin','bussyness@email.cz','Urbanak Martin','Smilovskeho 12/1391','SlezskÃ¡ Ostrava','Moravskoslezsky Kraj','CZECH REPUBLIC','71000','+420723739708','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 20:13:34',0,NULL,3,1,2,1,NULL,'æœºèº«ç›–/é•œå¤´åŽç›–  canon   1 '),(3481,651419926002,120601698609,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','vlporton','vporton@012.net.il','Vladislav Porton','Har Metsada 107/39','Ashdod','','ISRAEL','77711','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 20:34:00',0,NULL,3,1,3,1,NULL,'wf1005    1 RA022498049CN'),(3482,612192475001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tomsnetwork','tomi.jelic@gmail.com','Tomislav Jelic','J.J. Strossmayera 51','Bosnjaci','Croatia (Hrvatska)','CROATIA','32275','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 20:40:43',0,NULL,3,1,2,1,NULL,NULL),(3483,651423562002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','norsk_voyager','mario@mariotomic.com','Mario Tomic','Kornelija Stankovica 11/4','Novi Sad','EUROPE','SERBIA','21000','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 20:58:12',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3484,651434337002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',2,'AA1302',5,'hermeshine','aperfectgentleman','push.to.start@gmail.com','Ken Cavanagh','1118 Millwood Court','Orleans','ON','CANADA','K1C 3G1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 22:01:06',0,NULL,8,1,17,0,NULL,NULL),(3485,612204820001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','aperfectgentleman','push.to.start@gmail.com','Ken Cavanagh','1118 Millwood Court','Orleans','ON','CANADA','K1C 3G1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 22:01:07',0,NULL,8,1,17,0,NULL,NULL),(3486,651434186002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',2,'AA1315',5.98,'hermeshine','aperfectgentleman','push.to.start@gmail.com','Ken Cavanagh','1118 Millwood Court','Orleans','ON','CANADA','K1C 3G1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 22:01:08',0,NULL,8,1,17,0,NULL,NULL),(3487,651434074002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','aperfectgentleman','push.to.start@gmail.com','Ken Cavanagh','1118 Millwood Court','Orleans','ON','CANADA','K1C 3G1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 22:01:07',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ L   1\ræœºèº«ç›–/é•œå¤´åŽç›–  canon  2\r77mm é•œå¤´ç›– canon 2\r67mm é•œå¤´ç›–  canon 2 RA022498208CN'),(3488,651440476002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','skabbott','scott.abbott@gmail.com','Scott Abbott','7568 Silver View Ln','Raleigh','NC','UNITED STATES','27613-1071','(919) 449-2600','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 22:37:46',0,NULL,3,1,1,1,NULL,NULL),(3489,709751724015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','day130369','adamdaydecorator@aol.com','Adam Day','19 Chester Road Lavister','Wrexham','Wrexham','UNITED KINGDOM','LL12 0DN','01244570583','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-24 23:06:03',0,NULL,3,1,2,1,NULL,' æœºèº«ç›–/é•œå¤´åŽç›–  canon   1 '),(3490,612215636001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11,'hermeshine','gkreis','sub@pioneerdatasys.com','Greg Kreis','3710 Running Fox Dr','Marietta','GA','UNITED STATES','30062','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 23:08:55',0,NULL,3,1,1,1,NULL,NULL),(3491,651448988002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','ganchor41','alneyuribe@gmail.com','Jose A. Uribe','Calle P esq. Presa de Taveras, Res. E<br>Las Praderas','Santo Domingo','','DOMINICAN REPUBLIC','0001','(829)285-7733','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 23:46:19',0,NULL,8,1,17,0,NULL,NULL),(3492,651446579002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','ganchor41','alneyuribe@gmail.com','Jose A. Uribe','Calle P esq. Presa de Taveras, Res. E<br>Las Praderas','Santo Domingo','','DOMINICAN REPUBLIC','0001','(829)285-7733','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 23:46:20',0,NULL,8,1,17,0,NULL,NULL),(3493,612218438001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','ganchor41','alneyuribe@gmail.com','Jose A. Uribe','Calle P esq. Presa de Taveras, Res. E<br>Las Praderas','Santo Domingo','','DOMINICAN REPUBLIC','0001','(829)285-7733','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 23:46:20',0,NULL,8,1,17,0,NULL,'\r'),(3494,612216879001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','ganchor41','alneyuribe@gmail.com','Jose A. Uribe','Calle P esq. Presa de Taveras, Res. E<br>Las Praderas','Santo Domingo','','DOMINICAN REPUBLIC','0001','(829)285-7733','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 23:46:21',0,NULL,3,1,3,1,NULL,'å¤§å·ç°å¡   1\r100-150 åå…‰æ¿   1\rcpl   1\ræ¸å˜ç° + 58mm çŽ¯æž¶   1 \rRA022498667CN\ræ¬¾çš„'),(3495,695964646016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','lowstarr2010','leeramsay27@yahoo.co.uk','lee ramsay','5 weedon close carlton','nottingham','Nottinghamshire','UNITED KINGDOM','ng3 7de','01159120047','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-24 23:48:01',0,NULL,3,1,4,1,NULL,'2mx3mèƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  è‹±æ ‡  2\r115w 220v   2\råŒ…   1 \rlighting kit  $30\rYW863684671CN\r'),(3496,709768952015,250601901408,'Wireless Remote Control Cord for Canon 500D/1000D/450D',1,'',11.47,'hutongstore','andrejsaz','andrewaz@inbox.lv','Andrejs Zeicmanis','114 Curragh Birin Castletroy','Limerick','Limerick','IRELAND','353','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-25 01:02:07',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ C1   1 '),(3497,651468407002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','japs14','cezann14@yahoo.ca','cezar alocada','#701-350 Mill Road','toronto','ON','CANADA','M9C5R7','(647) 341-5804','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 02:27:38',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…   1 RA022498199CN'),(3498,651473567002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','madermotors','madermotors@hotmail.com','David Mader','28 First St.','Lr. Sackville','NS','CANADA','b4e 1s8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 03:23:43',0,NULL,3,1,2,1,NULL,NULL),(3499,612246881001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','rickblcharlotte','rblong@carolina.rr.com','Rick Blong','2017 Olde Towne Dr','Monroe','NC','UNITED STATES','28110-8806','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 04:11:53',0,NULL,3,1,1,1,NULL,NULL),(3500,651480560002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','bigmikeflan','gtg548u@mail.gatech.edu','Michael James Flanigan','1917 Wedgewood Dr.','Stone Mountain','GA','UNITED STATES','30088','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-25 04:36:10',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹  1 '),(3501,612248872001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','kyle_kuztom','kelix@hotmail.com','Kelix Budiadi','Gedung Kompas-Gramedia<br>Jalan Panjang No.8A , Kebon Jeruk','Jakarta Barat','DKI Jaya','INDONESIA','11530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 04:36:30',0,NULL,3,1,2,1,NULL,'6663a å¿«è£…æ¿    1 '),(3503,651339000002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','thita103','thita@diu.org','rudchadapan ittivarakorn(v.thitasudtho)','40   m  8<br>khlongsong','khlongluang','pathumtani','THAILAND','12120','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 05:32:20',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ  M   1 RA022498137CN'),(3504,612259293001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',1,'AB1305',3.79,'hermeshine','glrnsh','afekuri@netvision.net.il','&#1493;uri afek','hashomrim 36','tivon','','ISRAEL','36034','972-54-5680539','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 06:55:40',0,NULL,8,1,17,0,NULL,NULL),(3505,651490787002,120601698401,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','glrnsh','afekuri@netvision.net.il','&#1493;uri afek','hashomrim 36','tivon','','ISRAEL','36034','972-54-5680539','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 06:55:40',0,NULL,8,1,17,0,NULL,NULL),(3506,612259155001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','glrnsh','afekuri@netvision.net.il','&#1493;uri afek','hashomrim 36','tivon','','ISRAEL','36034','972-54-5680539','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 06:55:41',0,NULL,8,1,17,0,NULL,NULL),(3507,651490948002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','glrnsh','afekuri@netvision.net.il','&#1493;uri afek','hashomrim 36','tivon','','ISRAEL','36034','972-54-5680539','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 06:55:41',0,NULL,3,1,3,1,NULL,'55mm æ©¡èƒ¶ç½©   1\r58mm æ©¡èƒ¶ç½©   1\r67mm æ©¡èƒ¶ç½©   1\r77mm æ©¡èƒ¶ç½©    1 RA022498145CN'),(3508,612260468001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','hellog','hellog001@gmail.com','ZHI LI GUAN','189 10th St','Oakland','CA','UNITED STATES','94607-4838','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 07:09:40',0,NULL,3,1,1,1,NULL,NULL),(3509,612295702001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','img59','henrik_edberg@msn.com','Henrik Edberg','SandstensvÃ¤gen 9','Uppsala','Uppsala','SWEDEN','75267','073-507 37 04','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 12:11:17',0,NULL,3,1,2,1,NULL,NULL),(3510,651552807002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','fr4nt1k','franbaca@yahoo.com','Fran BaÄ‡a','PavletiÄ‡eva 12','Zagreb','','CROATIA','10000','+385 95 8580 218','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 15:02:23',0,NULL,3,1,5,1,NULL,'4ç¯å¤´ æ£š   2  æ¬§æ ‡  \rCP219437014CN\r'),(3511,612325227001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','spacefly70','wouter.w.v.d.kwaak@versatel.nl','wouter van der kwaak','preludeweg 44','Alphen aan den rijn','','NETHERLANDS','2402HD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 15:12:34',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´   1  æ¬§æ ‡  1 '),(3512,651555922002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','rajasekaranamie','rajay1000@yahoo.com','R. Rajasekaran, Assistant Engineer','4/998, TNEB Office, Sathy main road,<br>GANESAPURAM, S.S Kulam Via','Coimbatore  107','TN','INDIA','641 107','9443087381','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 15:23:53',0,NULL,3,1,2,1,NULL,NULL),(3513,651558871002,120500442483,'Large size Neoprene Lens Pouch / Case 90mm x 220mm',2,'AC1203',11.2,'hermeshine','sdsia','weiming88@gmail.com','Steve Sia','502 winding rose dr','rockville','md','UNITED STATES','20850-2869','(301) 762-6508','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 15:36:19',0,NULL,3,1,1,1,NULL,'å¤§å·é•œå¤´ç­’   2 '),(3514,709895313015,250746712937,'55mm Graduated Neutral Density Filter Gradual Grey 55',1,'',4.8,'hutongstore','lerroyjenkins','npmullins@hotmail.co.uk','NEIL MULLINS','53 CARISBROOKE CRES','POOLE','DORSET','UNITED KINGDOM','BH15 4LA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-25 15:56:57',0,NULL,3,1,2,1,NULL,'ç»¿å¶55mm æ¸å˜ç°  1 '),(3515,651607712002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','goodiegraber','hugzankizzez@hotmail.com','Cassandra Norman','147 Rougebank dr','markham','ON','CANADA','l3s4k5','(647) 209-2277','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 19:10:07',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…   1 RA022498052CN'),(3516,651609582002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','54lynne','lmuellernyc@gmail.com','Lynne  Feerick','255 cabrini blvd<br>Apt. 6c','new york','NY','UNITED STATES','10040-3614','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 19:18:53',0,NULL,3,1,1,1,NULL,NULL),(3517,709955039015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','garywilliams11','garywilliams0604@hotmail.com','gary williams','11 tomlinson street','rochdale','Lancashire','UNITED KINGDOM','OL11 3EW','01706668756','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-25 19:28:02',0,NULL,3,1,2,1,NULL,'RS-S1   1 '),(3518,696155011016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','kareca1982','bruno__reis@hotmail.com','BRUNO FONSECA','FLAT 1 WARRIOR COURT 244 COLD HARBOUR LANE','LONDON','London','UNITED KINGDOM','SW9 8SE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-25 19:28:14',0,NULL,3,1,2,1,NULL,'  æœºèº«ç›–/é•œå¤´åŽç›–  canon   1 '),(3519,612391599001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','barji13','barbara.kundolff@jahmasta.com','barbara kundolff','9 av gaston cabrier','salon de provence','Provence-Alpes-CÃ´te d\'Azur','FRANCE','13300','0645270493','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 20:00:18',0,NULL,8,1,17,0,NULL,''),(3520,612393664001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','kolan07','kokulan07@msn.com','Kokulan Shanmuganathan','23 Mare Cres.','Etobicoke','ON','CANADA','M9W7E8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 20:09:24',0,NULL,3,1,2,1,NULL,NULL),(3521,612398325001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',3,'AE2501',91,'hermeshine','barji13','barbara.kundolff@jahmasta.com','barbara kundolff','9 av gaston cabrier','salon de provence','Provence-Alpes-CÃ´te d\'Azur','FRANCE','13300','0645270493','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 20:29:21',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶   3 \r 2mx3m èƒŒæ™¯æž¶   1          reflector holder  $30\rYW863684660CN\r'),(3522,651632267002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','bloem32','onnobloemers@zonnet.nl','Onno Bloemers','Wikveld 18','\'s-Hertogenbosch','','NETHERLANDS','5236 EA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 20:54:18',0,NULL,3,1,2,1,NULL,NULL),(3523,709982426015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','a.ziakova07','a.ziakova@gmail.com','Andrea Ziakova','Zaporozska 6','Bratislava 5','Slovakia','SLOVAK REPUBLIC','851 01','+421905871436','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-25 21:03:59',0,NULL,3,1,2,1,NULL,NULL),(3524,612408230001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','jdavis9184','jeffdavis82778@gmail.com','jeffrey Davis','12689 stallion CT','Jacksonville','FL','UNITED STATES','32223-2094','(904) 260-9793','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 21:14:40',0,NULL,3,1,3,1,NULL,'RA022498110CN '),(3525,651640190002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','migel_999','migel999@gmail.com','Mikhail Belenkov','street Twardowski, House 4, Building 2, apartment 33','Moskow','','RUSSIAN FEDERATION','123458','89267190998','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 21:30:39',0,NULL,3,1,2,1,NULL,NULL),(3526,709965591015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'',3.76,'hutongstore','kavacca','kavacca@hotmail.com','Jenny Rothwell','Sunnyside Dunmore East','Co.Waterford','Waterford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-25 21:51:37',0,NULL,8,1,17,0,NULL,NULL),(3527,709964996015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'',3.76,'hutongstore','kavacca','kavacca@hotmail.com','Jenny Rothwell','Sunnyside Dunmore East','Co.Waterford','Waterford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-25 21:51:39',0,NULL,3,1,2,1,NULL,'77mm é•œå¤´ç›– canon  2\r58mm é•œå¤´ç›– canon 2 '),(3528,651647136002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','ingeborgsta123','ingeborg.stoea@c2i.net','Ingeborg StÃ¸a SÃ¸land','Gamle Tempelvei','Eggedal','Eggedal','NORWAY','3359','99637804','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 22:09:10',0,NULL,3,1,2,1,NULL,NULL),(3530,651651072002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bourbonbuzz','johngordon@worldnet.att.net','john gordon','1620 SW 27th St','troutdale','OR','UNITED STATES','97060-1983','(503) 206-9942','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 22:26:28',0,NULL,3,1,1,1,NULL,NULL),(3531,651654412002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','nestorpr1','nestorapr1@hotmail.com','Nestor A Reyes','Str. 17 D-3<br>Urb. Villa Nueva','Caguas','PR','UNITED STATES','00727','','NoPaymentFailure','CheckoutComplete','Other','2010-12-25 22:44:41',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RA022498066CN'),(3532,651676191002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','eugepark','elpbus@gmail.com','Gene Park','10115 Palace Way<br>Apt C','Richmond','VA','UNITED STATES','23238-5653','(520) 205-2391','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 01:00:27',0,NULL,3,1,1,1,NULL,NULL),(3533,651670386002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','luisaccardoso','luisaccardoso@gmail.com','Luisa Cardoso','12620 Ranger Rd','Leavenworth','WA','UNITED STATES','98826-9174','(206) 390-1685','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 01:56:37',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ… nikon   1 '),(3534,612459071001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','dajedi88','ijedi88@sbcglobal.net','george michael francisco','3808 Amy Ct','union city','CA','UNITED STATES','94587','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:45:46',0,NULL,3,1,1,1,NULL,'æ™®é€šçƒ­é´ç›–  1 '),(3535,612459009001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','lsheltie65ld','lsheltie@bellsouth.net','Laurie Sanderson','1511 Valley Brook Rd','Millbrook','AL','UNITED STATES','36054-4342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:48:09',0,NULL,8,1,18,0,NULL,NULL),(3536,612458486001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','lsheltie65ld','lsheltie@bellsouth.net','Laurie Sanderson','1511 Valley Brook Rd','Millbrook','AL','UNITED STATES','36054-4342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:48:10',0,NULL,8,1,17,0,NULL,NULL),(3537,651690269002,120461614281,'JJC Hand Strap Grip  HS-1 Nikon D40 D60 Canon 450D',1,'AB3402',6.99,'hermeshine','lsheltie65ld','lsheltie@bellsouth.net','Laurie Sanderson','1511 Valley Brook Rd','Millbrook','AL','UNITED STATES','36054-4342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:48:11',0,NULL,8,1,17,0,NULL,NULL),(3538,651690196002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',2,'AA1305',5,'hermeshine','lsheltie65ld','lsheltie@bellsouth.net','Laurie Sanderson','1511 Valley Brook Rd','Millbrook','AL','UNITED STATES','36054-4342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:48:11',0,NULL,3,1,1,1,NULL,'52mm é•œå¤´ç›– nikon  2\rjjc hs-1 è…•å¸¦   1\rå°å·å†…èƒ†åŒ… nikon  1\rlenspen    1 '),(3539,612460344001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','missxalohaxhula','f_lagpacan@hotmail.com','Flordeliz Lagpacan','2 EMBARCADERO CENTER, PROMENADE LEVEL<br>EMBARCADERO DENTISTRY','SAN FRANCISCO','CA','UNITED STATES','94111','(408) 666-0365','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:54:28',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(3540,612466354001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','coyote488','imwilley@telusplanet.net','ian willey','1020 Moyer Drive','Sherwood Park','AB','CANADA','t8a1e6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 03:45:25',0,NULL,3,1,2,1,NULL,' '),(3541,651701044002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',3,'AE1302',29.4,'hermeshine','evabluecanada','eva@evablue.com','eva blue','2025 Parthenais Suite 259','Montreal','QC','CANADA','h2k 3t2','(514) 808-2583','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 04:03:42',0,NULL,3,1,3,1,NULL,'å•ç¯å¤´   3 RA022498070CN'),(3543,612473601001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','windblown466','windblown466@mchsi.com','David Umphfleet','6110 E. Oakwood Dr.','Pleasant Hill','IA','UNITED STATES','50327','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 04:50:53',0,NULL,3,1,1,1,NULL,'æ˜Ÿå…‰é•œ  star 6   1 '),(3544,710083058015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'',5.8,'hutongstore','thotties','cher_jughead@hotmail.com','Cheryl Ou','4B Boon Tiong Road #07-33','default','','SINGAPORE','165004','97640206','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-26 07:22:10',0,NULL,3,1,11,1,NULL,'72mm æ¸å˜ç°  1 ç»¿å¶ '),(3545,696285355016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'',7.56,'hutongstore','ruslan201074','polonij210@mail.ru','Ruslan Bekjashev','Agrarnaya-14 Alexandrovskaya','S.Peterburg','','RUSSIAN FEDERATION','196631','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-26 08:20:35',0,NULL,3,1,2,1,NULL,NULL),(3546,651297480002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','oho75','t_ketchala75@hotmail.com','TATTIWAT TARADAMRONGLERD','797 Samsen Road,Tanonnakornchaisri<br>Dusit','default','BA','THAILAND','10300','66848919585','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 08:57:29',0,NULL,3,1,2,1,NULL,'3pcs æ»¤é•œè¢‹   1 '),(3547,612499662001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','dor_guy','dor_guy@netvision.net.il','Guy Dushansky','Elishva Kaplan 28','Kiryat-Haim','Israel','ISRAEL','26262','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 09:04:21',0,NULL,3,1,3,1,NULL,'RA022498123CN '),(3548,651738408002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','1234beanz','4dnewson@gmail.com','Dean Newson','36a Popes Road','Woonona','New South Wales','AUSTRALIA','2517','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 09:35:30',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(3549,612516264001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','arnaud6794','arnaud94@gmail.com','Arnaud  CHOQUART','7 rue de Choisy','ALFORTVILLE','ÃŽle-de-France','FRANCE','94140','01.43.78.18.77','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 10:34:09',0,NULL,3,1,4,1,NULL,'6662a   1 \rtripod  $15\rYW863684656CN\r'),(3550,612522082001,110532007214,'77mm CPL Circular Polarizing Filter 77 D40 D60 D80',1,'AA3314',6.5,'hermeshine','vijars84','vijars.prieditis@gmail.com','Vijars Prieditis','Hospitalu 28/4<br>Riga','Riga','','LATVIA','LV-1013','+371 29501449','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 11:06:50',0,NULL,3,1,2,1,NULL,NULL),(3551,651760475002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','twogiantscoops','twogiantscoops@aol.com','Chris Marshall','4 Veasy Park<br>Wembury','Plymouth','Devon','UNITED KINGDOM','PL9 0ES','01752862116','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 11:28:12',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3552,651771017002,120571007530,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','squd','aliaksandr.kokhno@gmail.com','Aliaksandr Kokhna','Esenina str<br>35-1-144','Minsk','','BELARUS','220025','+375296872411','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 12:22:40',0,NULL,3,1,2,1,NULL,'æ¸å˜è“   1 '),(3553,710149405015,250692240254,'Remote Control Cord Shutter Nikon D300/D200/D700â€‹ MC-30',1,'',2.98,'hutongstore','4tatanka','f.verhoef@hetnet.nl','Frank Verhoef-Roosenburg','Dolderseweg 164','Den Dolder','','NETHERLANDS','NL 3734 BN','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-26 12:39:35',0,NULL,3,1,2,1,NULL,'RS-N1   1 '),(3554,651777128002,120564178812,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','miki4853','ecines@gmail.com','Miguel Toral Garcia','calle Medico Pedro Herrero 23 6Âº B','Alicante','Comunidad Valenciana','SPAIN','03006','680331197','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 12:53:57',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°  + 52mm çŽ¯æž¶  1 '),(3555,651782484002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','mauricetsl','maurice.tjonsoeilen@gmail.com','Suralco Aireen Ranoesendjojo','3640 Nw 115th Ave<br>Ferm Suralco','Doral','FL','UNITED STATES','33178-1863','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 13:18:20',0,NULL,3,1,1,1,NULL,NULL),(3556,651788453002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','martisak','martin.isaksson@gmail.com','Martin Isaksson','Bergsgatan 30','Stockholm','','SWEDEN','11223','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 13:46:18',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž    1 RA022498154CN'),(3557,696365708016,260660051690,'Neoprene Lens Pouch Case 9.5cmx23cm 80-200 70-200mm XL',1,'',4.38,'hutongstore','rysavabrada1961','rysavabrada@seznam.cz','Jaromir Fajkus','Frantiska Krizka 26','Praha 7','','CZECH REPUBLIC','17000','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-26 14:05:00',0,NULL,3,1,2,1,NULL,'XLé•œå¤´ç­’   1 '),(3558,651828813002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jayv99','jvance@rogers.com','Jason   Vance','22 Hunt St','Guelph','ON','CANADA','N1L1T7','(519) 822-7769','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 16:19:48',0,NULL,3,1,2,1,NULL,NULL),(3559,650750625002,120581410942,'16chan Wireless Remote Control Cord for Nikon D90 D5000',4,'AA3202',74,'hermeshine','ame200968','quicolaras@hotmail.com','lara martinez fenoll','Escultor ValentÃ­n GarcÃ­a Quinto nÂº7 4ÂºA','Albatera','Alicante','SPAIN','03340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 17:04:51',0,NULL,3,1,3,1,NULL,'çˆµå½±æ— çº¿  N3   4 RA022498021CN'),(3560,696426495016,260660053270,'New Neoprene Reversible Cover for Nikon D300S D700 L',1,'',6.1,'hutongstore','adaslux','adaslux@wp.pl','Julia Skupny','43 Ashley Road','London','London','UNITED KINGDOM','N19 3AG','07518297453','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-26 17:11:33',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  nikon  1 '),(3561,651844415002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rangercb11','ranger_cb@mail.ru','Yuriy Kuznecov','Korablestroiteley 38/2, 83','Nizhny Novgorod','Nizhegorodskaya','RUSSIAN FEDERATION','603158','+7904-398-2495','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 17:14:14',0,NULL,3,1,2,1,NULL,NULL),(3562,612616769001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','spinifer','spinifer@aol.com','Nathan H. Nazdrowicz','817 Elkton Rd','Newark','DE','UNITED STATES','19711-7725','(302) 893-3645','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 17:20:50',0,NULL,3,1,1,1,NULL,'çƒ­é´ç›–  1 '),(3563,710290931015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','dmcd1973','tinoran@gmail.com','David  McDermott','Tinoran Hill','Baltinglass','Wicklow','IRELAND','ww','0879888750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-26 19:01:27',0,NULL,3,1,2,1,NULL,' '),(3564,612658468001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','onthere','onderyapici@gmail.com','Ã–NDER YAPICI','uludag.cad.pehlivan sok.<br>anadolu apt.31/10 Osmangazi/Ã‡ekirge','Busa','','TURKEY','16010','2396837','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 19:02:03',0,NULL,3,1,3,1,NULL,'10ç‰‡è£…  58mm çŽ¯æž¶ 1 RA022498450CN\r'),(3565,612661207001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',1,'AB1305',3.79,'hermeshine','ferdepalma','gongorafernando@gmail.com','Fernando Gongora','Gabriel Roca 14 1 a','Palma Mallorca','Baleares','SPAIN','07014','687548134','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 19:06:55',0,NULL,3,1,2,1,NULL,NULL),(3566,651897216002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','sezeryadigar10','sezeryadigar@hotmail.com','Sezer Yadigar','telsiz mah. 85/10 sk. no:2 d:3<br>zeytinburnu','istanbul','Marmara','TURKEY','34025','+905556848606','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 19:19:52',0,NULL,3,1,5,1,NULL,'4ç¯å¤´æ£š    2   æ¬§æ ‡  CP219437005CN\r'),(3567,651904606002,120581161784,'Light Stand 2m / 6\'56\" for photo studio lighting Ã—2',1,'AKT031',59,'hermeshine','jusosa','jusosa@msn.com','juan soberats','Taronger nÂº1   1Âº-4Âª','palma de mallorca','Baleares','SPAIN','07008','639771560','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 19:49:15',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  ç™½ç›’   2 \rlight stand   $18\rYW863684645CN\r'),(3568,612648567001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','littlemamajan','janbates@eastlink.ca','Janine Bates','199 Pictou Road','Truro','NS','CANADA','B2N 2S7','(902) 895-2459','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 19:54:28',0,NULL,8,1,17,0,NULL,NULL),(3569,651878553002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','littlemamajan','janbates@eastlink.ca','Janine Bates','199 Pictou Road','Truro','NS','CANADA','B2N 2S7','(902) 895-2459','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 19:54:29',0,NULL,3,1,2,1,NULL,'58mm é•œå¤´ç›–  canon  1\r58mm uv    1 '),(3570,612697096001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',9.8,'hermeshine','stephane_rp_91','slesmond@free.fr','StÃ©phane Lesmond','7, allÃ©e CÃ©zanne','Les Ulis','Ile de France','FRANCE','91940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 20:40:54',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹çƒå°   1 '),(3571,612705432001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','maxl_71','dmarkus@gmx.at','Markus Dobersberger','Spazenhofstrasse 26','Linz','','AUSTRIA','4040','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 21:05:13',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…   æ— å­—   1 '),(3572,612708976001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','etkdlk','david.kyle10@gmail.com','David Kyle','100 Glade Spgs','Anderson','SC','UNITED STATES','29621','(864) 224-5199','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 21:16:34',0,NULL,3,1,1,1,NULL,NULL),(3573,612704606001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','sifami','sifami26@hotmail.com','simon  fariza miralles','C/Alcoy n 1 pta 6','valencia','Comunidad Valenciana','SPAIN','46004','653352744','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 21:30:18',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶  ï¼ˆ ç™½ï¼‰   1\r2m ç¯æž¶  2\r50-70 æ£š   æ¬§æ ‡  2\r115w 220v    2\råŒ…    1\rlighting kit   $30\r YW863684634CN\r'),(3574,612151539001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','nooosa89','eaak89@hotmail.com','Enas Alkhudairy','320 Memorial Dr<br>Rm 221','Cambridge','MA','UNITED STATES','02139','(617) 999-2376','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 21:49:33',0,NULL,3,1,1,1,NULL,'æ˜Ÿå…‰é•œ star4   1 '),(3576,612723341001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',3.55,'hermeshine','rafael.chiti','rafaelchiti@gmail.com','Rafael Chiti','Av. Callao 410. 5th Floor','Capital Federal','Buenos Aires','ARGENTINA','1022','541130615564','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 22:08:59',0,NULL,3,1,2,1,NULL,'52mm æŽ¥å£çŽ¯   1 '),(3577,612743005001,110533631256,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','mikhail_kriviniouk','mikhail_kriviniouk@yahoo.co.uk','Mikhail Kriviniouk','ul. Karla Libknekhta<br>d. 16, kv. 21, tel. +79122401191','Ekaterinburg','','RUSSIAN FEDERATION','620000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 23:30:17',0,NULL,3,1,2,1,NULL,NULL),(3578,612754304001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','melisme1972','melody@polakow.com','melody polakow','4 Freedom Cir<br>Apt 10','portsmouth','NH','UNITED STATES','03801-5942','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 00:25:34',0,NULL,8,1,17,1,NULL,''),(3579,651989313002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','melisme1972','melody@polakow.com','melody polakow','4 Freedom Cir<br>Apt 10','portsmouth','NH','UNITED STATES','03801-5942','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 00:27:11',0,NULL,3,1,1,1,NULL,'60cm 2in1 åå…‰æ¿   1 \r40CM æ£š   1 '),(3580,612749914001,110513730296,'Remote Control Wireless Shutter Release Canon 450D 500D',1,'AA3227',35.5,'hermeshine','roch4t','roch4t@yahoo.com','Ken Rochefort','1858 Cherrywood Trail','London','ON','CANADA','N6H0E2','(519) 452-2750','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 00:35:31',0,NULL,3,1,3,1,NULL,'YN126-C1   1 RA022498035CN'),(3581,612767889001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','nogood204','ndepass@cogeco.ca','Neil DePass','3002- 100 Main St. East','Hamilton','ON','CANADA','L8N 3W4','(905) 818-4598','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 01:34:34',0,NULL,8,1,17,0,NULL,NULL),(3582,652002011002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','nogood204','ndepass@cogeco.ca','Neil DePass','3002- 100 Main St. East','Hamilton','ON','CANADA','L8N 3W4','(905) 818-4598','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 01:34:34',0,NULL,8,1,17,0,NULL,NULL),(3583,612766565001,110316941375,'Remote Shutter Release for Canon PowerShot G10 =RS-60E3',1,'AA3210',4.3,'hermeshine','nogood204','ndepass@cogeco.ca','Neil DePass','3002- 100 Main St. East','Hamilton','ON','CANADA','L8N 3W4','(905) 818-4598','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 01:36:01',0,NULL,3,1,2,1,NULL,'RS-C1   1 \r58mm é•œå¤´ç›– canon   1\rlenspen   1'),(3584,612777796001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','cperaltam','cperaltam@gmail.com','Carlos Peralta Martinez','Calz. Nva. Tulyehualco-Xochimilco 20-A<br>Nativitas Manantiales','Mexico City','Mexico','MEXICO','16450','+52 55 21570902','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 02:19:41',0,NULL,3,1,2,1,NULL,NULL),(3585,612778092001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','piscies75','stephen.dunn@rogers.com','Stephen Dunn','42 Haslett Ave.','Toronto','ON','CANADA','M4l 3r2','(416) 691-3436','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 02:19:52',0,NULL,3,1,2,1,NULL,'nikon -52  åæŽ¥çŽ¯  1 '),(3586,612781094001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','clu014','chiehfu@gmail.com','Chieh Fu Lu','5364 Kalanianaole Hwy','Honolulu','HI','UNITED STATES','96821-1961','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 02:34:45',0,NULL,3,1,1,1,NULL,NULL),(3587,612789256001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','beneluxboy','gary@encanto.org','Gary Moore','6920 Roosevelt Way NE<br>PMB 283','Seattle','WA','UNITED STATES','98115-6635','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 03:21:22',0,NULL,3,1,1,1,NULL,NULL),(3588,652033734002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','wwiijeep','jgcg99@usa.com','James Gray','63 Palomino Rd','Springfield','IL','UNITED STATES','62702-1590','','NoPaymentFailure','CheckoutComplete','Other','2010-12-27 03:57:45',0,NULL,3,1,1,1,NULL,'sony èƒŒå¿ƒ åŽš  xxxl   1 '),(3589,612813713001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',3,'AB1301',10.02,'hermeshine','vdrum4250','onlay@cox.net','Tuan Duc Pham','20 Goldstone','Irvine','CA','UNITED STATES','92614-7050','(323) 691-7426','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 06:19:46',0,NULL,3,1,1,1,NULL,NULL),(3591,652064373002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','aksirmaj','jamrro@gmail.com','Peter Jamriska','Matuskova 7','Dolny Kubin','Dolny Kubin','SLOVAK REPUBLIC','02601','00421907813628','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 08:04:33',0,NULL,3,1,2,1,NULL,NULL),(3592,696684092016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'',2.75,'hutongstore','paul123evenlegs','pauldhoult2@msn.com','Paul Hoult','16 legion Way East Wittering','CHICHESTER','West Sussex','UNITED KINGDOM','PO20 8PA','01243673189','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 08:29:57',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§ å¥¥æž—å·´æ–¯  1 '),(3603,612860926001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','vag_dr','vdrainas@mech.upatras.gr','Vagelis Drainas','Terma Geo.Xaralampopoulou/Leukwsias<br>Agios Vasilis/Rio','Patras','Achaias','GREECE','26500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 11:59:24',0,NULL,8,1,17,0,NULL,''),(3593,652071748002,120508253684,'YONGNUO 8ft I-TTL Off-Camera Flash Sync Cord for Nikon',1,'AB3320',28.99,'hermeshine','duanec26','duanec26@yahoo.com','Duane Cornish','21618 115th Ct','Cambria Heights','NY','UNITED STATES','11411-1109','(718) 200-2678','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-27 09:03:58',0,NULL,3,1,1,1,NULL,'nikon 3m ttlçº¿   1 '),(3594,696292083016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'',43.8,'hutongstore','sharabanstudio','asya.lukin@gmail.com','Asya (Anna) Lukin','22 A / 9  Bruria str','Jerusalem','Jerusalem','ISRAEL','93184','+972545588075','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 09:13:51',0,NULL,3,1,3,1,NULL,'æ–œè‡‚ 1\r2m ç¯æž¶  1 \rRR815340095CN'),(3595,652075402002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','kravtsovas','kravtsovas@gmail.com','Kravtsov Alexandr','Aliya Moldagulova, 2/1 - 3','Aktobe','','KAZAKHSTAN','030019','701-244-1484','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-27 09:29:45',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´ æ¬§æ ‡   1\råå…‰ä¼ž    1 \rRR815340104CN'),(3596,652078225002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','mani_esperpento','lovecore_s@hotmail.com','Jesus Javier Queizan Perez','c/ Las Lilas NÂº5 1ÂºA','Salamanca','Castilla y LeÃ³n','SPAIN','37004','680623596','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 09:48:52',0,NULL,3,1,2,1,NULL,NULL),(3597,710529492015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'',4.5,'hutongstore','efecu','germz666@hotmail.com','GERARD0 MARTÃN ZERPA','Pasaje la barca nÂº 3 - bajo A - B San AndrÃ©s','Arucas','Canarias','SPAIN','35414','616403544','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 10:29:54',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  canon  1 '),(3599,652093585002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','follabotes13','polite13@hotmail.com','Pierre L TORNERO','94 Church Crescent','Newtownabbey','Co Antrim','UNITED KINGDOM','BT36 6ET','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-27 11:19:59',0,NULL,3,1,3,1,NULL,'sony æ‘„å½±èƒŒå¿ƒ XXXL  1 \rRR815340020CN\r'),(3600,612854442001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','spinebass','udu.wudu@gmail.com','Deniss Arsenins','Anninmuizas bulvaris 38/3-46C','Riga','Latvia','LATVIA','LV-1067','+371 26411374','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 11:20:19',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ æ¬§æ ‡  1 '),(3601,710541546015,250599423416,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',1,'',1.88,'hutongstore','khan2510','elston.teresa@googlemail.com','douglas elston',' 9 park road','holbeach','Lincolnshire','UNITED KINGDOM','pe12 7ee','01406423682','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 11:26:11',0,NULL,3,1,2,1,NULL,NULL),(3604,652100826002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3201',70,'hermeshine','sifami','sifami26@hotmail.com','simon  fariza miralles','C/Alcoy n 1 pta 6','valencia','Comunidad Valenciana','SPAIN','46004','653352744','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 12:04:36',0,NULL,3,1,3,1,NULL,'ç»¿è‰²/è“è‰² èƒŒæ™¯å¸ƒ 1 \rRA022498684CN\r\r'),(3605,612868454001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','theleff','leif.madland@lyse.net','Leif Arne Madland','Kalamyrveien 15','hommersaak','','NORWAY','4310','+4748023721','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 12:37:46',0,NULL,3,1,2,1,NULL,NULL),(3606,612875181001,110531023352,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','vag_dr','vdrainas@mech.upatras.gr','Vagelis Drainas','Terma Geo.Xaralampopoulou/Leukwsias<br>Agios Vasilis/Rio','Patras','Achaias','GREECE','26500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 13:14:08',0,NULL,3,1,2,1,NULL,' 52-58 åŒé˜³çŽ¯  1 \r58-58 åŒé˜³çŽ¯  1'),(3607,612878652001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','bledixhafa','bledix@gmail.com','Bledar Xhafaj','Rruga: \"Vllazen Huta\" Nd:7 , H:11 , Ap:19 , Kodi Postar: 1017<br>Tirane','Tirane','Albania','ALBANIA','00355','00355694007155','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 13:31:10',0,NULL,3,1,2,1,NULL,'æœºèº«ç›–/é•œå¤´åŽç›– Nikon  1 '),(3608,710571547015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'',45.99,'hutongstore','lapexxx','lapexxx1@gmail.com','Tomas Lapenas','1 rossorry court  rossorry church rd.','enniskillen','Fermanagh','UNITED KINGDOM','bt74 7nh','07518635459','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-27 13:38:40',0,NULL,3,1,4,1,NULL,'6662a+6160h   1\rtripod $20 \rYW863684774CN\r'),(3609,612880312001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','portokali-2008','photo.linap@gmail.com','lina petrauskiene','P.Box 938 Ag. Nikolaou<br>Paiania','Athens','Europe','GREECE','19002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 13:40:30',0,NULL,3,1,2,1,NULL,NULL),(3610,696745356016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','fuzzywitch43','fuzzywitch@hotmail.co.uk','M CHAPMAN','59 TIBBATTS CLOSE WOODGATE VALLEY','Birmingham','West Midlands','UNITED KINGDOM','B32 3TE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 13:46:31',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(3611,612876785001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','rosalesproductions','rommar_10@yahoo.com','ROMMEL ROSALES','c/o ROSALES PRODUCTIONS<br>B3 STC Shopping Arcade (Back of Unicity Store)','Quezon Ave., Iligan City','LANAO DEL NORTE','PHILIPPINES','9200','0632214305','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 14:04:42',0,NULL,3,1,2,1,NULL,NULL),(3613,612892919001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','taladrin.simon','taladrin@andaluciajunta.es','Jose Luis SimÃ³nLÃ³pez','C/ CÃ¡novas del Castillo nÂº14 2ÂºB','AlcalÃ¡ de Henares','Madrid','SPAIN','28807','619661971','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 14:39:36',0,NULL,3,1,2,1,NULL,NULL),(3614,696765243016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'',3.58,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 14:43:49',0,NULL,3,1,2,1,NULL,NULL),(3615,696770078016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','funsingh','amaroffrance@hotmail.co.uk','Amar Singh','25 Avenue George Pompidou','Suresnes','Ile-de-France','FRANCE','92150','0033687725889','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 15:02:12',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(3618,612897903001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','nakmus','fruityfroob@hotmail.com','Erlend Aunan','Njords Vei 43a','Trondheim','','NORWAY','7032','90217255','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 15:02:16',0,NULL,3,1,2,1,NULL,NULL),(3619,707944610015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','camilasketch2010','camilasketch@yahoo.com','ruby','58a marchmont st','london','London','UNITED KINGDOM','wc1n 1ab','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-27 15:31:23',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š  è‹±æ ‡   2\r115w 220v   2\råŒ…    1\rlighting kit  $30 \rYW863684741CN\r'),(3620,710609719015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'',4.5,'hutongstore','mncompmn','mncomputers@abv.bg','MN Computers','Slavcho Karnalov 4a','Bratsigovo','Pazardjik','BULGARIA','4579','+359879608088','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 15:51:15',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  canon   1 '),(3621,710615616015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','argyllrab','argyll9193@msn.com','Robert Maclennan','16 Maxwelton Road','Glasgow','Glasgow (City of)','UNITED KINGDOM','G331LR','01417706446','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 16:19:02',0,NULL,8,1,17,0,NULL,NULL),(3622,652158976002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','sarahrwallace','sarah.wallace@lonoke.k12.ar.us','Sarah Wallace','102 Cotton Ln','Lonoke','AR','UNITED STATES','72086','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 16:20:10',0,NULL,3,1,1,1,NULL,NULL),(3623,652168031002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','volkswfreak','rvacjd@hotmail.com','Ruben Vanlauwe','Philemon Sabbestraat 14','Staden','West Vlaanderen','BELGIUM','8840','0496485885','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 16:51:28',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(3624,710617125015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','argyllrab','argyll9193@msn.com','Robert Maclennan','16 Maxwelton Road','Glasgow','Glasgow (City of)','UNITED KINGDOM','G331LR','01417706446','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 16:19:02',0,NULL,8,1,17,0,NULL,NULL),(3625,710618781015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','argyllrab','argyll9193@msn.com','Robert Maclennan','16 Maxwelton Road','Glasgow','Glasgow (City of)','UNITED KINGDOM','G331LR','01417706446','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 16:19:02',0,NULL,3,1,2,1,NULL,'3pcs æ»¤é•œè¢‹  2\r77mm çŽ¯æž¶   1\r '),(3626,710638397015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','garcia8914','salva.garcia.gil@gmail.com','Salvador Garcia Gil','Universitat Jaume I - Rectorado Avda. Sos Baynat, S/N','CastellÃ³n de la Plana','Comunidad Valenciana','SPAIN','12071','696408557','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 17:13:52',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶   1 '),(3627,612939019001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','giannispatra1972','giannisclick@gmail.com','Giannis Sarigiannis','Zakynthou 27','Patra','Ahaia','GREECE','24441','6938929178','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 17:26:25',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(3628,612944086001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','sparcules','sparko1976@yahoo.com','Kevin Carlborg','5636 Pershing Blvd','Kenosha','WI','UNITED STATES','53144-2426','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 17:44:41',0,NULL,8,1,17,0,NULL,NULL),(3629,652178018002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','sparcules','sparko1976@yahoo.com','Kevin Carlborg','5636 Pershing Blvd','Kenosha','WI','UNITED STATES','53144-2426','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 17:44:42',0,NULL,8,1,17,0,NULL,NULL),(3630,612942751001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','sparcules','sparko1976@yahoo.com','Kevin Carlborg','5636 Pershing Blvd','Kenosha','WI','UNITED STATES','53144-2426','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 17:44:42',0,NULL,3,1,1,1,NULL,'å“èƒœ 3.0  è†œ   1\r58mm é•œå¤´ç›–  canon   3\r58mm æ©¡èƒ¶ç½©    1 '),(3631,612951767001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','xsolp','petter.solbakken@gmail.com','Petter Solbakken','Bratsbergvegen 34B','Trondheim','SÃ¸r-TrÃ¸nderlag','NORWAY','7037','95892295','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 18:05:04',0,NULL,3,1,2,1,NULL,NULL),(3632,612952959001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',9.8,'hermeshine','user-maat-ra-63','felix-arranz-martin@hotmail.com','FÃ‰LIX ARRANZ MARTÃN','CARRETERA DE LA GRANJA, 4<br>CONSEJERÃA DE EDUCACIÃ“N','COLLADO VILLALBA','Madrid','SPAIN','28400','656560066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 18:07:56',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹ çƒå°   1 '),(3633,612954102001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','megmoser3','meganhmoser@gmail.com','Megan Moser','1680 Aliwood Way','Bountiful','UT','UNITED STATES','84010-5990','(801) 928-1868','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 18:11:34',0,NULL,3,1,1,1,NULL,NULL),(3634,652196243002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','bahus57','bahus1957@aol.com','john kudlacz','8657 village park ct','orangevale','CA','UNITED STATES','95662','','NoPaymentFailure','CheckoutComplete','Other','2010-12-27 18:19:34',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ xxl   1 \rRR815340152CN'),(3636,652207021002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','mista5four','l.hoover@yahoo.com','Linda  Hoover','4333 14th Ave S','Minneapolis','MN','UNITED STATES','55407-3225','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 18:50:37',0,NULL,3,1,1,1,NULL,NULL),(3637,652211033002,120618815334,'TianYa 52mm ND8 filter New 52 Neutral Density Grey NIB',1,'AA2308',5.7,'hermeshine','bsery974','ben.sery@orange.fr','Benjamin SERY','109 route Jules Reydellet<br>La Bretagne','SAINTE-CLOTILDE','RÃ©union','REUNION','97490','0692929840','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 19:00:44',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯ ND8   1 '),(3638,612974043001,110489360129,'JueYing Lambency Flash Diffuser for Nikon SB600 SB800 ',1,'AB3306',22,'hermeshine','pobiefuna','pobiefuna@gmail.com','peter Obiefuna','4711 190 St','Edmonton','AB','CANADA','t6m 2s9','(780) 707-2561','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-27 19:09:19',0,NULL,3,1,3,1,NULL,'ç¢—ç½© p1    1 \rRR815340121CN\r'),(3639,696897459016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',3,'',11.34,'hutongstore','r3dm4nn','r3dm4n_n@hotmail.com','Sam  Cooper','5 York Way','St.Ives','Cambridgeshire','UNITED KINGDOM','pe27 3du','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 20:38:46',0,NULL,3,1,2,1,NULL,NULL),(3640,710730222015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'',13.9,'hutongstore','chacho16','rbordon16@yahoo.es','Roberto  Bordon Aleman','Parroco Roman Navarro 16','Castillo del Romeral','Las Palmas de Gran Canaria','SPAIN','35107','928732440','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 20:52:04',0,NULL,3,1,2,1,NULL,'50cm æ£š  1 '),(3641,652251432002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','isinhcanon','sinhvuhoang@yahoo.com','Sinh VU HOANG','6 boulevard Joseph Vallier','Grenoble','Franche-ComtÃ©','FRANCE','38000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-27 20:57:22',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž    1 \rRR815340078CN\r'),(3642,613011873001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.8,'hermeshine','igasparini','alfonsojtr@bol.com.br','Ineli A. Gasparini','Rua Dr. Goulart Penteado, 85 - Apto. 72 - Vl. Diva','Sao Paulo','SP','BRAZIL','03351090','551126717542','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 21:05:02',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´  2  æ¬§æ ‡  '),(3643,613013007001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',4,'AE1301',31.8,'hermeshine','viperagp','gts@omikron.tv','George Tsartsianidis','Aristotelous 29','kozani','Kozani','GREECE','50100','003012461037711','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 21:06:09',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹   4 \rRR815340016CN'),(3644,710737126015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'',6.1,'hutongstore','opietro77','piotrp77@interia.pl','Piotr Poprawski','22 Robins Way','Bicester','Oxfordshire','UNITED KINGDOM','OX26 6XJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 21:08:29',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ… canon 1 '),(3645,613014049001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',2,'AE3601',36,'hermeshine','je21nn','je72184nn@yahoo.com','F & M Bank attn: JENN','2205 hanover pike','hampstead','md','UNITED STATES','21074','(410) 374-3436','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 21:08:52',0,NULL,3,1,3,1,NULL,'115w 110v   2 \rRR815340055CN\r'),(3646,652168898002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','hudsioo61','hudsioo@gmail.com','Sommart Sukmanee','61/13 Lamun Cafe\' Chongpon Rd.<br>T.Phapathomjadee Maung','Nakornpathom','Thailand','THAILAND','73000','(087)7009004','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 21:42:10',0,NULL,3,1,2,1,NULL,NULL),(3647,613028284001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','russellnedo','gayle_russell@mac.com','Gayle Russell','20789 Sam Rd','Albemarle','NC','UNITED STATES','28001','(704) 986-2559','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 22:00:43',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(3648,710771013015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'',29,'hutongstore','ilmaffobay','ilmaffo@gmail.com','Daniele Maffeis','Via Leopardi n.4','Corsico','MI','ITALY','20094','3476358398','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-27 22:47:28',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°   1\ræŸ”å…‰ä¼ž   1 \rRR815340081CN'),(3649,652281714002,120601700533,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','ylellanclaudia','nallelygarcia88@hotmail.com','Eduardo  garcia','501 S Carter St.','clarksville','AR','UNITED STATES','72830','(479) 774-4173','NoPaymentFailure','CheckoutComplete','Other','2010-12-27 22:49:12',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\r50-70 æ£š   2\råŒ…   1 \rlighting kit   $30\rYW863684752CN\r'),(3650,613051897001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64.99,'hermeshine','expatriate_ca','pasadenabear@gmail.com','Kevin Bishop','542 E Claremont St','Pasadena','CA','UNITED STATES','91104-3640','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-27 23:41:06',0,NULL,3,1,4,1,NULL,'çº¢å¤´ç¯   1\r800w 110v   1 \rlight  $20\rYW863684763CN\r'),(3651,696950516016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'',5.8,'hutongstore','samaudi1','sam.sun@portugalmail.pt','samuel ferreira','estrada lavradio 95, Tornada','Caldas da Rainha','Portugal','PORTUGAL','2504-912','00351965811578','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 23:41:56',0,NULL,8,1,17,0,NULL,NULL),(3652,696949457016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','samaudi1','sam.sun@portugalmail.pt','samuel ferreira','estrada lavradio 95, Tornada','Caldas da Rainha','Portugal','PORTUGAL','2504-912','00351965811578','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 23:41:56',0,NULL,8,1,17,0,NULL,NULL),(3653,710778203015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'',3.5,'hutongstore','samaudi1','sam.sun@portugalmail.pt','samuel ferreira','estrada lavradio 95, Tornada','Caldas da Rainha','Portugal','PORTUGAL','2504-912','00351965811578','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 23:41:57',0,NULL,8,1,17,0,NULL,NULL),(3654,696949621016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'',3.5,'hutongstore','samaudi1','sam.sun@portugalmail.pt','samuel ferreira','estrada lavradio 95, Tornada','Caldas da Rainha','Portugal','PORTUGAL','2504-912','00351965811578','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 23:41:57',0,NULL,3,1,3,1,NULL,'æ°”å¹ + å¸ƒ   1\r62mm cpl   1\rlenspen   1\rcanon ä¸‰è§’åŒ…   1\rRR815340033CN\r '),(3655,652297671002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.96,'hermeshine','gizzje','e-bayelwin@hotmail.com','Elwin Varkevisser','Clara Bartonstraat 18','AMSTERDAM','','NETHERLANDS','1025KT','020-6372734','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 23:50:48',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´   æ¬§æ ‡   2 \rRR815340149CN'),(3656,613061009001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',2,'AB2214',3,'hermeshine','chris_pavez','chris_cvpp@hotmail.com','Cristian Vicente Pavez Ponce','7 Norte A #2086 - 13 y 14 Oriente<br>Villa Los Conquistadores','Talca','Talca/Talca/Region del Maule','CHILE','3460000','+56997746990','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 00:32:17',0,NULL,3,1,2,1,NULL,'å“èƒœ3.0 è†œ   2 '),(3657,710802622015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','matthewringo','matthewandhispuntomk1@gmail.com','Matthew Bonnici','94 Iz-Zebbuga Triq Dun Luret Callus','Zebbug','','MALTA','zbg06','21461324','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 00:49:22',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³  1 '),(3658,696976823016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'',5.9,'hutongstore','radoslaw24','radoslawlukaszewski@wp.pl','Radoslaw Lukaszewski','Tranumparken 25, 2 TH','BRONDBY STRAND','','DENMARK','2660','004550216463','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-28 01:03:38',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹   1 '),(3659,710802985015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','jamieshore4','moonstonecrafts@hotmail.co.uk','James Milligan','Moonstone Crafts 113 Dalrymple Street','Girvan','South Ayrshire','UNITED KINGDOM','KA26 9BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-28 01:57:39',0,NULL,3,1,2,1,NULL,'45w 220v   2 '),(3669,652362279002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','curlly1980','votoy@yandex.ru','Vladimir Kryuchkov','N. Fedorova<br>16-9','Tyumen','Tyumen region','RUSSIAN FEDERATION','625007','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 05:46:42',0,NULL,3,1,5,1,NULL,'717 180cm   1 \rCP219437080CN\r'),(3661,652329017002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','hergeek','herge@live.ca','Raymond Gaudreault','47 De La Croix','Sherbrooke','QC','CANADA','J1C 0M3','(819) 821-3636 ext.: 238','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 02:19:46',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶   1 '),(3662,652330892002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','bredb71','bre_7171@yahoo.com','bryan balzomo','6925 Haskell Ave<br>Apt 109','van nuys','CA','UNITED STATES','91406-5076','(818) 300-7523','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 02:28:34',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…   nikon   1 '),(3663,652317768002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE1301',23.67,'hermeshine','bargain109','miro.sabic@gmail.com','Miro Sabic','Eosstraat 336','AMSTERDAM','','NETHERLANDS','1076DR','0617316262','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 02:34:50',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  3 \rRR815340047CN\r'),(3664,652332096002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','sandpitbrow','binrow@gmail.com','Robyn Payne','9 John street','Redcliffe','Queensland','AUSTRALIA','4020','0732838361','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 02:38:25',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶   1 \rreflector holder  $20\rYW863684730CN\r'),(3665,613096034001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','luciannem','rockgirl696@hotmail.com','Lucianne Guardiola','FK44 Calle Polaris<br>Santa Juanita','Bayamon','PR','UNITED STATES','00956-5501','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 03:46:43',0,NULL,5,1,18,0,NULL,NULL),(3666,652346651002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','dtsmith68','dtsmith@nctc.com','DOUGLAS SMITH','72 Brooks Hollow Ln','PLEASANT SHADE','TN','UNITED STATES','37145-3416','(615) 774-3307','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 03:55:53',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ… nikon   1 '),(3667,652353149002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0006',12.8,'hermeshine','mb155','burtonmj@hotmail.com','Melissa Burton','4 Champagne Court','Irymple','Victoria','AUSTRALIA','3498','0448506326','NoPaymentFailure','CheckoutComplete','AU_Other','2010-12-28 04:36:35',0,NULL,3,1,2,1,NULL,'1.6 x 2.1  é»‘è‰²èƒŒæ™¯å¸ƒ   1 '),(3668,652356739002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',9.25,'hermeshine','artkrot','adzhelali@gmail.com','Arthur Dzhelali','30 Lincoln Ave<br>Apt 2','New London','CT','UNITED STATES','06320','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 05:04:42',0,NULL,3,1,1,1,NULL,'å¤§å·å†…èƒ†åŒ… canon   1 '),(3670,613114100001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2101',59,'hermeshine','gastec56','gastec@shaw.ca','Tom Hamilton','119 Stein Close SE','Medicine Hat','AB','CANADA','T1B 4M8','(403) 526-0094','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 05:50:39',0,NULL,3,1,3,1,NULL,'nikon åŽŸè£…èƒŒå¿ƒ  xl   1 \rRR815340135CN'),(3671,697048873016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'',22,'hutongstore','greeceathens','6972999050@mycosmos.gr','GEORGE STRATOS','3 SOURI STREET-EUROBANK Syntagma','ATHENS','','GREECE','10557','306972999050','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 08:03:16',0,NULL,3,1,3,1,NULL,' RA022498675CN\r'),(3672,652396117002,120568073075,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',6.5,'hermeshine','hessel2001','thomashessel@yahoo.com','THOMAS HESSEL','DREYERSVEJ 35','Rungsted Kyst','','DENMARK','DK-2960','45865897','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 10:18:41',0,NULL,8,1,17,0,NULL,NULL),(3673,652395764002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',8.69,'hermeshine','hessel2001','thomashessel@yahoo.com','THOMAS HESSEL','DREYERSVEJ 35','Rungsted Kyst','','DENMARK','DK-2960','45865897','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 10:18:41',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ… canon   1\rä¸­å·é•œå¤´ç­’   1 '),(3674,652403434002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','einar8984','einar.schoyen@getmail.no','Einar Schoyen','Etterstadsletta 112','Oslo','Oslo','NORWAY','0659','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 11:00:55',0,NULL,3,1,4,1,NULL,'717ah   1 \r717 å¿«è£…æ¿  1\rballhead  $20\rYW863684962CN\r'),(3675,613155697001,110566021619,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','bisti1010','hasseltax@ya.ru','Yury Oprya','Kollontai street 26-81','Saint-Petersburg','','RUSSIAN FEDERATION','193231','(960)2434377','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 11:10:31',0,NULL,3,1,3,1,NULL,'sf18-canon   1 '),(3676,613157787001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','einar8984','einar.schoyen@getmail.no','Einar Schoyen','Etterstadsletta 112','Oslo','Oslo','NORWAY','0659','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 11:16:24',0,NULL,8,1,17,0,NULL,NULL),(3677,710917094015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','tirc83','gary83@gmail.com','Gary Martin','83 Tir Capel','Llanelli','Carms','UNITED KINGDOM','SA14 8SR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-28 11:20:16',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶   1 '),(3678,613157774001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','norasonlydad','terryshaw@trytel.net','Terry Shaw','573 Beech Terrace<br>Box 8076 RR#1','Peterborough','ON','CANADA','K9J 6X2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 11:20:25',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡   1 '),(3679,652409331002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',6,'AA1310',32.94,'hermeshine','bigos_74','arevva@gmail.com','Oleksandr Revva','3A Smolenskaya st. ap.4','Kiev','UA','UKRAINE','03057','(050) 462-3910','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 11:34:24',0,NULL,3,1,3,1,NULL,' RA022498741CN\r'),(3680,613164073001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','rajurajgopal','rajgopal18@gmail.com','Rajagopal Balasubramanian','F 57 Sector 39 Noida','Noida','UP','INDIA','201303','9811322855','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 11:50:16',0,NULL,3,1,2,1,NULL,'canon-58 åæŽ¥çŽ¯  1\ræ–°åœ°å€ï¼š\rRajagopal Balasubramanian \rChitra Swaminathan\r2/3 Norton 1st Street\rMandevali \rChennai - 600028\rINDIA\r9811322855\r '),(3681,613166872001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE1301',19.6,'hermeshine','georgebwmf','gcrook13@hotmail.com','George  Z Hantzis','Dilvoi 13-15 Byron','Athens','Greece','GREECE','16232','010 - 7629640','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 12:04:18',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹ çƒå°   2 \rRA022498755CN\r'),(3682,710940277015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'',4.99,'hutongstore','jodyboy10','jodyboy1@hotmail.com','joseph ryan','24 woodlands','portmarnock','Dublin','IRELAND','default','0864066949','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 13:00:04',0,NULL,3,1,2,1,NULL,'6662a å¿«è£…æ¿   1 '),(3683,710942853015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','swo0p360','j.c.r.bakker@kpnmail.nl','Richard Bakker','Joris Ivenslaan 63','ALMERE','','NETHERLANDS','1325LZ','036-5353616','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 13:12:02',0,NULL,3,1,2,1,NULL,'52-58mm åŒé˜³çŽ¯   1 '),(3684,697121850016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','joewright10','benkoch88@gmail.com','Ben Koch','19 Wollaton Close','Mansfield','Nottinghamshire','UNITED KINGDOM','NG18 3gd','01623650539','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-28 13:53:44',0,NULL,3,1,2,1,NULL,' '),(3685,710966807015,250599932668,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'',40,'hutongstore','punisher_1972','punisher_1972@hotmail.co.uk','mr d williams','1 the paddock','stubbington','Hampshire','UNITED KINGDOM','po143ns','07881868456','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-28 14:42:30',0,NULL,3,1,3,1,NULL,'10ç‰‡è£…  + 58mm çŽ¯æž¶  1 \rRR815340197CN\r'),(3686,613205996001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','duratec421','andrej.dosek@gmail.com','Andrej Dosek','Porzellangasse 30<br>(Zimmer 222)','Wien','','AUSTRIA','1090','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 15:15:40',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRA022498830CN\r'),(3688,652472687002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','hoganator','chogan1971@gmail.com','Chris Hogan','26693 Yale St','Hemet','CA','UNITED STATES','92544','(951) 551-0995','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 16:33:47',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(3689,613255188001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1601',87,'hermeshine','arzta','mr.arzta@gmail.com','Mattias Sandell','YttrÃ¶ 147','Tierp','','SWEDEN','81591','0739337275','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 18:08:45',0,NULL,3,1,4,1,NULL,'6663a   1\rtripod  $22 \rYW863684973CN\r'),(3690,711042737015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'',5.88,'hutongstore','michaelf3032','fjoelner@hotmail.com','Michael Fjoelner','Schleppegrellsgade 17, 2. th.','Aarhus C','','DENMARK','8000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 18:18:41',0,NULL,3,1,2,1,NULL,'60cm 2in1  åå…‰æ¿  1 '),(3691,652488633002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','chicago1924','peter@kadisnet.se','Peter BodÃ©n','Kaddisvagen 42','905 92 Umea','Vasterbottens Lan','SWEDEN','....','4690148050','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 18:23:27',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´  1 æ¬§æ ‡  \råå…‰ä¼ž   1 \rRA022498857CN\r'),(3692,652538314002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','arghiropolg','gabriel.arghiropol@gmail.com','Gabriel ARGHIROPOL','P-ta Victoriei<br>Bloc B.est, sc.A, et.2, apt 5','Ploiesti','Prahova','ROMANIA','100001','40723508555','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:32:12',0,NULL,3,1,2,1,NULL,' '),(3693,652540009002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','kathie828','joe@pciflortech.com','Kathie Tomazin','962 E Castlewood Ln','Bartlett','IL','UNITED STATES','60103-5078','(630) 830-0788','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 19:36:24',0,NULL,3,1,1,1,NULL,NULL),(3694,652540291002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','rvribeiro','ruivazribeiro@gmail.com','Rui Vaz Ribeiro','Rua do Ervideiro, 117 - Aguda','Arcozelo','Vila Nova da Gaia','PORTUGAL','4410-421','+351919928774','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:37:20',0,NULL,3,1,2,1,NULL,NULL),(3695,697241935016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'',2.75,'hutongstore','kekko64','fcarrani@gmail.com','Francesco Carrani c/o Clinica Veterinaria Cascina','via tosco romagnola 338','Fornacette','PI','ITALY','56012','0587-423123','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 19:38:04',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§ olympus   1 '),(3696,652544860002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','wateringer1','g.d.dekleijn@kabelfoon.nl','Guido de Kleijn','van Lottomstraat 25','Kwintsheul','','NETHERLANDS','2295HB','0624502686','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:49:26',0,NULL,8,1,17,0,NULL,NULL),(3697,652545379002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','wateringer1','g.d.dekleijn@kabelfoon.nl','Guido de Kleijn','van Lottomstraat 25','Kwintsheul','','NETHERLANDS','2295HB','0624502686','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:50:41',0,NULL,8,1,17,0,NULL,NULL),(3698,652545815002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','wateringer1','g.d.dekleijn@kabelfoon.nl','Guido de Kleijn','van Lottomstraat 25','Kwintsheul','','NETHERLANDS','2295HB','0624502686','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:51:53',0,NULL,3,1,2,1,NULL,'77mm æŽ¥å£çŽ¯   1\rå¹¿è§’æ‰˜æž¶   1\ræ¸å˜ç°   1 '),(3699,652545819002,120448645643,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','asgeirkolberg','akolberg@start.no','Asgeir Kolberg','Verven 34','Drammen','','NORWAY','3041','004795060443','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:52:30',0,NULL,8,1,17,0,NULL,NULL),(3700,652545547002,120571007530,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','asgeirkolberg','akolberg@start.no','Asgeir Kolberg','Verven 34','Drammen','','NORWAY','3041','004795060443','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:52:31',0,NULL,8,1,17,0,NULL,NULL),(3701,613291252001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','asgeirkolberg','akolberg@start.no','Asgeir Kolberg','Verven 34','Drammen','','NORWAY','3041','004795060443','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:52:31',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶  1\ræ¸å˜è“   1\ræ¸å˜æ©™    1 '),(3702,652556180002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',9.89,'hermeshine','croziercain','gregory_cain@csumb.edu','gregory cain','230 N Rios Ave','solana beach','CA','UNITED STATES','92075','(760) 224-9998','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 20:22:59',0,NULL,3,1,1,1,NULL,'æ— å­—è‚©å¸¦  1 '),(3703,613305140001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','jsm1467','magginnis@frontier.com','Joanna Magginnis','401 Deer Walk Trce','Westfield','IN','UNITED STATES','46074-9437','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 20:27:30',0,NULL,3,1,1,1,NULL,' '),(3704,613296272001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','rccroker-2008','rccroker@netscape.net','Clayton R Croker','75 Wentworth Avenue','Sydney','New South Wales','AUSTRALIA','2000','0292121005','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 20:30:30',0,NULL,3,1,3,1,NULL,' RA022498769CN\r'),(3705,613299222001,110529627255,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','rccroker-2008','rccroker@netscape.net','Clayton R Croker','75 Wentworth Avenue','Sydney','New South Wales','AUSTRALIA','2000','0292121005','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 20:30:29',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡   1 '),(3706,613305030001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','rabid_clam','aarrow-ranch@i-c.net','J Gordon Bengtson','7302 Hunterbrook Dr<br>AARROW-RANCH Aviation Ste 100','Mechanicsville','VA','UNITED STATES','23111','(804) 730-4035','NoPaymentFailure','CheckoutComplete','Other','2010-12-28 20:30:57',0,NULL,3,1,3,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ xl   1\rRA022498772CN\r '),(3707,613323413001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','yanachek','goodseller@email.cz','Tomas Janacek','Priseka 111','Svetla nad Sazavou','Vysocina','CZECH REPUBLIC','58291','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 21:27:59',0,NULL,8,1,17,0,NULL,NULL),(3708,613323320001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE1301',19.6,'hermeshine','yanachek','goodseller@email.cz','Tomas Janacek','Priseka 111','Svetla nad Sazavou','Vysocina','CZECH REPUBLIC','58291','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 21:28:00',0,NULL,3,1,3,1,NULL,'60cm æ£š   1\rå¤§åŠ›å¤¹ äº‘å°   2 \rRA022498738CN\r'),(3709,652435564002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mikedeparis','mikael.deltin@gmail.com','Del-Tin MikaÃ«l','2 chemin de l\'orient<br>Appartement nÂ°301 RDC Gauche','Lisses','ÃŽle-de-France','FRANCE','91090','0661462048','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 20:57:51',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRA022498786CN\r'),(3710,612804647001,110320736753,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',5,'AB1302',106.95,'hermeshine','garciapablo38-2008','garciapablo38@hotmail.com','PABLO ENRIQUE GARCIA INTERIAN','49 # 510-B X 62 Y 64 CENTRO','MERIDA','YUCATAN','MEXICO','97000','9999239171','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 21:36:44',0,NULL,3,1,3,1,NULL,'52mm æ©¡èƒ¶ç½©   5\r55mm æ©¡èƒ¶ç½©   5\r58mm æ©¡èƒ¶ç½©   5\r62mm æ©¡èƒ¶ç½©   5\r72mm æ©¡èƒ¶ç½©  5\r77mm æ©¡èƒ¶ç½©   5 \rRA022498812CN\r'),(3711,613334193001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',5,'AA1309',12.2,'hermeshine','ynovikov','portsmann@gmail.com','YURI NOVIKOV','Dunaisky prospekt 24, 48','St.Petersburg','-','RUSSIAN FEDERATION','196158','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 22:08:00',0,NULL,3,1,3,1,NULL,' \rRA022498790CN\r'),(3712,613335189001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','xete4motion','blainfalcon@hotmail.com','Nacho Oms','C/Ermitana nÂº 14 1Âº','PeÃ±iscola','Comunidad Valenciana','SPAIN','12598','649147617','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 22:13:45',0,NULL,8,1,17,0,NULL,NULL),(3713,652589896002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','xete4motion','blainfalcon@hotmail.com','Nacho Oms','C/Ermitana nÂº 14 1Âº','PeÃ±iscola','Comunidad Valenciana','SPAIN','12598','649147617','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 22:13:46',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰   1 \rbackground support  $25YW863684800CN\r'),(3714,613339933001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','racing-memorabilia','jelpspeed@hotmail.com','Ever Lopez','callejon del sereno 4257','zapopan','jalisco','MEXICO','45110','(523) 338-5681 ext.: 54','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 22:30:36',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRA022498809CN\r'),(3715,613352906001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','srl700','srlittle@rocketmail.com','Steven Little','6101 Lake Shore Dr','Fort Worth','TX','UNITED STATES','76179','(214) 274-7752','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 23:22:46',0,NULL,3,1,1,1,NULL,NULL),(3716,613195206001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','dazz-j','dazz_77keus10@hotmail.com','joel elhadj (chez Mlle Sarah Bellagamba)','40 avenue de la grande armÃ©e','Paris','Ile-de-France','FRANCE','75017','0686850928','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 23:28:51',0,NULL,8,1,17,0,NULL,NULL),(3717,613207151001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','dazz-j','dazz_77keus10@hotmail.com','joel elhadj (chez Mlle Sarah Bellagamba)','40 avenue de la grande armÃ©e','Paris','Ile-de-France','FRANCE','75017','0686850928','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 23:28:50',0,NULL,3,1,4,1,NULL,'æ–œè‡‚  1\råå…‰æ¿æ”¯æž¶   1\r2m ç¯æž¶   1\rlighting kit  $25 \rYW863684984CN\r'),(3718,613225709001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','jdraluck','jdraluck@yahoo.com','Alissa Dolderer','1007 Arezzo Cir','Boynton Beach','FL','UNITED STATES','33436-1113','(310) 980-1685','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 23:33:49',0,NULL,3,1,1,1,NULL,NULL),(3719,613359916001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','elcarlicos81','elcarlicos@mixmail.com','Carlos Perez Gracia','Avda. Gomez Laguna 28 2c','Zaragoza','AragÃ³n','SPAIN','50009','976751648','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 00:01:39',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶   1 '),(3720,652618258002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','johntiedeman7710','johntiedeman@gmail.com','JOHN TIEDEMAN','3680 BRAEDEN CT','Middleburg','FL','UNITED STATES','32068-3966','(904) 534-8280','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-29 00:05:17',0,NULL,3,1,1,1,NULL,'sony å•è‚©åŒ…   1 '),(3721,697331438016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','kadedoll','divaaa1@hotmail.com','FRANCISCO IVAN GARCIA PEREZ','C/Lope de Vega nÂº5 Chalet','Fuenlabrada (Loranca)','Madrid','SPAIN','28942','669625244','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-29 00:17:41',0,NULL,8,1,17,0,NULL,' FRANCISCO IVAN GARCIA PEREZ\rC/Lope de Vega n?5 Chalet\rFuenlabrada (Loranca) Madrid 28942\rSPAIN\r669625244\r\r'),(3722,711170454015,250666859818,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'',48.9,'hutongstore','kadedoll','divaaa1@hotmail.com','FRANCISCO IVAN GARCIA PEREZ','C/Lope de Vega nÂº5 Chalet','Fuenlabrada (Loranca)','Madrid','SPAIN','28942','669625244','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-29 00:17:42',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3m x 6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  3\r50-70 æ£š  3 æ¬§æ ‡  \ræ–œè‡‚   1\r115w 220v  2\r åŒ…   1\r lighting kit  $30 \rYW863684995CN\r'),(3723,652624838002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','negger99','palfaro@proseal.cl','Patricio Alfaro','Curtiduria 7701<br>La Florida','Santiago','Region Metropolitana','CHILE','8271237','56-2-3137191','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 00:35:11',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRA022498724CN\r'),(3724,652626038002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','nickgb83','home@nickandleash.com','N Bryant','39 Callum Place, Bracken Ridge','Brisbane','Queensland','AUSTRALIA','4017','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 00:40:59',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rlight stand  $22\rYW863685006CN'),(3725,613374782001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','bacaramaschi','bcaramaschi@gmail.com','Barbara Caramaschi','Rua Nestor do Val, 281','Piraju','SP','BRAZIL','18800-000','1488081027','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 01:10:57',0,NULL,3,1,2,1,NULL,NULL),(3726,613379570001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','thebalkanking','edin.ramicevic@gmail.com','Edin Ramicevic','Industrigata 71','Oslo','','NORWAY','0357','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 01:36:32',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRA022498715CN\r'),(3727,652651072002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','kameron808-123','torres_kameron@yahoo.com','Kameron Torres','1636 Gold St','Marysville','CA','UNITED STATES','95901-6812','(530) 926-2462','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-29 02:38:30',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹   1 '),(3728,652652229002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','globalestudio','tonrcc@gmail.com','weliton souza','Rua Couto MagalhÃ£es, NÂ° 2668 - CENTRO<br>Rua  Major Claudiano , NÂ° 2609 - Centro','Franca','SÃ£o Paulo','BRAZIL','14400-020','(016) 9256-2300','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 02:43:44',0,NULL,3,1,2,1,NULL,NULL),(3729,613399625001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','tonenino01','tonenino17@yahoo.com','Luis Pagan','166 Grand ave','Rochester','NY','UNITED STATES','14609-6348','(585) 576-8510','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 03:18:41',0,NULL,3,1,1,1,NULL,NULL),(3730,652660125002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','jinlsui123','jinlsui@yahoo.com','jinliang sui','180 rice ave','northborough','MA','UNITED STATES','01532','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-29 03:22:58',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  2 '),(3731,613400582001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','5_bueckertrustic','wiebe@cciwireless.ca','Margaret Wiebe','Po Box 21','Purple Springs','AB','CANADA','T0K 1X0','(403) 655-2582','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 03:25:06',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(3732,613219738001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','cristian_abcflor.com','cristian@abcflor.com','Cristian D. Nechuta','Av. Congreso 4937<br>Villa Urquiza','Buenos Aires','Buenos Aires','ARGENTINA','C1431AAE','5491169570101','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 04:17:08',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rRA022498905CN\r'),(3733,613409962001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','originalfrankiman','frankiman@hotmail.com','Francois Theriault Rehel','3848 Grand-Boulevard','Saint-Hubert','QC','CANADA','j4t 2m2','(450) 656-9429','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 04:23:06',0,NULL,3,1,2,1,NULL,' '),(3734,652324862002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','axelzule','axel_12_700@hotmail.com','axel cuevas','PO Box 990<br>PMB 681','san luis','AZ','UNITED STATES','85349','(623) 606-4893','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-29 04:41:59',0,NULL,3,1,1,1,NULL,'sonyå•è‚©åŒ…   1 '),(3735,652677832002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','totallytutus*com','totallytutus@hotmail.com','jackie heath','5918 Woodmere Dr','Corpus Christi','TX','UNITED STATES','78414','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 05:14:24',0,NULL,3,1,1,1,NULL,NULL),(3736,652680770002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','id4alexey','alexeypetrov@ngs.ru','Alexey Petrov','Uritskogo 12, 7','Novosibirsk','Novosibirsk','RUSSIAN FEDERATION','630099','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 05:37:24',0,NULL,3,1,3,1,NULL,' RA022498826CN\r'),(3737,613423239001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2101',59,'hermeshine','gkeith1','gkeithc@msn.com','Keith Clements','475 Heritage Ln','Johnstown','CO','UNITED STATES','80534-7815','(970) 587-9312','NoPaymentFailure','CheckoutComplete','Other','2010-12-29 06:07:45',0,NULL,3,1,1,1,NULL,'åŽŸè£…nikon èƒŒå¿ƒ L   1 '),(3740,652692578002,120571007047,'Green.L 77mm Neutral Density ND4 Filter 77 Nikon D90',1,'AE2307',8.2,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 07:22:32',0,NULL,8,1,17,0,NULL,NULL),(3741,652691766002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 07:22:33',0,NULL,8,1,17,0,NULL,NULL),(3742,613430207001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.95,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 07:22:33',0,NULL,8,1,17,0,NULL,NULL),(3743,613429697001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 07:22:34',0,NULL,8,1,17,0,NULL,NULL),(3744,613429443001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 07:22:34',0,NULL,8,1,17,0,NULL,NULL),(3745,613430641001,110419742832,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',8.2,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 07:22:35',0,NULL,3,1,5,1,NULL,'77mm ND8   1\ræ–œè‡‚  1\r2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶   1\rå¤§åŠ›å¤¹   1\rcåž‹å¤§åŠ›å¤¹   1\r77mm nd4    1 \rCP219437266CN'),(3746,711255728015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'',15,'hutongstore','bastelmonimo','monika.gutentag@googlemail.com','Monika Metzler','Pestalozzistrasse 3','Mainz','','GERMANY','55120','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-29 07:24:34',0,NULL,3,1,2,1,NULL,NULL),(3751,711271049015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','chrisf9439','christopher-faulder@sky.com','Mr C Faulder','168 West Street','Gorseinon','Swansea','UNITED KINGDOM','SA4 4AQ','01792894463','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 09:23:58',0,NULL,8,1,17,0,NULL,NULL),(3748,710956469015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'',61,'hutongstore','stefanov.stefan','stefan@stefanovs.com','Stefan Stefanov','23, James Baucher blvd.','Sofia','','BULGARIA','1164','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-29 08:24:00',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ çº¢ ç»¿ ï¼‰   1 \rç”µè¯æ˜¯ï¼š +359888510027\rCP219437252CN\r'),(3749,652706935002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','sladboy','sladkovic@gmail.com','Lubomir Sladkovic','Spartakovska 11','Trnava','','SLOVAK REPUBLIC','91701','+421944094249','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 09:12:28',0,NULL,3,1,3,1,NULL,'RR815340458CN '),(3752,711274935015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'',3,'hutongstore','chrisf9439','christopher-faulder@sky.com','Mr C Faulder','168 West Street','Gorseinon','Swansea','UNITED KINGDOM','SA4 4AQ','01792894463','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 09:23:58',0,NULL,3,1,2,1,NULL,'450dçœ¼ç½©   1 \r58mm é•œå¤´ç›– canon   1'),(3753,652718198002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0006',12.8,'hermeshine','dpspstewart','dan2452@hotmail.com.au','dan stewart','53 amaroo cres','Toormina','New South Wales','AUSTRALIA','2452','0266582803','NoPaymentFailure','CheckoutComplete','AU_Other','2010-12-29 10:18:54',0,NULL,3,1,2,1,NULL,'1.6x2.1 èƒŒæ™¯å¸ƒ  ç™½è‰²  '),(3754,652722990002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','chumkratok9094','chatetha@hotmail.com','Chatetha Chumkratoke','546 Moo 1<br>Huatala Subdistrict, Maung District','Nakhon Ratchasima','','THAILAND','30000','66862555445','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 10:49:10',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3755,613461271001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','drummer_hu','ebay@drummer.hu','Lorant Dobos','Haller u. 23-25 B116','Budapest','Budapest','HUNGARY','1096','+36204498687','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 10:51:02',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´  1 æ¬§æ ‡   '),(3756,697452947016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','6016michael','info@thefxworks.co.uk','michael gane','46 bath road, beckington','frome','Somerset','UNITED KINGDOM','BA11 6SH','01373831117','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 11:13:11',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(3757,652734914002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',2,'AC1302',18.5,'hermeshine','canaillarcos','ruizgonzalezjesus@gmail.com','JosÃ© Luis GonzÃ¡lez Almazo','C. Solis, NÂº 2 Bajo','San Fernando','AndalucÃ­a Ceuta y Melilla','SPAIN','11100','651148181','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 11:59:24',0,NULL,3,1,3,1,NULL,'å¤§å·å†…èƒ†åŒ… æ— å­—  2 RR815340427CN\r'),(3758,652758738002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','nemo350z','nemo_ee14@hotmail.com','Pornthep Puttharangsee','101/7 Moo3. Bangkruay-sianoy Rd. Bangrakpattana','Bangbuatong','Nonthaburi','THAILAND','11110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 13:53:04',0,NULL,3,1,2,1,NULL,'éº‚çš®  1 '),(3759,697497682016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'',5.9,'hutongstore','sebastian.bober','sebastian.bober@wp.pl','Sebastian Bober','Impellam, IT Helpdesk 800 The Boulevard, Capability Green','Luton','Bedfordshire','UNITED KINGDOM','LU1 3BA','01582692613','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 14:23:37',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹   1 '),(3760,613508610001,110445705855,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',1,'AB1405',9.9,'hermeshine','hyttipelto','erkki.hillukkala@netti.fi','Erkki Hillukkala','Kuovintie 3 B 6','MynÃ¤mÃ¤ki','Oletus','FINLAND','23100','258503588438','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 14:45:17',0,NULL,3,1,2,1,NULL,'è‚©å¸¦ pentax   1 '),(3761,652798305002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','sergey*gusty','lysikov@gmail.com','Sergey Lysikov','Gostenskaya 7/138','Belgorod','','RUSSIAN FEDERATION','308015','+79056796010','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 16:30:10',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ï¼‰    1 \rCP219437221CN\r'),(3762,652799389002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','vetdickg','docrhg@aol.com','Richard Galley','1601 Ranch House Rd','Willow Park','TX','UNITED STATES','76087-7691','(817) 441-7595','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 16:32:17',0,NULL,8,1,17,0,NULL,NULL),(3763,613537113001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','computer-tec','pctec101@yahoo.com','Tim O\'Dell','39 New Rd.','Salt Springs','NB','CANADA','E5N4J8','(506) 832-4528','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 16:33:15',0,NULL,3,1,2,1,NULL,NULL),(3764,652800360002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','vetdickg','docrhg@aol.com','Richard Galley','1601 Ranch House Rd','Willow Park','TX','UNITED STATES','76087-7691','(817) 441-7595','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 16:35:24',0,NULL,8,1,17,0,NULL,NULL),(3765,711388012015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','timjohnfish2000','timfishy@googlemail.com','Tim Fish','BOC Maxwell Rd','Plymouth','Devon','UNITED KINGDOM','Pl4 0RT','01752255033','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 16:36:16',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶   1 '),(3766,613538219001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',1,'AB1305',3.79,'hermeshine','vetdickg','docrhg@aol.com','Richard Galley','1601 Ranch House Rd','Willow Park','TX','UNITED STATES','76087-7691','(817) 441-7595','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 16:37:00',0,NULL,3,1,1,1,NULL,'67mm æ©¡èƒ¶ç½©   1\r72mm æ©¡èƒ¶ç½©   1\r77mm æ©¡èƒ¶ç½©   1 '),(3768,613547964001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','halg59','garner1@rogers.com','Hal Garner','115 William Roe Blvd','Newmarket','ON','CANADA','L3Y1B1','(905) 953-1926','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 17:09:42',0,NULL,3,1,2,1,NULL,NULL),(3769,613560422001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','dufranche','johannefrancis@sympatico.ca','RenÃ© Dumouchel','977, rue Chouinard','SteThÃ©rÃ¨se','QC','CANADA','J7E5M8','(450) 437-6545','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 17:50:18',0,NULL,3,1,2,1,NULL,NULL),(3770,613565849001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','lp_merino','len@ya.com','Lucia Palacios Merino','c/ Madres de la Plaza de Mayo<br>43, 1ÂºA','Artica','Navarra','SPAIN','31013','605503295','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 18:07:15',0,NULL,3,1,2,1,NULL,'40cm æ£š  1 '),(3771,652839064002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis nÂ°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 18:36:37',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR815340360CN\r'),(3772,652864795002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','danten0sense','dante.n0sense@gmail.com','Javier Hermosilla Jorge','Calvo Acacio 33 8','Valencia','Comunidad Valenciana','SPAIN','46017','678220722','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 19:50:37',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW863684833CN\r'),(3773,613608821001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','aeebilly','billy1463@yahoo.com','William Vazquez','9-J-13<br>Condado Moderno','Caguas','PR','UNITED STATES','00725','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 20:11:26',0,NULL,3,1,1,1,NULL,NULL),(3774,652872766002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','pantyusz85','pantyusz@gmail.com','Istvan Pantya','Berzsenyi 6','Veszto','','HUNGARY','5530','36305270671','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 20:12:17',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž    1 RR815340395CN\r'),(3775,652875442002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','wxytiramisu','wxycp3@gmail.com','Xiaoyang Wu','550 Bloomsdorf Dr','State College','PA','UNITED STATES','16801-2444','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 20:19:38',0,NULL,3,1,1,1,NULL,NULL),(3776,613612499001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','twistedstuff','twistedcory@gmail.com','Cory Breton','44 Welbourn Drive','Hamilton','ON','CANADA','L9A3N3','(905) 746-0661','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 20:20:30',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815340387CN\r'),(3777,711489096015,250690849529,'Background Support & Light Kit 3m x 6m 10 x 20ft white ',1,'',134,'hutongstore','h_salci','hunkar.salci@gmail.com','Hunkar Salci','Seher Yildizi Sok. Adak Apt. No:16 D:2 Etiler','Istanbul','Istanbul','TURKEY','34337','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-29 20:50:37',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç™½è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶   2\råŒç¯å¤´ æ¬§æ ‡   2\ræŸ”å…‰ä¼ž  2\r45w 220v  4\råŒ…   1 \rç”³æŠ¥$25\rCP219437155CN\r\rlighting kit  GBP55\r\r'),(3778,711495251015,250599423416,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',1,'',1.88,'hutongstore','ronniepickles','darren.odonnell@gmail.com','Darren O\'Donnell','48 Moat Road','Oldbury','West Midlands','UNITED KINGDOM','B688EB','07736395417','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 20:53:15',0,NULL,3,1,2,1,NULL,NULL),(3779,652897255002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','wlad2318','wladneto@uol.com.br','Wladimir Nequesaurt Pereira Neto','Rua Lucio Vitorino de Souza 186','Florianopolis','Santa Catarina','BRAZIL','88035060','48-32346911','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 21:25:52',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3780,652901441002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','mcaaway','michi8613@yahoo.com','Michelle Caaway','10857 Wallingford Rd','San Diego','CA','UNITED STATES','92126-2560','(858) 722-2820','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 21:40:10',0,NULL,3,1,1,1,NULL,NULL),(3781,652903071002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','ranianas','raniamns@yahoo.com','Despina Manasi','Thettalon<br>19','Karditsa','','GREECE','43100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 21:46:08',0,NULL,3,1,5,1,NULL,'light  $20 \r4 ç¯å¤´ æ£š  æ¬§æ ‡   2\rCP219437195CN\r\r'),(3782,652223458002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','honestbuy22','ra.alexis@gmail.com','Ranjeet Alexis','2872 Aberdeen Ln','El Dorado Hills','CA','UNITED STATES','95762-5683','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 21:58:12',0,NULL,3,1,1,1,NULL,NULL),(3784,613645560001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mariafg94','elry@online.no','ellen rygg','pasvikveien 23','Kirkenes','','NORWAY','9900','78992962','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 22:18:53',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 RR815340311CN\r'),(3785,652915265002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','admir.b','champ071@hotmail.com','admir begovic','Grbavicka 40','Sarajevo','ba','BOSNIA AND HERZEGOVINA','71000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 22:29:33',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´  æ¬§æ ‡  1\råå…‰ä¼ž    1 RR815340373CN'),(3786,652921509002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','dylanthanhcao','tcao1966@yahoo.com','NGOC CAO','1901 Long Prairie Rd<br>Ste 1037','FLOWER MOUND','TX','UNITED STATES','75022-4226','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 22:54:09',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡   1 '),(3787,652921558002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','fh_53','fh53@hetnet.nl','Ferry Horvath','Wilgenkamp 1','Losser','','NETHERLANDS','7581HA','053-5364964','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 22:54:29',0,NULL,3,1,3,1,NULL,'3m ä¼¸ç¼©æ¨ªæ†   1 RR815340339CN\r'),(3788,613664771001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','muhaimin1986','muhaimin86@gmail.com','Mohd Muhaimin','Kediaman PPP, Tingkat 3<br>kolej Kenanga 1, UiTM Shah Alam','Shah Alam','Selangor','MALAYSIA','40450','0194797139','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 23:32:21',0,NULL,3,1,3,1,NULL,'sf18-sb900   1 RR815340400CN'),(3789,652929856002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','pete_bean','peter@azuredigital.co.uk','Peter Smith','109 Orchard Way<br>Churchdown','Gloucester','Gloucestershire','UNITED KINGDOM','GL3 2AP','01452855666','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 23:33:23',0,NULL,3,1,4,1,NULL,'ballhead  $20 \rYW863684811CN\r'),(3790,711558409015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','mooneystephen','stephenjpmooney@gmail.com','Stephen Mooney','Heatherdale, Crutt, Clogh,','Castlecomer,','Kilkenny','IRELAND','default','0879126280','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-30 00:06:22',0,NULL,8,1,17,0,NULL,NULL),(3791,697702623016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'',3.5,'hutongstore','mooneystephen','stephenjpmooney@gmail.com','Stephen Mooney','Heatherdale, Crutt, Clogh,','Castlecomer,','Kilkenny','IRELAND','default','0879126280','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-30 00:12:50',0,NULL,3,1,2,1,NULL,'æ°”å¹+å¸ƒ   1\rlenspen   1 '),(3792,613687390001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','julzzz111','videojewels@yahoo.com','Juliusz Pokora','12045 N Pebble Beach Dr','SUN CITY','AZ','UNITED STATES','85351-3757','(623) 933-5525','NoPaymentFailure','CheckoutComplete','Other','2010-12-30 01:27:43',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815340342CN'),(3793,652961895002,120601699113,'EW-83E Lens Hood lenshood for Canon EF 16-35mm 10-22mm',1,'AA3406',8.99,'hermeshine','akarae','genchildren@hotmail.com','Teo   Hong Joo',' Block 426 Serangoon Avenue 1 #11-203','Singapore','Singapore','SINGAPORE','550426','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 02:22:44',0,NULL,3,1,11,1,NULL,NULL),(3794,652971498002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','larrable','landerton@comcast.net','Larry Anderton','2782 W 6870 S','West Jordan','UT','UNITED STATES','84084','(801) 971-7372','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 02:50:07',0,NULL,3,1,1,1,NULL,NULL),(3795,613709880001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','88pelican','tom_wilmers@hotmail.com','Tom Wilmers','2816 Central Ave','Big Pine Key','FL','UNITED STATES','33043-6215','(305) 872-5475','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 03:28:20',0,NULL,3,1,1,1,NULL,NULL),(3796,613712601001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','precisionartistics','philiparagones@gmail.com','Philip Aragones','71 Bacolod Street<br>Alabang Hills Village','Muntinlupa City','Metro Manila','PHILIPPINES','1770','9175099346','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 03:43:10',0,NULL,3,1,2,1,NULL,NULL),(3797,613713630001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','ftwb5658','ftwbnet@gmail.com','Matthew Cilia','84, Il-Hirondella Triq il-Barbagann','Kappara','MLT','MALTA','SGN02','0035699273990','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 03:48:49',0,NULL,3,1,3,1,NULL,'çº¢ç›’2m ç¯æž¶   1 RR815340356CN\r'),(3798,613717914001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','bandeparker2010','bandeparker@telus.net','Brian Parker','165 McTavish Cresent','Fort McMurray','AB','CANADA','T9K 2N9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 04:17:56',0,NULL,3,1,3,1,NULL,'2mç¯æž¶ ç™½ç›’   1 RR815340325CN'),(3799,652993315002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','poseur1234','leecf76@yahoo.com.sg','Lee Chien Fong','21B Kim Keat Close<br>Republic of Singapore','Singapore','','SINGAPORE','328931','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 04:56:06',0,NULL,3,1,11,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3800,613724443001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',99,'hermeshine','cul-de-sacs','loh_lcy@yahoo.com','Chong Yeou Loh','25 Main Road,<br>Bukit Jenun,','Pendang','Kedah','MALAYSIA','06720','0105662456','NoPaymentFailure','CheckoutComplete','AU_ExpressCourierInternational','2010-12-30 05:06:10',0,NULL,3,1,2,1,NULL,'2m ç¯æž¶  2\råŒç¯å¤´   2 è‹±æ ‡\råå…‰ä¼ž   2\råŒ…   1      3881\ré€’å››æ–¹é©¬æ¥è¥¿äºšä¸“çº¿ æ½˜\r89013446093'),(3801,652995214002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','lrmaruo','lucas.maruo@gmail.com','Lucas Ryoiti Maruo','Rua Frei Henrique de Coimbra,2116','Curitiba','PARANA','BRAZIL','81630220','+554199131465','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 05:08:33',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(3802,613635434001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',4,'AA1310',26,'hermeshine','rahollings','rahollings@shaw.ca','Ryan Hollings','268 Tuscany Estates Rise N.W.','Calgary','AB','CANADA','T3L0C5','(403) 208-3013','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 05:20:20',0,NULL,3,1,3,1,NULL,' RR815340435CN'),(3803,613730049001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','holistichealth','drnyvlt@hotmail.com','Pavel Nyvlt','Masarykovo nam.175','Podivin','','CZECH REPUBLIC','69145','(420) 739-4428 ext.: 66','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 05:52:25',0,NULL,3,1,5,1,NULL,'CP219437249CN\r'),(3804,653006004002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rb1m3b','rhkplam@verizon.net','Wilson Lam','5 Barnes Ave','Johnston','RI','UNITED STATES','02919-2601','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 06:36:15',0,NULL,3,1,1,1,NULL,NULL),(3805,653014017002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 07:50:01',0,NULL,3,1,2,1,NULL,' '),(3806,613746896001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','bxbe','bxbeworks@gmail.com','Dameng Wang','382 N Lemon Ave<br># 229','Walnut','CA','UNITED STATES','91789-2344','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-30 08:26:02',0,NULL,3,1,1,1,NULL,'å†æ”¹ä¸ªåœ°å€ï¼Œeé‚®å® \rå•å‘ä¸€ä¸ªé»‘è‰²çš„å†\rå®¢æˆ·è¦ä¸¤ä¸ªé»‘çš„ï¼Œå‘é”™äº†LK015764849CN'),(3807,697645205016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',44.58,'hutongstore','h_salci','hunkar.salci@gmail.com','Hunkar Salci','Seher Yildizi Sok. Adak Apt. No:16 D:2 Etiler','Istanbul','Istanbul','TURKEY','34337','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-30 08:31:38',0,NULL,3,1,5,1,NULL,'åå…‰æ¿æ”¯æž¶ 1\r2m ç¯æž¶  1\råå…‰ä¼ž   1\rlenspen    1\rå’Œå‰é¢çš„ä¸€ç¥¨åŒ…åœ¨ä¸€èµ·, å‰é¢çš„æˆ‘å¬å›žäº†,å°çŽ‹æ˜Žå¤©æ‹¿å›žæ¥\rCP219437155CN\r\r '),(3809,613753445001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','wuvzoo','kiarawoodsebay@gmail.com',' Kiara Woods','24 Dewhurst Street','Narrabri','New South Wales','AUSTRALIA','2390','0267944641','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 09:15:14',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR815340722CN\r'),(3810,613760568001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0024',20.99,'hermeshine','cserantesc','cserantesc@gmail.com','CÃ©sar Serantes Caballero','C/ Virgen de los Desamparados, 10 - 1ÂºD','Madrid','Madrid','SPAIN','28041','617733390','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 10:00:47',0,NULL,3,1,3,1,NULL,'nikon D1 å•è‚©åŒ…   1 \rRR815340719CN\r'),(3811,653041928002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.96,'hermeshine','freewinguk','ndt_ugur@hotmail.com','uÄŸur kÄ±lÄ±c','harmanlar mah.baharkent sitesi<br>3a blok daire:2','merzifon','amasya','TURKEY','05300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 11:07:01',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´  æ¬§æ ‡   2 \rRR815340665CN\r'),(3812,697829637016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'',2.52,'hutongstore','tompod1974','hairbear1974@btinternet.com','Thomas Podesta','39 Kilmersdon Road Haydon','Radstock','Somerset','UNITED KINGDOM','BA3 3QL','01761438978','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-30 11:36:14',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³   1 '),(3813,653060149002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','iz5165','ilanziv@bezeqint.net','49223ilan ziv','14 Moshe Sneh St.','Petach Tikva','','ISRAEL','49223','0545337325','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 12:41:30',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\räº‘å°   1\ræŸ”å…‰ä¼ž   1 \rRR815340740CN\r'),(3814,697851913016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','enchere_et_en_os','victorboissel@yahoo.fr','Cortex Ink. - Victor Boissel','37, rue du Faubourg PoissonniÃ¨re','Paris','','FRANCE','75009','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-30 13:18:58',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m èƒŒæ™¯å¸ƒ  ç»¿è‰²  1\r2m ç¯æž¶  2\r50-70 æ£š  æ¬§æ ‡   2\r115w 220v   2\råŒ…    1\rlighting kit  $30\rYW863684870CN\r\r '),(3815,711718434015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'',1.88,'hutongstore','jnejne','johannes.ne@gmail.com','Johannes Enevoldsen','Heboltoft 88','RingkÃ¸bing','','DENMARK','6950','+4528405305','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-30 13:28:55',0,NULL,3,1,2,1,NULL,NULL),(3816,711721504015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','jimboweb','jim.webster@sky.com','Jim Webster','27 Comrie Crescent','Hamilton','South Lanarkshire','UNITED KINGDOM','ML3 9QF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-30 13:40:49',0,NULL,3,1,2,1,NULL,'RS-S1   1 '),(3817,711721680015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'',125,'hutongstore','michaelf3032','fjoelner@hotmail.com','Michael Fjoelner','Schleppegrellsgade 17, 2. th.','Aarhus C','','DENMARK','8000','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-30 13:42:25',0,NULL,3,1,4,1,NULL,'2m  ç¯æž¶  2\r50-70 æ£š  æ¬§æ ‡  2\r115w 220v   2\rèƒŒæ™¯æž¶ï¼ˆ ç™½ï¼‰    1\råŒ…   1 \rlighting kit   $30\rYW863684881CN\r'),(3818,653072923002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','915lily','crypul2000@yahoo.com','Crystal Diaz','7090 NW 7th St','Plantation','FL','UNITED STATES','33317-1108','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 13:43:28',0,NULL,3,1,1,1,NULL,NULL),(3820,653072488002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0006',25.6,'hermeshine','krose-1910','kdoyle@live.com.au','krystle Walter','30 Moore Cres','Mount Isa','Queensland','AUSTRALIA','4825','0401081910','NoPaymentFailure','CheckoutComplete','AU_Other','2010-12-30 13:46:49',0,NULL,3,1,3,1,NULL,'1.6m x 2.1m  èƒŒæ™¯å¸ƒ 2\rç™½è‰² + é»‘è‰² \rRR815340784CN\r\r'),(3821,653077566002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','theartharindra','harindranishshanka@gmail.com','Harindra Nishshanka','30/1, Godellawaththa,<br>Mahawila','Panadura','Western','SRI LANKA','12500','0094773040696','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 14:08:09',0,NULL,3,1,8,1,NULL,'2m ç¯æž¶   2\r50-70 æ£š   è‹±æ ‡   2\r115w 220v   2\råŒ…    1 \rused lighting kit  $20\rCP219437164CN\r'),(3822,697869679016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'',14.5,'hutongstore','jdealmeida61','phportjose@hotmail.com','Jose de Almeida','Peterson Mitra Indonesia Jl Jendral Surdiman Blok G2/5','Balikpapan Permai','Kalimantan Timur','INDONESIA','76114','062 081520324739','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-30 14:23:34',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ å¤å­£ xl   1\rRR815340682CN\r'),(3823,653082757002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','mayoula_jewelry','mayoula.jewelry@gmail.com','tamar mandil','25 HaHistadroot street','Raanana','','ISRAEL','43404','972-54-7746107','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 14:27:58',0,NULL,3,1,3,1,NULL,'50cm æ£š   1 \rRR815340679CN\r'),(3824,653083535002,120564178467,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','jayhyunjaekim','kimh2@corning.com','Jay Kim','30 Hunters Run','Horseheads','NY','UNITED STATES','14845-2285','(607) 329-7214','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 14:31:21',0,NULL,3,1,1,1,NULL,NULL),(3826,652329098002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','urak81','verinicola@virgilio.it','caterina colanzi','VIA PORTELLE<br>n. 65','SAN VITO CHIETINO','CH','ITALY','66035','3207633318','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 14:43:00',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§     1\ræŸ”å…‰ä¼ž   1 \rRR815340736CN\r'),(3827,613831068001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','antozone','antoantous@yahoo.com','Adianto Adianto','Jl Percetakan Negara GG Muhirin I/4C<br>RT:002 RW:006 Kel Cempaka Putih Barat','Jakarta','Jakarta','INDONESIA','10520','6281328352308','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 15:56:34',0,NULL,3,1,2,1,NULL,NULL),(3828,613833488001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','valrval','valrichards7@gmail.com','Valerie Richards','Autumn Graphics<br>669 Sovereign Rd','London','ON','CANADA','N5V 4K8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 16:06:12',0,NULL,3,1,2,1,NULL,NULL),(3829,653114291002,120618815391,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',7.4,'hermeshine','naalsund','nathalie_1991@msn.com','nathalie naalsund','nordre husebytun 8b','trondheim','','NORWAY','7097','92270799','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 16:28:36',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯ 67mm ND8   1 '),(3830,653113989002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','jtharris1984','jtharris@ameritech.net','Jeffrey Harris','23303 Vance Ave','Hazel Park','MI','UNITED STATES','48030-1624','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 16:28:39',0,NULL,3,1,1,1,NULL,NULL),(3831,613869726001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','guillaume68490','guillaume.fels@gmail.com','guillaume fels','6, rue de gontaud','bantzenheim','Alsace','FRANCE','68490','0686893375','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 18:07:03',0,NULL,3,1,4,1,NULL,'6663a   1\rTripod   $22 \rYW863684866CN\r'),(3832,697599003016,260646700576,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'',54.5,'hutongstore','rozgon','rozgon.taras@gmail.com','Taras Rozgon','Crown Fort Club, B8, ap.158','Sveti Vlas','','BULGARIA','8256','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-30 18:43:59',0,NULL,3,1,5,1,NULL,'6663a   1 \rCP219437178CN\r'),(3833,653160750002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bretskyswanson','bretsky_swanson@hotmail.com','Brett Swanson','2303 College Ave<br>Huntington University','Huntington','IN','UNITED STATES','46750-1237','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 19:09:58',0,NULL,3,1,1,1,NULL,NULL),(3834,613894571001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','korn2402','zoltan.simon.rs@gmail.com','ZoltÃ¡n Simon','MalohontskÃ¡ 26/27','RimavskÃ¡ Sobota','','SLOVAK REPUBLIC','97901','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 19:22:45',0,NULL,3,1,3,1,NULL,'è‚©æž¶    1 \rRR815340753CN\r'),(3836,613930404001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','butleram10','butleram@iuk.edu','Amber Butler','1012 N Armstrong St','Kokomo','IN','UNITED STATES','46901-2824','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 21:20:27',0,NULL,3,1,1,1,NULL,NULL),(3837,711907370015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','binksley','susan@iklektik.co.uk','susan fraser','108 lossiemouth road','Elgin','Moray','UNITED KINGDOM','iv30 4ld','01343546328','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-30 22:22:21',0,NULL,3,1,2,1,NULL,'45w  2 '),(3838,613863798001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AE2301',5.95,'hermeshine','ashdot','ashdot@ashdot.co.il','Izhar Ashdot','Yosef Nassi 12','Tel Aviv','xx','ISRAEL','65236','+972-3-5253392','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 22:23:09',0,NULL,3,1,2,1,NULL,'52mm æ¸å˜ç°   1 '),(3839,653223258002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','adri25an','adri25anebay@gmail.com','AdriÃ¡n Batista Trenzado','C/Camino Lomo de Quintanilla, 62','Arucas','Canarias','SPAIN','35413','619993502','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 22:29:01',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§    1\ræŸ”å…‰ä¼ž    1 \rRR815340696CN\r'),(3840,653231937002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','m1shka66','michael.soroka@worleyparsons.com','Michael Soroka','217-23 Observatory lane','Richmond Hill','ON','CANADA','L4C 0M7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 22:48:18',0,NULL,3,1,2,1,NULL,NULL),(3841,613957106001,110414476355,'Remote Shutter Release for Canon Rebel XT XTi = RS-60E3',1,'AA3210',6.98,'hermeshine','browngirl0864','browngirl864@yahoo.com','Shonna  Jackson','4419 Colomba St','Houston','TX','UNITED STATES','77045-3523','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 23:01:56',0,NULL,3,1,1,1,NULL,'RS-C1    1 '),(3842,711923564015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',2.6,'hutongstore','p_trav','paultraviss@hotmail.com','Paul s Traviss','32 Kings Close Kingsdown','Nr Deal','Kent','UNITED KINGDOM','CT14 8BA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-30 23:13:05',0,NULL,3,1,2,1,NULL,NULL),(3843,711941683015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','littlewolver','honzavlcek@seznam.cz','Jan Vlcek','5 The Terrace Fengate Drove','Weeting, Brandon','Norfolk','UNITED KINGDOM','IP27 0XP','07870512901','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-31 00:21:52',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š   è‹±æ ‡   2\r115w 220v   2\råŒ…    1 \rå•ç¯å¤´  è‹±æ ‡  2 \rlighting kit   $30\rYW863684855CN\r'),(3845,711941684015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'',15.5,'hutongstore','littlewolver','honzavlcek@seznam.cz','Jan Vlcek','5 The Terrace Fengate Drove','Weeting, Brandon','Norfolk','UNITED KINGDOM','IP27 0XP','07870512901','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 00:21:55',0,NULL,8,1,17,0,NULL,''),(3847,653255278002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','leol985','tan.leo@gmail.com','Leo Tan','309 Shunfu Road<br>#13-179','Singapore','Singapore','SINGAPORE','570309','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 00:30:20',0,NULL,3,1,11,1,NULL,NULL),(3848,653273353002,120626873273,'New wide angle holder for Cokin P series filter',2,'AKT024',7.98,'hermeshine','barao1961','amgp@netvisao.pt','Antonio Manuel Gomes Paulino Paulino','R. Alves Redol NÂº 72 1Âº Esq.','Cova da Piedade - Almada','SetÃºbal','PORTUGAL','2805-071','936494274','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 01:58:27',0,NULL,3,1,2,1,NULL,NULL),(3849,711974392015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'',3.5,'hutongstore','zubair_samat','rasarasa10@gmail.com','rosnani hasan','smk tunku putra 07000 langkawi, kedah darul aman','Langkawi','Kedah','MALAYSIA','07000','0195696939','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-31 02:45:35',0,NULL,3,1,2,1,NULL,NULL),(3850,653306098002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',8.69,'hermeshine','vincecraft','vincecraft@msn.com','Samuel Vincent','349 Kimberly Ln','Los Alamos','NM','UNITED STATES','87544-3527','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-31 05:15:16',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…  canon   1 '),(3851,653308685002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','expatyorkshire','mwindle@singnet.com.sg','Windle Martin','28 Boon Teck Road','default','','SINGAPORE','329600','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 05:35:19',0,NULL,3,1,10,1,NULL,'é€’å››æ–¹æ–°åŠ å¡ä¸“çº¿\rèƒŒæ™¯æž¶ ï¼ˆ ç™½ï¼‰  2mçš„ æ½˜\r89013446115'),(3852,614028817001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','sanphoto251982','sanphoto25@yahoo.com','sandiren parianen','gentilly branch road<br>petit - verger','saint-pierre','..','MAURITIUS','...','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 05:58:26',0,NULL,5,1,18,0,NULL,'3mx6m ç™½è‰²èƒŒæ™¯å¸ƒ  1 '),(3853,653315828002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','seraphsky','derekhaochen@hotmail.com','Hao Chen','717 Flannery St','Santa Clara','CA','UNITED STATES','95051-5546','(408) 332-0269','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-31 06:36:50',0,NULL,3,1,1,1,NULL,NULL),(3854,653317672002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','traberw','wtraber@sunrise.ch','Werner Traber','rue de la Servette 30A','GenÃ¨ve','','SWITZERLAND','1202','41795079226','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 06:55:09',0,NULL,3,1,2,1,NULL,NULL),(3855,653325594002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','empo_vit','empo.vit@gmail.com','Vitaliy Emporopulo','PO Box 219<br>Hagefen 35','Elyakhin','','ISRAEL','38908','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 08:13:06',0,NULL,3,1,3,1,NULL,'RR815340974CN\r'),(3856,613797241001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',53.79,'hermeshine','pauliusb18','pbareika@yahoo.com','Paulius Bareika','Migliu 4','Ukmerge','','LITHUANIA','20136','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 09:13:34',0,NULL,3,1,3,1,NULL,'Lenspen   1\rå¹¿è§’æ‰˜æž¶   1\rcpl   1\ræ¸å˜æ£•   1\ræ¸å˜æ©™   1\ræ¸å˜ç»¿    1\ræ¸å˜ç°    1\r52mm çŽ¯æž¶   1\rç”³æŠ¥$25\rRR815342343CN\r\r '),(3857,653340429002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.2,'hermeshine','kb-diver','kb-diver@bezeqint.net','jacov breznikov','beniyamin 40/10, rehovot','rehovot','','ISRAEL','NON','972546445647','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 10:05:55',0,NULL,3,1,2,1,NULL,NULL),(3858,614059025001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','bogopolsky1','bog.vadim@gmail.com','vad bogopolsky','motzkin 21 ap 10','netanya','israel','ISRAEL','42460','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 10:11:44',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 RR815342175CN\r'),(3859,614058960001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','kim_brutis07','kim_brutis@msn.com','Kim Huynh','202/250 Barkly Street','Footscray','Victoria','AUSTRALIA','3011','0423583387','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 10:12:47',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(3860,698170980016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'',8.99,'hutongstore','zegarek777','zegar777@wp.pl','Przemyslaw Ruszkowski','22 Cardinal Road','Leeds','West Yorkshire','UNITED KINGDOM','LS11 8AL','07590073936','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 10:20:01',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°  1\r55mm çŽ¯æž¶   1 '),(3861,653353629002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','schrat17','dirk.doeding@gmx.net','Dirk DÃ¶ding','Bonner Str. 10','KÃ¶ln','','GERMANY','50677','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 11:29:28',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815342184CN\r'),(3862,712063036015,250746712937,'55mm Graduated Neutral Density Filter Gradual Grey 55',1,'',4.8,'hutongstore','skuuunk','m.pesenti@hotmail.fr','Maxence pesenti','684 route du badoit Domaine de la gargodiere','Estrablin','RhÃ´ne-Alpes','FRANCE','38780','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-31 11:39:05',0,NULL,8,1,17,0,NULL,NULL),(3863,712063178015,250599364553,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',2.1,'hutongstore','skuuunk','m.pesenti@hotmail.fr','Maxence pesenti','684 route du badoit Domaine de la gargodiere','Estrablin','RhÃ´ne-Alpes','FRANCE','38780','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-31 11:39:05',0,NULL,3,1,2,1,NULL,'55mm æ¸å˜ç°  1\r55mm uv    1 '),(3864,712064301015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'',3.62,'hutongstore','soares197150','fsfotosoares@gmail.com','Francisco Soares','Largoda Barreira nÂº2','Vilarandelo','ValpaÃ§os','PORTUGAL','5430-635','252419575','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-31 11:43:35',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶  1 '),(3865,712075414015,250599980827,'New Neoprene Reversible Bag Cover for Large-DSLR',1,'',6.1,'hutongstore','the_zakman9','the_zakman9@hotmail.com','Zakariyya  Chowdhury','44 oxney road','Manchester','Lancashire','UNITED KINGDOM','m14 5sz','07743900678','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 12:33:45',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ… æ— å­—  1 '),(3866,653373231002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','marialuciaph','marianaphph@yahoo.com.br','maria lucia','rua retiro dos artistas <br>1081','rio de janeiro','rio de janeiro','BRAZIL','22770104','2132566257','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 13:20:03',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR815342198CN\r'),(3867,712123805015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'',7.75,'hutongstore','pantharotsa','mevlutizci@hotmail.com','mevlut izci','9 Rivergate Apartments Creywell','Newross','Wexford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-31 15:29:23',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ è‹±æ ‡  1 '),(3868,653395112002,120564178624,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','rafihay_123','hayat57@gmail.com','rafi hayat','kaliser 1/4','reson-lezion','reson lezion','ISRAEL','75754','0523-862080','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 15:36:41',0,NULL,3,1,3,1,NULL,'ND2/4/8   1\r62mm çŽ¯æž¶    1\rRR815342207CN\r'),(3869,653407288002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',10,'AA1310',54.9,'hermeshine','lolica007','rcararo@ig.com.br','LOURDES LISE CARARO','RUA BORTOLO ZANI, 97<br>SALA 1','CAXIAS DO SUL','RIO GRANDE DO SUL','BRAZIL','95072-000','054 3228 5664','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 15:42:21',0,NULL,3,1,3,1,NULL,'RR815342119CN\r '),(3870,653408364002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jayjay689','chung.jerome@gmail.com','jerome chung','bp 9242','papeete','tahiti','FRENCH POLYNESIA','98715','+689 789868','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 15:46:55',0,NULL,3,1,3,1,NULL,' RR815342122CN\r'),(3871,614135214001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','platonkhegai','pkhegai@gmail.com','Platon Khegai','3-b Butomy str., ap. 105','Nikolaev','','UKRAINE','54040','+380682704430','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 16:23:40',0,NULL,3,1,2,1,NULL,NULL),(3872,653429116002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','compraslagi','lagartillo_13@hotmail.com','ROBERTO  GONZALEZ ENCINAR','CALLE PASAJE DEL PINTOR MURILLO NÂº3','COLLADO VILLALBA','Madrid','SPAIN','28400','627965418','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 17:02:11',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864144081CN\r'),(3873,698291822016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','cia1976','chrisallen1976@live.com','Chris Allen','30 Loftin Way','CHELMSFORD','Essex','UNITED KINGDOM','CM2 9TW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 17:59:19',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—  1 '),(3874,614160976001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','allstar-dj','allstardj@optonline.net','Factory Brands','117 Nassau Ave','Manhasset','NY','UNITED STATES','11030-2403','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-31 18:01:42',0,NULL,3,1,1,1,NULL,NULL),(3875,712174069015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','cannibalism84','gaspuitis25@gmail.com','Sarunas Gaspuitis','15 Kilmarnock gardens','Dagenham','London','UNITED KINGDOM','RM8 2RE','07787083669','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 18:03:08',0,NULL,3,1,2,1,NULL,NULL),(3876,653444078002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','fivedollarngatgmail','fivedollarng@gmail.com','Hak Man Ng','Room 1808, Fu Ming House,<br>Wah Ming Estate, Fanling','default','','HONG KONG','default','(852) 6488 - 0671','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 18:03:52',0,NULL,3,1,2,1,NULL,NULL),(3877,712188629015,250692237083,'Green.L 77mm 77 Neutral Density ND8 Filter ND 8 New',2,'',9.6,'hutongstore','lee2001uk','leigh20034567@yahoo.co.uk','Leigh Hogben','184-6 the street Boughton','Faversham','Kent','UNITED KINGDOM','ME13 9AL','441227751586','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 18:52:37',0,NULL,3,1,2,1,NULL,'77mm ND4   1\r77mm ND8   1 '),(3878,653472520002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','bootje1974','corne@agrios.nl','Corne Boogaard','Zandbergsestraat 5','Graauw','','NETHERLANDS','4569TC','(06)55190592','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 20:19:15',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3879,614198758001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','edgar.ulises','edgar.cortes@prodigy.net.mx','Edgar Ulises CortÃ©s Ortega','Av. TecomÃ¡n Sur #99<br>Col. El moralete','Colima','Colima','MEXICO','28060','','NoPaymentFailure','CheckoutComplete','NotSelected','2010-12-31 21:14:46',0,NULL,3,1,2,1,NULL,NULL),(3880,653494563002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','jdmkun','jdmkun@yahoo.com','Jon Moody','5935 Crescent Ln','Colleyville','TX','UNITED STATES','76034','(817) 723-5085','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-31 21:59:00',0,NULL,3,1,1,1,NULL,NULL),(3881,653507170002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','plantseeds4him','blwong2@mac.com','Barb Wong','5585 NW Konigs Ct','Issaquah','WA','UNITED STATES','98027','(206) 940-8671','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-31 23:16:09',0,NULL,3,1,1,1,NULL,NULL),(3882,712256250015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'',2.98,'hutongstore','thesewords04','thesewords@fsmail.net','andrew taylor','43 polden close','peterlee','Durham','UNITED KINGDOM','sr8 2lh','01915862109','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 23:53:48',0,NULL,3,1,2,1,NULL,'RS-C3   1 '),(3883,653515902002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','fibro66','fitbro@online.no','Finn Brodal','Ingerfjellveien 2<br>Berg','Halden','Ostfold','NORWAY','1788','+47 99539357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 00:12:25',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(3884,653526550002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','lungemos','joachim@ringstad.cc','Joachim Ringstad','Grenseveien 58','Oslo','Oslo','NORWAY','0579','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 01:20:37',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW863600083CN\r'),(3885,614242198001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','randall.gerhart','randall.gerhart@gmail.com','Randall Gerhart','14517 32nd Ave NE','Shoreline','WA','UNITED STATES','98155-7523','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-01 01:48:49',0,NULL,3,1,1,1,NULL,'nikon-52mm åæŽ¥çŽ¯  1 '),(3886,653451101002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',71.3,'hermeshine','therapy171275','therapy2005@gmail.com','Roberto Vergara','Huerfanos 2328,. Depto 101','Santiago, Chile','RegiÃ³n Metropolitana','CHILE','6520248','56-09-74760541','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-01 03:58:18',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\rbåº§    2\ræŸ”å…‰ä¼ž  1\råå…‰ä¼ž   1 \rCP219487925CN\r'),(3887,653555526002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',3,'AE1201',14.4,'hermeshine','abkaroh1','abkaroh@hotmail.com','Abkar Alawi','3445 Cote-des neiges Apt: 511','Montreal','QC','CANADA','H3H1T5','(514) 550-2020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 05:15:43',0,NULL,3,1,2,1,NULL,NULL),(3888,698434652016,260660053846,'Photo Studio Background Support 2mÃ—3m 7 x 10 ft + BAG',1,'',54.6,'hutongstore','valasakis','valasakis@gmail.com','LOGOTHETIS VALASAKIS','ANAXIMENOUS 59 K. TOUMPA','THESSALONIKI','GREECE','GREECE','54454','6948207802','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-01 08:19:14',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶   1 \rCP219487934CN\r'),(3889,614279366001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','softital','talbruchiel85@walla.com','tal bruchiel','menachem begin 7/3<br>ramat poleg','netanya','israel','ISRAEL','42201','0547828798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 08:29:37',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´  1  æ¬§æ ‡ '),(3890,614300991001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','koklv53','ekok1207@yahoo.com','yevgeni kokizov','arbel 12/19','karmiel','','ISRAEL','21821','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 11:24:35',0,NULL,3,1,2,1,NULL,NULL),(3891,698474268016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'',2.52,'hutongstore','taffytubby','taffytubby@another.com','Owen LLewellyn','56, Blenheim Gardens','London','n/a','UNITED KINGDOM','SW2 5DA','02086714110','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-01 12:19:05',0,NULL,3,1,2,1,NULL,NULL),(3892,698471212016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'',12,'hutongstore','rtohome','seng@renttoownhome.com.au','Seng Wong','P O Box 137','Forest Hill','Victoria','AUSTRALIA','3131','61412271336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 12:21:46',0,NULL,8,1,17,0,NULL,NULL),(3893,698155123016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','rtohome','seng@renttoownhome.com.au','Seng Wong','P O Box 137','Forest Hill','Victoria','AUSTRALIA','3131','61412271336','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-01 12:21:46',0,NULL,8,1,17,0,NULL,NULL),(3894,698473298016,260660055197,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'',5.88,'hutongstore','rtohome','seng@renttoownhome.com.au','Seng Wong','P O Box 137','Forest Hill','Victoria','AUSTRALIA','3131','61412271336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 12:21:47',0,NULL,8,1,17,0,NULL,NULL),(3895,712031310015,250606686008,'IR Wireless Remote Control for Nikon D90/D80/D60 ML-L3',1,'',2.75,'hutongstore','rtohome','seng@renttoownhome.com.au','Seng Wong','P O Box 137','Forest Hill','Victoria','AUSTRALIA','3131','61412271336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 12:21:47',0,NULL,8,1,17,0,NULL,NULL),(3896,712041101015,250600315434,'Flash Softbox Diffuser for internal flash for D500 D90',1,'',6.8,'hutongstore','rtohome','seng@renttoownhome.com.au','Seng Wong','P O Box 137','Forest Hill','Victoria','AUSTRALIA','3131','61412271336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 12:21:48',0,NULL,3,1,4,1,NULL,'NG128   1\rçº¢å¤–é¥æŽ§ nikon   1\r60cm  2in1   1\r2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  æ¾³æ ‡  2\r115w 220v   2\råŒ…    1\r1.6m x 3m é»‘è‰²èƒŒæ™¯å¸ƒ  1\rSeng Wong\r32 Jolimont Road, Forest \rHill, VIC 3131,\r Australia.\r61412271336\rYW863600072CN\r\r\r\r '),(3897,712364960015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','1584stefan','aikistef@hotmail.co.uk','stefan tofari','16 clammas way uxbridge','uxbridge','Middlesex','UNITED KINGDOM','ub83an','01895234591','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-01 12:23:45',0,NULL,3,1,2,1,NULL,'RS-S1   1 '),(3898,653603040002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','emmo2011','sherryhuang2010@gmail.com','Sherry Huang','21B, Tower 3, Bel-air on the Peak<br>68 Bel-air Peak Avenue','default','','HONG KONG','default','(852)98126036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 12:24:24',0,NULL,3,1,2,1,NULL,NULL),(3899,653604509002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kephihx','hhxx@msn.com','XIN HU','Unit 3, No.19 Collins St<br>Preston','Melbourne','Victoria','AUSTRALIA','3072','61425825298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 12:31:43',0,NULL,3,1,2,1,NULL,NULL),(3900,698466006016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','1mewant','anthonypalaje1@optusnet.com.au','Anthony Palaje','46B Attunga Rd','Yowie Bay','New South Wales','AUSTRALIA','2228','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-01 13:04:22',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m èƒŒæ™¯å¸ƒ  ç»¿è‰²  1\r2m ç¯æž¶  2\r50-70 æ£š  æ¾³æ ‡  2\r115w 220v   2\råŒ…   1 \rYW863600061CN\r'),(3901,614346134001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','show_needs','tpetrosky@showneeds.com','Thomas  Petrosky','15726 Drake St','Southgate','MI','UNITED STATES','48195-3251','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-01 15:15:41',0,NULL,3,1,1,1,NULL,'58mmæ©¡èƒ¶ç½©   4\r52mmæ©¡èƒ¶ç½©  1\r55mmæ©¡èƒ¶ç½©   2\r77mmæ©¡èƒ¶ç½©  1\r72mmæ©¡èƒ¶ç½©   2'),(3902,653640245002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','mcvetnic1985','mcvetnic@gmail.com','Matija Cvetnic','Stanka Vraza 7a','Sisak','CROATIA','CROATIA','44000','00385992694624','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 15:20:48',0,NULL,3,1,3,1,NULL,'50-70 å¡‘æ–™å¡å£  1 RR815342136CN\r'),(3903,698515366016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'',5.8,'hutongstore','dustyblue05','tasha_s_25@hotmail.com','Natasha Strelzyn','243 Pendlebury Drive West Knighton','Leicester','Leicestershire','UNITED KINGDOM','LE2 6GU','01162920613','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-01 15:07:13',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…  1 '),(3904,653648769002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','hope4success','kdta@aol.com','Brad Link','315 Dodge St','Delta','CO','UNITED STATES','81416-1715','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-01 15:52:05',0,NULL,3,1,1,1,NULL,NULL),(3905,653648732002,120581410942,'16chan Wireless Remote Control Cord for Nikon D90 D5000',1,'AA3202',18.5,'hermeshine','xuestong','guostong@gmail.com','Qiang Guo','331 Hillside Dr','Mississauga','ON','CANADA','L5M2N3','(905) 826-6904','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 15:52:19',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿  N3   1 '),(3906,653651387002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','hakka69','nakka@internode.on.net','Lincoln Harrison','42 Ellis st','bendigo','Victoria','AUSTRALIA','3550','0437386554','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(3907,653672290002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','malinovskii','mauglispb@rambler.ru','Andrei Malinovskii','prospect Sizova 32-1-386','Saint-Petersburg','','RUSSIAN FEDERATION','197349','+7(911)959-5130','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-01 17:11:42',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ï¼‰ 2mçš„  1 \rCP219437120CN\r'),(3908,614397654001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','oddgeirn','ebay@oddgeir.no','Oddgeir Nossen','VÃ¥gnesvegen 9','LangevÃ¥g','MÃ¸re og romsdal','NORWAY','6030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 18:08:35',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹çƒå°  1 \rç”³æŠ¥ ï¼„9.80 '),(3909,614424764001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',3,'AE1301',53.7,'hermeshine','tucorigo','erigaut@wanadoo.fr','Emmanuel RIGAUT','2 ROUTE DE VILLENOTTE','SAINT-EUPHRÃ”NE','CÃ”TE D\'OR','FRANCE','21140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 19:20:03',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´   3 æ¬§æ ‡\r1543  RR815342710CN\r'),(3910,614434020001,110566019962,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',3.55,'hermeshine','samael96','borralla@wanadoo.es','Santiago Hernaez Arzua','Avda Finisterre 187-195 portal 2<br>6 Dcha','A Coruna','Galicia','SPAIN','15010','881918176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 19:48:34',0,NULL,8,1,17,0,NULL,NULL),(3911,653725631002,120581555818,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','samael96','borralla@wanadoo.es','Santiago Hernaez Arzua','Avda Finisterre 187-195 portal 2<br>6 Dcha','A Coruna','Galicia','SPAIN','15010','881918176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 19:48:35',0,NULL,8,1,17,0,NULL,NULL),(3912,614433827001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','samael96','borralla@wanadoo.es','Santiago Hernaez Arzua','Avda Finisterre 187-195 portal 2<br>6 Dcha','A Coruna','Galicia','SPAIN','15010','881918176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 19:48:35',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶  1\r52mm æŽ¥å£çŽ¯  1\r67mm æŽ¥å£çŽ¯   1 '),(3913,653735706002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kazachok','ak-al@mail.ru','aleksey chebykin','Kurganskaya, 3-206','Moscow','Ru','RUSSIAN FEDERATION','107065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 20:25:07',0,NULL,8,1,17,0,NULL,NULL),(3914,614443203001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','kazachok','ak-al@mail.ru','aleksey chebykin','Kurganskaya, 3-206','Moscow','Ru','RUSSIAN FEDERATION','107065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 20:25:07',0,NULL,3,1,2,1,NULL,'80cm 5in1   1\rlenspen   1 '),(3915,614463788001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','swetlitme81','duffie81@yahoo.com','Casandra Cross','14 Walker ave','Bradford','PA','UNITED STATES','16701-1229','(814) 598-9259','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-01 21:25:43',0,NULL,3,1,1,1,NULL,NULL),(3916,653757431002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','tlamo20','lamo@epost.no','Thomas Lamo','Malmvegen 126','Tromso','Krokelvdalen','NORWAY','9022','91858178','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-01 21:34:42',0,NULL,3,1,3,1,NULL,'sony a1 å•è‚©åŒ…  1 RR815342140CN\r'),(3917,712557592015,250692236297,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',2,'',6,'hutongstore','instantclassic','subasaudio@gmail.com','Hans I. Jonsson','SolvÃ¤gen 7','Ã–rnskoldsvik','VT','SWEDEN','S-89142','+46 660 560 30','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 21:38:01',0,NULL,8,1,17,0,NULL,NULL),(3918,698657512016,260661403957,'TianYa 82mm UV filter New 82 Protects Your Lens NIB',1,'',5.2,'hutongstore','instantclassic','subasaudio@gmail.com','Hans I. Jonsson','SolvÃ¤gen 7','Ã–rnskoldsvik','VT','SWEDEN','S-89142','+46 660 560 30','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 21:38:01',0,NULL,8,1,17,0,NULL,NULL),(3919,712557383015,250692242462,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',3.5,'hutongstore','instantclassic','subasaudio@gmail.com','Hans I. Jonsson','SolvÃ¤gen 7','Ã–rnskoldsvik','VT','SWEDEN','S-89142','+46 660 560 30','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 21:38:02',0,NULL,3,1,2,1,NULL,'77mm uv   1\r67mm uv  2\rå¤©æ¶¯ 82mm uv   1 '),(3920,653778766002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','pedro_tdm','pedro.tdm@gmail.com','Pedro Mateus','Praceta das Comunidades LusÃ­adas, Bloco B, Lote 2, 6Âºdto','Agualva-CacÃ©m','','PORTUGAL','2735-093','+351966579783','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-01 22:51:44',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW863600094CN\r'),(3921,653786681002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',9.8,'hermeshine','repeterka','rpeterka@juno.com','robert peterka','3011 62nd Ave E','bradenton','FL','UNITED STATES','34203','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-01 23:25:11',0,NULL,3,1,1,1,NULL,NULL),(3922,614498792001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','leifern83','leiferns@gmail.com','Leif Roger Olsen','GangsÃ¥sveien 45','Harstad','','NORWAY','9408','+47 99749639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 23:52:38',0,NULL,3,1,2,1,NULL,NULL),(3923,614507570001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','motorola_01','macjus@gmail.com','Jun Miyagi','2-24-2F Teramachi Nakaku','Hiroshima','Hiroshima','JAPAN','7300801','082-909-3071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 00:37:10',0,NULL,3,1,3,1,NULL,'50-70 å•ç¯å¤´æ£š  1 RR815342286CN\r\r'),(3924,614510502001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','godov09roman','godov09@rambler.ru','Roman Godovanyk','st. Voroshilov, 12 kv.48','Uman','Cherkasy','UKRAINE','20300','380977530073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 00:52:47',0,NULL,3,1,2,1,NULL,NULL),(3925,653808959002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','mikewest1977','mikewest13@hotmail.com','mike west','1214 tredmore dr','mississauga','ON','CANADA','l5j 3v3','(416) 436-8494','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 00:58:23',0,NULL,3,1,3,1,NULL,'84cm ç¯æž¶   1 RR815342290CN\r'),(3926,614511793001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','garnet44','angelaeds@yahoo.com','andrew hagaman','328 Ixora Dr','palm harbor','FL','UNITED STATES','34684-3419','(727) 946-7312','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-02 01:01:00',0,NULL,3,1,3,1,NULL,'nikon  å•è‚©åŒ…  d1   1 RR815342309CN\r'),(3927,653817527002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','lrargerich','lrargerich@gmail.com','Luis Argerich','Rastreador Fournier 2233','Olivos','Buenos Aires','ARGENTINA','1636','+541147979908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 01:42:16',0,NULL,3,1,2,1,NULL,NULL),(3928,653818746002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','a-l-r2624367','a-l-r@e1.ru','Alexandr Senkevich','Kuibushev str.<br>house â„–121 apartment â„–23','Ekaterinburg','Sverdlovskaya obl','RUSSIAN FEDERATION','620026','79022797111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 01:47:49',0,NULL,8,1,17,0,NULL,NULL),(3929,653818716002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','a-l-r2624367','a-l-r@e1.ru','Alexandr Senkevich','Kuibushev str.<br>house â„–121 apartment â„–23','Ekaterinburg','Sverdlovskaya obl','RUSSIAN FEDERATION','620026','79022797111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 01:47:49',0,NULL,3,1,3,1,NULL,'50-70 æ£š  é€šç”¨å¡å£  2 RR815342215CN\r'),(3930,653818987002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0005',12.8,'hermeshine','nicdotnet','niccjd@gmail.com','Nic Duthie','17 Connock Street<br>Urangan','Hervey Bay','Queensland','AUSTRALIA','4655','0401924846','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-02 01:51:36',0,NULL,3,1,2,1,NULL,'1.6x2.1 èƒŒæ™¯å¸ƒ é»‘è‰²  1 '),(3931,653819415002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','fotoz09','zubpho@yahoo.com','zubeyr kureemun','7A, Paul et Virginie Street','Port-Louis','Port-Louis','MAURITIUS','00230','(230) 7683969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 01:51:44',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹ 1 '),(3932,712627740015,250600489459,'New Hairlight photostudio boom arm ',1,'',20.9,'hutongstore','tenderowicz123','rick.tz@hotmail.co.uk','Mr Rick Tenderowicz','96 Fathoms Reach','Hayling Island','Hampshire','UNITED KINGDOM','PO11 0RS','07507545900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 03:23:54',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR815342224CN\r'),(3933,614541807001,110489360129,'JueYing Lambency Flash Diffuser for Nikon SB600 SB800 ',1,'AB3306',22,'hermeshine','eighteenvision','fleaustar@hotmail.com','FrÃ©dÃ©ric Garneau','6304 St-AndrÃ©','MontrÃ©al','QC','CANADA','H2S2K5','(514) 686-8217','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 03:51:13',0,NULL,3,1,3,1,NULL,'çˆµå½±ç¢—ç½© P1   1 RR815342238CN\r'),(3934,653845759002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',46.99,'hermeshine','sp.f828','sp@kloda.com','Stephane Poirier','2130 Park','St-Hubert','QC','CANADA','J3Y4Y3','(450) 462-9166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 04:16:22',0,NULL,3,1,3,1,NULL,'40cm é—ªå…‰ç¯ç½©   1 RR815342241CN\r'),(3935,614547249001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','mivsr08','smruud@gmail.com','Svein Mikael Ruud','Vestre Furmyrvei 26','Ã…lesund','','NORWAY','6017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 04:26:51',0,NULL,3,1,2,1,NULL,NULL),(3936,653849209002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','fkaviani50','fk1002000@yahoo.com','Fred Kaviani','117c South Route 70','Marlton','NJ','UNITED STATES','08053-3024','(856) 396-2490','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 04:39:58',0,NULL,3,1,1,1,NULL,NULL),(3937,653850161002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','davevanrheenen','davidvanrheenen@yahoo.com','David Van Rheenen','1201 Enterprise Ave #701','League City','TX','UNITED STATES','77573','(832) 472-1744','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'echeckï¼Œ æ”¹ä¸ªåœ°å€å‘å§ LK016323065CN'),(3938,653855561002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',3,'AB1202',20.97,'hermeshine','jackjen006','p21ras@gmail.com','Jongyun Heo','700 Planetarium Place Room 351<br>Dept. of Chemistry and Biochemistry','Arlington','TX','UNITED STATES','76019','(817) 272-1076','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 05:26:35',0,NULL,3,1,1,1,NULL,'6662a å¿«è£…æ¿ 3 \ræ”¹ä¸ªåœ°å€LK016549104CN'),(3939,712662818015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'',4.5,'hutongstore','rjohnj','ryansexcellentadventure@hotmail.com','Ryan Jephcott','49 Hurst Court','Horsham','West Sussex','UNITED KINGDOM','RH12 2EW','07862990309','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 05:37:49',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(3940,614558459001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',20,'hermeshine','guru_lurks','mrcroft@gmail.com','David Croft','40 Gray St.','Woonona','New South Wales','AUSTRALIA','2517','0242849228','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-02 06:10:26',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹   2 RR815342255CN\r'),(3941,614569713001,110464615814,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',8.69,'hermeshine','cikuba','nafizreza@gmail.com','Nafiz Reza','4375 Fairlands Dr<br>Apt 2','Pleasanton','CA','UNITED STATES','94588-3444','(925) 895-3978','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 07:44:01',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…  æ— å­—  1 '),(3942,653888590002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','d_totzev','d_totzev@yahoo.com','Dimitar Totsev','Tapulintie 14 A 2','Kangasala','','FINLAND','36200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 09:42:31',0,NULL,3,1,2,1,NULL,NULL),(3943,653894945002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','thinredline2006','zhang_miaoyan@yahoo.com','Miaoyan Zhang','2118 Junction Ave','El Cerrito','CA','UNITED STATES','94530','','NoPaymentFailure','CheckoutComplete','Other','2011-01-02 10:12:35',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR815342167CN\r'),(3944,653917823002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.9,'hermeshine','habeebali2010','habeeeb@gmail.com','Habeeb Ali M. Al Maateeq/DHA 9090','14729 182nd St','Springfield Gardens','NY','UNITED STATES','11413-4028','966506805260','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-02 11:53:06',0,NULL,3,1,1,1,NULL,'301p ä¸€æ‹–äºŒ  1 '),(3945,698849771016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','sizmonz77','sizmonz@yahoo.com','Kiang Kim Lee','8 Ellendale Way','South Morang','Victoria','AUSTRALIA','3752','0394042616','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-02 12:06:36',0,NULL,3,1,2,1,NULL,NULL),(3946,653920608002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','i_fes','anabioz@list.ru','Igor Fesenko','Orangeva, 66','Dnipropetrovsk','','UKRAINE','49007','067-742-7256','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 12:09:26',0,NULL,3,1,3,1,NULL,'50cm æ£š   1 RR815342153CN\r'),(3947,653933852002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','odepropa','otso.alanko@gmail.com','Otso Alanko','Laurinpolku 4 B 20','JyvÃ¤skylÃ¤','','FINLAND','40500','+358407407733','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 12:54:52',0,NULL,3,1,4,1,NULL,'717ah   1 \rballhead $20\rYW863600105CN\r'),(3948,613585003001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',86.9,'hermeshine','zabousik','zabous@zabous.cz','Gabriela Homolova','Rabstejnska 49','Plzen','Czech Republic','CZECH REPUBLIC','32300','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 13:33:49',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ é»‘ç™½ç°ï¼‰  1 \rCP219437133CN\r'),(3949,653956358002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','615mikel','lovinma@bellsouth.net','Mike Lovin','1227 Coffee Avenue','Murfreesboro','TN','UNITED STATES','37129','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 14:11:27',0,NULL,3,1,1,1,NULL,NULL),(3950,698901124016,260660055035,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'',40,'hutongstore','xmartin86x','xmartin86x@yahoo.com','Low Martin','BLK 698C Hougang St 52 #03-31 Singapore 533698','Singapore','','SINGAPORE','533698','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-02 14:39:30',0,NULL,3,1,3,1,NULL,'10ç‰‡è£…  1\r58mm çŽ¯æž¶   1 RR815342272CN\r'),(3951,614674051001,110569963962,'New thicken Non Woven Fabric Backdrop 3m x 3m(10x10 ft)',1,'AO0018',45,'hermeshine','mivsr08','smruud@gmail.com','Svein Mikael Ruud','Vestre Furmyrvei 26','Ã…lesund','','NORWAY','6017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 15:05:51',0,NULL,3,1,3,1,NULL,'èƒŒæ™¯å¸ƒ ç™½è‰²  3mx3m   1\råŽšçš„ 1457RR815342723CN\r'),(3952,653978297002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','spettan80','wargert@hotmail.com','Petter Wargert','Dragarbrunnsgatan 66A','Uppsala','Uppsala','SWEDEN','75320','0704-822572','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 15:34:55',0,NULL,3,1,4,1,NULL,'ball head  $20 \rYW863684940CN\r'),(3953,614707073001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',92,'hermeshine','dr.abd','dr-abdallah-fr@wanadoo.fr','FDMJ C/O Dr.Milcent','17B rue de la glaciÃ¨re','Schiltigheim','Alsace','FRANCE','67300','0388196444','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 16:37:56',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚  1\r50-70 æ£š æ¬§æ ‡   1\r115w 220v   1 \rYW863684914CN\r'),(3954,614709541001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','hucho31.1978','zerho@msn.com','angel del alamo caÃ±amero ','calle monegros / 34 / 1c','leganes','Madrid','SPAIN','28915','679438307','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 16:40:47',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 RR815342065CN\r'),(3955,614713103001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','tolikid','toliknik@gmail.com','ANATOLIY NYKILCHYK','317 - 3160 CASORSO RD','KELOWNA','BC','CANADA','V1W 3L7','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 16:49:09',0,NULL,3,1,3,1,NULL,' åå…‰æ¿æ”¯æž¶   1 RR815342079CN\r'),(3956,614717163001,110531023352,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','popihmt','popihmt@hotmail.com','Hugo MaÃ±ez Tamariz','Avda/ Sierra de Aralar<br>nÂº21 / 2Âº C','san SebastiÃ¡n','PaÃ­s Vasco','SPAIN','20014','617222008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 16:58:23',0,NULL,3,1,2,1,NULL,NULL),(3957,654000080002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',5,'AA1301',12.2,'hermeshine','star031','eric.gueant@aliceadsl.fr','GuÃ©ant Eric','11 esplanade Sainte Germaine','Pibrac','Midi-PyrÃ©nÃ©es','FRANCE','31820','06.81.86.63.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 17:02:04',0,NULL,8,1,17,0,NULL,NULL),(3958,654000939002,120560203127,'72mm Lens lenscap for Canon Combined shipping discounts',2,'AA1303',5,'hermeshine','star031','eric.gueant@aliceadsl.fr','GuÃ©ant Eric','11 esplanade Sainte Germaine','Pibrac','Midi-PyrÃ©nÃ©es','FRANCE','31820','06.81.86.63.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 17:02:03',0,NULL,8,1,17,0,NULL,NULL),(3959,614700044001,110532007043,'67mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',2,'AA1302',5,'hermeshine','star031','eric.gueant@aliceadsl.fr','GuÃ©ant Eric','11 esplanade Sainte Germaine','Pibrac','Midi-PyrÃ©nÃ©es','FRANCE','31820','06.81.86.63.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 17:02:04',0,NULL,8,1,17,0,NULL,NULL),(3960,614700365001,110532007244,'77mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',2,'AA1304',5,'hermeshine','star031','eric.gueant@aliceadsl.fr','GuÃ©ant Eric','11 esplanade Sainte Germaine','Pibrac','Midi-PyrÃ©nÃ©es','FRANCE','31820','06.81.86.63.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 17:02:05',0,NULL,3,1,3,1,NULL,'58mm é•œå¤´ç›– canon   5\r72mm é•œå¤´ç›– canon   2\r67mm é•œå¤´ç›–  canon   2\r77mm é•œå¤´ç›–   canon   2 RR815342082CN\r'),(3962,614725085001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','vtectegs','vtectegs@hotmail.com','John P Strott','625 Marine St','La Jolla','CA','UNITED STATES','92037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 17:17:29',0,NULL,3,1,1,1,NULL,NULL),(3963,614727832001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','gregajekos','psiho1@gmail.com','Grega JekoÅ¡','ÄŒanje 25','Blanca','Sevnica','SLOVENIA','8283','051248845','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 17:24:28',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815342096CN\r'),(3964,654048175002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ofigetj','zjamka@inbox.lv','Julija Antonovica','Staraja Rusas 5 - 23','Riga','','LATVIA','LV-1048','+37126595119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 18:00:34',0,NULL,3,1,2,1,NULL,NULL),(3965,614782514001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','jscraire','piccolo999000@hotmail.com','Jean-SÃ©bastien Scraire','12 Rue Deschambault','Ste-ThÃ©rÃ¨se','QC','CANADA','J7E3N7','(450) 420-9974','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 19:05:53',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rCP219437116CN\r'),(3966,654095995002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','wzwlwh','kgrweiss9@roadrunner.com','Gary Weiss','235 Smoke Tree Ave','Oak Park','CA','UNITED STATES','91377','(818) 399-2989','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 19:24:21',0,NULL,3,1,1,1,NULL,''),(3967,654097105002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','ditatev','ditatev61@mail.ru','Yury Ditatev','severnoe chertanovo, h 5 \"b\", flat 258','Moscow','Russia','RUSSIAN FEDERATION','117648','+79035846093','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 19:26:36',0,NULL,3,1,3,1,NULL,'sony a1 å•è‚©åŒ…   1RR815342105CN\r'),(3968,654105623002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','windslave2110','ghwilson@gmail.com','Gregory H Wilson','1982 Dakin Ave','Menlo Park','CA','UNITED STATES','94025-6045','(650) 561-9817','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 19:42:37',0,NULL,3,1,1,1,NULL,'90th è‚©å¸¦   1 '),(3969,712982020015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','buysellprofit_bsp','buysellprofit@live.co.uk','Lisa Whitehead','32 Regent Street Willenhall','Wolverhampton','West Midlands','UNITED KINGDOM','wv13 1dj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 19:47:03',0,NULL,3,1,2,1,NULL,NULL),(3970,713009529015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'',3.62,'hutongstore','jose_luis_t','joseluistrullo@yahoo.es','JosÃ© Luis Trullo Herrera','Alberche 3, 3Âº Dcha.','Sevilla','AndalucÃ­a','SPAIN','41005','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-02 20:21:26',0,NULL,3,1,2,1,NULL,NULL),(3971,713010134015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'',26,'hutongstore','businjka','marija.sinutkina@inbox.lv','Marija Sinutkina','4a Ballysimon crescen Fairgreen','Limerick','','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-02 20:22:00',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 RR815342670CN\r'),(3972,654016523002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','09klaasjan','kjschraa@gmail.com','Klaas Jan Schraa','Slingerbeek 21','ZWARTSLUIS','','NETHERLANDS','8064JE','06-10657474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 20:36:27',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(3973,654133701002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','watchthis32','lenz32@gmail.com','Len Zielenski','10124 Haines Canyon Ave','Tujunga','CA','UNITED STATES','91042','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 20:38:49',0,NULL,3,1,1,1,NULL,NULL),(3974,614830067001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','snezokk2009','violet@planet.ee','Natalja Grigorjeva','Kivikalme pÃµik 2','Kopli kÃ¼la','Harjumaa','ESTONIA','75321','+37253482549','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 20:38:51',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ ç™½ç›’  1 RR815342025CN\r'),(3975,614834750001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','sezeryadigar10','sezeryadigar@hotmail.com','Sezer Yadigar','telsiz mah. 85/10 sk. no:2 d:3<br>zeytinburnu','istanbul','Marmara','TURKEY','34025','+905556848606','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 20:51:13',0,NULL,8,1,17,0,NULL,NULL),(3976,654138080002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','sezeryadigar10','sezeryadigar@hotmail.com','Sezer Yadigar','telsiz mah. 85/10 sk. no:2 d:3<br>zeytinburnu','istanbul','Marmara','TURKEY','34025','+905556848606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 20:51:13',0,NULL,3,1,5,1,NULL,'æ¡Œé¢ç¯   2\rèƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰ 2m  1 \rCP219437102CN\r'),(3977,699126804016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'',7.52,'hutongstore','gastate09','rhagen1@student.gsu.edu','Rashad Hagen','240 North Ave Apt# 1316','Atlanta','GA','UNITED STATES','30308','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-02 21:18:51',0,NULL,3,1,1,1,NULL,NULL),(3978,654158734002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','jalstton','jalston@wanadoo.es','Antonio Teva Ruiz','Porto, 5 1Âº 3Âª','Sabadell','CataluÃ±a','SPAIN','08206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 21:35:56',0,NULL,3,1,2,1,NULL,NULL),(3979,614872736001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','vaiaphay','ashleypha@verizon.net','Khambeng Aphayaraj','1111 Entrada dr','oxnard','CA','UNITED STATES','93030-2592','','NoPaymentFailure','CheckoutComplete','Other','2011-01-02 22:30:42',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR815342697CN\r'),(3980,713078541015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',1,'',3.38,'hutongstore','porsche94462','ianbattlezone@hotmail.co.uk','ian price','78 chiltern road','st albans','Hertfordshire','UNITED KINGDOM','al4 9tb','01727762134','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 22:35:04',0,NULL,3,1,2,1,NULL,' '),(3981,614874934001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3307',9,'hermeshine','scroc_fr','scroc@hotmail.com','Guillaume ALEXANDRE','68, les Casses Vivert','La Batie Neuve','Provence-Alpes-CÃ´te d\'Azur','FRANCE','05230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 22:37:38',0,NULL,3,1,3,1,NULL,' 77mm uv   2\rå¹¿è§’æ‰˜æž¶  1RR815342017CN\r'),(3982,614878169001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','drx-604','drx604@yahoo.com','Dennis Taruc','#9 8250 158th Street','Surrey','BC','CANADA','V4N0R5','(604) 501-9189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 22:46:50',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon  1'),(3983,713090773015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','icouldntfindnemo','mrdavidpchapman@yahoo.co.uk','David Chapman','P&O, Suite 12, Alcora Building Mucklows Hill','Halesowen','West midlands','UNITED KINGDOM','B62 8DG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 23:05:01',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  nikon  1 '),(3984,698886290016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','mortija2004','mortija2004@hotmail.com','Caron Mortimer','2 Pettits Boulevard','Romford','Essex','UNITED KINGDOM','RM1 4PL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 23:21:04',0,NULL,3,1,2,1,NULL,'æœºèº«ç›–/é•œå¤´åŽç›–  canon  1 '),(3985,713092394015,250599389839,'55mm CPL Circular Polarizing Filter 55 CPL Green.L New',2,'',6.76,'hutongstore','beijer82','stefan.beijer@surfbox.se','Stefan Beijer','BjÃ¤rka Lund 2','Skara','','SWEDEN','53294','0702917441','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-02 23:26:47',0,NULL,3,1,2,1,NULL,NULL),(3986,654196782002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','evita_11','e.giger@hotmail.com','Eva Giger','LÃ¼rlibadstrasse 30','Chur','','SWITZERLAND','7000','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 23:27:21',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 æ½˜'),(3987,654200836002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','vinhtran75','vinhtran@hotmail.ca','vinh tran','7-11745 126 ST NW','Edmonton','AB','CANADA','T5M 0S1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 23:41:50',0,NULL,3,1,3,1,NULL,'sf18  nikon sb800   1 RR815342048CN\r'),(3988,654211939002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','chitalina','denisesaura@gmail.com','Denise Saura','Rua Visconde de Nacar, 1200 / 105<br>Bairro Centro','Curitiba','PR','BRAZIL','80410-201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-03 00:19:32',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR815342051CN\r'),(3989,713142299015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','mapnunes77','mapnunes@gmail.com','Marco Nunes','Av. das ForÃ§as Armadas, 125, 6Âº SECIL - CTRI','Lisboa','Lisboa','PORTUGAL','1600-079','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-03 01:36:22',0,NULL,3,1,2,1,NULL,NULL),(3990,654238387002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','joaolferreira','boizaum@gmail.com','Joao Lucas Ferreira','Av Buenos Aires 139','Pocos de Caldas','Minas Gerais','BRAZIL','37701367','553588689301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 01:51:03',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´ æ¬§æ ‡  1 '),(3991,713157067015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'',5.8,'hutongstore','pumalives','ianbowers@usa.net','Ian Bowers','3 Melbourne Square Leconfield','Beverley','East Riding of Yorkshire','UNITED KINGDOM','HU17 7LG','07947822012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 02:22:42',0,NULL,3,1,2,1,NULL,'72mm æ¸å˜ç°   1 '),(3992,654247865002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','123botas123','desipp@msn.com','Juan RamÃ³n PÃ©rez Pozo','C/RÃ­o Tajo 10, 8ÂºD','AlcorcÃ³n','Madrid','SPAIN','28923','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-03 02:23:00',0,NULL,3,1,4,1,NULL,'ballhead  $20 \rYW863684925CN\r'),(3994,614952661001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','global-security','jordan@shattergard.com','ShatterGARD- Frankel','3065 McCall Dr<br>Ste 3','Atlanta','GA','UNITED STATES','30340','(888) 380-9350','NoPaymentFailure','CheckoutComplete','Other','2011-01-03 03:28:06',0,NULL,3,1,1,1,NULL,NULL),(3995,713202777015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'',4.5,'hutongstore','stracj','stracj@btinternet.com','John Strachan','EBC Civic Centre, High Street','Esher','Surrey','UNITED KINGDOM','KT10 9SD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 05:23:01',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(3996,654292105002,120618815419,'TianYa 77mm ND8 filter New 77 Neutral Density Grey NIB',1,'AA2314',7.9,'hermeshine','irrubesco','chrislueshing@gmail.com','Christopher  Lue-Shing','19 Valemount Way','Aurora','ON','CANADA','L4G7S7','(905) 726-4055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 05:53:17',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯ 77mm nd8   1 '),(3997,654236832002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','amalia0910','miss.amalia@hotmail.com','Amalia Wakid','98 Lakemba Street<br>Lakemba','Sydney','New South Wales','AUSTRALIA','2195','0297033555','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-03 06:03:48',0,NULL,3,1,3,1,NULL,'1.6x2.1m èƒŒæ™¯å¸ƒ 2\rç™½è‰²ï¼Œ ç°è‰² RR815342683CN\r'),(3998,654293668002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','glamourbomb','burncast@gmail.com','GlamourBomb + BURNcast','7005 Woodley Ave','Van Nuys','CA','UNITED STATES','91406-3924','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 06:06:04',0,NULL,3,1,1,1,NULL,'\r '),(3999,614989730001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','terencen60','terenceng@telus.net','Terence Ng','4450 Fraserside Drive','Richmond','BC','CANADA','V6V 2L7','(604) 522-8319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 07:49:58',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(4000,614989576001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','capitan.jack','kiril.kirilov.bg1@gmail.com','Kiril Kirilov','1 Kiril Tzonev Str.','Sofia','','BULGARIA','1172','359885730714','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 07:50:21',0,NULL,8,1,17,0,NULL,NULL),(4001,614989639001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',4,'AKT007',75.96,'hermeshine','capitan.jack','kiril.kirilov.bg1@gmail.com','Kiril Kirilov','1 Kiril Tzonev Str.','Sofia','','BULGARIA','1172','359885730714','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 07:50:22',0,NULL,3,1,5,1,NULL,'ä¸€è½¬å›› ç¯å¤´  2\r45w    8 \rCP219487894CN\r'),(4004,654307261002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','fanxun2009','fanxun@hotmail.com','Xun Fan','2102 Oak St<br>Apt 1','Los Angeles','CA','UNITED STATES','90007-6001','(626) 354-3877','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 08:07:44',0,NULL,3,1,1,1,NULL,NULL),(4005,654317560002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0005',12.8,'hermeshine','tropheus72','bluetang@iinet.net.au','Mr S Faulkner','5/9 Hamilton Street','Osborne Park','Western Australia','AUSTRALIA','6017','0412098071','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-03 09:15:30',0,NULL,3,1,2,1,NULL,'1.6x2.1 èƒŒæ™¯å¸ƒ  1\rç™½è‰² '),(4006,713240508015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','red_october','harrypilling2@aol.com','Tony Thornton','18 Witton Road Duston','Northampton','Northamptonshire','UNITED KINGDOM','NN56TS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 09:17:34',0,NULL,3,1,2,1,NULL,'rs-s1   1 '),(4007,615000999001,110534332901,'New Flash Hot Shoe Adapter YN-H3 for Alpha and Minolta',2,'AB3318',15.8,'hermeshine','miguel.barreiro','miguel_barreiro_docampo@hotmail.com','Miguel Barreiro Docampo','Barrio do Redondo<br>117A','MoaÃ±a','Galicia','SPAIN','36950','654715233','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 09:17:45',0,NULL,3,1,2,1,NULL,'æ°¸è¯º sony è½¬æ¢å™¨  2 '),(4008,615006805001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','cheetahnl','frankderoos69@hotmail.com','Frank de Roos','Hendrik Piersonstraat 1','Zetten','','NETHERLANDS','6671CK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 09:50:46',0,NULL,3,1,2,1,NULL,NULL),(4009,615005912001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','sukie057','sukitha_ranaba@yahoo.com','Sukitha Udugamasooriya','369/23, 2nd Lane,<br>Shanthi Mawatha,','Makumbura, Pannipitiya','Colombo','SRI LANKA','10230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 10:06:15',0,NULL,3,1,2,1,NULL,'nikon-52mm åæŽ¥çŽ¯  1 '),(4010,713256998015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',4,'',7.52,'hutongstore','webgeoff1961','g_a_harrison@hotmail.com','G. Harrison','Carril de Don Cecilio 11 Alfacar','Granada','AndalucÃ­a Ceuta y Melilla','SPAIN','18170','661855676','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-03 10:32:00',0,NULL,3,1,2,1,NULL,NULL),(4011,654334123002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','afonja2000','rusimport@brevet.se','Maxim Agafonov','Lofotengatan 21','Kista','none','SWEDEN','16433','+46739989420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 10:50:03',0,NULL,3,1,2,1,NULL,'6662aå¿«è£…æ¿  1 '),(4012,654337909002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','enzo22071985','enzo2207@hotmail.com','Renaud Holtzinger','11 rue Ste CÃ©cile','Neufchef','Lorraine','FRANCE','57700','03.82.55.39.71','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-03 11:16:28',0,NULL,3,1,3,1,NULL,'è‚©æž¶ 1 \rRR815342992CN\r'),(4013,654339803002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','clivealpine14011970','alpine14011970@yahoo.com.au','Clive Baumann','43 Imperial Pde','Labrador','Queensland','AUSTRALIA','4215','0755376576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 11:18:59',0,NULL,3,1,2,1,NULL,'58mm æ¸å˜ç°   1 '),(4014,654339504002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dvdark','pichanjr@yahoo.com','pichan jaraswatcharin','1424/234 Soi Prachasongkhro16<br>Dindaeng Hwaikwang','bangkok','bangkok','THAILAND','10400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 11:19:18',0,NULL,3,1,2,1,NULL,''),(4015,615025628001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','andonigruevski','deepandblue9@gmail.com','andoni gruevski','marrbella 20 piso 2 puerta 209','palma del mallorca','Baleares','SPAIN','07610','658472122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 11:30:12',0,NULL,3,1,2,1,NULL,NULL),(4016,653927977002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','alcintas','alcintas@gmail.com','Antonio Luis Cintas GarcÃ­a','TomÃ¡s Romero de Castilla nÂº4 1ÂºA','Badajoz','Badajoz','SPAIN','06011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-03 12:07:02',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\rbåº§   2\ræŸ”å…‰ä¼ž   2 \rlight kit  $25\rYW864144044CN\r'),(4017,654356503002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','palaeuffer','palaeuffer@hotmail.com','Pierre-Antoine Laeuffer','25 (flat 3) Colingwood street','Auckland (freemans Bay)','','NEW ZEALAND','1011','(022) 692-5935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 12:38:59',0,NULL,3,1,2,1,NULL,NULL),(4018,654366211002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','ojellav','roger_vallejo@hotmail.com','Roger Vallejo','2905 Bushnell Dr','Austin','TX','UNITED STATES','78745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 13:21:44',0,NULL,3,1,1,1,NULL,' '),(4019,654366709002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','kapicka','kapicka@msn.com','Kapicka','1609 41st St','Sacramento','CA','UNITED STATES','95819','(916) 705-3160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 13:23:54',0,NULL,8,1,17,0,NULL,NULL),(4020,654366475002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','kapicka','kapicka@msn.com','Kapicka','1609 41st St','Sacramento','CA','UNITED STATES','95819','(916) 705-3160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 13:23:55',0,NULL,3,1,1,1,NULL,'67mm é•œå¤´ç›– canon  1\ræœºèº«ç›–/é•œå¤´åŽç›– canon 1 '),(4021,615051540001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','waviralw','ford_10avi@hotmail.com','Ajay kochhar','# 24 denbigh ave<br>Mt.Roskill','Auckland','OR','NEW ZEALAND','1041','0212615916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 13:27:07',0,NULL,3,1,2,1,NULL,NULL),(4022,713305853015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',2,'',3.76,'hutongstore','owen.thomas','owen@thethumbwebsite.com','Owen Thomas','Thumb 63 Westgate Rd','Newcastle upon Tyne','Tyne & Wear','UNITED KINGDOM','NE1 1SG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 13:36:22',0,NULL,3,1,2,1,NULL,NULL),(4023,614979249001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','sweetbabylaine11','sweetbabylaine11@yahoo.com','CHRISTIAN BALUYUT','3394 Redpath Circle','Mississauga','ON','CANADA','L5N8R8','(905) 820-1240','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 14:05:24',0,NULL,3,1,2,1,NULL,NULL),(4024,654378628002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bigbird11','glmarkle@energage.com','Gary Markle','327 Riverview Dr<br>Unit 5728','Ellijay','GA','UNITED STATES','30540-5486','(706) 636-3429','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 14:18:48',0,NULL,3,1,1,1,NULL,NULL),(4025,615066231001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','guitar4pax','kidz2raise@gmail.com','David Hanvey','404 Shoemaker Dr','Chesapeake','VA','UNITED STATES','23325-4825','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 14:29:34',0,NULL,3,1,1,1,NULL,NULL),(4026,713328887015,250692240830,'Wireless Remote Control for Olympus E-420/E-410/E-400',1,'',11.47,'hutongstore','eavi7102','medi11158@telefonica.net','Emilio Avila Marquez','Avinguda del Montgo 16 bajo','paiporta','Comunidad Valenciana','SPAIN','46200','677382249','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-03 14:51:25',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ E2    1 '),(4027,615074556001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','jakubnozicka','nozicka.jakub@gmail.com','Jakub Nozicka','U Dvora 1076','Uherske Hradiste','','CZECH REPUBLIC','68605','00420-723-131-668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 15:01:31',0,NULL,3,1,2,1,NULL,NULL),(4028,615077581001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','zens_nl','zen_stolk@hotmail.com','Jaap Stolk','EMI Music<br>Paul van Vlissingenstraat 10-C','Amsterdam','','NETHERLANDS','1096 BK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 15:09:03',0,NULL,3,1,2,1,NULL,NULL),(4029,614818471001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','terechka','terenaz@bigpond.com.au','Theresa Zagorski','12 Daffodil Court<br>GOWANBRAE','Melbourne','Victoria','AUSTRALIA','3043','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 15:15:36',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… Nikon  1 '),(4030,615083615001,110414472986,'Remote Cord Shutter Release for Nikon D200 D3 = MC-30',1,'AA3207',4.18,'hermeshine','chacablue','carolannphelps@sbcglobal.net','Carol Ann Phelps','309 Quinnipiac Ave','North Haven','CT','UNITED STATES','06473','(203) 752-9925','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 15:33:07',0,NULL,3,1,1,1,NULL,'RS-N1   1 '),(4031,615088798001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','mivsr08','smruud@gmail.com','Svein Mikael Ruud','Vestre Furmyrvei 26','Ã…lesund','','NORWAY','6017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 15:48:27',0,NULL,3,1,3,1,NULL,'å•ç¯å¤´æ£š  æ¬§æ ‡    1 \rRR815342913CN\r'),(4032,654410460002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','gontzal84','gontzal20@hotmail.com','Gonzalo Rubinos Artolozaga','arebeta bidea 10 bajo','Berango','PaÃ­s Vasco','SPAIN','48640','946680889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 16:05:28',0,NULL,3,1,4,1,NULL,'6662a   1 \rYW864144033CN\r'),(4033,615094514001,110532007553,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','kerkuan','shellshocking@yahoo.com','Ho Pang Cheng','118, Serangoon Ave 3, #14-09','default','','SINGAPORE','554773','96421046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 16:09:16',0,NULL,3,1,11,1,NULL,'æ°”å¹+å¸ƒ   1 '),(4034,654420449002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','corndogpilot','acorn@progress.com','Aaron Corn','141 Wallace Hill Rd','Townsend','MA','UNITED STATES','01469','(978) 597-0123','NoPaymentFailure','CheckoutComplete','Other','2011-01-03 16:35:46',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRR815342961CN\r'),(4035,654425567002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ryanisaitebruh','aitebruh@yahoo.com','Ryan Ricklefs','1796 Dexter Oaks Ln<br>Apt 204','Cordova','TN','UNITED STATES','38016-1581','(901) 757-2985','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 16:51:38',0,NULL,3,1,1,1,NULL,NULL),(4036,615113093001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','soundcoast','adriankangkl@gmail.com','Adrian Kang','Blk. 22 Eunos Crescent #16-3003','Singapore','','SINGAPORE','400022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 17:02:12',0,NULL,3,1,11,1,NULL,'å“èƒœ3.0   1 '),(4037,654429958002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','evilkido','evil_kid_o@hotmail.com','Alberto Juarbe','1932 Calle Perafan Rivera','San Juan','PR','UNITED STATES','00926-7744','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 17:03:01',0,NULL,3,1,1,1,NULL,NULL),(4038,615119309001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',12,'AA1309',29,'hermeshine','t-minustom','thomjrogers@tminusproductions.com','Thom Rogers','40213 N La Cantera Dr','Phoenix','AZ','UNITED STATES','85086-2973','(928) 699-4041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 17:18:26',0,NULL,3,1,1,1,NULL,NULL),(4039,615136246001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','losangeles8264','csinetpro@gmail.com','Ingo Lehmann','6331 Hollywood Blvd<br>Ste 1200','Los Angeles','CA','UNITED STATES','90028-6340','(323) 960-3500','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 18:05:31',0,NULL,3,1,1,1,NULL,'éº‚çš®  3 '),(4040,699483423016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'',5.8,'hutongstore','aldav33','ales.vym@tiscali.cz','Ales Vymetal','Zlutava 63','Napajedla','Czech Republic','CZECH REPUBLIC','76361','604855020','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-03 18:09:37',0,NULL,3,1,2,1,NULL,'77mm æ¸å˜ç°  1 '),(4041,654467635002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','matje56','matje_kater@hotmail.com','Matthijs Kater','Pr. Bernhardlaan 36','maartensdijk','','NETHERLANDS','3738 DP','06-17194733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 18:37:45',0,NULL,3,1,2,1,NULL,NULL),(4042,699505471016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'',120,'hutongstore','adbidonline','andylong1969@googlemail.com','Andrew Long','6 Sancroft Way','Fressingfield','Eye, Suffolk','UNITED KINGDOM','IP21 5QN','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-03 18:53:32',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´ æ£š  è‹±æ ‡   2\r45w   8\råŒ…   1\rlighting kit  $30 \rYW864144022CN\r'),(4043,654476345002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','northshore96712','taydork@hotmail.com','Taylor Vollrath','58-130 Kamehameha Hwy','Haleiwa','HI','UNITED STATES','96712-9714','(808) 638-7101','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 18:57:45',0,NULL,3,1,1,1,NULL,NULL),(4044,615150726001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','rinse68','rina@bcbnet.dk','Rina Torp','Soeborg Hovedgade 42 C, 4. tv','Gladsaxe','Gladsaxe','DENMARK','2860','(0045) 28122954','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 18:59:41',0,NULL,3,1,2,1,NULL,'éº‚çš®   1 '),(4045,654479506002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','grnath09','ranganath.gogineni@gmail.com','Ranganadh Gogineni','1427 Valley Lake Dr<br>Apt 404','Schaumburg','IL','UNITED STATES','60195-3629','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 19:06:46',0,NULL,3,1,1,1,NULL,NULL),(4046,615176317001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','jen_n_lena','gowithwindap@gmail.com','Jieyi Xu','1808 Van Wickle Dr','Franklin Park','NJ','UNITED STATES','08823-2613','(816) 256-1206','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 19:38:42',0,NULL,3,1,1,1,NULL,NULL),(4047,615194241001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',2,'AA2326',21.6,'hermeshine','blueandy963','andy@jobbii.fsnet.co.uk','ANDREW M JOBBINS','25 HONITON WAY ALDRIDGE','WALSALL','West Midlands','UNITED KINGDOM','WS9 0JS','','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-01-03 20:21:58',0,NULL,3,1,3,1,NULL,'cpl   2 \rRR815342975CN\r'),(4048,713502454015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'',3.62,'hutongstore','andy7777777rugby','andyread40@hotmail.com','Andy Read','Greenham A1/A2 Gellihirion Ind Est','Pontypridd','Mid Glamorgan','UNITED KINGDOM','CF37 5SX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 21:01:50',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶   1 '),(4049,654529980002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','kallirae21','kallirae21@yahoo.com','Kalli Sterling','33 Alamosa Dr','Trophy Club','TX','UNITED STATES','76262','(817) 490-5149','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 21:11:19',0,NULL,3,1,1,1,NULL,NULL),(4050,654539510002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','beautyhest','bjorn.setekleiv@powermail.no','BjÃ¸rn Setekleiv','Anders Henriksensvei 10','SaltrÃ¸d','','NORWAY','4815','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 21:30:44',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶   1\r2m ç¯æž¶   1 \rreflector holder   $20\rYW864144011CN\r'),(4051,615225282001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','pia_kl','siri.krohn@gmail.com','Siri Alice Krohn','Pegasusveien 21','TÃ¸nsberg','','NORWAY','3113','4793267161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 21:42:42',0,NULL,3,1,2,1,NULL,'æ°”å¹+å¸ƒ   1 '),(4052,713522845015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'',3.76,'hutongstore','peters3298','petersaunders@nhs.net','Peter Saunders','3 Woodperry Hill Woodperry','Oxford','Oxfordshire','UNITED KINGDOM','OX33 1AL','01865351045','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 21:44:37',0,NULL,3,1,2,1,NULL,NULL),(4053,615226498001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','gemplayer','cs_support@gemplayer.com','Pongchanok Poonnotok','940/103 Soi Udomsuk56','Bangna','Bangkok','THAILAND','10260','(084)121-3132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 21:47:50',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´   1 \rRR815342989CN\r'),(4055,615230975001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','charlieking20','charlieking20@hotmail.com','karine brousseau','1474    46rue','shawinigan','QC','CANADA','g9n5b8','(819) 539-6024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 22:01:22',0,NULL,3,1,2,1,NULL,'1.6x2.1 èƒŒæ™¯å¸ƒ  ç™½è‰²  1 '),(4056,615232872001,110532007553,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','cubebleu','imwt@hotmail.com','Mathieu Pelletier','1-3620 Henri-Weber','Trois-Rivieres','QC','CANADA','G8Y6H1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 22:04:26',0,NULL,3,1,2,1,NULL,'æ°”å¹+ å¸ƒ   1 '),(4057,654557443002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','mapleridgeauction','sales@mapleridgeauction.com','Maple Ridge Auction','21730 121 Ave','Maple Ridge','BC','CANADA','V2X 3S6','(604) 805-1148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 22:20:31',0,NULL,3,1,2,1,NULL,'115w 110v  1 '),(4058,713538912015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.58,'hutongstore','beata1980s','kstrycharz@op.pl','Beata Pastuszak','Flat 4 Chapel House Club Lane','Halifax','West Yorkshire','UNITED KINGDOM','hx2 8ae','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 22:21:17',0,NULL,3,1,2,1,NULL,NULL),(4059,654567443002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ksalicat','alisonebright@yahoo.com','Alison Ebright','6041 Locust St','Kansas City','MO','UNITED STATES','64110','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 22:57:04',0,NULL,3,1,1,1,NULL,NULL),(4060,654570960002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','elysiachoo','chooeunzi@naver.com','Elysia Choo','201 Husson Ave<br>Apt T4','Bangor','ME','UNITED STATES','04401-3242','(818) 454-0637','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 23:06:12',0,NULL,3,1,1,1,NULL,NULL),(4061,615255537001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','yamahagreg','shellcullen@hotmail.com','Shelley Cullen','N7870 Creekside Drive','Sherwood','WI','UNITED STATES','54169','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 23:22:57',0,NULL,3,1,1,1,NULL,NULL),(4062,654578114002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','tiancew','wangtiance@gmail.com','Tiance Wang','10 Lawrence Dr<br>Apt 202','Princeton','NJ','UNITED STATES','08540-7139','(609) 865-6855','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 23:33:12',0,NULL,3,1,1,1,NULL,NULL),(4063,615264398001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',3,'AA1204',4.97,'hermeshine','henzmeeali','henzmee@yahoo.com','MdRapi Jomain','No 12,Lot 10917<br>Taman Selasih Perdana Fasa 2','Dungun','Terengganu','MALAYSIA','23000','013-9375010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 23:58:26',0,NULL,3,1,2,1,NULL,'çƒ­é´ç›– 3 '),(4064,615281462001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','esp0715','epoysp@yahoo.com','efren san pedro','10063 Canyon Hills Ave','las vegas','NV','UNITED STATES','89148-7646','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 01:09:43',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(4065,713593273015,250643703886,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'',7.99,'hutongstore','n-gauge-2topcat2','duncandown@aol.com','  CLIVE THORNE','LAHAI-ROI BORSTAL AVENUE','WHITSTABLE','KENT','UNITED KINGDOM','CT5 4NX','01227275389','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 01:11:25',0,NULL,3,1,2,1,NULL,'1.6x2.1 èƒŒæ™¯å¸ƒ ç™½è‰²  1 '),(4066,699665043016,260660053578,'New Pro Photo Vest for all DSLR fans Size: XL',1,'',19.5,'hutongstore','shaw_bob','shaw_bob@hotmail.com','Robert Shaw','c/o Ihnen Electronics 236 Battlefield Road','Battlefield','Glasgow','UNITED KINGDOM','G42 9HN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 01:41:21',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ å†¬å¤  xl   1\råŽŸæ¥ç°è‰²çš„é‚£æ¬¾ \rRR815343009CN\r'),(4067,615043713001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','kurtsin','kerhhk2000@yahoo.com','Haun Keey Kerh','63 Tampines Ave 1 #13-06 The Tropica<br>Singapore 529777','default','','SINGAPORE','529777','6597847212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 01:53:35',0,NULL,3,1,11,1,NULL,'å°å·å†…èƒ†åŒ…  nikon   1'),(4068,654619392002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','mtg-978','probbob@gmail.com','Connor Scanlon','178 Sterling Rd','Princeton','MA','UNITED STATES','01541-1201','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-04 02:24:31',0,NULL,3,1,1,1,NULL,'58mm æ¸å˜ç°  1 '),(4069,654624184002,120571006893,'Green.L 67mm Neutral Density ND8 Filter  67 D90 D300s',1,'AE2312',6.7,'hermeshine','trixot23','daniel.hedberg92@hotmail.com','Daniel Hedberg','alftavÃ¤gen 58','BollnÃ¤s','BollnÃ¤s','SWEDEN','82130','0705267814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 02:42:34',0,NULL,8,1,17,0,NULL,NULL),(4070,654623207002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','trixot23','daniel.hedberg92@hotmail.com','Daniel Hedberg','alftavÃ¤gen 58','BollnÃ¤s','BollnÃ¤s','SWEDEN','82130','0705267814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 02:42:34',0,NULL,3,1,2,1,NULL,'80cm 2in1 åå…‰æ¿ 1\r67mm ND8   1 '),(4071,654631558002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','nonefilm85','j.hanna.filmmaker@gmail.com','Jay Hanna','po box 4163','valley village','CA','UNITED STATES','91617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-04 03:07:46',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹   1 '),(4072,654641157002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','alancole2000','alan@alancole.com','Alan Cole','17411 Kirstin Ct','Olney','MD','UNITED STATES','20832-2542','(301) 794-1131','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 03:52:43',0,NULL,8,1,17,0,NULL,NULL),(4073,615317108001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',2,'AA1307',5,'hermeshine','alancole2000','alan@alancole.com','Alan Cole','17411 Kirstin Ct','Olney','MD','UNITED STATES','20832-2542','(301) 794-1131','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 03:53:41',0,NULL,3,1,1,1,NULL,'67mm é•œå¤´ç›–  nikon  2\r77mm é•œå¤´ç›–  nikon  1 '),(4074,615324771001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','kian0212','acg1612@optonline.net','ANDY DEGUZMAN','209 Comly R. Apt. G-13','Lincoln Park','NJ','UNITED STATES','07035','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 04:34:50',0,NULL,3,1,1,1,NULL,NULL),(4075,615325298001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','tarabaman','masiegel.esq@gmail.com','Marcus A Siegel','35 James Street<br>Windsor','Melbourne','Victoria','AUSTRALIA','3181','0395211177','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-04 04:41:27',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰  1 \rbackground support $20\rYW864144000CN\r'),(4076,654654074002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','thomasjavier','thomasjcastillo@gmail.com','Thomas Castillo','445 S 5th Ave','Tucson','AZ','UNITED STATES','85701-2446','(520) 403-1467','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-04 05:08:44',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹   2 '),(4077,615331038001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','manna1722','manna1722@aol.com','Anna Kearns','4869 Village Gardens Dr.','Sarasota','FL','UNITED STATES','34234','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 05:15:02',0,NULL,3,1,2,1,NULL,'Thomas Richard Meszaros\rBudapest Horanszky u. 6\r1085 Hungary \r\r'),(4078,654660397002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','fritz4003','alphy27@cox.net','James Olivier','123 Evergreen St','Providence','RI','UNITED STATES','02906-2510','(401) 527-4238','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-04 05:54:42',0,NULL,3,1,1,1,NULL,NULL),(4079,654679053002,120601698743,'Canon 52mm Reverse Adapter 450D 50mm 1.8 500D Macro',1,'AA1207',4.4,'hermeshine','xtrobe','xtrobe@gmail.com','Reamur David','32 Viceroy St., East Fairview','Quezon City','Metro Manila','PHILIPPINES','1118','6325834754','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 08:21:20',0,NULL,3,1,2,1,NULL,NULL),(4080,654675791002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','nina-0047','ninae-k@online.no','nina karlsen','godÃ¸ynes','tverlandet','bodÃ¸','NORWAY','8050','004790293266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 08:39:11',0,NULL,3,1,3,1,NULL,'50-70 å½±è§†ç¯æ£š å¡‘æ–™å¡å£   1 \rRR815341303CN\r'),(4081,713701759015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','alanreed53','alanreed53@talktalk.net','Alan Reed','17 Postwick Lane, Brundall','Norwich','Norfolk','UNITED KINGDOM','NR135RQ','01603713216','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 09:49:35',0,NULL,3,1,2,1,NULL,NULL),(4082,713709858015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',2,'',3.76,'hutongstore','rudomadar','rudo.madar@gmail.com','Rudolf Madar','Ovrucska 12','Kosice','Slovakia','SLOVAK REPUBLIC','04022','421902139908','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 10:25:31',0,NULL,3,1,2,1,NULL,NULL),(4083,654698797002,120601700210,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','arojasb','arojasb76@gmail.com','Antonio Rojas Borrego','Paseo la Florida, 70A 1Âº1Âº','Santa Perpetua de Mogoda','CataluÃ±a','SPAIN','08130','935742234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 10:26:48',0,NULL,3,1,4,1,NULL,'æ¡Œé¢ç¯   2 å¥—\rç¯æž¶+ç¯å¤´ \rYW864143974CN\r'),(4084,699771254016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',38,'hutongstore','jphotographyb','jamesbianchi88@gmail.com','James Bianchi','13, Olive Street The Gardens','St Julains','Malta','MALTA','stj 1953','0035621359413','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 10:30:06',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶    1 \rRR815341215CN\r'),(4085,654701966002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','chitalina','denisesaura@gmail.com','Jason Silva','Rua Visconde de Nacar, 1200 / 105 Bairro Centro','Curitiba','PR','BRAZIL','80410-201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 10:45:20',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§    1\ræŸ”å…‰ä¼ž    1 \rRR815341229CN\r'),(4086,654703351002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','niktos26','jozef.hanak@gmail.com','Jozef HanÃ¡k - s IT Solutions CZ','Antala Staska 32','Prague','','CZECH REPUBLIC','14200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 10:51:05',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(4087,654707274002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','ibedo75','aliibedo@gmail.com','ALI IBEDO','ABU DHABI - AL SAADA STREET','ABU DHABI','ABU DHABI','UNITED ARAB EMIRATES','31414','00971508198689','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 11:12:22',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ canon L   1 \rRR815341232CN\r'),(4088,654706505002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','v11555','cyclone.15@msn.com','Umur Derinyar','1.Murat Mah. Gungor Mazlum Cad. Umit Apt. A/2 Blok - D:7','Edirne / Merkez','','TURKEY','22030','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 11:13:13',0,NULL,3,1,3,1,NULL,' RR815341246CN\r'),(4089,709735005015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'',127,'hutongstore','huhucool','ailin.ohearchai@gmail.com','Alan Harrison','Knockegan Cloona','Ballina','Mayo','IRELAND','096','09621940','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-04 11:26:09',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ï¼‰   1\r2m ç¯æž¶   2\råŒç¯å¤´ è‹±æ ‡   2\råå…‰ä¼ž   2\r115w 220v    4\råŒ…    1\r lighting kit   $30 \rYW864143985CN\r'),(4090,654719944002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','johnsonxu1121','haojixu@hotmail.com','JOHNSON XU','6 LIZ PLACE<br>SUNNYBANK HILLS','BRISBANE','Queensland','AUSTRALIA','4109','61433570227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 12:13:11',0,NULL,3,1,2,1,NULL,'lenspen   1 '),(4091,615398502001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','vadbe2l2','vadimbelya@gmail.com','vadim belya','haliya 74/23','beer sheva','n/a','ISRAEL','84742','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 12:29:27',0,NULL,3,1,11,1,NULL,NULL),(4092,713741341015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','asor3084','antoinesorin@ebuyclub.com','antoine sorin','51 rue migault','frontenay rohan rohan','Poitou-Charentes','FRANCE','79270','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 12:36:22',0,NULL,3,1,2,1,NULL,NULL),(4093,654725493002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','lyuboslav.asenov','lyubo.asenov@gmail.com','Lyuboslav Asenov - GeoCon','Boris Hristov 2A / et.2 office GeoCon','Sofia','Sofia','BULGARIA','1111','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 12:39:41',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶    1\räº‘å°   1\ræŸ”å…‰ä¼ž    1 \rRR815341250CN\r'),(4094,713752152015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','arazi145','sentaur14@gmail.com','Akhtar Ramzan','65a Devonshire Street','Keighley','West Yorkshire','UNITED KINGDOM','BD21 2BJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 13:15:07',0,NULL,3,1,2,1,NULL,NULL),(4095,615414881001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','cave.explorer2008','cave.explorer@yahoo.com','Manuel Jimenez','Calle Alameda #8<br>Munoz Rivera','Guaynabo','PR','PUERTO RICO','00969','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-04 13:43:13',0,NULL,3,1,3,1,NULL,'301p ä¸€æ‹–ä¸‰   1 \rRR815341161CN\r'),(4096,699820182016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','caterham7go','axfordg@googlemail.com','Graham Axford','The Creative Assembly, Southern Housing Group 2nd Floor, Spire Court, Albion Way','Horsham','West Sussex','UNITED KINGDOM','RH12 1FB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 13:45:04',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(4097,654742342002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',46.99,'hermeshine','fabianopasold','fabianopasold@brturbo.com.br','fabiano pasold','rua bernardo dornbusch, 1973<br>vila lalau','jaraguÃ¡ do sul','santa catarina','BRAZIL','89256100','47 3371-2464','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 13:49:25',0,NULL,3,1,3,1,NULL,'40cm é—ªå…‰ç¯æ£š   1 \rRR815341175CN\r'),(4098,654738808002,120568891616,'Male-Male 52mm-52mm Reverse Macro 40D 450D 550D D90',1,'AA1211',7.6,'hermeshine','auc1','agmail48-buy10ebay@yahoo.com','Gabriel Ash','Rte de Bardonnex 23','Plan les Ouates','','SWITZERLAND','1228','(022) 340-0005','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 14:29:49',0,NULL,3,1,2,1,NULL,'52-52mm åŒé˜³çŽ¯ 1\r52-58mm åŒé˜³çŽ¯  1\r '),(4099,654768967002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','ajrogers111','ajrogers111@hotmail.com','John Rogers','4908 Boundview Ct','Summerville','SC','UNITED STATES','29485-8683','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 15:38:53',0,NULL,3,1,1,1,NULL,NULL),(4100,654774709002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','danpont','danielaaronpont@gmail.com','Dan Pont','PO Box 81<br>916 W. Buffalo','Rawlins','WY','UNITED STATES','82301-0081','(307) 321-0307','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 15:50:27',0,NULL,3,1,1,1,NULL,NULL),(4101,615458860001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','closetm','info@closetm.com','Mark Sher','2210 Forest Haven Blvd','Edison','NJ','UNITED STATES','08817','(732) 241-5100','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 16:27:39',0,NULL,3,1,1,1,NULL,'éº‚çš®   1 '),(4102,699874052016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'',5.8,'hutongstore','jerseymermaid1','sue@suedalyproductions.com','Sue Daly','La Retraite Sark','Guernsey','Channel Islands','GG','GY9 0SF','01481 832175','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 16:28:06',0,NULL,5,1,18,0,NULL,'77mm æ¸å˜ç°  1 \rSue Daly\rLa Retraite\rSark\rGuernsey, Channel Islands\rGY9 0SF\rGuernsey\r'),(4103,615508119001,110445705855,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',1,'AB1405',9.9,'hermeshine','sd1609','d.plantrou@laposte.net','David plantrou','2 avenue des abattoirs','Louviers','Haute-Normandie','FRANCE','27400','02.32.25.55.88','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 18:46:30',0,NULL,3,1,2,1,NULL,'pentax è‚©å¸¦   1 '),(4104,713881317015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','legros555','rudy.terras@wanadoo.fr','RUDY TERRAS','15 COURS GAMBETTA','TARBES','Midi-PyrÃ©nÃ©es','FRANCE','65000','0562930559','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 18:54:15',0,NULL,3,1,2,1,NULL,NULL),(4105,654847023002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','kitenut1','dzke06109@hotmail.com','Richard M. Johnson','4 David St','Greenville','RI','UNITED STATES','02828-2307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 19:17:24',0,NULL,3,1,1,1,NULL,NULL),(4106,654848597002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','kjeteriks','kjet.erik@yahoo.no','kjetil Eriksen','Hamningbergveien 14','BÃ¥tsfjord','','NORWAY','9990','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 19:17:52',0,NULL,3,1,2,1,NULL,NULL),(4107,654861881002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','chadan2009','danny1968@live.fr','Danny Jack','151 McConville','Joliette','QC','CANADA','J6E 4L2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 19:47:21',0,NULL,8,1,17,1,NULL,' '),(4108,615543129001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','olegluft','olegl72@gmail.com','Oleg Luft','Ezra Sofer 17/4','Ashdod','','ISRAEL','77468','0508116967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 20:10:07',0,NULL,3,1,11,1,NULL,'åŒç¯å¤´   æ¬§æ ‡   1 '),(4109,615562466001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','450_belisle','lbelisle@videotron.ca','Luc Belisle','67 Varin','Repentingy','QC','CANADA','J5Y1L8','(450) 585-2279','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 20:58:32',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡  1 '),(4110,615571993001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','p2auctions','jeckalbr69@msn.com','Pierre Chambrin','310 Berry Bush Ct','Wildwood','MO','UNITED STATES','63011-2086','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 21:24:25',0,NULL,3,1,1,1,NULL,'40cm æ£š   1 '),(4111,654902835002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','dtadeuribeiro','dtadeu@gmail.com','Daniel Tadeu Ribeiro','Rua Padre Questor, 91<br>Bairro Timirim','TimÃ³teo','Minas Gerais','BRAZIL','35180-304','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 21:28:29',0,NULL,8,1,17,0,NULL,''),(4112,700027332016,260660051378,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'',2.75,'hutongstore','koolsony','koolsony@hotmail.com','SCHMITT Pierre','3 rue de la Verrerie Les Balladines B2','Cannes La Bocca','Provence-Alpes-CÃ´te d\'Azur','FRANCE','06150','0493902405','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 21:56:41',0,NULL,8,1,17,0,NULL,''),(4113,615583182001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','henkslot','henk@theidea.nl','Henk Slotboom','Willem Alexanderweg 73B','Cothen','','NETHERLANDS','3945 CH','06 5333 1778','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 21:57:09',0,NULL,3,1,2,1,NULL,'canon å°åŒ…  1 '),(4114,700027666016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','falderro','mjhager@uwalumni.com','Mitchell Hager','2124 Winterberry Ln','Shakopee','MN','UNITED STATES','55379-5901','(612) 483-5821','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 21:57:37',0,NULL,3,1,1,1,NULL,NULL),(4115,700027900016,260660051230,'Hot Shoe Cap Cover for SONY a900 a700 a350 FA-SHC1AM /B',1,'',2.3,'hutongstore','koolsony','koolsony@hotmail.com','SCHMITT Pierre','3 rue de la Verrerie Les Balladines B2','Cannes La Bocca','Provence-Alpes-CÃ´te d\'Azur','FRANCE','06150','0493902405','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 21:57:57',0,NULL,3,1,2,1,NULL,' sony çº¢å¤–é¥æŽ§  1 \rsony çš„çƒ­é´ç›–   1'),(4116,713983750015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'',2.39,'hutongstore','pajr777','pajr777@hotmail.com','Paul Robinson','21 Chesterton Lane','Cirencester','Gloucestershire','UNITED KINGDOM','GL7 1XQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 22:19:34',0,NULL,3,1,2,1,NULL,'67mm æŽ¥å£çŽ¯   1 '),(4117,615581701001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','mellena88','mellena88@yahoo.com','Matt Ellena','12118 Crystal Glen Way','Northridge','CA','UNITED STATES','91326','(818) 360-8383','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 22:27:17',0,NULL,3,1,1,1,NULL,NULL),(4118,654927005002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ckelton','kelton@uwindsor.ca','Chrissy Kelton','1781 Cottonwood Avenue','Kingsville','ON','CANADA','N9Y 2W2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 22:36:10',0,NULL,3,1,2,1,NULL,NULL),(4119,700044340016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','sramolu','sramo@svetielko.sk','Lubomir Sramo','Kvetoslavov 456','Kvetoslavov','','SLOVAK REPUBLIC','93041','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 22:47:13',0,NULL,8,1,17,0,NULL,NULL),(4120,713992118015,250600523996,'Shutter Release Remote Cord For Pentax K20D K10D K-7 K7',1,'',2.98,'hutongstore','sramolu','sramo@svetielko.sk','Lubomir Sramo','Kvetoslavov 456','Kvetoslavov','','SLOVAK REPUBLIC','93041','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 22:47:14',0,NULL,3,1,2,1,NULL,'lenspen   1\rRS-C1   1 '),(4121,615539399001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','lunka1979','alya_lunina@mail.ru','Aliya Lunina','Universitetskaya, 52/48','Donetsk','donetsk','UKRAINE','83050','+38095-137-11-72','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 22:58:16',0,NULL,3,1,2,1,NULL,NULL),(4123,615597550001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.55,'hermeshine','mtg-978','probbob@gmail.com','mine','178 Sterling Rd.','Princeton','MA','UNITED STATES','01541','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-01-04 23:30:12',0,NULL,3,1,1,1,NULL,'77mm æ¸å˜ç°  1 '),(4124,714010210015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'',5.2,'hutongstore','bormio2003maloneyx','hughedwards@supanet.com','Hugh Edwards','7 Bryn Heulog Ysceifiog','Holywell','Flintshire','UNITED KINGDOM','CH88NR','01352720837','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 23:33:47',0,NULL,3,1,2,1,NULL,'62mm æ¸å˜ç°   1 '),(4125,714025751015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'',7.48,'hutongstore','pols0074031','ilmarsguza@inbox.lv','Ilmars Guza','Ilukstes34-139','default','','LATVIA','LV-1082','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 00:26:31',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡   1 '),(4126,615623302001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','zouwen10','wenzou@thewenstudio.com','wen zou','1209 Richmond St. APT# 1009','London','ON','CANADA','n6a 3l7','(519) 433-9334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 00:29:45',0,NULL,3,1,2,1,NULL,'2.1X1.6MèƒŒæ™¯å¸ƒ  1 é»‘è‰² '),(4127,615643983001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','jan.juan','jan.juan@yahoo.com','Janette Juan','134 31 Avenue NW','Calgary','AB','CANADA','T2M 2N9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 01:56:56',0,NULL,3,1,2,1,NULL,NULL),(4128,654979992002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','pukko21','sydneythaitown@hotmail.com','peerapong yenchaisit','179/303 castleragh st.','sydney','New South Wales','AUSTRALIA','2000','0413378434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 02:02:15',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(4129,654980992002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','dtadeuribeiro','dtadeu@gmail.com','Daniel Tadeu Ribeiro','Rua Padre Questor, 91<br>Bairro Timirim','TimÃ³teo','Minas Gerais','BRAZIL','35180-304','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 02:06:06',0,NULL,3,1,3,1,NULL,' D8å•è‚©åŒ… ï¼ˆ olympus logo ï¼‰ 2 \r1605\rRR815341365CN'),(4130,615648155001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','chadan2009','danny1968@live.fr','Danny Jack','151 McConville','Joliette','QC','CANADA','J6E 4L2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 02:15:31',0,NULL,3,1,2,1,NULL,'58mm æ©¡èƒ¶ç½©   1\r58mm é•œå¤´ç›– canon  1 '),(4131,654988126002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','jbone1101','justinrthom@gmail.com','Justin Thom','414 Cross Hill Rd','Monroe','CT','UNITED STATES','06468-2710','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 02:35:58',0,NULL,3,1,1,1,NULL,NULL),(4132,615653180001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','emul5552','mulleneddie10@gmail.com','Edward Mullen','PO BOX 689','Paddington','New South Wales','AUSTRALIA','2021','0405699325','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-05 02:37:17',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ é»‘ï¼‰   1 \rç­‰æ–°åœ°å€\rbackground support $20\rEdward Mullen\r1/212 Oxford St, \rPaddington New South Wales 2021\rAUSTRALIA\r0405699325\rYW864143930CN\r\r'),(4133,655023942002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bruno_monteiro','bruno_mm21@hotmail.com','Bruno Monteiro','Neudelia Monte, 700','Fortaleza','Ceara','BRAZIL','60830-135','558532731633','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 05:39:22',0,NULL,3,1,2,1,NULL,NULL),(4134,615687179001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','gailinbc','gailalcock@telus.net','Gail e Alcock','114 Dunant Crs','Penticton,','BC','CANADA','V2A 3E9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 05:53:58',0,NULL,3,1,2,1,NULL,NULL),(4136,655037151002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','linaboard78','linarellomarco@tiscali.it','marco linarello','via barengo, 1','agnellengo di momo','NO','ITALY','28015','3938929816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 07:20:08',0,NULL,8,1,17,0,NULL,''),(4137,655038881002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','linaboard78','linarellomarco@tiscali.it','marco linarello','via barengo, 1','agnellengo di momo','NO','ITALY','28015','3938929816','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 07:33:47',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹   1 \ræ–œè‡‚   1 \rRR815341453CN\r'),(4138,615707301001,110529627209,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','equipossoftes','m_escanciano@hotmail.com','Miguel  Martin Escanciano','c/ Monasterio de las Huelgas 25<br>Portal D 3ÂºA','Madrid','Madrid','SPAIN','28049','635548055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 08:30:34',0,NULL,8,1,17,0,NULL,NULL),(4140,655046646002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','equipossoftes','m_escanciano@hotmail.com','Miguel  Martin Escanciano','c/ Monasterio de las Huelgas 25<br>Portal D 3ÂºA','Madrid','Madrid','SPAIN','28049','635548055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 08:36:24',0,NULL,8,1,17,0,NULL,NULL),(4141,655046653002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',1,'AA1205',2.99,'hermeshine','equipossoftes','m_escanciano@hotmail.com','Miguel  Martin Escanciano','c/ Monasterio de las Huelgas 25<br>Portal D 3ÂºA','Madrid','Madrid','SPAIN','28049','635548055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 08:36:24',0,NULL,3,1,2,1,NULL,'cpl   1\réº‚çš®   1\rsonyçš„çƒ­é´ç›–   1 '),(4142,615721778001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',2,'AB2214',3,'hermeshine','zvika26','zvyu26@gmail.com','Zvika Mizrahi','Dreyfus st. 25/24','Haifa','','ISRAEL','35434','972523794650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 09:57:33',0,NULL,3,1,2,1,NULL,'å“èƒœ3.0   2 '),(4143,615721438001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','lalune05','petitbisous@gmail.com','Julia Kristina','Digue des peupliers 86A','Mons','','BELGIUM','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 09:59:57',0,NULL,8,1,17,0,NULL,NULL),(4144,655057327002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','lalune05','petitbisous@gmail.com','Julia Kristina','Digue des peupliers 86A','Mons','','BELGIUM','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 09:59:58',0,NULL,3,1,3,1,NULL,'1.6mx2.1m= PINK 1.6mx3m= WHITE  \rRR815344097CN\r'),(4145,714152665015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'',4.8,'hutongstore','boyanvaltchev','boyan.valtchev@gmail.com','Boyan Valtchev','WTC Interpred, Block B, Office 604, 36 Dragan Tsankov Blvd','Sofia','Bulgaria','BULGARIA','1040','00359 886 00 93 76','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 10:07:16',0,NULL,3,1,2,1,NULL,'52mm æ¸å˜ç°  1 '),(4146,714168958015,250692240898,'Wireless Remote Shutter Release for Sony A900/A200/â€‹A10',1,'',11.47,'hutongstore','hee_siong01','hee_siong@yahoo.com','YBK ENGINEERING - ONG HEE SIONG','NO.17-1, Jalan 3/93, Taman Miharja, Cheras','Kuala Lumpur','Kuala Lumpur','MALAYSIA','55200','0166106390','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 11:17:49',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ S1   1 '),(4147,615417976001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',3,'AE3301',41.94,'hermeshine','amperel2010','service@amperel.co.il','Amperel Danny','Shderot Jerusalem 168 Street<br>P.O. Box 2161','Holon','Israel','ISRAEL','58829','+97235594299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 11:30:06',0,NULL,3,1,3,1,NULL,'ä¸€è½¬å››ç¯å¤´  3\rè¦æŽ§åˆ¶åœ¨2kgä»¥å†…ï¼Œä¸è¡Œçš„è¯å°±å¾—å‘ä¸¤ä¸ªåŒ…äº†RR815341422CN\r'),(4148,655077966002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','ronnialbert','ronnymp@yahoo.com','roni albert','silver<br>4 / 4','nahariya','','ISRAEL','22385','+97240779500415','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 11:30:21',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  2\rbåº§  2\ræŸ”å…‰ä¼ž  2\r åˆ†ä¸¤ç¥¨æŒ‚å·å°åŒ…å‘ï¼Œ2kgä»¥å†…ä¸€ä¸ª RR815341475CN\rRR815341440CN\r'),(4149,615745953001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','sreenivasamurthy','rrsreenu@gmail.com','SREENIVASAMAURTHY RAJANAHALLI','HANUMANTHAPPA BUILDING<br>POONA, BANGALORE ROAD','DAVANGERE','KA','INDIA','577002','918192258834','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 12:02:23',0,NULL,3,1,2,1,NULL,'çƒ­é´ç›–  1 '),(4150,615746925001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','l.khabaz','lutfimk@gmail.com','Lutfi M. Al-Khabaz','P.O.Box # 11627<br>Saudi Aramco','Dhahran','Eastern','SAUDI ARABIA','31311','00966504908852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 12:06:56',0,NULL,3,1,2,1,NULL,' '),(4151,655093315002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','dhubhh','dhubhe@vodafone.es','Jose Manuel Beltran Puig','C/ Clapisa nÂº32','BenicarlÃ³','Castellon','SPAIN','12580','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 12:39:43',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶ '),(4152,714192327015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','burlaks.q','austris.birkans@gmail.com','Austris Birkans','Ciekurkalns 6sk.l 19','Riga','','LATVIA','LV1026','+37129116007','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 12:43:32',0,NULL,3,1,2,1,NULL,NULL),(4153,700241408016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'',8.99,'hutongstore','hamoniaux123','steve.hamoniaux@hotmail.co.uk','steve hamoniaux','4 windsor ave','corringham','essex','UNITED KINGDOM','ss17 7nu','01375643754','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 12:46:19',0,NULL,3,1,2,1,NULL,'52mm çŽ¯æž¶  1\ræ¸å˜æ©™   1 '),(4154,654811024002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jlojosnegros','jl.ojosnegros.manchon@gmail.com','Jose Luis Ojosnegros Manchon','Avenida de Portugal,49 4ÂºD Esc Izq','Mostoles','Madrid','SPAIN','28931','916175419','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 13:13:33',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864143926CN\r'),(4156,655106527002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','mp34life','alex@acpu.se','Alexander Papacosta','Anthimou Panaretou 5<br>Apartment 3','Paphos','Paphos','CYPRUS','8036','00357 99 164158','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 13:37:34',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶  1 RR815341691CN\r'),(4157,714212089015,250599931920,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',7.8,'hutongstore','nick7131','nick.oates20@ntlworld.com','Nick Oates','C/O Windsor Partners Ltd 71 Fenchurch Street','London','London','UNITED KINGDOM','EC3M 4BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 13:51:24',0,NULL,3,1,2,1,NULL,NULL),(4158,614724911001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','larsdok7.5','larsdok@hotmail.com','Lars DoksÃ¦ter','Valkendorfsgaten 2c','Bergen','Hordaland','NORWAY','5012','92410814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 14:08:39',0,NULL,3,1,3,1,NULL,'RR815341419CN\r '),(4159,714229264015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','unitedtrev','trevorharrop1@btinternet.com','Trevor Harrop','26 Church Lane Backford','Chester','Cheshire','UNITED KINGDOM','CH2 4BE','01244851877','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 14:46:03',0,NULL,3,1,2,1,NULL,NULL),(4160,615498655001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','garjang13','garjang_13@yahoo.com','Reza Joana Lacsamana','308<br>Rizal Avenue Extension','Batangas','Batangas','PHILIPPINES','4200','9175121322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 15:08:15',0,NULL,3,1,2,1,NULL,NULL),(4161,615805241001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','soldier6685','samuel6685@gmail.com','Samuel Hall','14580 McElroy Rd','Auburn','CA','UNITED STATES','95602-8823','(706) 526-8471','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-05 16:09:14',0,NULL,3,1,3,1,NULL,'Nikon D1 å•è‚©åŒ…  1 RR815341524CN\r'),(4162,615806221001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','macvsog_23','macvsog_23@yahoo.co.uk','Robert Marklew','19 Goslet Road<br>Stockwood','Bristol','Bristol','UNITED KINGDOM','BS14 8SP','01275836164','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 16:42:17',0,NULL,8,1,17,0,NULL,''),(4163,615806865001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',1,'AKT029',24,'hermeshine','macvsog_23','macvsog_23@yahoo.co.uk','Robert Marklew','19 Goslet Road<br>Stockwood','Bristol','Bristol','UNITED KINGDOM','BS14 8SP','01275836164','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 16:42:17',0,NULL,3,1,3,1,NULL,'1 x52mm lens cap for Nikon\r4 x62mm lens cap for Nikon\r1 x67mm lens cap for Nikon\r2 x72mm lens cap for Nikon\r2x77mm lens cap for Nikon \rnikon 90th é•œå¤´ç­’   1 \rRR815341802CN\r\r'),(4164,700318832016,260660055182,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',15,'hutongstore','bartvic','grizzlyr@yandex.com','Victoria Bartunova','Osennyaya, 5','Krasnogorsk','Moscow region','RUSSIAN FEDERATION','143444','(985)973-5957','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 16:46:30',0,NULL,3,1,2,1,NULL,'50cm æ£š   1 '),(4165,655175636002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','jwilliamsdms87','jacob.ryan.w@gmail.com','Jacob Williams','190 Willow Way Rd','Barboursville','VA','UNITED STATES','22923','(434) 760-0672','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-05 17:30:30',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£å¡‘æ–™  1 RR815341498CN\r'),(4166,700367706016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','garfield-26','nick@nickhall.net','Nick Hall','Connect Internet Cafe, Centra Commercial Calle Aquario, Las Terrazas Miraflores Golf','Riviera del Sol, Mijas Costa','AndalucÃ­a Ceuta y Melilla','SPAIN','29649','951273242','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-05 18:37:17',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡   2\r115w 220v   2\r åŒ…   1\rlighting kit  $30 \rYW864143941CN\r\r'),(4167,714323886015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',5,'AA1304',9.4,'hutongstore','jameschetwode','jameschetwoderam@hotmail.com','james ram','number 8 elm court gardens','truro','cornwall','UNITED KINGDOM','tr11ds','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 18:39:40',0,NULL,3,1,3,1,NULL,' RR815341538CN\r'),(4168,655206088002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','mivsr08','smruud@gmail.com','Svein Mikael Ruud','Vestre Furmyrvei 26','Ã…lesund','','NORWAY','6017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 18:49:16',0,NULL,3,1,3,1,NULL,'é˜²å¯’ç½©   1 RR815341507CN\r'),(4169,615864721001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','zahi150','zahi1500@gmail.com','Zahi Zamir','12 Andersn st.<br>apartment 9','Petach-Tikva','','ISRAEL','49203','972523811919','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 18:52:48',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR815341847CN'),(4172,700399256016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',3,'AKT056',114,'hutongstore','*banis*','alanbanis@live.com','Alan Banis','Furugatan 8','BorÃ¥s','','SWEDEN','50439','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 19:40:14',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  3\råå…‰æ¿æ”¯æž¶   3 \rreflector holder  $30\rYW864143963CN\r'),(4173,700405133016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','gryph0n','rowangee@gmail.com','Rowan Griffin','Flat G, Oakmount Mansions 11a Oakmount Avenue','Southampton','Hampshire','UNITED KINGDOM','SO17 1EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 19:50:39',0,NULL,3,1,2,1,NULL,NULL),(4174,655256316002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',6,'AA1301',14.6,'hermeshine','oldschool03','atrentacost@aol.com','Anthony N. Trentacost','28243 leticia','mission viejo','CA','UNITED STATES','92692-2329','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 20:49:28',0,NULL,3,1,1,1,NULL,' '),(4175,655265132002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','cards_comics_jax','cardscomicsjax@yahoo.com','T. Martin c/o Martin and Associates','8823 San Jose Blvd<br>Ste 103','Jacksonville','FL','UNITED STATES','32217-4288','(904) 334-1351','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 21:13:27',0,NULL,3,1,1,1,NULL,NULL),(4176,615591982001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','arturbq','arturgmlcosta@gmail.com','Artur Costa','Rua das Marinhas, nÂº 59, M14<br>Gulpilhares','Vila Nova de Gaia','Porto','PORTUGAL','4405-663','351914746250','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 21:29:25',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…æ— å­—  1 '),(4177,700455491016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'AA1311',3.5,'hutongstore','1nish2rule_them_all','nishmania@yahoo.com','Rajnishpal Udhian','24 Manor Road','West Ealing','London','UNITED KINGDOM','W130JA','07966094942','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 21:37:54',0,NULL,3,1,2,1,NULL,'æ°”å¹+å¸ƒ   1 '),(4179,615936038001,110531023243,'JJC Leather Hand Strap Grip for NIKON AH-4 D3x D90 D300',1,'AB1411',17.99,'hermeshine','c130','cc130h@yahoo.com','Marc Favre','R. R. #3<br>(561 Scriver Rd)','Brighton','ON','CANADA','K0K 1H0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 21:56:15',0,NULL,3,1,2,1,NULL,'JJC-4   1 '),(4180,615938636001,110606921919,'New Portable 50cm 20\"x20\" Soft Box Softbox for Flash ',1,'AB3328',50.99,'hermeshine','santoku87','jruyson@yahoo.com','Rodolfo R Uyson III','314 Scott St S','Shakopee','MN','UNITED STATES','55379-1248','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-05 22:05:08',0,NULL,3,1,3,1,NULL,'50cm é—ªå…‰ç¯æŸ”å…‰æ£š  1 RR815341541CN\r'),(4181,655285913002,120581555598,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',9.25,'hermeshine','donnat-missy','donnatcd@aol.com','D. Turner','4325 Kendall St','Wheat Ridge','CO','UNITED STATES','80033-5031','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 22:10:01',0,NULL,3,1,1,1,NULL,'å¤§å·å†…èƒ†åŒ… nikon   1 '),(4183,615953843001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','yhoel','yhoel19@gmail.com','Jose Manuel Martinez Cases','Asuncion ParreÃ±o Garcia NÂº 75 - 4Âº Iz','Elche','Comunidad Valenciana','SPAIN','03205','965446980','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 22:54:39',0,NULL,3,1,3,1,NULL,'äº•å­—æ‰³æ‰‹   1 RR815341484CN\r'),(4184,615953359001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','kraedson','ekraemer@pop.com.br','EDSON KRAEMER','Qd 105 Norte, Al. Mangueiras, LT 26<br>QI 02','Palmas','TOCANTINS','BRAZIL','77001-050','(63)8405-7845','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 22:55:54',0,NULL,3,1,2,1,NULL,NULL),(4185,615957916001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','victorlizana','victorantoniohp@hotmail.com','Victor Lizana','Vichuquen 1498<br>Conchali','Santiago','Region Metropolitana','CHILE','8560313','56987072497','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 23:10:07',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 RR815341467CN\r'),(4186,615960011001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','evie1964','madcrazyartist@yahoo.com.au','Yvonne Warren','191 Gleniffer Rd','Bonville','New South Wales','AUSTRALIA','2441','0266535638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 23:18:31',0,NULL,3,1,2,1,NULL,NULL),(4187,655313351002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','melissacopebeaty','melissacancope@yahoo.com','Melissa Beaty','226 Freeman Dr','Biloxi','MS','UNITED STATES','39531-3244','(478) 213-0103','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 23:37:32',0,NULL,3,1,1,1,NULL,NULL),(4188,615967528001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','renoboydz','renoboyd@charter.net','Boyd Zegers','1285 Baring Blvd<br># 240','Sparks','NV','UNITED STATES','89434','(775) 842-4160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 23:47:21',0,NULL,3,1,1,1,NULL,NULL),(4189,615966777001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','stephan.dcosta','dcosta.stephan@gmail.com','Stephan DCosta','233 Sun Arbor Ter<br>Apt 1188','Salt Lake City','UT','UNITED STATES','84116-4558','(801) 683-7004','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-05 23:51:14',0,NULL,3,1,1,1,NULL,NULL),(4190,714471185015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',4,'AA1301',7.52,'hutongstore','lobopl','camelgd@gmail.com','Kamil Nasuta','136 Wigan lane','WIGAN','Lancashire','UNITED KINGDOM','WN1 2LA',' 07732798335','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 00:14:17',0,NULL,3,1,2,1,NULL,NULL),(4191,714472679015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','pajka2007','pajka@inbox.ru','Pavel Alekno','16 Sebert road','London','London','UNITED KINGDOM','e7 0nq','07708619085','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 00:20:02',0,NULL,3,1,2,1,NULL,NULL),(4192,655325562002,120581555818,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','gclaudiu','gclaudiu2007@gmail.com','Claudiu Georgescu','358B East Coast Road','default','','SINGAPORE','428975','93865433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 00:26:56',0,NULL,8,1,17,0,NULL,NULL),(4193,615976591001,110502916198,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',3.55,'hermeshine','gclaudiu','gclaudiu2007@gmail.com','Claudiu Georgescu','358B East Coast Road','default','','SINGAPORE','428975','93865433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 00:26:57',0,NULL,3,1,11,1,NULL,'58mm æŽ¥å£çŽ¯  1\r67mm æŽ¥å£çŽ¯  1 '),(4194,655333405002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','sherman026','selina_y7@hotmail.com','yin tang','139 Midway Dr','Negaunee','MI','UNITED STATES','49866','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 01:00:16',0,NULL,3,1,1,1,NULL,'åŒç¯å¤´  1 '),(4195,655340274002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','electronicnecessities','electronic_necessities@hotmail.com','Eamonn Wall','58 Tinigira Cres','Kiama','New South Wales','AUSTRALIA','2533','6142331901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 01:28:20',0,NULL,3,1,2,1,NULL,NULL),(4196,616009936001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','novikov1729','alex.746@gmail.com','Alexander Novikov','2817 Rue Des Perce-Neige','Vaudreuil-Dorion','QC','CANADA','J7V 0C4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 02:56:49',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´   2 '),(4197,714523332015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',24.95,'hutongstore','grifter06','gergriffin05@yahoo.co.uk','Gerard Griffin','48 Dun Na Manach Quin','Ennis','Clare','IRELAND','default','0863675005','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 03:23:30',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815341555CN\r'),(4198,714542689015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','superpig106','jack_sky@yahoo.com','Jacky Shum','EO(CSD)1, Room 1346, 13/F, West Wing, Central Government Offices, Lower Albert Rd, Central, Hong Kong','default','','HONG KONG','default','(852)91065135','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 04:49:30',0,NULL,3,1,2,1,NULL,'72mm cpl   1 '),(4200,616043792001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','googieburra','leishy22@hotmail.com','Aleisha Goiran','Level 11<br>172 St Georges Tce','Perth','Western Australia','AUSTRALIA','6000','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-06 06:27:34',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ é»‘ï¼‰1 \rbackground support  $20\rYW864143915CN\r'),(4201,616044527001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','bigboatdaddy','adrian_rumney@yahoo.com','Adrian Rumney','c/- Medical Assurance Society<br>19-21 Broderick Road, Johnsonville','Wellington','.','NEW ZEALAND','6037','+64 4 4941372','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 06:33:05',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ ç»¿è‰² canon  xxl   1 \rRR815341731CN\r'),(4202,615935901001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',133.92,'hermeshine','wontfix123','omeryairmail@gmail.com','Omer Yair','20 Havradim Street','Yehud','Gush Dan','ISRAEL','56275','97235362750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 06:37:00',0,NULL,3,1,3,1,NULL,'110cm 5in1  2\r80cm 5in1   3\r60cm æ£š  1\r2kgä»¥å†…ï¼Œçœ‹åŒ…å‡ ä¸ªåŒ…\rRR815341714CN\rRR815341728CN\r'),(4204,655406718002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','helperi','seppo.helpio@iki.fi','Seppo HelpiÃ¶','Salomaantie 5 H 57','Valkeakoski','Pirkanmaa','FINLAND','37630','0400632565','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 07:43:59',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815341776CN'),(4206,616064880001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',4.4,'hermeshine','iwangun','ione_6@hotmail.com','Iwan Gunardi','Jl. Rawa Sumur II Kavling BB3<br>Kawasan Industri Pulo Gadung','Jakarta','DKI - Jakarta','INDONESIA','13930','+6281513603656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 09:29:52',0,NULL,3,1,2,1,NULL,' '),(4207,616081899001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','ostad07','ohusta@hotmail.com','Ã˜yvind Hustad','Skrenten<br>5 F','Molde','','NORWAY','6411','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 10:38:23',0,NULL,3,1,3,1,NULL,'52mm~77mm æŽ¥å£çŽ¯  1\ræ‰˜æž¶   1 \r\rRR815341864CN'),(4208,700655374016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','jacek1702','fotojacek@diginet.ie','Marian Pieciak','11 Laurelmount Avenue Rock Road','Carrigaline','Cork','IRELAND','000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 11:27:33',0,NULL,3,1,3,1,NULL,'1.6x3m çº¢è‰²èƒŒæ™¯å¸ƒ  1 \rRR815341952CN'),(4209,652865657002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','geiolima','geiolima@hotmail.com','Rogerio Silva','Estrada do Capuava, 2530 - casa 205','COTIA','SP','BRAZIL','06715-685','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 11:42:23',0,NULL,3,1,2,1,NULL,NULL),(4210,616105903001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','lestournelles682','diolots@free.fr','jeanclaude BOUCHEZ','8,rue du poirier de sauge','MONTIGNY SUR LOING','Ile-de-France','FRANCE','77690','0687200936','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 12:28:13',0,NULL,3,1,4,1,NULL,'6663a   1 \rtripod  $22\rYW864143904CN\r'),(4211,714650469015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','zephyr0161','lukedevereux@btinternet.com','paul devereux','4 griffiths close salford','manchester','Lancashire','UNITED KINGDOM','m7 1td','01618396846','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 13:08:34',0,NULL,3,1,2,1,NULL,NULL),(4212,714654654015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','tatitt','tania_dim@abv.bg','Tsvetan Todorov','Hadzi Dimitar bl. 130, entr. 3, fl. 4, ap. 69','Sofia','Bulgaria','BULGARIA','1510','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 13:22:00',0,NULL,3,1,2,1,NULL,NULL),(4213,700693182016,260675927807,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',21,'hutongstore','martyn190189','mart_morris4321@hotmail.co.uk','martyn morris','47 cradley park road','dudley','West Midlands','UNITED KINGDOM','dy2 9sp','075055825838','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 13:39:37',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…  A1   1 \rRR815341904CN'),(4214,655489895002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','tolga5484','tolga00@gmail.com','Tolga Tosun','Fethiye Mahellesi FSM BulvarÄ±<br>EryÄ±l Ap. kat:2 no:141-3','Bursa','NilÃ¼fer','TURKEY','16140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 14:25:03',0,NULL,3,1,3,1,NULL,'60cm é—ªå…‰ç¯æŸ”å…‰æ£š  1 \rRR815341895CN'),(4215,714698523015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','tony1409','tonyuttley@tiscali.co.uk','Tony Uttley','1 Palmer Crescent','Dronfield','Derbyshire','UNITED KINGDOM','S181XW','01246415688','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 15:34:13',0,NULL,3,1,2,1,NULL,NULL),(4216,655498440002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','sdora2010','stalter_harrison@yahoo.co.uk','Sylvia Banszki','72 B Ranelagh Road','London','London','UNITED KINGDOM','W5 5RP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 15:50:55',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   1 '),(4217,655517400002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','xbusterx82','xbusterx@gmail.com','Olga Dolgopolova','Respublika Avenue<br>30 , 22','Shymkent','South Kazakhstan , KAZ','KAZAKHSTAN','160005','+77017892862','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 15:59:51',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…  A1    1\rRR815341780CN '),(4218,616162937001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','sinjon01','simon.jonssons@gmail.com','simon jÃ¶nsson','vittervÃ¤gen 175','UMEÃ…','none','SWEDEN','90751','070-299 78 34','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 16:03:39',0,NULL,8,1,17,0,NULL,NULL),(4219,616163687001,110451007962,'New Timer Remote Control for Canon EOS 5DMarkII 5D 50D',1,'AA3222',45.9,'hermeshine','sinjon01','simon.jonssons@gmail.com','simon jÃ¶nsson','vittervÃ¤gen 175','UMEÃ…','none','SWEDEN','90751','070-299 78 34','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 16:06:42',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1\rMC-C3    1 \r\rRR815341833CN'),(4220,616165420001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','tmldesignstyle','twenzel@redeye-inc.com','Tara Wenzel','5835 S Broad St','Yardville','NJ','UNITED STATES','08620-9508','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 16:10:26',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(4221,655282619002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','olinko5','bergl@zoznam.sk','Oliver Bergl','Mandlova 70','Bratislava','','SLOVAK REPUBLIC','85110','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 16:35:05',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶( ç™½)   1 \rCP219486752CN\r'),(4222,616169995001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','toni2929-2007','modi_29@hotmail.com','Antonio Salaverri Leiras','Carrascal 6','MondoÃ±edo','Galicia','SPAIN','27740','651958916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 16:29:59',0,NULL,3,1,3,1,NULL,'60cm æ£š   1 \rRR815341878CN'),(4223,700789349016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','nchris198705','nchris1987@gmail.com','Krisztian Nyvelt','Radnoti ltp. 10/2','Abda','GY-M-S','HUNGARY','9151','0036204329390','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-06 17:52:58',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m èƒŒæ™¯å¸ƒç»¿è‰²   1\r2m ç¯æž¶  2\r50-70 æ£š  2  æ¬§æ ‡  \r115w 220v   2\råŒ…    1\rCP219486766CN\r\r'),(4224,655578126002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','miga_29','miguelasselin@hotmail.com','Miguel Asselin','2630 bellerose apt. 1','Longueuil','QC','CANADA','j4l4h9','(514) 208-6458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 18:42:54',0,NULL,8,1,17,0,NULL,NULL),(4225,616222617001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','miga_29','miguelasselin@hotmail.com','Miguel Asselin','2630 bellerose apt. 1','Longueuil','QC','CANADA','j4l4h9','(514) 208-6458','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 18:42:53',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  1\rè‚©æž¶    1 \rRR815341762CN'),(4226,616234254001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.8,'hermeshine','firecrowlives','firecrowlives@yahoo.com','nick perez','1211 S 1st Ave','arcadia','CA','UNITED STATES','91006-4130','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 19:08:48',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´  2 \rRR815341816CN'),(4227,616235346001,110533631256,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','evabluecanada','eva@evablue.com','eva blue','2025 Parthenais Suite 259','Montreal','QC','CANADA','h2k 3t2','(514) 808-2583','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 19:12:17',0,NULL,3,1,2,1,NULL,NULL),(4228,714798863015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','rado8307','rado126@gmail.com','Radovan Holly','L. Novomeskeho 2671/3','Trencin','','SLOVAK REPUBLIC','91108','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 19:13:53',0,NULL,3,1,2,1,NULL,NULL),(4229,655609887002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','popocarrocao','popo@carrocao.com.br','Manoel Leite','PraÃ§a da Bandeira, 32','Tatui','SP','BRAZIL','18270390','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 19:54:49',0,NULL,3,1,2,1,NULL,NULL),(4230,616255657001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','gregaudet','gpaudet@yahoo.com','Gregory Audet','5262 Shephard Rd','Brown City','MI','UNITED STATES','48416','(810) 837-1262','NoPaymentFailure','CheckoutComplete','Other','2011-01-06 20:00:47',0,NULL,3,1,1,1,NULL,'æ‘„å½±èƒŒå¿ƒ è–„ é»‘è‰² canon  xxl  1 '),(4231,655618421002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','elenapavlova','elenkapavlova@gmail.com','Elena Pavlova','ul. Shotmana 60-46','Petrozavodsk','Respublika Karelia','RUSSIAN FEDERATION','185001','+7 9114021469','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 20:15:19',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°   1\ræŸ”å…‰ä¼ž  1 \rRR815341855CN'),(4232,714636089015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'AKT023',3.62,'hutongstore','kennyipcu','kmclellon@aol.com','Kenneth   McLennan','58 Ness Circle','Ellon','Aberdeenshire','UNITED KINGDOM','AB419BR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 20:27:29',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶  1 '),(4233,655627160002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','joshk51','joshk@brooklynunderground.org','Josh  Koury','75 Monitor St<br>Apt 3R','Brooklyn','NY','UNITED STATES','11222-5125','(646) 541-6916','NoPaymentFailure','CheckoutComplete','Other','2011-01-06 20:33:38',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR815341881CN'),(4234,655635107002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','swim311977','fionapyke2@bigpond.com','Fiona Pyke','216 cane street<br>Redland Bay','Brisbane','Queensland','AUSTRALIA','4165','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'58mm æ¸å˜ç°  1 '),(4235,616282528001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','gasdocmusic','rgmatalon@gmail.com','Ralph Matalon','105 Rock Squirrel','Shavano Park','TX','UNITED STATES','78231-1426','(210) 602-5558','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 21:06:45',0,NULL,3,1,1,1,NULL,NULL),(4236,655641432002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','jazzinid','jazzinid@yahoo.com','Trevor Little','1923 Autumn Sage Ave','North Las Vegas','NV','UNITED STATES','89031-1699','(702) 334-3700','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 21:09:07',0,NULL,3,1,1,1,NULL,'MC-C1  1 '),(4237,655647404002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','prepaee','kayjet64@gmail.com','Mitchell Wolfrom','PO BOX 1362','Vieques','PR','UNITED STATES','00765-1362','(787) 435-9252','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 21:24:39',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ… nikon   1 '),(4238,714872260015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.95,'hutongstore','hannahlewis2010','hvl@hotmail.co.uk','Hannah Lewis','11 Union Street','Glossop','Derbyshire','UNITED KINGDOM','SK13 8LT','01457899430','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 21:38:02',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4239,616309957001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','manur2009','manuel_rivas@vodafone.es','MANUEL RIVAS DEL FRESNO','ARQUITECTO REGUERA 3-6A','OVIEDO','Asturias','SPAIN','33004','629934347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 22:23:03',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹çƒå°  1 '),(4240,700927761016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.28,'hutongstore','sterrydent308','nessrob1@aol.com','ROB CURTIS','10 BROOMHOUSE PARK, WITHERIDGE','TIVERTON','Devon','UNITED KINGDOM','EX16 8HB','01884860185','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 22:35:44',0,NULL,3,1,2,1,NULL,' '),(4241,616297651001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ecurb13z','bchapin1@cox.net','Bruce Chapin','207 S Bonnie Brae St','Wichita','KS','UNITED STATES','67207-1103','(316) 634-1665','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 22:41:31',0,NULL,3,1,1,1,NULL,NULL),(4242,616323477001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','steelie13steelie','steelie14@hotmail.com','John L Durfee','401 Chestnut Ave','Red Bluff','CA','UNITED STATES','96080','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-06 23:08:46',0,NULL,3,1,1,1,NULL,'52mm æ¸å˜ç°   1 '),(4243,616323692001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','leondcx','allan_hudson@hotmail.com','Allan Hudson','Av. General Rondon, 3542<br>Vila Leopodina','Duque de Caxias','Rio de Janeiro','BRAZIL','25050-230','552126528640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 23:09:28',0,NULL,3,1,3,1,NULL,'RR815341820CN '),(4244,700946634016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','wilsonpazos','wilsonpazos@hotmail.com','Wilson Pazos','Ekkodalen 16 2.tv','Aarhus','Danmark','DENMARK','8210','004528814877','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 23:31:49',0,NULL,3,1,2,1,NULL,NULL),(4245,655702575002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','mickkennally','mkennally@hotmail.com','Michael Kennally','28 Quasons Path','Brewster','ma','UNITED STATES','02631','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 00:18:48',0,NULL,3,1,1,1,NULL,NULL),(4247,655478876002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','perthsimon','simon.may8@gmail.com','Simon May','19 Mayfair Mews','Meadow Springs','Western Australia','AUSTRALIA','6210','610417703000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 01:05:41',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹  1 '),(4248,616371788001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','mdspace76','mdspace@yahoo.com','David Masuoka','Prol. Zaragoza 206 Privilege C21<br>Fracc. Fatima','Aguascalientes','Aguascalientes','MEXICO','20130','(449) 996-6797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 02:34:22',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(4249,655737776002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','tiggergr81','tiggergr81@sbcglobal.net','Lora J Russell','770 Glen Vista Dr','Sparks','NV','UNITED STATES','89434-1545','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 02:45:12',0,NULL,3,1,1,1,NULL,'rs-c3   1 '),(4250,655759329002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','hailstone421','rickdicks@rickdicks.com','Rick J Dicks','939 Southfork Dr','Allen','TX','UNITED STATES','75013','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 04:24:41',0,NULL,3,1,1,1,NULL,NULL),(4252,616404212001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','airmac3131','shapka@hotmail.com','Igor Synayuk','1928 Main St W Apt # 615','Hamilton','ON','CANADA','L8S 1J4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 05:38:20',0,NULL,3,1,2,1,NULL,NULL),(4253,654738316002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','ronnialbert','ronnymp@yahoo.com','roni albert','silver<br>4 / 4','nahariya','','ISRAEL','22385','+97240779500415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 05:28:30',0,NULL,3,1,3,1,NULL,'æ¡Œé¢ç¯   2 \rRR815343689CN\r'),(4254,655776122002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','lpnan','obk6260@gmail.com','ooi bkai','7, Cangkat Minden Lorong 6,<br>11700 Gelugor, Penang.','Gelugor','Penang','MALAYSIA','11700','012-5856674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 06:14:57',0,NULL,3,1,3,1,NULL,'50-70 å¡‘æ–™å¡å£  æ£š  2 \rRR815343882CN\r'),(4255,715019351015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','lacza66','vancsol@freemail.hu','Volvo Auto Hungary, Laszlo Vancso','Kulso Vaci ut 50-58.','Budapest','','HUNGARY','H-1044','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 06:16:19',0,NULL,3,1,2,1,NULL,NULL),(4256,701055961016,260660055110,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',15.5,'hutongstore','spiderlakesprings','wcheng55@netscape.net','willie cheng','4240 kincaid street','victoria','BC','CANADA','V8X4R3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 07:26:58',0,NULL,8,1,17,0,NULL,NULL),(4257,715029059015,250692237499,'Large size Neoprene Lens Pouch Case 90mm x 220mm L',1,'AC1203',4.18,'hutongstore','spiderlakesprings','wcheng55@netscape.net','willie cheng','4240 kincaid street','victoria','BC','CANADA','V8X4R3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 07:26:59',0,NULL,8,1,17,0,NULL,NULL),(4258,715028414015,250635197300,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.16,'hutongstore','spiderlakesprings','wcheng55@netscape.net','willie cheng','4240 kincaid street','victoria','BC','CANADA','V8X4R3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 07:26:59',0,NULL,8,1,17,0,NULL,' '),(4259,715028188015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.16,'hutongstore','spiderlakesprings','wcheng55@netscape.net','willie cheng','4240 kincaid street','victoria','BC','CANADA','V8X4R3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 07:27:00',0,NULL,8,1,17,0,NULL,' '),(4260,701054344016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','spiderlakesprings','wcheng55@netscape.net','willie cheng','4240 kincaid street','victoria','BC','CANADA','V8X4R3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 07:27:00',0,NULL,3,1,3,1,NULL,'52-52mm åŒé˜³çŽ¯   1\rcanon-58mm åæŽ¥çŽ¯   1\rcanon-52mm åæŽ¥çŽ¯   1\rå¤§å·é•œå¤´ç­’   1\r40cm  æ£š   1 \rRR815344021CN\r'),(4261,616425247001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','duaneorriss8','duaneorriss@gmail.com','Duane Orriss','14 Delafield Way','Balcatta','Western Australia','AUSTRALIA','6021','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 08:15:35',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\råŒç¯å¤´   æ¾³æ ‡  2\råå…‰ä¼ž  2\r45w   4\råŒ…   1\rlighting kit   $30\rYW864614830CN\r\r '),(4262,655795208002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','johnny_bjorling','johnny.bjorling@gmail.com','Johnny Bjorling','Bergdalsvagen 5','Aby','','SWEDEN','61633','+461160535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 08:34:26',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815343825CN'),(4263,655795392002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','ozkingdom','13week@gmail.com','Nitzan Oz','27481 Grassland Dr','Laguna Niguel','CA','UNITED STATES','92677-6032','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-07 08:35:52',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹   2 '),(4264,715044621015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',13.9,'hutongstore','nikonistad80','nikon1971@hotmail.es','MIGUEL ANGEL PELAEZ GONZALEZ','UNIVERSIDAD DE CANTABRIA (PabellÃ³n de Gobierno) Avda Los Castros s/n','Santander','Cantabria','SPAIN','39005','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 08:50:17',0,NULL,3,1,2,1,NULL,'50cm æ£š   1 '),(4266,714916110015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',16.97,'hutongstore','kurtl42','kurt@hanauer-automaten.de','Kurt Hanauer','Marktplatz 30','Pfreimd','','GERMANY','92536','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 09:10:35',0,NULL,3,1,3,1,NULL,'canon æœºèº«ç›–/é•œå¤´åŽç›–  1 \rå¤§å·ç°å¡   1\rçƒ­é´ç›–   1\rRE-A   1\rRR815344035CN\r\r'),(4267,616436310001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','lagunshop','lagun_shop@hotmail.com','Ozkan Gozu','Rasim pasa Mah. Uzunhafiz Sk.<br>no:25 kat:3 No:9','istanbul','Kadikoy','TURKEY','34716','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 09:27:46',0,NULL,3,1,5,1,NULL,' 2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\råŒç¯å¤´   æ¬§æ ‡ 2\ræŸ”å…‰ä¼ž  2\r45w   4\råŒ…   1\rç”³æŠ¥$50\rCP219486868CN'),(4268,655813406002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','pincianito','briskdal@hotmail.com','JOSE ALBERTO DUQUE VICENTE','BERNESGA, 9 6Âº D','LEÃ“N','Castilla y LeÃ³n','SPAIN','24010','654051136','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 10:23:10',0,NULL,8,1,17,0,NULL,NULL),(4269,655813277002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','pincianito','briskdal@hotmail.com','JOSE ALBERTO DUQUE VICENTE','BERNESGA, 9 6Âº D','LEÃ“N','Castilla y LeÃ³n','SPAIN','24010','654051136','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 10:23:11',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ 2m ( ç™½ï¼‰   1\r2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rYW864614841CN\r'),(4270,655839729002,120568891616,'Male-Male 52mm-52mm Reverse Macro 40D 450D 550D D90',1,'AA1211',3.8,'hermeshine','nikon2704','raven645@iol.cz','rene novak','zborovska 6','prague 5','CZ','CZECH REPUBLIC','150 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 12:22:05',0,NULL,8,1,17,0,NULL,NULL),(4271,616474180001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','nikon2704','raven645@iol.cz','rene novak','zborovska 6','prague 5','CZ','CZECH REPUBLIC','150 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 12:23:54',0,NULL,3,1,3,1,NULL,'52-52mm åŒé˜³  1\r52mm-nikon åæŽ¥çŽ¯  1\rRR815343967CN\r '),(4272,616485585001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',2,'AB1204',34,'hermeshine','banhtruong','vanmien@gmail.com','van nguyen','10 conley st<br>noble park','Mel','Victoria','AUSTRALIA','3174','0397983751','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 13:13:05',0,NULL,3,1,3,1,NULL,'717å¿«è£…æ¿  2 \rRR815343851CN\r'),(4273,715116299015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',2,'AKT007',25.98,'hutongstore','innerarmour','innerarmoursales@gmail.com','Adrian O Donnell','6 River Road Rhebouge','Limerick','Limerick','IRELAND','default','0872727624','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 13:23:42',0,NULL,3,1,3,1,NULL,'45w   4 \rRR815344004CN\r'),(4274,616489539001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','yekovekim','mike.vokey@gmail.com','Michael Vokey','13 Cahill Dr.','St. John\'s','Newfoundland','CANADA','A1A5H4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 13:28:48',0,NULL,3,1,3,1,NULL,'\r60cm æ£š   1 \rRR815343848CN\r\r'),(4275,715124720015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','nickreuland','nickreuland@eircom.net','Nicolas Reuland','4 Grange Park Close','Raheny','Dublin','IRELAND','D5','0876685013','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 13:49:17',0,NULL,3,1,2,1,NULL,NULL),(4276,616017175001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','rockforli','rockforli@libero.it','Luca Castellani','via Giuseppe Orceoli nÂ° 3 -  47122 FC','Forli - FC','FO','ITALY','47100','0543-796534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 14:07:44',0,NULL,3,1,2,1,NULL,NULL),(4277,655869490002,120439964418,'MACRO CLOSE UP Filter Lens kit +2 +3 +4 +8 40d d80 d90',1,'AKT012',23.6,'hermeshine','evolpexx','evolpe@smith.edu','elena volpe','221 Park Hill Rd','florence','MA','UNITED STATES','01062-9723','(413) 695-9799','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 14:21:25',0,NULL,3,1,1,1,NULL,'67mm   +2 +3 +4 +8 1 '),(4278,655879088002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','rogiwi','rogiwi@bluewin.ch','Roger Giger','Talmattring 4','Muhen','','SWITZERLAND','5037','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 14:48:05',0,NULL,3,1,3,1,NULL,'Canon èƒŒå¿ƒ  M  1\rè€ç‰ˆ \rRR815343777CN\r'),(4279,654418770002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','gasfire58','claudio.piovesana@fastwebnet.it','Claudio Piovesana','Via Ferrante Aporti, 32','Milano','MI','ITALY','20125','0039022822300','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 14:52:46',0,NULL,3,1,4,1,NULL,'717AH   1 \rhead ball  $20\rYW864614804CN'),(4280,715152005015,250692241952,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',2.4,'hutongstore','gianluca3735','gianluca.marinelli@tin.it','Gianluca Marinelli','Via dell\'annunziatella 129','ROMA','Roma','ITALY','00147','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 15:06:20',0,NULL,8,1,17,0,NULL,NULL),(4281,715151808015,250601900955,'Wireless Remote Control Cord for Canon 50D/40D/30D/20D',1,'AA3210',11.47,'hutongstore','gianluca3735','gianluca.marinelli@tin.it','Gianluca Marinelli','Via dell\'annunziatella 129','ROMA','Roma','ITALY','00147','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 15:06:20',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ C3   1\r58mmé•œå¤´ç›– canon  1 '),(4282,715160493015,250692242733,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'AA1309',2.4,'hutongstore','klausnjules','kanj@blueyonder.co.uk','David Harrison','43 Runshaw Avenue Appley Bridge','Wigan','Lancashire','UNITED KINGDOM','WN6 9JP','01257253157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-07 15:29:21',0,NULL,8,1,17,0,NULL,NULL),(4283,655872909002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',24.3,'hermeshine','esiskandar','esiskandar@yahoo.com.sg','Is\'al Ismail','Blk 787B, Woodlands Crescent,<br>#04-78','default','','SINGAPORE','732787','96971456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 15:29:21',0,NULL,3,1,3,1,NULL,'ND4 + ND8+ æ¸å˜ç°  1\r52mm çŽ¯æž¶  1\réº‚çš®  1\rRR815344049CN\r'),(4284,701185890016,260660055606,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',2,'hutongstore','klausnjules','kanj@blueyonder.co.uk','David Harrison','43 Runshaw Avenue Appley Bridge','Wigan','Lancashire','UNITED KINGDOM','WN6 9JP','01257253157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-07 15:32:21',0,NULL,3,1,2,1,NULL,'77mm é•œå¤´ç›–  nikon  1\r52mm é•œå¤´ç›–  nikon  1 '),(4285,700832949016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','jromey19','jromey@hotmail.co.uk','Jeremiah Williams','12 The Grove','Luton','Bedfordshire','UNITED KINGDOM','LU1 5PE','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-07 16:08:18',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  2 è‹±æ ‡\r115w 220v  2\råŒ…   1\rlighting kit  $30\rYW864614815CN\r\r '),(4286,715181072015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','markusandre1992','markus_andre1992@hotmail.com','Markus MollandsÃ¸y','Heiane 101','Bergen','Bergen','NORWAY','5131','+4794164348','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-07 16:21:34',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ é»‘ï¼‰   1\r2må®½çš„ \rbackground support  $25\rYW864614771CN'),(4287,715182955015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','diarek73','jar3@o2.pl','Jaroslaw Krausewicz','Ty\'n Rhos Country House','Seion, Caernarfon','Gwynedd','UNITED KINGDOM','ll55 3ae','01248670489','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-07 16:26:28',0,NULL,3,1,2,1,NULL,NULL),(4288,655918231002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6,'hermeshine','sadolkz','dolzhenko.sergei@gmail.com','Sergey Dolzhenko','Ch.Valihanova st., h-19/1, r-24','Temirtau','KZ','KAZAKHSTAN','101400','77015301392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 16:50:45',0,NULL,3,1,2,1,NULL,NULL),(4289,655926443002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','cdn_smiles','krae89@gmail.com','Kaitlynne-Rae Landry','301 Carlisle Road','Carlisle','ON','CANADA','L0R 1H2','(905) 689-5268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:16:20',0,NULL,3,1,2,1,NULL,' '),(4290,655928084002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','lucysdua','kiev.ua@gmail.com','Kateryna Cherepanova','PO Box 6143<br>a/c 6143','Lviv','UKRAINE','UKRAINE','79000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:16:33',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£æ£š å¡‘æ–™  1 \rRR815343817CN'),(4292,616517390001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','golfinkar','peterrichnak@zoznam.sk','Peter Richnak','Nedarska 43','Surovce','','SLOVAK REPUBLIC','91925','421949455988','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:17:19',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ æ¬§æ ‡  1 '),(4293,616569674001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:40:34',0,NULL,8,1,17,0,NULL,NULL),(4294,616569108001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:40:34',0,NULL,8,1,17,0,NULL,NULL),(4295,616568748001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:40:35',0,NULL,3,1,3,1,NULL,'45w 2\rå¤§å·ç°å¡  1\r80cm 5in1 åå…‰æ¿  1 \rRR815344083CN\r'),(4296,655947255002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','2400flying','kk@kkwil.com','Karl K. Wilson','505 S State','La Verkin','UT','UNITED STATES','84745','(435) 635-2400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 18:07:14',0,NULL,3,1,1,1,NULL,NULL),(4297,655952096002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',2,'AA1302',5,'hermeshine','lukek145','jessekeady@hotmail.com','luke keady','P.O. Box 985, Cowes','phillip island','Victoria','AUSTRALIA','3922','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:20:03',0,NULL,3,1,2,1,NULL,NULL),(4298,616592125001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.95,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:40:44',0,NULL,8,1,17,0,NULL,NULL),(4299,655947088002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:40:45',0,NULL,8,1,17,0,NULL,NULL),(4300,655959898002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 18:40:44',0,NULL,8,1,17,0,NULL,NULL),(4301,616579831001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:40:45',0,NULL,8,1,17,0,NULL,NULL),(4302,616579575001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:40:46',0,NULL,8,1,17,0,NULL,NULL),(4303,616587493001,110499652243,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:40:46',0,NULL,3,1,5,1,NULL,'æŸ”å…‰ä¼ž  1\råå…‰ä¼ž  1\rå•ç¯å¤´ æ¬§æ ‡  2\r45w   2\r50cm æ£š   1\rå¤§åŠ›å¤¹   1 \r2m ç¯æž¶  1\rCP219487320CN\r'),(4304,616602632001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','djuxa_pk','djuxapk@inbox.lv','Andrejs Turanovs','A.Saharova 19-42','Riga','Latvia','LATVIA','LV-1082','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 19:06:51',0,NULL,3,1,3,1,NULL,'肩架 1RR815344874CN'),(4305,655973190002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','ahcm','andre.mehta@gmail.com','Andre Mehta','2 Brookside Rd','Southborough','MA','UNITED STATES','01772-2046','(508) 229-2456','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 19:10:21',0,NULL,3,1,1,1,NULL,NULL),(4306,616332466001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',2,'AB1303',6.68,'hermeshine','foreverphotonashville1','foreverphotonashville@yahoo.com','rachel walker','320 W Maple St','morrison','TN','UNITED STATES','37357-7717','(615) 586-0743','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 19:20:49',0,NULL,3,1,1,1,NULL,NULL),(4307,655979533002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','joaobatista55','joao-fotografo@bol.com.br','JOÃƒO BATISTA MACÃŠDO DE ARAÃšJO','RUA ODILON SATOS ,19 ,RIO VERMELHO','SALVADOR','BAHIA','BRAZIL','41940-350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 19:26:37',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£å¡‘æ–™  2 \rRR815343905CN\r'),(4308,715273575015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'AA1309',1.88,'hutongstore','micky-cantona','info@creanfoto.com','Michael J Crean','48 Monastery Drive','clondalkin','Dublin','IRELAND','D22','0035314573166','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 19:38:14',0,NULL,3,1,2,1,NULL,NULL),(4309,715288932015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',7.75,'hutongstore','pmaccounts','pmservices1@hotmail.co.uk','scott Jefferies','141 Henley Avenue','North Cheam','Surrey','UNITED KINGDOM','SM3 9SD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-07 20:10:47',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ è‹±æ ‡  1 '),(4310,715299079015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','changkailung','kailung.chang@gmail.com','Kai Lung CHANG','17, rue des Pastoureaux','OrlÃ©ans','Centre','FRANCE','45000','0238543340','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 20:29:57',0,NULL,3,1,2,1,NULL,'45w    2 '),(4311,656008546002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','stafordyull','sk9875@gmail.com','Sergejs Kisils','6.Berwick Place, Swords Manor,<br>Swords','Dublin','Dublin','IRELAND','IRL','0876713245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 20:39:42',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶   1 \rreflector holder   $25\rYW864614793CN'),(4312,656011372002,120550514695,'Remote Control Wireless Shutter Release NIKON D90 D5000',1,'AA3226',35.5,'hermeshine','r.norvaisas22','r.norvaisas@yahoo.com','Ramunas  Norvaisas','574a rainham road<br>Dagenham','london','London','UNITED KINGDOM','rm10 7xd','447576865825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 20:47:16',0,NULL,5,1,18,0,NULL,'YN126-N3   1 '),(4314,616665234001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','sunnhippie','sunnhippie@hawaii.rr.com','Kimberly Kessler','PO Box 8197','Honolulu','HI','UNITED STATES','96830-0197','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 21:55:20',0,NULL,3,1,1,1,NULL,NULL),(4315,656050529002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','kaksl','kasias1@yahoo.com','Elisabeth Siwanowicz','5901 Spaatz Pl','Rockville','MD','UNITED STATES','20851','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 22:38:38',0,NULL,3,1,1,1,NULL,NULL),(4316,656060677002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','sladboy','sladkovic@gmail.com','Lubomir Sladkovic','Spartakovska 11','Trnava','','SLOVAK REPUBLIC','91701','+421944094249','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 23:12:09',0,NULL,3,1,3,1,NULL,'肩架 1RR815344931CN'),(4317,656063921002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','alexbelik','alex@alexbelik.com','Aleksander Belik','Naberegnaja 26-176','Energodar','Zaporizka','UKRAINE','71500','380502189039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 23:24:22',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4318,701391033016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','raijakee','raimond@harta.ee','RAIMOND JAKOBS','VARSAALLIKA 36','TALLINN','','ESTONIA','12013','(372) 600-6508','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-07 23:33:44',0,NULL,3,1,5,1,NULL,' 2mx3m èƒŒæ™¯æž¶  1\r3mx6m é»‘è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  2 æ¬§æ ‡\r115w 220v  2\råŒ…   1\rlighting kit  $30\rCP219486854CN\r\r '),(4319,616692019001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',6,'AA3315',35.7,'hermeshine','blue_bomber_gt-s','christian.fiore@gmail.com','Christian Fiore','15877 SW 11th Terrace Road','Ocala','FL','UNITED STATES','34473','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-07 23:41:52',0,NULL,3,1,1,1,NULL,'绿叶52mm 渐变灰 6片 '),(4320,616697925001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','jonm19670824','jonmalagon67@gmail.com','JON MALAGON ZALDUA','ARROBITXULO BIDEA, 13 1A ','ASTIGARRAGA','PaÃ­s Vasco','SPAIN','20115','658739287','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 23:52:30',0,NULL,3,1,4,1,NULL,'tripod  $22 \rYW864614782CN'),(4321,656062683002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',6,'AA1301',14.6,'hermeshine','vicki6347','vmayhew@comcast.net','Vicki Mayhew','4503 Menaul Blvd NE','Albuquerque','NM','UNITED STATES','87110-2953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 00:13:30',0,NULL,3,1,1,1,NULL,NULL),(4322,616704205001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','dave_075','davidpascolo@gmail.com','David Pascolo','Via Principe di Piemonte, 24','Campoformido','UD','ITALY','33030','3396563614','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 00:19:02',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(4323,616712467001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','anderskristoffer','anderss@stokkes.net','Anders Stokke','Prost Castbergs veg 11','Trondheim','SÃ¸r TrÃ¸ndelag','NORWAY','7051','(+47) 97197901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 00:56:07',0,NULL,3,1,2,1,NULL,NULL),(4324,656091185002,120508253684,'YONGNUO 8ft I-TTL Off-Camera Flash Sync Cord for Nikon',1,'AB3320',28.99,'hermeshine','and-the-greatest-of-these-is-love','lifetastic@gmail.com','Justin Morgan','1376 Miners Dr<br>STE 106','Lafayette','CO','UNITED STATES','80026-2988','(303) 219-0020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-08 01:16:20',0,NULL,3,1,1,1,NULL,'nikon ttl çº¿  3m   1 '),(4325,656091506002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','eliseogozalvez','eliseo_gozalvez@yahoo.com','ELISEO GOZALVEZ','BULNES 1642 PISO 8 DEPTO B','CAPITAL FEDERAL','BUENOS AIRES','ARGENTINA','1425','5411-4822-2946','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 01:18:05',0,NULL,3,1,2,1,NULL,NULL),(4326,616723033001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','brcash','rosscash@bellsouth.net','Ross Cash','5768 Descartes Cir','Boynton Beach','FL','UNITED STATES','33472-2429','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-08 01:48:23',0,NULL,3,1,1,1,NULL,'nikon å•è‚©åŒ… D1   1 '),(4327,616692113001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','bapsite','bapsite@hotmail.com','Baptiste Nobre','29 Nassau Street','Toronto','ON','CANADA','M5T1M3','(336) 838-5141 ext.: 0','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 02:15:47',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRR815343750CN\r'),(4328,656115200002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lucky_soi','irvia2000@yahoo.com','Oana Stan','2527 Crescent St<br>ap. Walk In','Astoria','NY','UNITED STATES','11102-2937','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 03:14:56',0,NULL,3,1,1,1,NULL,NULL),(4329,656126285002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','iceyfiery87','iceyfiery@singnet.com.sg','Wen Hao Wong','Hawkins Hall, Room 02010<br>430 Wood Street','West Lafayette','IN','UNITED STATES','47906','(765) 201-5093','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 04:06:01',0,NULL,3,1,11,1,NULL,' æ–°åœ°å€ï¼š\rWen Hao Wong\rBlk 457 Choa Chu Kang Ave 4\r#11-187\rSingapore 680457\rSingaporeRR815344463CN\r\r'),(4330,615775401001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',1,'AC1204',7.9,'hermeshine','bquan94545','vir94545@yahoo.com','bruce quan','3490 savage ave','pinole','ca','UNITED STATES','94564','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 04:30:27',0,NULL,3,1,1,1,NULL,'é•œå¤´ç­’ xl   1 '),(4331,616756680001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3403',37.95,'hermeshine','shriekingvioletta','shriekingvioletta@yahoo.com','april colby','260 forest street','chatham','ON','CANADA','N7L 2A9','(519) 397-3853','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 04:52:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  çº¢ç›’  1 \rRR815343675CN\r'),(4332,616766513001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','rajeshau1505','rajeshau15@gmail.com','parimala Karthigeyan','38 Castleton Rd','Princeton','NJ','UNITED STATES','08540-1647','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 06:07:34',0,NULL,3,1,1,1,NULL,NULL),(4333,715469902015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','andyvanddetta','andyvandetta@hotmail.com','AbdulRedha Ahmed','C/o Natalie Hollyman HR Manager Alghanim Industries Ext 3204 PF12920 P O Box 223 Safat 13003','Kuwait','','KUWAIT','965','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-08 06:53:22',0,NULL,8,1,17,0,NULL,'\r'),(4334,715472607015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','andyvanddetta','andyvandetta@hotmail.com','AbdulRedha Ahmed','C/o Natalie Hollyman HR Manager Alghanim Industries Ext 3204 PF12920 P O Box 223 Safat 13003','Kuwait','','KUWAIT','965','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 07:10:45',0,NULL,3,1,8,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´æ£š   2\r115w 220v   8\råŒ…   1\rCP219487347CN\r\r'),(4336,701495392016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','joneff51','desmo450@hotmail.com','John Farrell','12 Light Place Colonel Light Gardens','Adelaide','South Australia','AUSTRALIA','5041','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 07:45:22',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR815343661CN\r'),(4337,701498970016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','gerhold03','gerhold@btinternet.com','darren gerhold','90 kennerley rd, davenport','stockport','Cheshire','UNITED KINGDOM','SK2 6EY','01614560660','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-08 08:07:05',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…æ— å­—  1 '),(4338,701500405016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',3,'hutongstore','vyrusu','vyrusu_18@yahoo.com','Popa Razvan','25 Frunzei street, apartment 11','Timisoara','timis','ROMANIA','300495','40724866325','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 08:16:30',0,NULL,3,1,2,1,NULL,'450d çœ¼ç½©   1 '),(4339,656166852002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','zeonstrike','wattanadejj@hotmail.com','Wattanadej Jutacharoensuk','89/1 Soi Saparnqua Pracharaj2 road Bangsue','Bangkok','Bangkok','THAILAND','10800','66891371772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 08:54:48',0,NULL,3,1,3,1,NULL,'RR815343834CN\r '),(4340,656168682002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','www.photostudio.ch','ebay@photostudio.ch','Patrick Geissmann','Foto LÃ¼thard AG<br>Seminarstrasse 91','Wettingen','','SWITZERLAND','5430','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 09:05:53',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ xl   1\rè€æ¬¾ \rRR815343763CN\r'),(4342,616800715001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','david.wien','nachname.vorname@gmx.at','David Moser','Abelegasse 13-15','Wien','','AUSTRIA','1160','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 10:00:08',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR815343879CN\r'),(4343,616811445001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','furouribarri','paugomis@hotmail.com','Pau Gomis','Calle Segria 46 , 5Âº ,2Âª','Lleida','CataluÃ±a','SPAIN','25006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 10:47:33',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4344,616824229001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',5,'AB1201',85,'hermeshine','hans2900','hanzelmans@gmail.com','Hans Heins','Carrouselweg 117','Apeldoorn','','NETHERLANDS','7335PM','0031558431977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 11:42:47',0,NULL,3,1,4,1,NULL,'å€’å½±æ¿  5 \rYW864614826CN'),(4345,656204189002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','smar3250','scottmar@istar.ca','J. P McConnell','3 rue du Moulin','Courtauly','Languedoc-Roussillon','FRANCE','11230','(046) 869-5752','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 11:52:29',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864614874CN\r'),(4347,656214962002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','hanif0856','maninerror@gmail.com','Hanif, Muhammad','Gedung Temprint Lt.3<br>Jl. Palmerah Barat No.8','Jakarta Selatan','','INDONESIA','12210','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 12:39:13',0,NULL,3,1,3,1,NULL,'100-150 5in1 åå…‰æ¿  1 \rRR815343692CN\r'),(4348,656226680002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','prokudin-pavel','propadi@list.ru','Pavel Prokudin','Altayskaya st. 23-68','Nizhny Tagil','Sverdlovskaya obl','RUSSIAN FEDERATION','622004','+7-912-22-000-66','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 13:19:52',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ 2m ( ç™½ï¼‰   1\rCP219486871CN '),(4349,616851428001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','telezini','studio1@telezini.com','Sergio Marranzino','45 Gramercy Ave','Yonkers','NY','UNITED STATES','10701-5123','(914) 424-1066','NoPaymentFailure','CheckoutComplete','Other','2011-01-08 13:30:07',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR815343715CN\r'),(4350,616868193001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','avibarami','avi_barami@walla.co.il','Avi Barami','Binyamin 1','RAMAT GAN','','ISRAEL','52512','972506923925','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 14:24:43',0,NULL,5,1,18,0,NULL,NULL),(4351,701519697016,260660055167,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.95,'hutongstore','marcelloparola','m.stroh@gmx.ch','Marcel Stroh','In der WÃ¤sseri 37','ZÃ¼rich','','SWITZERLAND','8047','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 14:34:46',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4352,715611088015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','nottingham-forest','dmm@ebusinesslogic.com','David Mason','29 Boundary Close Kingsdown','Swindon','Wiltshire','UNITED KINGDOM','SN2 7TF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-08 15:20:52',0,NULL,3,1,2,1,NULL,'45w   2 '),(4353,616889283001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mixajura','mixajiri@gmail.com','Jiri Mixa','Bozeny Nemcove 1','Vyskov','','CZECH REPUBLIC','682 01','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 15:27:38',0,NULL,3,1,2,1,NULL,NULL),(4354,656276155002,120601698401,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','holcaul','holcaul22@yahoo.com','Philipp Voloshin','admonit 11, apt. 17','Lod','','ISRAEL','71338','97289203711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 15:50:43',0,NULL,3,1,2,1,NULL,'72mm 橡胶罩  1\r77mm 橡胶罩   1'),(4355,616899375001,110566018419,'72mm 3-Stage Rubber Lens Hood for 80-200mm 24-105mm',1,'AB1306',3.79,'hermeshine','holcaul','holcaul22@yahoo.com','Trecia Thomas','744 Noble Ave','Bronx','NY','UNITED STATES','10473-4115','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 16:01:38',0,NULL,8,1,17,1,NULL,'\r'),(4356,616932305001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','qqlll88','qiqilili88@gmail.com','Qiang Li','249 Colonnade Dr<br>Apt 6','Charlottesville','VA','UNITED STATES','22903-4931','(434) 284-0390','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 17:12:43',0,NULL,3,1,1,1,NULL,NULL),(4357,656317480002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','daniels3145','drdanny@earthlink.net','Daniel Schainholz, MPH','630 Lake St<br>Apt 303','San Francisco','CA','UNITED STATES','94118-1201','(415) 666-3765','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 17:29:18',0,NULL,3,1,1,1,NULL,NULL),(4359,616977855001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','atmapower2k','vinchy1@gmail.com','Jacques Baudoux','rue de la Chapelle 35','TriviÃ¨res','','BELGIUM','7100','0472551410','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 18:53:23',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR815343729CN\r'),(4360,656377984002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','alinochka14','alinochka14@yahoo.com','alina ozeruga','2201 Northview Dr<br>Apt 71','sacramento','CA','UNITED STATES','95833-2459','(916) 564-7315','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 19:43:09',0,NULL,3,1,1,1,NULL,'çˆµå½±æ— çº¿ N1  1 '),(4361,656374862002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',5,'AA3306',21,'hermeshine','minasnoivaswagner','minasnoivas-wagner@bol.com.br','wagner pereira da silva','av afonso pena 526 sl 708<br>centro','belo horizonte','Minas Gerais','BRAZIL','30130-001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 19:50:06',0,NULL,3,1,3,1,NULL,'RR815343785CN '),(4362,715758494015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.16,'hutongstore','oscarius87','oskars-miesnieks@inbox.lv','Oskars Miesnieks','Ciekurkalns 5. skerslinija 15/2 - 3','Riga','','LATVIA','LV-1026','26103660','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 19:56:24',0,NULL,3,1,2,1,NULL,'58mm-canon åæŽ¥çŽ¯  1 '),(4363,617020488001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',67,'hermeshine','monatemplada','jmuyshondt@gmail.com','iTrader Online','7801 NW 37TH ST<br>Ste VIP-2892','Doral','FL','UNITED STATES','33166-6503','(305) 394-6605','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 20:31:34',0,NULL,3,1,3,1,NULL,'æŸ”å…‰ç®± 50-70cm å•ç¯å¤´   2 \rRR815343940CN\r'),(4364,656402483002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','kizsoli10','kizsoli@gmail.com','Zsolt KirÃ¡ly','FÅ‘ utca 19. 3. emelet 2.','Budapest','','HUNGARY','1011','+36209758028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 20:41:06',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£ å¡‘æ–™  1 \rRR815343896CN\r'),(4365,617034066001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','bobzimlich','rzimlich@ussa.edu','Robert Zimlich','1 Academy Dr','Daphne','AL','UNITED STATES','36526-7055','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 21:03:55',0,NULL,3,1,3,1,NULL,'æŸ”å…‰ç®± 50-70cm å•ç¯å¤´  1 \r867RR815344517CN'),(4366,656415773002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','hamber_russia','hamber@bk.ru','Mikhail Kuznetsov','Tatyany Makarovoy street 3,307','Moscow','RU','RUSSIAN FEDERATION','111674','(926)566-4200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 21:08:07',0,NULL,3,1,2,1,NULL,NULL),(4367,656411519002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','kbra3748','kenyatta.brame@cascadeng.com','kenyatta brame','2531 Barfield Dr SE','grand rapids','MI','UNITED STATES','49546-5507','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 21:16:02',0,NULL,3,1,1,1,NULL,NULL),(4368,617037185001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','aimerladybird','samuelcapdeville@hotmail.com','Buizard David','ThÃ©Ã¢tre du Soleil Cartoucherie<br>Route des grandes manoeuvres','Paris','Ile-de-France','FRANCE','75012','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 21:17:32',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR815343865CN\r'),(4369,715818243015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',7.75,'hutongstore','sick.pig','thomasbuckley1@hotmail.com','Thomas Buckley','51 Intake Lane Rodley','Leeds','West Yorkshire','UNITED KINGDOM','LS13 1BT','01132561244','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-08 21:54:30',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ è‹±æ ‡   1 '),(4370,656449257002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','psasacp17hg','number1oregonbroker@yahoo.com','Erik Berglund','1831 SW Park Ave<br>Apt 404','Portland','OR','UNITED STATES','97201-3279','(971) 226-5874','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 22:36:46',0,NULL,3,1,1,1,NULL,NULL);
INSERT INTO `hmsh_ebay_transaction` VALUES (4371,617098159001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','1mans_tresjya','nweideman@bigpond.com','Nick Weideman','Level 5, 440 Collins St','Melbourne','Victoria','AUSTRALIA','3000','0359774555','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 00:32:12',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \ræ½˜'),(4372,715880801015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','love_bat','dennissterne@hotmail.com','Dennis Sterne','59 Pageant Rd','St Albans','Herts','UNITED KINGDOM','AL1 1NB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 00:41:26',0,NULL,3,1,2,1,NULL,NULL),(4373,715850452015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','d-missy-p','debsiporter@googlemail.com','Debi Porter','15 Lanhydrock Close Compton Vale','Paignton','Devon','UNITED KINGDOM','TQ3 3GP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 00:41:53',0,NULL,3,1,2,1,NULL,NULL),(4374,656489358002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','bockcaron','mcgignac@gmail.com','hugues caron','43 ste-julienne','trois-rivieres','QC','CANADA','g8t4r6','(819) 909-1839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 00:54:11',0,NULL,3,1,2,1,NULL,NULL),(4375,617106722001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',2,'AKT029',48,'hermeshine','kq','d29501@gmail.com','Dan Hicks','137 S Coit St','Florence','SC','UNITED STATES','29501','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 00:57:22',0,NULL,3,1,1,1,NULL,' 8-      52mm lens cap for Nikon \r6-      62mm lens cap for Nikon\r2-      67mm lens cap for Nikon\r2-      72mm lens cap for Nikon\r2-      77mm lens cap for Nikon\r\r'),(4376,656501347002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','sammysue2u','samantha.roth2u@gmail.com','Samantha Roth','500 Rainbow Dr','Kokomo','IN','UNITED STATES','46902','(765) 453-3002','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 01:43:34',0,NULL,3,1,1,1,NULL,NULL),(4377,617117870001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','kirwinj','kirwinja@knology.net','John Kirwin','709 Wynsom Dr SE','Huntsville','AL','UNITED STATES','35803','(256) 508-3448','NoPaymentFailure','CheckoutComplete','Other','2011-01-09 01:45:27',0,NULL,3,1,1,1,NULL,'sf18-sb900   1 '),(4378,656502415002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','shabas.muhammed','shabasmuhammed@gmail.com','Shabas Muhammed','21/17<br>Park St','Hawthorn','Victoria','AUSTRALIA','3122','00610431947765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 01:45:42',0,NULL,3,1,2,1,NULL,'6662aå¿«è£…æ¿  1 '),(4379,656460241002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','stef0303','stefanidangelo@gmail.com','Stefani D\'Angelo','909 E Broad St<br>Apt 530','Athens','GA','UNITED STATES','30601-4841','(678) 276-5939','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 02:06:59',0,NULL,3,1,1,1,NULL,NULL),(4380,617128691001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','hassanteyx','hassanteyz@hotmail.com','hassan thalhath','ma.pashens','male\'','machan goalhi','MALDIVES','00960','(960)9743604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 02:33:10',0,NULL,3,1,2,1,NULL,'canon-58mm åæŽ¥çŽ¯  1 '),(4381,701929852016,260660053110,'New IR Remote Control for Pentax K10D K20D K200D',1,'AA2205',2.75,'hutongstore','countcharlie','charles.dp@ntlworld.com','Charles de Podesta','46 Filbert Street East','Leicester','Leicestershire','UNITED KINGDOM','LE27JE','0116228059','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 03:05:29',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§ 5in1   1 '),(4382,656530758002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','wrc78','pdenys@wp.pl','Paul Denys','140 Maranda Close NE','Calgary','AB','CANADA','T2A 3E8','(403) 539-8933','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 03:50:33',0,NULL,3,1,2,1,NULL,NULL),(4383,617160160001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','appenzeller98','hjstehr@web.de','Hans Joachim Stehr','HÃ¼nninghausenweg 29','Essen','NRW','GERMANY','45276','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 05:16:13',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚  1 \rlight stand  $20 \rYW864143860CNåŠ åˆ°è¿™è¡Œäº†'),(4385,617161815001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','djkramer1','djkramer@aol.com','Darren Kramer','92 Genesee Ln','Madison','CT','UNITED STATES','06443-1666','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 05:27:37',0,NULL,3,1,1,1,NULL,NULL),(4386,617162835001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','blackmajj','info@bassment.se','Petri Jokinen','Kverndalslinna 2','Gran','','NORWAY','2750','4798830923','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 05:32:58',0,NULL,3,1,3,1,NULL,'肩架 1\rRR815344959CN\r'),(4387,617185295001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','jantanjo','jan@cbbe.tv','jan tanjo','47 - 9870 151 st','surrey','BC','CANADA','v3r 8c9','(760) 705-8888','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 08:19:04',0,NULL,3,1,3,1,NULL,'RR815343919CN\r '),(4388,656576882002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','maoriboy.nz','rgcampbell.nz@gmail.com','Ross Campbell','Smales Farm, Telstraclear Building, Taharoto and Northcote Rd<br>Takapuna','Auckland','','NEW ZEALAND','0622','64299125740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 08:42:50',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4389,617200147001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','beecacher','edcylam@yahoo.com','Edmund Lam','170 West Tasman Dr','San Jose','CA','UNITED STATES','95134','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 09:27:23',0,NULL,3,1,1,1,NULL,NULL),(4390,617201711001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','jjacek59','jacekjackiewicz@bredband.net','Jacek Jackiewicz','Nobelv.89','MalmÃ¶','SkÃ¥ne','SWEDEN','21433','0704547235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 09:35:59',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹çƒå° 2 \rRR815343936CN\r'),(4392,702016995016,260660051940,'New 52mm 52 Ring adapter and Holder for Cokin P Series',1,'AKT018',3.62,'hutongstore','prendydo','prendydor@pt.lu','Dorothee Prendergast','5 Rue Michel Welter','OLM','','LUXEMBOURG','L-8339','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 10:15:04',0,NULL,8,1,17,0,NULL,NULL),(4393,702020403016,260660055606,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',2,'hutongstore','prendydo','prendydor@pt.lu','Dorothee Prendergast','5 Rue Michel Welter','OLM','','LUXEMBOURG','L-8339','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 10:15:04',0,NULL,8,1,17,0,NULL,NULL),(4394,702018664016,260660052333,'New 72mm Ring adapter for Cokin P Series Filter Holder',1,'AA2213',2.39,'hutongstore','prendydo','prendydor@pt.lu','Dorothee Prendergast','5 Rue Michel Welter','OLM','','LUXEMBOURG','L-8339','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 10:15:04',0,NULL,8,1,17,0,NULL,NULL),(4395,702019261016,260660054471,'TianYa Gradual Gray Plexigl Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','prendydo','prendydor@pt.lu','Dorothee Prendergast','5 Rue Michel Welter','OLM','','LUXEMBOURG','L-8339','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 10:15:05',0,NULL,8,1,17,0,NULL,NULL),(4396,716010932015,250599947231,'New 3 filters & Ring set for Cokin System P Series',1,'AKT062',15,'hutongstore','prendydo','prendydor@pt.lu','Dorothee Prendergast','5 Rue Michel Welter','OLM','','LUXEMBOURG','L-8339','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 10:15:05',0,NULL,3,1,3,1,NULL,'ND2, 4, 8   \ræ¸å˜ç°  1\r72mm æŽ¥å£çŽ¯  1\r52mm çŽ¯æž¶  1\r52mm é•œå¤´ç›–  nikon   1 æ½˜RR815344830CN\r'),(4397,617222280001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',65.96,'hermeshine','l.khabaz','lutfimk@gmail.com','Lutfi M. Al-Khabaz','P.O.Box # 11627<br>Saudi Aramco','Dhahran','Eastern','SAUDI ARABIA','31311','00966504908852','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 10:42:49',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   2 \r2kgä»¥å†…\rRR815343746CN\r'),(4398,617223741001,110566018453,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','haavard79','haavard_myhre@yahoo.no','HÃ¥vard Myhre','BrÃ¸drene Bergs vei 7','VÃ¥ler','Moss','NORWAY','1592','+47 90958397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 10:48:12',0,NULL,8,1,17,0,NULL,''),(4399,617227289001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','haavard79','haavard_myhre@yahoo.no','HÃ¥vard Myhre','BrÃ¸drene Bergs vei 7','VÃ¥ler','Moss','NORWAY','1592','+47 90958397','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 10:58:06',0,NULL,3,1,3,1,NULL,'10ç‰‡è£…   1\r77mm çŽ¯æž¶  1\r72mm çŽ¯æž¶  1 \rRR815344052CN\r'),(4400,656613545002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','falinicesc','faliniji17@gmail.com','Chakkij Israngoor Na Ayoothaya','87/243 Karnkanok 1 Village<br>M.12 T.Sankampang A.Sankampang','Chiangmai','','THAILAND','50130','0819611476','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 10:58:12',0,NULL,3,1,2,1,NULL,NULL),(4401,702054526016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.39,'hutongstore','dilon44','gmurillomendez1@elmejor.e.telefonica.net','Gaspar Murillo Mendez','lopez de tovar 14 2A','badajoz','Extremadura','SPAIN','06008','696427065','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 11:29:48',0,NULL,3,1,2,1,NULL,'58mm æŽ¥å£çŽ¯  1 '),(4402,702049062016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','stephenebi01','ebi01@hotmail.com','Stephen Agisilaou','1/146 St Kilda Road St Kilda','Melbourne','Victoria','AUSTRALIA','1382','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-09 11:53:43',0,NULL,3,1,4,1,NULL,' 2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  2 æ¾³æ ‡\r115w 220v  2\råŒ…   1\rlighting kit  $30\rYW864143856CN\r '),(4403,617250716001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','rocio779','mafiosa_779@hotmail.com','Rocio Garcia Alonso','Sambara 55 1ÂºB','Madrid','Madrid','SPAIN','28027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 12:06:10',0,NULL,3,1,2,1,NULL,NULL),(4404,656651906002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','alexbraso','alex.bra@gmail.com','Alexandre Braso','al. barao de limeira, 511 - ap62','sao paulo','SP','BRAZIL','01202001','55-11-33617442','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 12:49:02',0,NULL,3,1,5,1,NULL,'4ç¯å¤´æ£š  æ¬§æ ‡   2\rCP219486845CN '),(4405,656677895002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','lepreghaun','lepreghaun@hotmail.com','Hakan Oztopcu','IBM ISSC<br>KÃ¶ztelek utca 6','Budapest','Hungary','HUNGARY','1092','362053312825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 13:56:00',0,NULL,3,1,2,1,NULL,'90th è‚©å¸¦  1 '),(4406,617298278001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','isocron','morgan.morleh@gmail.com','Morgan MorlÃ©h','Ã– LinnÃ©gatan 5','Kumla','Sweden','SWEDEN','69232','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 14:09:05',0,NULL,8,1,17,0,NULL,''),(4407,656687001002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','isocron','morgan.morleh@gmail.com','Morgan MorlÃ©h','Ã– LinnÃ©gatan 5','Kumla','Sweden','SWEDEN','69232','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 14:15:50',0,NULL,3,1,2,1,NULL,'RS-C3    1 \r40cm æ£š  1 '),(4408,656697124002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','gogogottshall','riptidebumblingbee@gmail.com','Beth Gottshall','106 S Miller St','Shillington','PA','UNITED STATES','19607','','NoPaymentFailure','CheckoutComplete','Other','2011-01-09 14:41:29',0,NULL,3,1,1,1,NULL,'ç¢—ç½© P1  1 '),(4409,617313367001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','massimolc','maxlc@fastwebnet.it','Massimo La Cecilia','via Amerigo Vespucci 41','Roma','Roma','ITALY','00153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 14:44:08',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹çƒå°  1 '),(4410,656700181002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','spirou54250','yvan.bombarde@free.fr','Yvan Bombarde','54 rue Charles Martel','Champigneulles','Lorraine','FRANCE','54250','06.07.59.44.92','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 14:48:25',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\rbåº§   2\ræŸ”å…‰ä¼ž   2\rlight kit  $25 \rYW864143882CN'),(4411,716180037015,250692240830,'Wireless Remote Control for Olympus E-420/E-410/E-400',1,'AA3229',11.47,'hutongstore','rolfinge12','rolf.kvernstad@online.no','Rolf Inge Kvernstad','HansÃ¸yveien 5','6520 Frei','Frei','NORWAY','6520','+4799722279','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 15:55:04',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ olympus  1 '),(4412,617348102001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','chantilly_mckinnon','chantilly.mckinnon@gmail.com','Chantilly McKinnon','B - 532 Bolivar Street','Peterborough','ON','CANADA','K9J 4R8','(705) 768-4725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 15:59:32',0,NULL,8,1,17,0,NULL,''),(4413,617350031001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','chantilly_mckinnon','chantilly.mckinnon@gmail.com','Chantilly McKinnon','B - 532 Bolivar Street','Peterborough','ON','CANADA','K9J 4R8','(705) 768-4725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 15:59:31',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—  1 \réº‚çš®  1 '),(4414,617351088001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','pellejodirt','locomoteros@yahoo.es','Jose Ignacio Guio Antolin','C/ Montemayor de Pililla nÂº15 3ÂºC','MADRID','Madrid','SPAIN','28043','913886058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 16:00:53',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—  1  '),(4415,617353771001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','bxhylander','wjlappe@hotmail.com','William Lappe','1239 Mayflower Ave','Bronx','NY','UNITED STATES','10461-6109','(646) 924-9095','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 16:06:19',0,NULL,3,1,1,1,NULL,NULL),(4416,656743049002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','icmatyi1','icmatyi@gmail.com','GÃ¡bor Fekete','TÃ¡ncsics M utca 150.','MezÅ‘keresztes','','HUNGARY','3441','0036703738980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 16:16:13',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4417,656745416002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',6,'AA1312',9,'hermeshine','guillaume0987','guillaumenadeau@videotron.ca','Guillaume Nadeau','595 d\'Aiguillon','Quebec','QC','CANADA','g1r 1m6','(418) 522-1512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 16:17:23',0,NULL,3,1,3,1,NULL,'éº‚çš®  6\rRR815343984CN\r'),(4418,656782518002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','arl999261','kaczmarskir@op.pl','Ewelina KACZMARSKA','35 ALEXANDRA ROAD','Southampton','Hampshire','UNITED KINGDOM','SO15 5DH','02380636131','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 17:16:39',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…  a1   1 \rRR815343998CN\r'),(4419,617466783001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','dmitriyla','info@da-group.ru','Dmitriy Lagunov','Uinskaya 1b-26','Perm','Permski krai','RUSSIAN FEDERATION','614051','83422712669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 18:50:45',0,NULL,3,1,3,1,NULL,'1è½¬4ç¯å¤´   2 \rRR815343794CN\r'),(4420,617478980001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','copperdoggi','e.k.choy@gmail.com','Evan Choy','2202 Erin Centre Blvd.','Mississauga','ON','CANADA','L5M 5C1','(226) 220-3788','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 19:05:27',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR815343803CN\r'),(4421,716345833015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1307',5.16,'hutongstore','christianhylse','christian.hylse@telia.com','Christian Hylse','GrÃ¥bovÃ¤gen 5','Ronneby','Blekinge','SWEDEN','37239','0705-275714','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 19:07:22',0,NULL,3,1,2,1,NULL,' '),(4422,617486776001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','rpm_916','ebay.6qv@gishpuppy.com','Rex Mendoza','1425 Leaf Ter','San Diego','CA','UNITED STATES','92114-6820','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 19:11:16',0,NULL,3,1,1,1,NULL,'è‚¥çš‚ç›’ 430ex   1 '),(4423,617500498001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.95,'hermeshine','trinity_studios','lovefoundanew@gmail.com','Paul Griffith','14344 Polo Ranch St','Haslet','TX','UNITED STATES','76052-3327','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-09 19:28:06',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  1 '),(4424,656902158002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','alxg3','alxgag3@gmail.com','Alexander Vedeler','Fjellveien<br>123','Bergen','Hordaland','NORWAY','5019','+4797514080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 19:49:52',0,NULL,3,1,2,1,NULL,'æ°”å¹+å¸ƒ   1 '),(4425,702395731016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','barb3jp','roger.barbaraplatt@googlemail.com','Mrs B Platt','36 Monument Way','Ulverston','Cumbria','UNITED KINGDOM','LA12 9SY','07791130563','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 20:01:03',0,NULL,3,1,2,1,NULL,NULL),(4426,656924746002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','tocklee8831','tocklee@live.ca','Tock Lee','15131 Kennedy Road','Stouffville','ON','CANADA','L4A 7X5','(905) 888-8831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:25:41',0,NULL,8,1,17,0,NULL,NULL),(4427,656918232002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',17.99,'hermeshine','tocklee8831','tocklee@live.ca','Tock Lee','15131 Kennedy Road','Stouffville','ON','CANADA','L4A 7X5','(905) 888-8831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:25:42',0,NULL,8,1,17,0,NULL,NULL),(4428,617535565001,110533631226,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','tocklee8831','tocklee@live.ca','Tock Lee','15131 Kennedy Road','Stouffville','ON','CANADA','L4A 7X5','(905) 888-8831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:25:42',0,NULL,3,1,3,1,NULL,'72mm æ©¡èƒ¶ç½©   1\ré˜²é›¨ç½©   1\rè‚¥çš‚ç›’ 580exII     1 \rRR815343975CN\r'),(4429,716427876015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'AKT024',3.62,'hutongstore','bilbo_baggins1','abartup@aol.com','Andrew Bartup','21 Cowley Drive Woodingdean','Brighton','East Sussex','UNITED KINGDOM','BN2 6WB','01273302218','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 20:34:15',0,NULL,8,1,17,0,NULL,NULL),(4430,716430169015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',2.39,'hutongstore','bilbo_baggins1','abartup@aol.com','Andrew Bartup','21 Cowley Drive Woodingdean','Brighton','East Sussex','UNITED KINGDOM','BN2 6WB','01273302218','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 20:37:02',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶  1\r67mm æŽ¥å£çŽ¯  1 '),(4431,656938037002,120560330004,'64pcs LED Light Flash Camcorder/Camera Photo Light ',1,'AB3317',36.99,'hermeshine','cbarrondj','cbarron88@gmail.com','Cory Barron','11500 N Dale Mabry Hwy<br>APT 1402','Tampa','FL','UNITED STATES','33618-3854','(813) 679-5737','NoPaymentFailure','CheckoutComplete','Other','2011-01-09 20:40:44',0,NULL,3,1,1,1,NULL,NULL),(4432,617550698001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','kazakh082010','chompy@mail.ru','Alyona Burova','Chokin 23/1-31','Pavlodar','','KAZAKHSTAN','140008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:42:38',0,NULL,3,1,2,1,NULL,NULL),(4433,617556666001,110566020598,'New GGS Digital Camera 3.0\" LCD Screen Protector Glass ',1,'AB2208',5.6,'hermeshine','ecourtey','evelyne_courteyn@yahoo.com','Evelyne Courteyn','Kerkstraat 24A bus1','Deftinge','','BELGIUM','9570','+3254245665','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:50:44',0,NULL,3,1,2,1,NULL,'ggs 3.0â€™ è†œ   1 '),(4434,702436742016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'AA2204',2.75,'hutongstore','wysecom','antti.mikkola@netti.fi','Antti Mikkola','Kammintie 6','SF','JyvÃ¤skylÃ¤','FINLAND','40520','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 20:56:37',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§ olympus  1 '),(4435,617561197001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','czinbr','czinovich@sasktel.net','Celina Zinovich','101 4th Ave S<br>PO Box 858','Big River','SK','CANADA','S0J0E0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:58:53',0,NULL,3,1,2,1,NULL,NULL),(4436,716448364015,250643703886,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','crucialpro2010','alex@alexhibbert.com','Alexander Hibbert','314 The Bridge 334 Queenstown Road','London','London','UNITED KINGDOM','SW8 4NP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 21:02:26',0,NULL,3,1,2,1,NULL,'1.6x2.1 é»‘è‰²èƒŒæ™¯å¸ƒ  1 '),(4437,617566204001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','gidi2011','gidi.binder@gmail.com','gidi binder','amizur shimshon 9/6','beer sheva','beer sheva','ISRAEL','84717','972544718723','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 21:09:13',0,NULL,3,1,2,1,NULL,'nikon-52mm åæŽ¥çŽ¯  1 '),(4438,656956570002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','kzoo10s','m_malvitz@hotmail.com','Michael Malvitz','352 Calkins Ave SE','Grand Rapids','MI','UNITED STATES','49506-1522','(269) 377-3500','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 21:12:36',0,NULL,3,1,1,1,NULL,NULL),(4439,617570151001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3303',6.8,'hermeshine','imkratelsinore','irelsinore@yahoo.co.uk','Ian Robertson','7 elsinore<br>Castletroy','Limerick','','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 21:14:53',0,NULL,3,1,2,1,NULL,' '),(4440,716476468015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','stuinboro','emma.c.232@btinternet.com','Stuart Carter','10 Water End Brompton','Northallerton','N Yorkshire','UNITED KINGDOM','DL6 2RL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 21:43:43',0,NULL,3,1,2,1,NULL,NULL),(4441,716489896015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','ivolondon','ivo__g@hotmail.com','Ivo Gormley','3 Elwin Street','Tower Hamlets','London','UNITED KINGDOM','E2 7BU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 22:10:48',0,NULL,3,1,2,1,NULL,NULL),(4442,716497690015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','trifasic13','anxel13@hotmail.com','Angel Badia Guix','Barri de Coma nÂº37','CARDONA','BARCELONA','SPAIN','08261','652676743','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 22:21:59',0,NULL,3,1,3,1,NULL,'4ç¯å¤´æ£š   1  æ¬§æ ‡  1 \rRR815343922CN'),(4443,702502818016,260660055167,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.95,'hutongstore','smokeybluecat1','djnstafford@gmail.com','David Stafford','48 Eleanor Road','London','London','UNITED KINGDOM','N11 2QS','07702329959','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 22:39:45',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4444,657002369002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','klong09','avalino@yahoo.com','Al Valino','35 Poppy Place','Scarborough','ON','CANADA','M1X1Y7','(647) 567-2200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 22:43:57',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4445,617621168001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','tatikaltatiana','tatikalantzi@yahoo.gr','Kalantzi Tatiana','mithridatou 13-15','Athens','Greece','GREECE','11632','(0030)6974634689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 23:12:28',0,NULL,8,1,17,0,NULL,NULL),(4446,657012389002,120598267593,'New Camera shoulder bag nova 4 with raincover 4 7D 5Dii',1,'AO0024',40.99,'hermeshine','tatikaltatiana','tatikalantzi@yahoo.gr','Kalantzi Tatiana','mithridatou 13-15','Athens','Greece','GREECE','11632','(0030)6974634689','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 23:12:28',0,NULL,3,1,3,1,NULL,'60cm æ£š  1\rcanon å•è‚©åŒ…  N4   1 RR815344525CN'),(4447,657032026002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','artboolid','pechenyy@gmail.com','Pechenyy Vasil','Prostornaya st. 8 ap. 152','Moscow','','RUSSIAN FEDERATION','107392','+7(925)0065940','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 00:13:16',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ï¼‰ 1.6å®½çš„ 1\r2m ç¯æž¶  2\råŒç¯å¤´  æ¬§æ ‡   2\råå…‰ä¼ž   2\r115w   220v   4\råŒ…   1 \rCP219486823CN'),(4448,657037371002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','fashion-rtn','enzons78@gmail.com','Onur Kaya','13 rue richard Byrd','Mantes La Jolie','ÃŽle-de-France','FRANCE','78200','0615271775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 00:18:31',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815343732CN\r'),(4449,657050479002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','kampong_boy','eric@treasure-images.com','Eric and Cheryl Madeja','Taman Hilton, Lrg Hilton 6, House 62<br>Jalan Penampang','Kota Kinabalu','Sabah','MALAYSIA','88200','0128382272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 00:59:22',0,NULL,3,1,2,1,NULL,'58mm æ¸å˜ç°  1 '),(4450,617361725001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','mstr2438','mironstrutinski@gmail.com','Miron Strutinski','611  28thStreetWest','Saskatoon','SK','CANADA','S7L 0L2','(306) 384-4392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 01:02:10',0,NULL,8,1,17,0,NULL,NULL),(4451,656745917002,120560203215,'Nikon 52mm Reverse Adapter Combined shipping discounts',1,'AA1210',4.4,'hermeshine','mstr2438','mironstrutinski@gmail.com','Miron Strutinski','611  28thStreetWest','Saskatoon','SK','CANADA','S7L 0L2','(306) 384-4392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 01:02:11',0,NULL,3,1,2,1,NULL,'52mm-nikon  åæŽ¥çŽ¯  1\r55mm æ©¡èƒ¶   1 '),(4452,617666338001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',67,'hermeshine','rix3783','mrix@bigpond.net.au','Mike Rix','8 Aldag Court','Karratha','Western Australia','AUSTRALIA','6714','610891441648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 02:13:53',0,NULL,8,1,17,0,NULL,NULL),(4453,617665715001,110625498117,'Photo  Background Support 2 x 2m (7Ã—2 ft) + Backdrop',1,'AO0010',70,'hermeshine','rix3783','mrix@bigpond.net.au','Mike Rix','8 Aldag Court','Karratha','Western Australia','AUSTRALIA','6714','610891441648','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 02:13:54',0,NULL,8,1,17,0,NULL,NULL),(4454,657077925002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',111.98,'hermeshine','rix3783','mrix@bigpond.net.au','Mike Rix','8 Aldag Court','Karratha','Western Australia','AUSTRALIA','6714','610891441648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 02:18:25',0,NULL,8,1,17,0,NULL,NULL),(4455,657080045002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',70,'hermeshine','rix3783','mrix@bigpond.net.au','Mike Rix','8 Aldag Court','Karratha','Western Australia','AUSTRALIA','6714','610891441648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 02:24:02',0,NULL,3,1,4,1,NULL,'è“è‰²ï¼Œç»¿è‰²èƒŒæ™¯æ¿   1\r60cm é—ªå…‰ç¯æ£š   2\rèƒŒæ™¯æž¶ï¼ˆæ²³åŒ—ï¼‰  ç™½è‰²å¸ƒ   1\r50-70 å•ç¯å¤´æ£š  æ¾³æ ‡  2\rYW864614852CN\r\r'),(4456,657095425002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','setiya_tarun','setiya_tarun@yahoo.com','Tarun Setiya','4020 St. Jean, Apt#610','Dollard Des Ormeaux','QC','CANADA','H9G2L6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 03:13:29',0,NULL,3,1,2,1,NULL,NULL),(4457,617724741001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3401',59.25,'hermeshine','rconline2010','remielcomia@gmail.com','Remiel Comia','c/o Ansari Engineering Services 3rd Floor, House 338 Sabha Bldg<br>Rd 1705, Diplomatic Area 317','Manama','Diplomatic Area','BAHRAIN','10122','97339881831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 05:30:30',0,NULL,3,1,3,1,NULL,'110cm 5in1   2 RR815344485CN'),(4458,617727047001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','sazamora26','sazamora23@aol.com','Sean Zamora','21307 E Venton St','Covina','CA','UNITED STATES','91724-1937','(626) 827-3553','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 05:51:36',0,NULL,3,1,1,1,NULL,'1.6m x2.1m  èƒŒæ™¯å¸ƒ  2\ré»‘è‰² + çº¢è‰²  '),(4459,657136444002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rudygree','lolobartolo@hotmail.com','francisco manuel cano rodriguez','c/ joan josep amengual i reus nÂº51 2ÂºA','binissalem','Islas Baleares','SPAIN','07350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 06:32:09',0,NULL,3,1,2,1,NULL,NULL),(4460,657136443002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','jiriv','j.vanek@email.cz','Jana Langrova','Hulvacka 11','Ostrava Zabreh','','CZECH REPUBLIC','70030','420776276152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 07:11:40',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(4461,657152432002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','emeuvede','emeuvede@hotmail.com','Marco ValdÃ©s DÃaz','Calle del MosÃ©n Jacinto Verdaguer<br>Portal 9 Puerta 8','Valencia','Comunidad Valenciana','SPAIN','46008','656873563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 08:20:45',0,NULL,8,1,17,1,NULL,''),(4462,617752165001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','michaelkl2009','michaelkl@mail.ru','Michael Klimenko','Gaydara 27-55','Ozersk','Chelyabinsk region','RUSSIAN FEDERATION','456785','79222350750','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 08:38:48',0,NULL,3,1,5,1,NULL,' CP219487846CN\r'),(4464,657153652002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','terpus','bterpus@yahoo.com','Boris Terpinov','Permyakova, 43 building, 41 apt.','Tyumen','Tyumen region','RUSSIAN FEDERATION','625051','(3452)339789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 08:43:00',0,NULL,8,1,17,0,NULL,NULL),(4465,617750493001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','terpus','bterpus@yahoo.com','Boris Terpinov','Permyakova, 43 building, 41 apt.','Tyumen','Tyumen region','RUSSIAN FEDERATION','625051','(3452)339789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 08:43:01',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§    1\ræŸ”å…‰ä¼ž    1\rå¤§åŠ›å¤¹çƒå°  1 RR815344432CN'),(4466,617752686001,110414472986,'Remote Cord Shutter Release for Nikon D200 D3 = MC-30',1,'AA3207',4.18,'hermeshine','2011code','setsero02@gmail.com','orestes martinez','isla de la graciosa 14 bajo B<br>vecindario','las palmas','Canarias','SPAIN','35110','928716246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 09:28:30',0,NULL,3,1,2,1,NULL,'RS-N1   1 '),(4467,656581302002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','istokka','admoccia@alice.it','antonio chiacchio','via gramsci 55','frattaminore','NA','ITALY','80020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 09:43:31',0,NULL,3,1,4,1,NULL,'4ç¯å¤´æ£š   2 \rYW864614863CN\r'),(4468,657170183002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','albiertas','apa@dge-baltic.lt','Albertas Paplauskas','Bajoru kelias 5-29','Vilnius','','LITHUANIA','08459','(370) 68618648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 10:03:47',0,NULL,3,1,2,1,NULL,'\r '),(4469,616807921001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',52.99,'hermeshine','bigmommapaul','bumblebel@hotmail.com','Belinda Turpin','290 Everard Road','Kyabram','Victoria','AUSTRALIA','3620','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-10 10:08:03',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž  1 RR815344450CN'),(4470,716707505015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','aadr2673','albertino.adriani@gmail.com','Alberto adriani','500 archway road','London','London','UNITED KINGDOM','N6 4NA','07763185423','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-10 10:20:06',0,NULL,3,1,2,1,NULL,NULL),(4471,657179830002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','11_remix_11','11remix11@rambler.ru','Aleksander Remishevskiy','Kurchatova str. 4/1, ap.108','Khmelnitskiy','Khmelnitskiy','UKRAINE','29025','+38-068-202-102-7','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 10:45:23',0,NULL,3,1,2,1,NULL,NULL),(4472,657190222002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','jds31415','jdsebay1@xemaps.com','James  Schroeder','1988 Ririe Cir','Idaho Falls','ID','UNITED STATES','83404-5709','(208) 524-4143','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-10 11:36:53',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  1 '),(4473,617687723001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',44.78,'hermeshine','boogii1','gabortoronto@gmail.com','Gabor Bognar','902-555 Sheppard Ave W','Toronto','ON','CANADA','M3H 2R7','(647) 299-1394','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 11:48:38',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  2\råå…‰æ¿ æ”¯æž¶   1 RR815344551CN'),(4474,657211660002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','natuska76','natasheorlovoj@gmail.com','Natasha Orlova','dom.36 kv.185','poselok Mosrentgen','Moskovskaya obl','RUSSIAN FEDERATION','142771','79161285354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 13:00:41',0,NULL,8,1,17,0,NULL,NULL),(4475,657211614002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','natuska76','natasheorlovoj@gmail.com','Natasha Orlova','dom.36 kv.185','poselok Mosrentgen','Moskovskaya obl','RUSSIAN FEDERATION','142771','79161285354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 13:00:42',0,NULL,3,1,3,1,NULL,'å•ç¯å¤´ æ¬§æ ‡   1\r115w 220v   1 RR815344503CN'),(4478,657221257002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','polkan-irk','pavel_arsentev@s268604749.onlinehome.us','Pavel M. Arsentev','Dalnevostochnaya str, 61-73','Irkutsk','','RUSSIAN FEDERATION','664046','+79501128600','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 13:37:24',0,NULL,3,1,2,1,NULL,'80cm 2in1   1 '),(4480,702756101016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',11.8,'hutongstore','dasagi10','dsg_tgn@hotmail.com','OMNIA SOLUTIONS (Sr. David Sanz GironÃ¨s)','C/ del Plom 109 nave 4 PolÃ­gon Industrial Riu Clar','Tarragona','CataluÃ±a','SPAIN','43006','680737427','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-10 13:43:39',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹  2 '),(4481,617832519001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','comprador2os','udistritaljohn@yahoo.com','John Martinez','504 Forest Cir<br>Apt 317','Walterboro','SC','UNITED STATES','29488-2973','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'6663a å¿«è£…æ¿  1 \ræ”¹ä¸ªåœ°å€LK018103270CN'),(4482,617803403001,110532007553,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','cf3sk8','cf3rules@gmail.com','Charles Farina III','1821 W McGalliard Ave','Hamilton','NJ','UNITED STATES','08610','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 14:43:00',0,NULL,3,1,1,1,NULL,'æ°”å¹ + å¸ƒ   1 '),(4483,657256680002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','sindilevich','sindilrv@mail.jct.ac.il','Matanel Sindilevich','73/16 Shahal St.','Jerusalem','Jerusalem','ISRAEL','93721','+972544705353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 15:40:12',0,NULL,3,1,2,1,NULL,NULL),(4484,656092002002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',68,'hermeshine','antonia8058','er_goza@hotmail.com','antonia pichardo ramirez','palos de la frontera nÂº 23','la palma del condado','AndalucÃ­a Ceuta y Melilla','SPAIN','21700','628681432','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 16:40:50',0,NULL,3,1,3,1,NULL,'canon è€æ¬¾èƒŒå¿ƒ m  1\rcanon è€æ¬¾èƒŒå¿ƒ xl   1 \r1291RR815344605CN'),(4485,617887269001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','planet-earth-2008','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 17:13:13',0,NULL,8,1,17,0,NULL,NULL),(4486,617885881001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','planet-earth-2008','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 17:13:14',0,NULL,8,1,17,0,NULL,''),(4487,657300847002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','planet-earth-2008','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 17:31:23',0,NULL,3,1,1,1,NULL,'58mm æ©¡èƒ¶ç½©  1\r52mm æ©¡èƒ¶ç½©   1 \r58mm é•œå¤´ç›–   canon 1 '),(4488,616539510001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','twobabys_rig','norali2004@mac.com','Maria Gonzalez','7684 Whitsett Ave','Los Angeles','CA','UNITED STATES','90001','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 18:15:34',0,NULL,3,1,1,1,NULL,'æ–°æ¬¾å†…èƒ†åŒ…   1 '),(4489,657320930002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','mirivah','njanja_2003@yahoo.com','Anna Gaspotic','Olge Ban 13','Pula','Istra','CROATIA','52100','+385981766645','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 18:18:40',0,NULL,3,1,2,1,NULL,'58mm镜头盖 1个'),(4490,657202079002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','cotxero','cotxero@yahoo.es','David   Saez Forner','C mig nÂº1','Canet d\'en Berenguer','Comunidad Valenciana','SPAIN','46529','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 18:48:13',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\rbåº§    2\ræŸ”å…‰ä¼ž   2 \rlighting stand  $22\rYW864614896CN\r'),(4491,617936091001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','foxmulderebe','kittie4ebay@yahoo.com','Kittie M. Aleman','3404 Fillmore St','Riverside','CA','UNITED STATES','92503','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-10 19:01:09',0,NULL,3,1,1,1,NULL,'40cm æ£š  1 '),(4492,617942338001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',3,'AE3601',54,'hermeshine','niggaphil','philippe.gaudens@photomask.com','GAUDENS Philippe','TOPPAN PHOTOMASKS<br>224, Bd John Kennedy','CORBEIL ESSONNES','ESSONNES','FRANCE','91100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 19:16:31',0,NULL,3,1,3,1,NULL,'115w 220v   3 RR815344477CN'),(4495,657363123002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','csuc1980','timmyc2000@hotmail.com','Tim Cook','401 Crescent Ct<br>Apt 4104','San Francisco','CA','UNITED STATES','94134-3384','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 19:42:22',0,NULL,3,1,1,1,NULL,' '),(4496,617959313001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','citronyecki','eszenyi.david@freemail.hu','Eszenyi DÃ¡vid','TÃ©glÃ¡skert utca 97.','Debrecen','HajdÃº-Bihar','HUNGARY','4030','0036206692806','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 19:47:22',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 RR815344534CN'),(4497,617966108001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','isabellajewelry','scarlet@actcom.co.il','isabella lam','108 hagalil st<br>neveshaanan','haifa','israel','ISRAEL','32683','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 20:04:38',0,NULL,8,1,17,0,NULL,NULL),(4498,617966517001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','isabellajewelry','scarlet@actcom.co.il','isabella lam','108 hagalil st<br>neveshaanan','haifa','israel','ISRAEL','32683','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 20:04:39',0,NULL,3,1,3,1,NULL,'40cm æ£š   1\rå€’å½±æ¿   1 RR815344494CN'),(4499,657384586002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','jbenben09','johanbencker@gmail.com','johan bencker','segervÃ¤gen 204','Ã„lvsjÃ¶','Stockholm','SWEDEN','12534','+46708614662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 20:23:19',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 RR815344548CN'),(4500,617984203001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','thedoyman','thedoyman@hotmail.com','Sebastien Doyon','5220 ST-LAURENT','MONTREAL','QC','CANADA','H2T1S1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 20:38:43',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹ çƒå°  1 '),(4501,617981743001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','nadine220661','legroux.daniel@neuf.fr','nadine legroux','23 rue cerfeuille','ollainville','ÃŽle-de-France','FRANCE','91340','01 69 26 94 80','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 20:39:21',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864614900CN\r'),(4502,617999887001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','cardiff800i','kcelldweller@gmail.com','Berislav Kovacevic','vukovarska 4','Cakovec','PW','CROATIA','40000','00385959012763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 21:13:22',0,NULL,3,1,2,1,NULL,' '),(4503,657419812002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','9003peter','jukebox_74@hotmail.com','p.westheim','bernhardlaan 18','sint odilienberg','','NETHERLANDS','6077 at','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 21:41:40',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   2 '),(4505,618026940001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','mil_bot','boslitterbox@aol.com','Mike Ho','942 S Stanley Ave','Los Angeles','CA','UNITED STATES','90036-4602','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 22:21:51',0,NULL,3,1,1,1,NULL,'éº‚çš®  2 '),(4506,657446372002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','llhgantz','llhgantz1@yahoo.ca','Judy Tailby','53 221 RR #183<br>Box 8032','Edson','AB','CANADA','T7E1W2','(780) 712-1147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 22:45:52',0,NULL,3,1,2,1,NULL,'6662aå¿«è£…æ¿   2'),(4507,703033593016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','davidclimb85','david.toncic@gmail.com','David TonÄiÄ','TomÅ¡iÄeva 17/B','Idrija','Slovenia','SLOVENIA','0386','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-10 23:14:54',0,NULL,3,1,2,1,NULL,' '),(4508,657446209002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','keeper_25','rbf0069@gmail.com','Raul Bustos Fernandez','Calle Finestrat 33-46<br>Calle Finestrat 33-58','Valencia','Comunidad Valenciana','SPAIN','46006','619935988','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 23:16:19',0,NULL,3,1,2,1,NULL,'6662aå¿«è£…æ¿   1  '),(4509,717062307015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','bezejmeny2','bezejmeny@gmail.com','Tibor BalÃ¡zs','RÃ¡kocziho 41','Å tÃºrovo','vÃ½chozÃ­','SLOVAK REPUBLIC','94301','+421948508788','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-10 23:46:36',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 RR815344429CN'),(4510,717067126015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',3,'AA1304',5.64,'hutongstore','classy.sassy','bashori_bmw@yahoo.com','bashar mudar waleed','GudingvÃ¤gen 17','Ã¥kersberga','','SWEDEN','18461','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 00:00:17',0,NULL,3,1,2,1,NULL,NULL),(4511,717071122015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'AC1304',6.1,'hutongstore','whatashottiger','nuno.costacampos@gmail.com','Nuno Costa Campos','Rua das Macieiras, 124 Torre','Cascais','','PORTUGAL','2750-010','+351 93 698 45 42','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 00:14:14',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon  1 '),(4512,618070991001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','123szymanowski','adam.nycity@gmail.com','Frank Kohner','340 E 80th St<br>Apt 7B','New York','NY','UNITED STATES','10075-0988','(917) 945-7005','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 00:57:30',0,NULL,3,1,1,1,NULL,NULL),(4513,618072284001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','colcampbell07','colcamp@gmail.com','Colin Campbell','280 Wellesley St.E<br>Suite 2409','Toronto','ON','CANADA','M4X1G7','(416) 727-6402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 01:02:50',0,NULL,3,1,2,1,NULL,NULL),(4516,657496594002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','sonthesun','hbms65@yahoo.ca','hazim aldujaili','2439 yeovil road','mississauga','ON','CANADA','l5j2g1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 01:43:28',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´   1\råå…‰ä¼ž   1 RR815344446CN'),(4517,618087347001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','doan_andrew','iayla_vz@hotmail.com','Trinh My Kien','7905 21 avenue','montreal','QC','CANADA','h1z3s9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 02:01:57',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(4518,657511730002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','scrapladycamping','tnbluegrassfan@aol.com','Bishop Rebecca','246 County Road 728','Riceville','TN','UNITED STATES','37370','(423) 462-2063','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 02:43:04',0,NULL,3,1,1,1,NULL,NULL),(4519,657514142002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','*wildlifewatcher*','abelocastro@hotmail.com','Abel LÃ³pez Castro','Colonia San JosÃ©, bloque 1, piso 2Âº pta.8','El Escorial','Madrid','SPAIN','28280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 02:55:58',0,NULL,8,1,17,0,NULL,''),(4520,657517403002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','*wildlifewatcher*','abelocastro@hotmail.com','Abel LÃ³pez Castro','Colonia San JosÃ©, bloque 1, piso 2Âº pta.8','El Escorial','Madrid','SPAIN','28280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 02:58:23',0,NULL,3,1,3,1,NULL,'å¹¿è§’æ‰˜æž¶   1  \r77mm æŽ¥å£çŽ¯  1RR815344415CNåŠ åˆ°è¿™è¡Œäº†'),(4522,618102102001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','emeuvede','emeuvede@hotmail.com','Marco ValdÃ©s DÃaz','Calle del MosÃ©n Jacinto Verdaguer<br>Portal 9 Puerta 8','Valencia','Comunidad Valenciana','SPAIN','46008','656873563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 03:01:27',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´æ¬§æ ‡   1 \rCåž‹å¤¹   1 '),(4524,618126215001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','sarhan.ahmed','shab.t@hotmail.com','SARHAN AHMED','Apt. 11, 54 Munroe Place','Regina','SK','CANADA','S4S4P7','(306) 351-0088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 05:04:13',0,NULL,3,1,2,1,NULL,NULL),(4530,657569641002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','lhkisses','wswseee@hotmail.com','Jung Min Lee','330810 Georgia Tech Station','Atlanta','GA','UNITED STATES','30332-0001','(229) 389-9403','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 07:56:31',0,NULL,3,1,1,1,NULL,'小号canon内胆包  1 '),(4525,657546114002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','nadarola','xboxdaniel@gmail.com','Daniel Moreira','223 E Hyde Park Blvd<br>APT 9','Inglewood','CA','UNITED STATES','90302-5591','(323) 868-1479','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-11 05:15:48',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  1 '),(4526,618135206001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','quincibea','quincy@thegrindhouse.com','Brent Buchanan','230 Crown St<br>(Upstairs)','Darlinghurst','New South Wales','AUSTRALIA','2010','0299501500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 06:05:35',0,NULL,8,1,17,0,NULL,NULL),(4527,618135428001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','quincibea','quincy@thegrindhouse.com','Brent Buchanan','230 Crown St<br>(Upstairs)','Darlinghurst','New South Wales','AUSTRALIA','2010','0299501500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 06:06:41',0,NULL,3,1,2,1,NULL,'80cm 5in1 åå…‰æ¿  1\r77mm é•œå¤´ç›–  canon  1 '),(4528,617995135001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',3.3,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 06:56:51',0,NULL,8,1,17,0,NULL,NULL),(4529,616529960001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',230.36,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 06:56:52',0,NULL,3,1,5,1,NULL,'50cm æ£š   1\rMC-N3   1\rNIKON D1 å•è‚©åŒ…  1\r115w 220v   2\r45w  2\r50-70å•ç¯å¤´æ£š  æ¬§æ ‡ 2\r40cm æ£š   1\r67mm uv   1\r55mm uv  1 æ½˜\rCP219486956CN\r'),(4531,657582435002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','williamt84','williamt84@tvisuals.net','William Townley','2669 Fleet St','Detroit','MI','UNITED STATES','48238-2727','(313) 571-1000','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 09:14:13',0,NULL,3,1,1,1,NULL,' '),(4532,717214390015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','basiliss77','hex001@hotmail.com','Vasilis Sfiridakis','Alikianos','Chania','','GREECE','73005','00302821078395','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-11 10:16:23',0,NULL,3,1,3,1,NULL,'2m 灯架 1\r柔光伞 1\r云台 1RR815344769CN\r'),(4533,715820622015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','nikki_leigh18','nikkis_2006@hotmail.co.uk','nikki swimby','18 harpford drive breightmet','bolton','Greater Manchester','UNITED KINGDOM','bl2 6tw','01204370366','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 10:57:41',0,NULL,3,1,2,1,NULL,'1.6x3m 白色背景布 1 '),(4534,618185596001,110566020598,'New GGS Digital Camera 3.0\" LCD Screen Protector Glass ',1,'AB2208',5.6,'hermeshine','rohit1_blore','rohit.sharma2@in.unisys.com','Rohit Sharma','Flat # 804, Block-1C (Senswe), Divyasree Elan Homes<br>Opp. Total Mall, Sarjapur Road','BANGALORE','KA','INDIA','560035','09741513700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 11:18:31',0,NULL,3,1,2,1,NULL,' '),(4535,657609967002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','jr123rj','jrada@volny.cz','Jiri Rada','Dysinska 9','Plzen','','CZECH REPUBLIC','312 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 11:31:46',0,NULL,3,1,3,1,NULL,'2m灯架  1\rB座 1\r柔光伞   1 RR815344715CN\r'),(4536,657610183002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',17.99,'hermeshine','revivevision','hadjivasilev@gmail.com','Andrey Hadjivasilev','Professor N. Mihailov 1','Sofia','','BULGARIA','1142','+359-888-736-822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 11:31:49',0,NULL,3,1,2,1,NULL,'防雨罩 1 '),(4537,618189575001,110534333190,'Green.L 77mm Neutral Density ND8 Filter 550D D90 5DII',1,'AE2314',8.2,'hermeshine','yannr5362','ron_kalezz@hotmail.com','Yann Romming','9.imp E Manet','Folschviller','Lorraine','FRANCE','57730','0387910159','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 11:34:05',0,NULL,3,1,2,1,NULL,'77mm ND8   1 '),(4538,618195530001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','alexbarket','barket@mail.ru','Alexey Barket','Perovskaya str. 22 k.2, 156','Moscow','','RUSSIAN FEDERATION','111398','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 12:10:19',0,NULL,3,1,5,1,NULL,'WT600    1 \rCP219487364CN\r'),(4539,717246871015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',43,'hutongstore','fayem2880','linese2001@yahoo.com','faye manuel','31 crossfield road kitts green','birmingham','West Midlands','UNITED KINGDOM','b33 9hs','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 12:21:36',0,NULL,8,1,17,0,NULL,' '),(4540,717247891015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',2,'AC3201',53.12,'hutongstore','fayem2880','linese2001@yahoo.com','faye manuel','31 crossfield road kitts green','birmingham','West Midlands','UNITED KINGDOM','b33 9hs','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 12:23:45',0,NULL,3,1,4,1,NULL,'40×60 5合1 反光板 2个\r\r反光板支架  2个\rYW864615003CN\r'),(4541,657634866002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','imogenkimmel','imogenkimmel@yahoo.de','Imogen Kimmel','Tengstr.25','MÃ¼nchen','','GERMANY','80798','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 13:27:00',0,NULL,3,1,3,1,NULL,'肩架 1 \rRR815344928CN\r试着召回吧，客户改地址了\r新地址：\rImogen Kimmel\rc/o Mrs. Yeuth Sothary\rNo 5 street 410\rSangkat Boeung Trabek\rKhan Chamkamorn\rPhnom Penh\rCambodia\rRR843879022CN\r\r'),(4543,618216861001,110566018873,'Digital SLR Camera Raincover rain cover for Nikon Canon',1,'AA3101',17.99,'hermeshine','sonthesun','hbms65@yahoo.ca','hazim aldujaili','2439 yeovil road','mississauga','ON','CANADA','l5j2g1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 13:36:22',0,NULL,3,1,2,1,NULL,'防雨罩 1 '),(4544,618219967001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','stoicov2p','cstoicov@iname.com','Chris Stoicovici','4330 Dufferin St.','Toronto','ON','CANADA','M3H 5R9','(416) 523-4482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 13:47:52',0,NULL,3,1,2,1,NULL,' '),(4546,618226779001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','masterphone75','protestand21@gmail.com','ANDRYIANAU SIARHEI','JUKOVA str<br>26 - kor 2 - 128','GOMEL','BLR','BELARUS','246029','(375) 293880382','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 14:14:50',0,NULL,3,1,5,1,NULL,' CP219487378CN\r'),(4547,618239885001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','luis3648','luis.jimenez.delgado@gmail.com','Luis Jimenez Delgado','Pablo Picasso, 3','Algeciras','AndalucÃ­a Ceuta y Melilla','SPAIN','11203','600516593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 15:01:56',0,NULL,3,1,2,1,NULL,' '),(4548,657673775002,120626873273,'New wide angle holder for Cokin P series filter',2,'AA2216',7.98,'hermeshine','druitas','druitas@hotmail.com','Iskander Barrena','Aita Patxi Ugalde 12, 4ÂºC','Larrabetzu','PaÃ­s Vasco','SPAIN','48195','678654334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 15:35:06',0,NULL,3,1,2,1,NULL,''),(4549,657687100002,120598267593,'New Camera shoulder bag nova 4 with raincover 4 7D 5Dii',1,'AO0024',40.99,'hermeshine','rccroker-2008','rccroker@netscape.net','Clayton R Croker','75 Wentworth Avenue','Sydney','New South Wales','AUSTRALIA','2000','0292121005','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 16:15:16',0,NULL,8,1,17,0,NULL,' '),(4550,618265972001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','rccroker-2008','rccroker@netscape.net','Clayton R Croker','75 Wentworth Avenue','Sydney','New South Wales','AUSTRALIA','2000','0292121005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 16:24:10',0,NULL,3,1,3,1,NULL,'黑白倒影板 各1\rCanon N4   1\rRR843879053CN\r\r'),(4551,618266064001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','shotov2007','shotov@mail.ru','Alexey Shotov','pr-t Gazety Pravda, d.62, kv.13','Dnepropetrovsk','','UKRAINE','49051','(+38)067-2954731','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 16:26:49',0,NULL,3,1,3,1,NULL,'绿色nikon标XL背心 1RR843879036CN\r\r'),(4552,657693099002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','cicomare','raniz@libero.it','Ranieri Costa','Via Ugo Betti, 69','Milano','MI','ITALY','20151','3387524483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 16:33:45',0,NULL,3,1,3,1,NULL,'2m灯架 1\rB座 1\r柔光伞 1RR815344724CN\r'),(4553,618281459001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','open331964','yossi888@gmail.com','Joseph Schwartz','mitzpe 34 apt 8','shoham','israel','ISRAEL','60850','972778103887','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 17:05:50',0,NULL,3,1,3,1,NULL,'黑色Canon标XXXL背心 1RR815344891CN\r薄的新款 黑\r'),(4554,717347283015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',7.5,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 17:09:52',0,NULL,8,1,17,0,NULL,NULL),(4555,717348781015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-11 17:09:52',0,NULL,8,1,17,0,NULL,NULL),(4556,703321119016,260660055262,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',8,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 17:09:51',0,NULL,8,1,17,0,NULL,' '),(4557,717346069015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',127,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-11 17:09:51',0,NULL,3,1,4,1,NULL,'背景架（白） 1.6m  1\r背景架（ 白 黑）  2m   1\r2m 灯架   2\r双灯头 欧标  2\r反光伞   2\r柔光伞   1\r115w 220v   4\r包   1\r80cm 2in1   1\rYW864489246CN\r\r\r'),(4558,618287080001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','magican4','trond@solem.nu','Trond Solem','Furuhaugvegen 35','N-7550 Hommelvik','','NORWAY','7550','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 17:21:37',0,NULL,3,1,3,1,NULL,'斜臂 1\rRR815344786CN\r发错了，补发一个2m 灯架  1  和上面的反光板支架一起\r'),(4559,703343545016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','handsomesteve','istvan@prenergia.hu','Ferenczi IstvÃ¡n','Ugron Gabor u. 28','Budapest','','HUNGARY','1118','0036302009172','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 17:47:35',0,NULL,3,1,3,1,NULL,' RR815344826CN\r'),(4560,653772041002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',9.25,'hermeshine','unoqueno','maciatico@hotmail.com','David MaciÃ¡','Porta de la Morera, nÂº12. Museo del Palmeral','Elche','Comunidad Valenciana','SPAIN','03203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 17:53:29',0,NULL,3,1,2,1,NULL,'大号无字内胆包 1'),(4561,618300842001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','jb_chrome','john.b.poisson@maine.gov','John B Poisson','9 Prospect St','Livermore Falls','ME','UNITED STATES','04254-1518','(207) 287-7176','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-11 17:54:56',0,NULL,3,1,1,1,NULL,' '),(4562,717389378015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'AA1304',3.76,'hutongstore','jerzyk69-2008','jerzyk.j1@wp.pl','Jerzy Jerzmanowski','212 King Arthurs Walk Castelfields','Runcorn','Cheshire','UNITED KINGDOM','WA7 2NE','07709994966','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 18:22:55',0,NULL,3,1,2,1,NULL,' '),(4563,618325237001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','duncemedia','coffeelover1973@hotmail.com','Jason Rossi','87 Fort Sullivan Cir','Dalzell','SC','UNITED STATES','29040','','NoPaymentFailure','CheckoutComplete','Other','2011-01-11 18:50:57',0,NULL,3,1,3,1,NULL,'黑色Canon标 XL背心 1 RR815344888CN\r'),(4564,657752408002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','playtaf','playvision@ono.com','CRISTOBAL BELLES VIDAL','c/ SAN FEDERICO NÂº1 2Âºd','ALMASSORA','Comunidad Valenciana','SPAIN','12550','964563106','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 18:56:22',0,NULL,3,1,3,1,NULL,'肩架 1\rRR815344865CN'),(4565,717405644015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.99,'hutongstore','piccies4j','juliesalam@jsalam.fsnet.co.uk','Omar Salam','12 cairnsmore way bourtreehill','irvine','North Ayrshire','UNITED KINGDOM','KA11 1EP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 19:03:03',0,NULL,3,1,2,1,NULL,' '),(4566,618336403001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','ferblues70','fernandomblues@gmail.com','David Fernando Miranda','San Miguel Bloque L#35<br>P.O.BOx 312 350','La Paz - Bolivia','La Paz','BOLIVIA','P.O 312 350','2 795762','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 19:14:00',0,NULL,3,1,3,1,NULL,'2m灯架 1 RR815344790CN\r'),(4567,717408752015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',15.5,'hutongstore','guszty81','guszty23@freemail.hu','TamÃ¡s Hornyacsek','Fok u. 18.','KomÃ¡rom','','HUNGARY','2921','36702476923','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 19:51:23',0,NULL,3,1,2,1,NULL,' 单灯头 2个  欧标'),(4568,717442898015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'AA1304',3.76,'hutongstore','tosan1980','tu_luna@hotmail.com','Anh Thu Nguyen Hoang','GrÃ¤sholmsvÃ¤gen 9D','SkÃ¤rholmen','','SWEDEN','12746','0046709273456','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 19:54:56',0,NULL,3,1,2,1,NULL,'77mmCanon镜头盖 2个 '),(4569,618356266001,110445658116,'New YONGNUO  LCD Timer Remote Control  for Nikon MC-DC1',1,'AA3219',48.9,'hermeshine','clibanq96','queyquep@earthlink.net','Cesar Queyquep','7837 Cape Charles Dr','Raleigh','NC','UNITED STATES','27617','(865) 712-7016','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 19:55:32',0,NULL,3,1,1,1,NULL,'MC-N2   1 '),(4570,618301999001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','michaelf2940','mikefalzon@hotmail.com','Michael Falzon','Id-Dwejra<br>Palm Street','Tarxien','','MALTA','TXN 2245','+356 79008973','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 20:39:24',0,NULL,8,1,17,0,NULL,' '),(4571,618301172001,110523102293,'72mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1308',2.6,'hermeshine','michaelf2940','mikefalzon@hotmail.com','Michael Falzon','Id-Dwejra<br>Palm Street','Tarxien','','MALTA','TXN 2245','+356 79008973','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 20:39:25',0,NULL,8,1,17,0,NULL,' '),(4572,618300898001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','michaelf2940','mikefalzon@hotmail.com','Michael Falzon','Id-Dwejra<br>Palm Street','Tarxien','','MALTA','TXN 2245','+356 79008973','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 20:39:26',0,NULL,3,1,3,1,NULL,'反光板支架 1\r72 NIKON镜头盖 1\r 大力夹球台    1 1RR815344857CN\r'),(4573,618379079001,110534333084,'Green.L 67mm Neutral Density ND4 Filter 67  550D 5DII',1,'AE2305',6.7,'hermeshine','delgado8610','dani_delgado_@hotmail.com','daniel delgado','urb. las torres 18. 4Âº A4','las palmas','Canarias','SPAIN','35010','686690929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 20:41:41',0,NULL,3,1,2,1,NULL,' '),(4574,717465275015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.5,'hutongstore','ozlemyusuf','ozlemsakally@gmail.com','Ozlem Sakalli','4 Lowick Court','Newcastle Upon Tyne','Northumberland','UNITED KINGDOM','NE3 1YQ','07570031819','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 21:05:26',0,NULL,3,1,2,1,NULL,' 小号canon标内胆包 1'),(4575,657814571002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.9,'hermeshine','lobis78','lobis22@hotmail.com','Rogerio Policarpo','688 Boston Post Rd E<br>Apt 105','Marlborough','MA','UNITED STATES','01752-3710','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-11 21:07:27',0,NULL,3,1,1,1,NULL,'CTR-301P 1拖2 '),(4576,657820176002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','alxg3','alxgag3@gmail.com','Alexander Vedeler','Fjellveien<br>123','Bergen','Hordaland','NORWAY','5019','+4797514080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 21:14:53',0,NULL,3,1,3,1,NULL,'2m灯架+B座+柔光伞 1RR815344809CN\r'),(4577,618069686001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',6.68,'hermeshine','junglistic_maxim','ebay_junglistic@mail.ru','Mogildea Maxim','A. Xenopol 11','Chisinau','','MOLDOVA, REPUBLIC OF','MD-2051','079844160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 21:16:36',0,NULL,3,1,2,1,NULL,'58mm 橡胶罩  1\r52mm 橡胶罩  1\r应该是漏发了58mm的,如果是再发一下 \r已经发货'),(4578,618138045001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',155.64,'hermeshine','lars3389','larsisachsen@hotmail.com','lars isachsen','bjerregaardsgate 22','oslo','N/A','NORWAY','0172','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 21:29:00',0,NULL,3,1,4,1,NULL,'2m灯架+云台+柔光伞 2套\rCTR-301P 1拖3\r大号无字内胆包 1\rSB-800肥皂盒 1\rlighting kit  $26\rYW864489202CN\r\r '),(4579,717500481015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','baldyfudgepacker7','andrew.hall137@ntlworld.com','andrew hall','41 county st, hollinwood','oldham','Lancashire','UNITED KINGDOM','OL8 3RN','07876213253','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 21:37:10',0,NULL,3,1,3,1,NULL,'40×60 5合1反光板 1 RR815344843CN\r'),(4580,717515666015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','josh125897463','goodshipalbion@hotmail.com','Josh Taylor','253 Neasham Road','Darlington','Durham','UNITED KINGDOM','DL1 4DH','07817622183','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 22:03:50',0,NULL,3,1,2,1,NULL,'72mm CPL 1'),(4581,703499900016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','jeromeamb','jeromeamb@aol.com','Jerome RAOULT','310 rue Serval - Appt E03','DOUAI','Nord-Pas-de-Calais','FRANCE','59500','06.78.91.49.57','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-11 22:35:30',0,NULL,3,1,4,1,NULL,'2mx3m 背景架  1\r3mx6m 绿色背景布  1\r2m 灯架  2\r50-70 棚 欧标   2\r115w 220v   2\r包    1\rlighting kit   $30\rYW864489213CN\r'),(4582,618423783001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','masteret1234','eric_tardif1@hotmail.com','eric tardif','154 St-Germain Est<br>Apt. 18','Rimouski','QC','CANADA','G5L 1A8','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 22:36:28',0,NULL,3,1,3,1,NULL,'肩架 1 RR815344945CN\r'),(4583,618429838001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','nmoh6141','ndmohrmann@gmail.com','Noel Mohrmann','180 West Brooks #3510','Norman','OK','UNITED STATES','73019','(405) 213-7949','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 22:53:21',0,NULL,3,1,1,1,NULL,' '),(4584,657861388002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','briz30','brijesh_aryal@hotmail.com','Brijesh Aryal','3/45-49 Gladstone Street<br>Kogarah','Sydney','New South Wales','AUSTRALIA','2217','0295872782','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 23:00:10',0,NULL,3,1,3,1,NULL,'SONY A1单肩包 1 RR843879291CN\r'),(4585,618439783001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',2,'AKT006',123,'hermeshine','smoofe33','swisschick33@hotmail.com','Michaela Preston','55 Church Street','Alliston','ON','CANADA','L9R1G9','(705) 434-9410','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 23:29:32',0,NULL,3,1,3,1,NULL,'10片装 58mm环架 2套\r\rRR843879725CN\r'),(4587,717564719015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','tommyv203','matthew.dixon4@ntlworld.com','Matthew Dixon','5 Whites Row','Kenilworth','Warwickshire','UNITED KINGDOM','cv8 1hw','01926777468','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 00:15:35',0,NULL,3,1,3,1,NULL,'2m灯架 1\r\rB座 1\r\r柔光伞 1 RR815344772CN\r'),(4588,618452018001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','1215zaphod','sgvanhoose@gmail.com','Steve Van Hoose','4149 Mount Alifan Pl<br>Unit B','San Diego','CA','UNITED STATES','92111-2837','(858) 277-3231','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 00:16:40',0,NULL,3,1,1,1,NULL,' '),(4590,618486922001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.55,'hermeshine','sergeantcigar','sammy@derezes.com','Sammy Derezes','1916 NE 127th St','Seattle','WA','UNITED STATES','98125','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-12 02:42:35',0,NULL,3,1,1,1,NULL,'77mm 绿叶渐变灰 1 '),(4591,703584683016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',5,'AA1310',18.9,'hutongstore','lovelylovelygifts','anh.phan@iinet.net.au','Anh Phan','Suite 293 66 Kingsway','Glen Waverley','Victoria','AUSTRALIA','3150','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 03:06:17',0,NULL,3,1,3,1,NULL,'镜头笔 5支 RR815344905CN\r'),(4592,657931988002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','rebber1224','dots.are.stylish@gmail.com','Rebecca Lin','356 Greenfield Ave.','Toronto','ON','CANADA','M2N3E8','(416) 318-2919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 03:14:01',0,NULL,3,1,2,1,NULL,'小号canon标内胆包 1 '),(4593,618507180001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','sidebysidepartsforless','crashegordon@yahoo.com','Earl Gordon','269 N Keeneland Dr<br>Apt 2','Richmond','KY','UNITED STATES','40475','(859) 321-2485','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 04:10:46',0,NULL,3,1,1,1,NULL,' '),(4594,618514526001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',1,'AC1204',7.9,'hermeshine','nightguest8826','night_guest2000@yahoo.com','Azer Aliyev','814 Oakcrest st','Iowa city','IA','UNITED STATES','52246-3417','(515) 520-7961','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 04:55:02',0,NULL,3,1,1,1,NULL,'镜头筒 xl   1 '),(4595,657962138002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','denybarboza','denyzinho@gmail.com','Deny Barboza','Rua Ver. Severo Ribeiro, 912','Pelotas','Rio Grande do Sul','BRAZIL','96020-620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 05:55:16',0,NULL,3,1,3,1,NULL,'50-70 通用卡口 塑料  1 RR843879331CN\r'),(4856,705539719016,260661734966,'NEW 55mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT043',15.2,'hutongstore','kahlanka','pieczarka1900@o2.pl','Kamila Mielczarek','27 Suffolk Avenue','Southampton','Hampshire','UNITED KINGDOM','so155ef','07874273879','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 01:59:04',0,NULL,3,1,3,1,NULL,'55mm CPL+ND8+ close-up+4 +Gradual grey RR843877097CN'),(4597,618535389001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','flyinslovak','svk1@windsurfing.sk','Patrik POLLAK','Jantarova 2','Kosice','Kosice','SLOVAK REPUBLIC','04001','421905785001','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 07:19:43',0,NULL,3,1,5,1,NULL,'717 135高   1 \rCP219487418CN\r'),(4598,618542478001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','jorgengrytoyr','jorgen@grytoyr.no','Jørgen Grytøyr','Hertug Skules vei 6','GAMLE FREDRIKSTAD','','NORWAY','1639','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 08:08:16',0,NULL,3,1,3,1,NULL,'肩架  1 RR843879274CN\r'),(4599,618542049001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','ildar2010','uldar@mail.ru','ildar abulhanov','Rabochaya, dom 7, kv. 17','ulyanovsk','ulyanovsk','RUSSIAN FEDERATION','432007','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 08:10:22',0,NULL,3,1,3,1,NULL,'肩架  1 RR843879212CN\r'),(4600,657983494002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','vitalmax2009','alfast@inbox.ru','Vitaly Maksimchuk','Narvskaya street 6-105','Vladivostok','Primorsky region','RUSSIAN FEDERATION','690011','+79147077862','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 08:23:25',0,NULL,8,1,17,0,NULL,' '),(4601,618543474001,110566021477,'TianYa ND8 Filter for Cokin P Series Neutral Density',1,'AA2325',7.2,'hermeshine','vitalmax2009','alfast@inbox.ru','Vitaly Maksimchuk','Narvskaya street 6-105','Vladivostok','Primorsky region','RUSSIAN FEDERATION','690011','+79147077862','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 08:23:26',0,NULL,3,1,2,1,NULL,'ND8   1\rCPL   1 '),(4602,657988571002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','ac9999ac','a_c9999@hotmail.com','choo anthony','blk 984c buangkok link #09-39 singapore','Singapore','','SINGAPORE','533984','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 08:45:08',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843879257CN\r'),(4604,618557087001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','2005audun','asjoeset@online.no','Audun Sjoeseth','Oevre Hylla 8','Glomfjord','','NORWAY','N-8160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 09:35:46',0,NULL,3,1,2,1,NULL,NULL),(4603,618553015001,110523102341,'77mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1309',2.6,'hermeshine','nitsum14','amfleica@gmail.com','Agustin Moreno Fernandez','c./ Jose Ignacio de Pineda, nº 5<br>Bloque 2, Bajo C','Jerez de la Frontera','Cadiz','SPAIN','11405','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 09:12:14',0,NULL,3,1,2,1,NULL,NULL),(4605,657791002002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',10,'AA1310',54.9,'hermeshine','numberone_kiev','sergey_pets@list.ru','Sergey Prokopets','Chokolovskiy Boulevard, 18, flat 42','Kiev','','UKRAINE','03186','+380967602992','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 10:11:17',0,NULL,3,1,3,1,NULL,' RR843879305CN\r'),(4606,658010399002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','fkisicek','filipkisicek@yahoo.com','Filip Kišiček','Lipovnik 139','Klenovnik','','CROATIA','42244','+385989127807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 10:38:23',0,NULL,3,1,2,1,NULL,'机身盖/镜头后盖  canon   1 '),(4607,717725341015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','palabe-h','palabe61@gmail.com','László Papp','Dózsa György utca 15/A','Balatonfüred','','HUNGARY','8230','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 11:28:07',0,NULL,3,1,2,1,NULL,' '),(4608,654640082002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','indal77','saindal@gmail.com','S.A. Indal','Kirkeveien 200','Nesoddtangen','Akershus','NORWAY','1450','+4793699573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 11:41:59',0,NULL,8,1,17,0,NULL,''),(4609,615316898001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','indal77','saindal@gmail.com','S.A. Indal','Kirkeveien 200','Nesoddtangen','Akershus','NORWAY','1450','+4793699573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 11:41:59',0,NULL,3,1,4,1,NULL,'6662a    1\r倒影板  1\r\r tripod $18 \rYW864489176CN\r'),(4610,717734177015,250692242647,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.68,'hutongstore','argirius','seunam@gmail.com','Andre Stavrakis','rue des Begonias 17','Rhode-Saint-Genese','','BELGIUM','1640','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 11:59:43',0,NULL,3,1,2,1,NULL,NULL),(4611,618591778001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','wangmarco','marcowang@gmail.com','Marco Wang','5135 Forest Sage Ln','Katy','TX','UNITED STATES','77494-5839','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 12:22:21',0,NULL,3,1,1,1,NULL,NULL),(4612,717746083015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','170jazmin','bobnield@aol.com','Robert Nield','5 Belle Vue Road','Exmouth','Devon','UNITED KINGDOM','EX8 3DR','01395279537','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 12:41:52',0,NULL,3,1,2,1,NULL,'45w   2 '),(4613,658038691002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',4,'AE3102',31.56,'hermeshine','malaseda02','pejiosisima@gmail.com','Lidia Esther Diaz Gil','Bateria de San Juan, 12','Las Palmas de G C','Canarias','SPAIN','35015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 12:47:15',0,NULL,3,1,3,1,NULL,'大力夹  4 RR843879288CN\r'),(4614,658045247002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','chickgirdoug2000','mike-odonnell@austin.rr.com','Mike O\'Donnell','6801 Beckett Rd<br>Unit 142L','Austin','TX','UNITED STATES','78749','(512) 895-2304','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 13:12:41',0,NULL,3,1,1,1,NULL,'肥皂盒  580ex   1 '),(4615,658045608002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6,'hermeshine','juancoffi','juan.coffi@gmail.com','Juan Carlos Coffi da Silva','Atlantida 232','Porto Alegre','Rio Grande do Sul','BRAZIL','91760150','555132497088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 13:14:22',0,NULL,8,1,17,0,NULL,NULL),(4616,658046246002,120618815391,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',7.4,'hermeshine','juancoffi','juan.coffi@gmail.com','Juan Carlos Coffi da Silva','Atlantida 232','Porto Alegre','Rio Grande do Sul','BRAZIL','91760150','555132497088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 13:15:50',0,NULL,3,1,2,1,NULL,'67mm 天涯 nd8  1\r67mm 绿叶 cpl   1 '),(4617,717758490015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',23.9,'hutongstore','dpspstewart','dan2452@hotmail.com.au','dan stewart','53 amaroo cres','Toormina','New South Wales','AUSTRALIA','2452','0266582803','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 13:22:46',0,NULL,3,1,3,1,NULL,'斜臂  1 RR843879169CN\r'),(4619,658060151002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','jcruizduarte','jcruizduarte@msn.com','juan carlos ruiz duarte','C. Venecia 18','jerez de la frontera','Andalucía Ceuta y Melilla','SPAIN','11408','659978054','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 14:07:13',0,NULL,3,1,2,1,NULL,NULL),(4620,618639804001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','jandoctor','avershov@gmail.com','Alexey Ershov','Zaharinskie dvoriki 1-1-184','Moscow','RU','RUSSIAN FEDERATION','117148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 15:21:55',0,NULL,3,1,2,1,NULL,NULL),(4622,618658410001,110414374077,'55mm 55 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT019',4.87,'hermeshine','iamtorpe','manuelhigueras@gmail.com','manuel higueras garcia','reina sofia, 10','los villares, jaen','Andalucía Ceuta y Melilla','SPAIN','23160','953323199','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 16:22:53',0,NULL,3,1,2,1,NULL,'55mm 环架  1 '),(4623,658112357002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','kamomyete','dafeen@free.fr','Mlle Miozzo','8 b rue de reims','Paris','Ile-de-France','FRANCE','75013','0627611928','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 16:51:00',0,NULL,3,1,3,1,NULL,'115w220v   2 RR843879172CN\r'),(4624,703845742016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','sawber67','billkemmy@eircom.net','Bill Kemmy','Bishop\'s House Dublin Road','Carlow','Carlow','IRELAND','default','0872308053','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-12 18:19:47',0,NULL,3,1,4,1,NULL,'2mx3m 背景架 1\r3mx6m 绿色背景布  1\r2m 灯架   2\r50-70 棚  英标   2\r115w 220v 灯泡  2\r包   1\rlighting kit  $30 \rYW864489224CN\r'),(4625,618724134001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',4,'AC3301',58.24,'hermeshine','mystery_ghosttrain','anders_1@ukr.net','Andriy Yermak','Revutskogo 7, kv. 229','Kyiv','','UKRAINE','02091','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 18:57:52',0,NULL,3,1,3,1,NULL,' RR843879345CN\r'),(4626,717925790015,250601900955,'Wireless Remote Control Cord for Canon 50D/40D/30D/20D',1,'AA3210',11.47,'hutongstore','dplatakis','dplatakis@yahoo.com','Darius Platakis','34 Gleann Na Ri Druid Valley','Cabinteely','Dublin 18','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 19:23:32',0,NULL,3,1,2,1,NULL,'爵影无线 C3   1 '),(4627,618740244001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','flevofred','f.wilcke@hetnet.nl','Fred Wilcke','Kamp','Lelystad','','NETHERLANDS','8225GD','+31612867336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 19:29:36',0,NULL,3,1,2,1,NULL,NULL),(4628,658185142002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.9,'hermeshine','b2y_ni','b2y_ni@yahoo.com','Beethoven Awit , Jr.','108 N Varner St','Bonifay','FL','UNITED STATES','32425-2324','(850) 849-1080','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-12 19:29:49',0,NULL,3,1,1,1,NULL,'301p 一拖二   1 '),(4629,717932349015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','7500nigel','nigelchadwick@btinternet.com','Nigel Chadwick','17 Biggar Bank Road Walney','Barrow in Furness','Cumbria','UNITED KINGDOM','LA14 3YF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 19:33:48',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r云台   1 \r柔光伞   1RR843879243CN\r'),(4630,717934463015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',5.5,'hutongstore','bmonteiro05','bmonteiro@gmail.com','Elzbieta Karasinska','62 Upper Cheltenham Place','Bristol','Bristol','UNITED KINGDOM','BS65HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 19:36:52',0,NULL,3,1,2,1,NULL,'中号内胆包  canon  1 '),(4631,717941460015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','dicksue16','dickrsfabs@googlemail.com','RICHARD TURNER','24 TWYFORD AVE','GREAT WAKERING','Essex','UNITED KINGDOM','SS30EU','07867544494','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 19:48:24',0,NULL,3,1,2,1,NULL,' '),(4632,618748134001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','wamper','martin.almasi@gmail.com','Zuzana Almasi Korenova','Borovianska 1994/49','Zvolen','Zvolen','SLOVAK REPUBLIC','96001','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 19:50:47',0,NULL,3,1,5,1,NULL,'2mx3m 背景架   1 \rCP219487381CN'),(4633,658201152002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','romikos','roman_z@walla.co.il','roman oren','asaifan 2/31','ashdod','','ISRAEL','77430','0542571780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 19:57:53',0,NULL,3,1,2,1,NULL,NULL),(4634,618767929001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.48,'hermeshine','timandnat','natfrank@yahoo.com','Timothy M. Frank','230 Pershing Way','West Palm Beach','FL','UNITED STATES','33401-8036','(561) 820-0099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-12 20:26:49',0,NULL,3,1,1,1,NULL,NULL),(4635,658219451002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','jiffemann','taulen@gmail.com','Jonny Taulen','Fagerliveien 28','Gjøvik','Oppland','NORWAY','2818','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 20:34:52',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843879230CN\r'),(4636,618535342001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','diveevo2009','divmult@gmail.com','Pavel Sushkov','50 Sitnova street','Diveevo vilage','Nizhegorodskaya oblast','RUSSIAN FEDERATION','607320','79030582922','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 20:38:21',0,NULL,3,1,5,1,NULL,'2mx3m背景架  1 \rCP219487395CN\r'),(4637,618770672001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','dkdiaz','davidkarldiaz@hotmail.com','David Diaz','9582 Roan Fields Pl','elk grove','CA','UNITED STATES','95624-6064','(916) 647-4270','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 21:05:33',0,NULL,3,1,1,1,NULL,NULL),(4638,717991448015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',2.39,'hutongstore','docsharp66','sharp-andrew2@sky.com','Andrew Sharp','8 Beaumaris Road Connah\'s Quay','Deeside','Flintshire','UNITED KINGDOM','CH5 4 YA','01244819917','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 21:10:20',0,NULL,3,1,2,1,NULL,'可以发了 '),(4639,717996499015,250600489459,'New Hairlight photostudio boom arm ',2,'AE3101',41.8,'hutongstore','raijakee','raimond@harta.ee','RAIMOND JAKOBS','VARSAALLIKA 36','TALLINN','','ESTONIA','12013','(372) 600-6508','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 21:21:45',0,NULL,3,1,3,1,NULL,'斜臂   2 RR843879226CN\r'),(4641,658253794002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','bobbyddixon117','bobbyddixon@hotmail.com','Bobby D. Dixon','1617 Country Meadows Dr','Sevierville','TN','UNITED STATES','37862-9335','(865) 441-1859','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 21:48:36',0,NULL,3,1,1,1,NULL,NULL),(4642,658259951002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','pawee.th','pond79@hotmail.com','Pawee Lorsuwannarat','14 Jompol Rd.','Amphur Muang','Nakhon Ratchasima','THAILAND','30000','6644267671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 22:04:20',0,NULL,3,1,2,1,NULL,NULL),(4643,703979766016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','pmangan1234','pmangan@oceanfree.net','Patrick Mangan','The Glebe Ramelton Road','Letterkenny','Donegal','IRELAND','default','0749124012','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 22:19:14',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(4644,618781938001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','zathos123','xathorm@gmail.com','Rubén López Reina','Av. Conselheiro Fernando de Sousa, 25, 4ºA','Lisbon','Lisbon','PORTUGAL','1070','00351913944272','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 22:28:19',0,NULL,3,1,4,1,NULL,'2mx3m 背景架   1\rYW864489666CN\r \r这个燕文拿走了，但是燕文815（李月红）说邮编不对，我写信问了，等答复。\r重打'),(4645,658282494002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','hs*88','lamhs2@mcmaster.ca','Hoishing Lam','Apt#2107, 100 Main Street East,','Hamilton','ON','CANADA','L8N3W4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 23:04:41',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(4646,658284240002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','jertui','ville.koivumaki@tut.fi','Ville Koivumäki','Insinöörinkatu 60 b 107','Tampere','Länsi-Suomen lääni','FINLAND','33270','040 7780956','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 23:10:31',0,NULL,3,1,4,1,NULL,'ballhead  $20 \rYW864489180CN\r'),(4647,658289262002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','bvdq68','bvdq68@yahoo.ca','Belron Canada','a/s Pierre-Paul Blanchette<br>8288 Pie-Ix Blvd','Montreal','QC','CANADA','H1Z 3T6','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 23:27:00',0,NULL,3,1,3,1,NULL,'sony A1 单肩包   1 RR843879265CN\r'),(4648,618526883001,110597207686,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',150,'hermeshine','rouxbynne04','rouxbynne.m@optusnet.com.au','Rubin Miller','10 Robinson Street','Croydon','Victoria','AUSTRALIA','3136','0387113546','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2011-01-12 23:29:43',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r斜臂   1 \rlight stand  $20\rYW864489191CN\r'),(4649,704034609016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','alanroseman','alanroseman@comcast.net','Alan M. Roseman','6 Old Pine St','Rehoboth','MA','UNITED STATES','02769-1421','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 00:57:15',0,NULL,3,1,1,1,NULL,NULL),(4650,658314915002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Francisco alves, 222<br>Vl. dos Remédios','Osasco ','Sao paulo','BRAZIL','06296160','55-11-93530450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 01:00:25',0,NULL,3,1,5,1,NULL,'红头灯   1\r800w 110v  灯泡  1\rCP219487435CN\r'),(4652,658321662002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','marymom1220','aadams38975@everestkc.net','Alan Adams','12612 W 121st Ter','Overland Park','KS','UNITED STATES','66213','(913) 897-3721','NoPaymentFailure','CheckoutComplete','Other','2011-01-13 01:24:15',0,NULL,3,1,1,1,NULL,'摄影背心 canon xxxl  老款  1 '),(4653,658337324002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','mona123mona','marandym@yahoo.com','mona marandy','21441 providencia st','woodland hills','CA','UNITED STATES','91364','(818) 676-0840','NoPaymentFailure','CheckoutComplete','Other','2011-01-13 02:20:46',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r单灯头  1\r反光伞   1 RR843878185CN\r'),(4654,618288573001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','magican4','trond@solem.nu','Trond Solem','Furuhaugvegen 35','N-7550 Hommelvik','','NORWAY','7550','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 02:39:34',0,NULL,3,1,3,1,NULL,'2m灯架   1\r反光板支架   1 RR843879186CN\r'),(4655,658352996002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','dirge168','kyk1082@gmail.com','Ken Kee','Blk 132 Bedok Reservoir Road #09-1257<br>(S)470132','default','','SINGAPORE','470132','6582337483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 03:23:19',0,NULL,3,1,11,1,NULL,'中号内胆包 nikon   1 \r'),(4656,658359785002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','zhengkai136','zhengkai136@hotmail.com','Kai Zheng','11 Farina Millway','North York','ON','CANADA','M2L1S2','(416) 388-1362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 03:57:59',0,NULL,3,1,2,1,NULL,'40cm 棚  1 '),(4657,618905421001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.9,'hermeshine','p_pohjanjoki','pohjanjoki@gmail.com','Petri Pohjanjoki','Turunmaankatu 2 A 1','Turku','','FINLAND','20740','+358509115918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 04:13:06',0,NULL,8,1,17,0,NULL,NULL),(4658,618905275001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','p_pohjanjoki','pohjanjoki@gmail.com','Petri Pohjanjoki','Turunmaankatu 2 A 1','Turku','','FINLAND','20740','+358509115918','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 04:13:07',0,NULL,3,1,3,1,NULL,'反光板支架   1\r大力夹   2 RR843879190CN\r'),(4659,658367013002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','us.chotikorn','us.chotikorn@gmail.com','Chotikorn Buranarachada','291 Martin Luther King Jr Blvd','Newark','NJ','UNITED STATES','07102-2012','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-13 04:29:11',0,NULL,3,1,1,1,NULL,'广角托架  1 '),(4660,618928513001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','okidoky1','onetwothreemike@gmail.com','Michael Pot','25 Kolo Drive<br>RR 4','Ashton','ON','CANADA','K0A1B0','(613) 257-5584','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 06:42:18',0,NULL,8,1,17,0,NULL,' '),(4661,618930487001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','okidoky1','onetwothreemike@gmail.com','Michael Pot','25 Kolo Drive<br>RR 4','Ashton','ON','CANADA','K0A1B0','(613) 257-5584','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 06:57:06',0,NULL,3,1,2,1,NULL,'这票应该是2个55橡胶罩， 发了几个？ \r发了两个    王'),(4662,618934508001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','guru_lurks','mrcroft@gmail.com','David Croft','40 Gray St.','Woonona','New South Wales','AUSTRALIA','2517','0242849228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 07:27:01',0,NULL,3,1,2,1,NULL,'大力夹球台  2 '),(4663,704133915016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'AC2304',5.5,'hutongstore','paranoid73','seventy_three@hotmail.co.uk','Karl Fennell','Mill Cottage Norwich Road','Chedgrave','Norwich','UNITED KINGDOM','NR14 6ND','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 08:16:55',0,NULL,3,1,2,1,NULL,'中号内胆包 nikon   1 '),(4664,618953870001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','randop84123','randop84@hotmail.com','Rando Pitkäärt','Pikk 76-5','Tartu','Tartumaa','ESTONIA','50603','+3725220702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 09:27:52',0,NULL,3,1,2,1,NULL,' '),(4665,618953772001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','katechiangmai','katerous@hotmail.com','Rermphant Promnuchanont','Pair Wedding Studio   158/4  ChiangMai - Lamphang Rd.<br>Tambon PaThun    Aumphur Muang','ChiangMai','Thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 09:31:18',0,NULL,8,1,17,0,NULL,NULL),(4666,658409313002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','katechiangmai','katerous@hotmail.com','Rermphant Promnuchanont','Pair Wedding Studio   158/4  ChiangMai - Lamphang Rd.<br>Tambon PaThun    Aumphur Muang','ChiangMai','Thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 09:31:18',0,NULL,8,1,17,0,NULL,NULL),(4667,618948573001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1309',7.4,'hermeshine','katechiangmai','katerous@hotmail.com','Rermphant Promnuchanont','Pair Wedding Studio   158/4  ChiangMai - Lamphang Rd.<br>Tambon PaThun    Aumphur Muang','ChiangMai','Thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 09:31:19',0,NULL,8,1,17,0,NULL,NULL),(4668,618951652001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','katechiangmai','katerous@hotmail.com','Rermphant Promnuchanont','Pair Wedding Studio   158/4  ChiangMai - Lamphang Rd.<br>Tambon PaThun    Aumphur Muang','ChiangMai','Thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 09:31:19',0,NULL,3,1,3,1,NULL,'77mm 镜头盖 canon   3\r58mm 镜头盖  canon  1\r430ex 肥皂盒   1\r渐变灰  1\r77mm 环架   1 RR843879504CN\r'),(4669,704151575016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','dblenk89','domen.blenkus@gmail.com','Domen Blenkuš','Ulica prvoborcev 5','Ljubljana','Ljubljana','SLOVENIA','1131','+386 31 307060','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 09:39:17',0,NULL,3,1,3,1,NULL,'sf18-canon  1 RR843879495CN\r'),(4670,704153271016,260675927807,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',21,'hutongstore','niko-nik1967','mayer_nk@mail.ru','Nikolay Mayer','Semafornaya 189 \"b\"  - 30','Krasnoyarsk','','RUSSIAN FEDERATION','660012','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 09:45:32',0,NULL,3,1,3,1,NULL,'sony a1 单肩包  1 RR843879420CN\r'),(4671,718227697015,250601900955,'Wireless Remote Control Cord for Canon 50D/40D/30D/20D',1,'AA3210',11.47,'hutongstore','capnemo101','credlands@googlemail.com','Peter Credland','Island Cottage Island Road','Garthorpe','Lincolnshire','UNITED KINGDOM','DN17 4AA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 11:19:42',0,NULL,3,1,2,1,NULL,'爵影无线c3   1 '),(4672,618978855001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','pixz12','susanefong@hotmail.com','Susan Zamolo','4 Driffield Street<br>Anula','Darwin','Northern Territory','AUSTRALIA','0812','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 11:30:19',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r斜臂  1 \rYW864489272CN\r'),(4673,704184357016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','goborut','borut.gorenjak@gmail.com','Borut Gorenjak','Ulica Staneta Severja 15','Maribor','','SLOVENIA','2000','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 11:46:18',0,NULL,3,1,3,1,NULL,'sf18-canon  1  RR815344962CN\r'),(4674,718240719015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',2,'AB1204',25.98,'hutongstore','beautch173','beautchbailey@hotmail.com','steven martin bailey','41 elgar drive maltby','nr rotherham','South Yorkshire','UNITED KINGDOM','s66 7qe','07984607679','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 12:11:24',0,NULL,3,1,3,1,NULL,'717快装板  2 RR843879464CN\r'),(4675,718248620015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','daitaylor54','daitaylor@live.co.uk','David  TAYLOR','19 BELLAMY\'S COURT ABBOTSHADE ROAD','LONDON','London','UNITED KINGDOM','SE16 5RF','02072376071','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 12:33:24',0,NULL,3,1,2,1,NULL,' '),(4676,658458775002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','dmitriyla','info@da-group.ru','Dmitriy Lagunov','Uinskaya 1b-26','Perm','Permski krai','RUSSIAN FEDERATION','614051','83422712669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 12:52:01',0,NULL,3,1,3,1,NULL,'50-70 塑料卡口棚   2 RR843879376CN\r'),(4677,658469877002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','alex17wiper','alex17wiper@hotmail.com','Alexandre Martin','7-A rue Corno','St-Basile','NB','CANADA','e7c 1p6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 13:42:33',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座  1\r柔光伞   1 RR843879455CN\r'),(4678,619010805001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','larbyrne','lar_byrne@hotmail.com','Lar byrne','104 saunders lane','Rathnew','Wicklow','IRELAND','00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 13:44:35',0,NULL,3,1,2,1,NULL,'小号镜头筒  1 '),(4679,618957215001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','philosomatographer','dawidl@solms.co.za','Dawid Loubser','113 Barry Hertzog avenue<br>Emmarentia','Johannesburg','Gauteng','SOUTH AFRICA','2029','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 14:19:24',0,NULL,3,1,3,1,NULL,'井字扳手  1 RR843879478CN\r'),(4680,618930958001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',125.05,'hermeshine','voux','byronwee@gmail.com','Wee Eng Peen','24 Jalan Daud','Singapore','','SINGAPORE','419567','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 14:20:27',0,NULL,3,1,10,1,NULL,'c型大力夹  1\r大力夹 球台  1\r斜臂  2\r1.6x2.1 背景布 2 （ 白+黑）\r渐变灰  1\rND8  1\r渐变橙   1\r72mm 环架  1\r递四方新加坡专线\r '),(4681,658489192002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','michele88catena','michelecatena@hotmail.it','Michele Catena','via montefanese 79','Osimo','AN','ITALY','60027','349-4516530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 14:47:59',0,NULL,3,1,2,1,NULL,' '),(4682,657659435002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sfwangphg','sfwang1973@yahoo.com.tw','WANG SWEE FOCK','5,LRG PELINDUNG PANTAI 9<br>TMN PELINDUNG PANTAI','BESERAH,KUANTAN,','PAHANG','MALAYSIA','26100','019-9457999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 14:57:07',0,NULL,3,1,3,1,NULL,'2m灯架 1\rB座  1\r柔光伞 1 RR815345000CN\r'),(4683,619032021001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','terjefro','tfrostad@gmail.com','Terje Frostad','Kuhaugen 47','Melhus','ST','NORWAY','N7224','+4793098048','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 15:00:36',0,NULL,3,1,3,1,NULL,'nikon标黑色 XL背心\r\r新款RR815344980CN\r发错了，应该是老款的（看客户反映吧）\r'),(4684,619044929001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','najort-perm','alexandr.abramenkov@gmail.com','Alexandr Abramenkov','M. Gorkogo Street<br>64-145','Perm','Permskiy Kray','RUSSIAN FEDERATION','614007','8-902-7918020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 15:45:58',0,NULL,3,1,3,1,NULL,'肩架 1 RR815344914CN\r'),(4685,718317569015,250599414645,'Green.L 77mm 77 Neutral Density ND8 Filter ND 8 New',1,'AE2314',4.8,'hutongstore','klum8997','lumsdenkevin@ymail.com','Kevin Lumsden','49 Standhouse Lawns','Newbridge','Kildare','IRELAND','nil','045438375','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 15:51:43',0,NULL,3,1,2,1,NULL,' '),(4686,658512234002,120593062257,'New Pro Photo Vest for all DSLR fans  Size: XL',1,'AA1104',26.8,'hermeshine','bjslatham','bobbie.latham@cox.net','Bobbie Latham','8225 Crown Court Road','Alexandria','VA','UNITED STATES','22308','','NoPaymentFailure','CheckoutComplete','Other','2011-01-13 15:56:55',0,NULL,3,1,1,1,NULL,'无字XL背心 冬夏'),(4687,658513619002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','williams_43_1728','billy_corleone@hotmail.com','Guillermo Blasco Jiménez','Paseo.ZonaFranca 145 escalera A 6º 1ª','Barcelona','Cataluña','SPAIN','08038','933328883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 16:03:35',0,NULL,3,1,4,1,NULL,'\rYW864489261CN'),(4688,658522167002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6,'hermeshine','dimans89','dimans@i.ua','Dmytro Ganzhus','Danyla Galytskogo 9/206','Rivne','','UKRAINE','33027','380985253027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 16:25:44',0,NULL,3,1,2,1,NULL,''),(4689,658533431002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','paul780','ptrawick37@gmail.com','Paul Trawick','Site 8, Lot 8,<br>RR1','Westerose','AB','CANADA','T0C 2V0','(780) 497-0005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 16:57:25',0,NULL,3,1,2,1,NULL,' 小号灰卡 1'),(4691,718361351015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','sakisti','a_tsivas@hotmail.com','ATHANASIOS TSIVAS','MITROPOLITOU IOAKEIM 6','ALEXANDROUPOLI','EVROS','GREECE','68100','00302551026440','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 17:28:37',0,NULL,3,1,2,1,NULL,'【 '),(4692,619099020001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','suziecutiepatootie','robnsuzie@earthlink.net','Suzanna M. Swift','8206 Blairton Rd','Springfield','VA','UNITED STATES','22152','(925) 408-4473','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-13 18:08:30',0,NULL,3,1,1,1,NULL,' '),(4694,619104143001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','vladimir_17','r17studio@yahoo.com','Vladimir Eskin','Anilevich st. 15/16','Raanana','Hasharon','ISRAEL','43321','972-547972118','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 18:26:35',0,NULL,3,1,3,1,NULL,'反光板支架 1 RR843879393CN\r'),(4695,619108858001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','botjeti','doordouwers@hotmail.com','Andy Bothof','kloosterstraat 4','Venlo','','NETHERLANDS','5921HC','0628971293','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 18:31:16',0,NULL,3,1,4,1,NULL,'3m×6m 白色背景布\rYW864489283CN\r '),(4696,658141863002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','azat-juni','azat.juni@gmail.com','Azat Shakirzyanov','Bigicheva<br>d.3 kv.44','Kazan','Tatarstan','RUSSIAN FEDERATION','420100','+79033887866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 18:32:15',0,NULL,3,1,3,1,NULL,'2m灯架 1\rB座 1\r柔光伞 1 RR815344993CN\r'),(4697,718397018015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','v27xxx','mini_v69@hotmail.com','Vanessa Nguyen','83 Lesney Gardens','Rochford','Essex','UNITED KINGDOM','SS4 1TZ','07769171785','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 18:41:32',0,NULL,3,1,3,1,NULL,'斜臂1RR843879362CN\r'),(4698,658587538002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','evri4mann','evri4man@gmail.com','Mikhlyayev Yevgeniy','Respubliki 39/4-82','Temirtau','Karagandinskaya obl','KAZAKHSTAN','101400','87053002969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 19:03:31',0,NULL,3,1,2,1,NULL,' '),(4699,619134482001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','kozlik5lion','igor.kozel@gmail.com','Mr Igor Kozel','Svatoplukovo 210','Nitra','Nitra','SLOVAK REPUBLIC','95116','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 19:23:59',0,NULL,3,1,3,1,NULL,'反光板支架 1 RR815344976CN\r'),(4700,619132924001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','elizeucine','elizeumol@hotmail.com','elizeu mol','rua 05 de maio, 6 b<br>centro','Timóteo','Minas Gerais','BRAZIL','35180036','3138493361','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 20:08:06',0,NULL,3,1,2,1,NULL,'小号灰卡 1 '),(4701,619176419001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','bobdrake','drbobdrake@gmail.com','Robert F. Drake','3489 Fort Independence St<br>Apt 7D','Bronx','NY','UNITED STATES','10463','(718) 601-8735','NoPaymentFailure','CheckoutComplete','Other','2011-01-13 20:52:08',0,NULL,3,1,1,1,NULL,' '),(4702,619195866001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','chris1gina','chris1gina@peoplepc.com','christopher cordaro','24 Harding Dr','new rochelle','NY','UNITED STATES','10801','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-13 21:38:39',0,NULL,3,1,1,1,NULL,' '),(4703,619197123001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','gavnshez','gavin.mca@gmail.com','Gavin & Sheree McArthur','5 Narambi Street','Warana','Queensland','AUSTRALIA','4575','0408187789','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 21:42:02',0,NULL,3,1,4,1,NULL,' 背景架2m（黑白） 1\rYW864489493CN\r'),(4704,619212629001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','tag1967andrey','tag1967@mail.ru','Andrey Tolokov','Ak.Glushkova 10/5','Volodymyr-Volynskiy','Volynska','UKRAINE','44700','+380637270683','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 22:24:45',0,NULL,3,1,5,1,NULL,'背景架2m（黑白）  1\rCP219487789CN\r'),(4705,718545539015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','jekyll_1001','steven.heide@blueyonder.co.uk','Steven Heide','7 Stamfordham Close','Wallsend','Tyne and Wear','UNITED KINGDOM','NE288ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 23:14:40',0,NULL,3,1,2,1,NULL,NULL),(4706,658700955002,120601698401,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','scatteredpictures','scatteredpictures@msn.com','John Malott','630 Cypress Dr','Prescott','AZ','UNITED STATES','86303','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-13 23:30:57',0,NULL,3,1,1,1,NULL,' '),(4707,658701370002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','ebit4e2009','ebit4e@hotmail.com','Hungyi Lai','397/122 Regent Home Condo Building B<br>Soi Phongpetniwej , Leapkhongprapa Road Jatujuk','Bangkok','Bangkok','THAILAND','10900','+66805592088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 23:32:49',0,NULL,3,1,2,1,NULL,'渐变灰  1 '),(4708,718553201015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','020pinstripethug','pinstripethug@googlemail.com','Charles Kilkenny','15 Shepherd House, York Way,','London','London','UNITED KINGDOM','N7 9QB','02076078654','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 23:37:00',0,NULL,3,1,2,1,NULL,'热靴盖 1'),(4709,718560761015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'AA3204',2.98,'hutongstore','fingermouse1911','fingermouse1911@hotmail.com','Simon Gill','22 Strickland Street','Hull','East Riding of Yorkshire','UNITED KINGDOM','HU3 4AQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 23:59:54',0,NULL,3,1,2,1,NULL,' RS-C3 1'),(4710,658710186002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vtlively09','vtlively@gmail.com','Vitaliy Golobotchansky','Mishmar HaYarden str. 5/3','Ramat Gan','','ISRAEL','52271','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 00:05:05',0,NULL,3,1,2,1,NULL,' '),(4712,619261249001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',2,'AB1302',6.68,'hermeshine','volcomscout822','cjhoken@yahoo.com','Chris Hokenson','6265 Meadow Crest Drive','La Mesa','CA','UNITED STATES','91942','(619) 589-6129','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 01:17:46',0,NULL,3,1,1,1,NULL,' '),(4713,658739008002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Francisco alves, 222<br>Vl. dos Remédios','Osasco ','Sao paulo','BRAZIL','06296160','55-11-93530450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 01:53:36',0,NULL,8,1,17,0,NULL,''),(4714,658743296002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','delgado8610','dani_delgado_@hotmail.com','daniel delgado','urb. las torres 18. 4º A4','las palmas','Canarias','SPAIN','35010','686690929','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 02:10:23',0,NULL,3,1,4,1,NULL,' YW864489250CN\r'),(4715,619276554001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','jlpoletti','jabespoletti@terra.com.br','Jabes Levi Poletti','Rua 8A nº 828 - Vila Nova','Rio Claro','São Paulo','BRAZIL','13506544','(55-19) 3524-1208','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 02:19:49',0,NULL,3,1,2,1,NULL,'单灯头 2 \r没发欧标吧， 等客户反映'),(4716,619278777001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','dvbxu','dan.villanueva@oracle.com','Dan Villanueva','12 Oakhill Dr','Castle Hill','New South Wales','AUSTRALIA','2154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 02:38:21',0,NULL,3,1,2,1,NULL,'小号灰卡 1 '),(4717,619284396001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Francisco alves, 222<br>Vl. dos Remédios','Osasco ','Sao paulo','BRAZIL','06296160','55-11-93530450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 02:51:04',0,NULL,8,1,17,0,NULL,''),(4718,658772845002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','alexanderowl09','kaliv@bk.ru','Alexander Kachan','Margelova<br>354-57','Omsk','Omskaya','RUSSIAN FEDERATION','644025','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 04:11:52',0,NULL,3,1,3,1,NULL,' RR843879402CN'),(4719,619312432001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',29.12,'hermeshine','chompachompin','orbemax@gmail.com','Adrian Ramirez','La Villa 2012<br>Campo de Polo Chapalita','Zapopan','Jalisco','MEXICO','45050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 05:20:00',0,NULL,3,1,3,1,NULL,' \rRR843879433CN\r'),(4720,718293801015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',88.83,'hutongstore','macchia1960','macchia60@hotmail.com','MASSIMO CHIACCHIARO','VIA FORNILLI, N. 86','CAPACCIO','SA','ITALY','84047','3333091082','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 08:17:44',0,NULL,3,1,4,1,NULL,'50cm棚 1\r4合1灯头 1\r镜头笔 1\r斜臂 1\r2m灯架 1\r50×70棚 1\r115W  220v灯 1\r欧标转换器头 1\r\r\r\r'),(4721,619343428001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','phoenixsoaring','phoenixsoaring2008@gmail.com','Glen Chin','8778 24th Ave','Brooklyn','NY','UNITED STATES','11214','(646) 807-8182','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 08:41:04',0,NULL,3,1,1,1,NULL,' '),(4722,618184518001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','ferokabat','ferokabat@pro-com.sk','frantisek kabat','hostovce 34','hostovce','slovakia','SLOVAK REPUBLIC','951 91','00421 905 664 025','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 08:48:22',0,NULL,3,1,3,1,NULL,'肩架  1 RR843878265CN\r'),(4724,658817299002,120531377860,'JueYing Lambency Flash Diffuser for 430EX F36AM',1,'AB3308',22,'hermeshine','2pinguelos','jvalgon@telefonica.net','Juan pedro valdes gonzález','Calle Achaman, 63','Santa Cruz de Tenerife','Canarias','SPAIN','38111','922686464','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 08:57:51',0,NULL,3,1,3,1,NULL,'碗罩  P2   1 RR843878424CN\r'),(4725,619346403001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','morpheus_t','morpheus.dt@gmail.com','Morpheus Believer','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 09:05:15',0,NULL,8,1,17,0,NULL,NULL),(4726,619346843001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','morpheus_t','morpheus.dt@gmail.com','Morpheus Believer','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 09:05:15',0,NULL,3,1,8,1,NULL,'2mx3m 背景架  1\r3mx6m 绿色背景布  1\r2m 灯架  2\r双灯头  欧标  2\r柔光伞  2\r45w   4\r110cm 5in 1  反光板  1\r包   1\r算算看吧\r申报 $60\rCP219487761CN\r\r '),(4727,658819665002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','caposaure','capcav@neuf.fr','Gilles Bangratz','8 rue du moulin','HILSENHEIM','Alsace','FRANCE','67600','0388859493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 09:11:00',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843878407CN\r\\'),(4728,658829239002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','erik_efv','erik@u2us.nl','Erik Vries','Stellingmolenstraat 56','Culemborg','GL','NETHERLANDS','4105 XG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 09:58:53',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1  RR843878194CN\r'),(4729,619386989001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','sortjensen','jannicksort@hotmail.com','Jannick Jensen','43 Sycamore, Trimbleston<br>Goatstown Road','Clonskeagh','Dublin','IRELAND','14','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:12:35',0,NULL,3,1,2,1,NULL,'52mm 渐变灰  1 '),(4730,619389187001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','tom_dror','tomdror155@walla.com','Tom Dror','David Elazar<br>77','Holon','ID','ISRAEL','58558','03-5595303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:25:11',0,NULL,3,1,3,1,NULL,'110cm 5in1  反光板  1 RR843878490CN\r'),(4731,658864087002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',2,'AA3408',19.98,'hermeshine','elpeladoedu','enocetti@adinet.com.uy','EDUARDO NOCETTI','AVDA  RONDEAU  1470','MONTEVIDEO','','URUGUAY','11100','59829029106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:33:58',0,NULL,8,1,17,0,NULL,''),(4732,658864678002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','fali_fribi','fali_ibi@hotmail.com','Rafael Girón','c/marques de mondejar 19 - 5ºB','granada','Andalucía Ceuta y Melilla','SPAIN','18004','958262947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:36:05',0,NULL,3,1,3,1,NULL,'50-70 柔光箱   塑料卡口  1 RR843878472CN\r'),(4733,618218535001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',2,'AC1201',72.72,'hermeshine','sukasurf','sukatechnologies@gmail.com','Cathal Furey','138 The Waterside Apts<br>Ringsend Road','Dublin 4','Dublin','IRELAND','4','0868100148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:38:21',0,NULL,3,1,3,1,NULL,'肩架  1\r67mm 镜头盖  canon  1\r中号镜头筒   1\r小号镜头筒    2\rLenspen  1\r大号内胆包  canon  1RR843878225CN\r\r\r\r\r '),(4734,619395996001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',5,'AA3305',18,'hermeshine','elpeladoedu','enocetti@adinet.com.uy','EDUARDO NOCETTI','AVDA  RONDEAU  1470','MONTEVIDEO','','URUGUAY','11100','59829029106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:48:35',0,NULL,3,1,3,1,NULL,'EW-73B   2 \r67mm uv   5 RR843878628CN\r'),(4735,658868151002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','alainice06','gromalain@yahoo.fr','gromy alain','hopital ste marguerite centre hyperbare<br>270 boulevard ste marguerite','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13009','0660892365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:53:13',0,NULL,3,1,2,1,NULL,'大力夹  1 '),(4736,617884242001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','thecrow5msr','agrogin@nycap.rr.com','Adam Grogin','1095c central ave','albany','NY','UNITED STATES','12205','','NoPaymentFailure','CheckoutComplete','Other','2011-01-14 13:10:07',0,NULL,3,1,4,1,NULL,'2m 灯架   1\r斜臂  1 \rYW864489482CN\r'),(4737,619408439001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','chitalina','denisesaura@gmail.com','Jason Silva','Rua Visconde de Nacar, 1200 / 105 Bairro Centro','Curitiba','PR','BRAZIL','80410-201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 13:35:54',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r斜臂  1 RR843878336CN\r'),(4738,658749989002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','gegapm2008','gegapm@hotmail.com','Rolando Villaroel','Curicó # 380<br>Departamento 212','Santiago','Chile','CHILE','8330145','0056989411899','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 13:44:01',0,NULL,3,1,2,1,NULL,'40cm 棚  1 '),(4739,619017294001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','stix_bizz','steven.pribilinskiy@gmail.com','Steven Pribilinskij','Generala Petrova str., 10/56','Mukachevo','Zakarpatye','UKRAINE','89600','380509667377','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 13:34:11',0,NULL,3,1,3,1,NULL,'肩架   1 RR843878282CN\r'),(4740,658880082002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','shabshay','shabshay@hotmail.com','Pavel Shabshay','Ha-Tizmoret 26/6','Rishon Le-Zion','','ISRAEL','75562','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 13:34:38',0,NULL,3,1,3,1,NULL,' RR843878509CN\r'),(4741,718783110015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','leanneoliewright','leanne_nicole_wright@hotmail.co.uk','Leanne Wright','Dunston House Pump Lane','Fenton','Nottinghamshire','UNITED KINGDOM','NG23 5DF','01476408316','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-14 14:19:19',0,NULL,3,1,3,1,NULL,'反光板支架   1 RR843878203CN\r'),(4742,658894729002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',2,'AO0014',15.8,'hermeshine','mikewest1977','mikewest13@hotmail.com','mike west','1214 tredmore dr','mississauga','ON','CANADA','l5j 3v3','(416) 436-8494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 14:23:55',0,NULL,3,1,2,1,NULL,'800w 110v   2 '),(4743,658907236002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','blake_bilbo','ikerblake@gmail.com','iker lago','federico garcia lorca nº2 Bj. H','sestao','País Vasco','SPAIN','48910','686326820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:06:07',0,NULL,3,1,4,1,NULL,'tripod $20 \rYW864489471CN\r'),(4744,658755117002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',2,'AO0014',15.8,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Francisco alves, 222<br>Vl. dos Remédios','Osasco ','Sao paulo','BRAZIL','06296160','55-11-93530450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:16:18',0,NULL,3,1,5,1,NULL,'红头灯×1  欧标转美标的头 2个\r800w  110V 灯泡×3\r800w 220v 灯泡   5\r\rCP219487792CN\r'),(4745,658908512002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:17:08',0,NULL,8,1,17,0,NULL,NULL),(4746,619434906001,110407881132,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',5.6,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:17:11',0,NULL,8,1,17,0,NULL,NULL),(4747,619434922001,110464610934,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',5.6,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:17:24',0,NULL,8,1,17,0,NULL,NULL),(4748,658908526002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:17:25',0,NULL,8,1,17,0,NULL,NULL),(4749,619434978001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',2,'AA3314',13,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:17:38',0,NULL,3,1,3,1,NULL,'77mm  cpl   2\r72mm  cpl   1\r55mm cpl    1\r52mm cpl   1\r67mm cpl   1 RR843878591CN\r'),(4750,658916263002,120601698198,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','teddbg','chazi@abv.bg','Teodor Georgiev','13 block, floor 6, apt.6C<br>Studentski grad distr.','Sofia','Bulgaria','BULGARIA','1700','(359)878659354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:30:07',0,NULL,3,1,2,1,NULL,'52mm 环架  1 '),(4752,718826129015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','dezm0nnd','demonn-90@yandex.ru','Ptitsyn Dmitry','60 let SSSR st. 5/43','Skovorodino','Amurskaya oblast\'','RUSSIAN FEDERATION','676014','+7 924 144 1226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 16:28:46',0,NULL,8,1,17,0,NULL,NULL),(4753,704755942016,260660054359,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',2.8,'hutongstore','dezm0nnd','demonn-90@yandex.ru','Ptitsyn Dmitry','60 let SSSR st. 5/43','Skovorodino','Amurskaya oblast\'','RUSSIAN FEDERATION','676014','+7 924 144 1226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 16:28:46',0,NULL,8,1,17,0,NULL,NULL),(4754,718825536015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','dezm0nnd','demonn-90@yandex.ru','Ptitsyn Dmitry','60 let SSSR st. 5/43','Skovorodino','Amurskaya oblast\'','RUSSIAN FEDERATION','676014','+7 924 144 1226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 16:28:47',0,NULL,8,1,17,0,NULL,NULL),(4755,718824432015,250635198378,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.16,'hutongstore','dezm0nnd','demonn-90@yandex.ru','Ptitsyn Dmitry','60 let SSSR st. 5/43','Skovorodino','Amurskaya oblast\'','RUSSIAN FEDERATION','676014','+7 924 144 1226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 16:28:47',0,NULL,3,1,3,1,NULL,'58mm-canon 反接环  1\r52-58mm 双阳环   1\r430肥皂盒   1\r58mm cpl    1 RR843876281CN\r'),(4756,658948001002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','-jm1-','juergen_m@web.de','Juergen Meier','K.-Schumacher-Str. 20','Mitterteich','','GERMANY','95666','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 16:56:05',0,NULL,3,1,3,1,NULL,'斜臂    1 RR843878322CN\r'),(4758,704812118016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'AA2204',2.75,'hutongstore','brukner3571','brukner@seznam.cz','Vladimir Brukner','Stritez 91','Trebic','Vysocina','CZECH REPUBLIC','67401','00420721873760','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 18:05:58',0,NULL,3,1,2,1,NULL,'红外无线 olympus  1 '),(4759,619512842001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','danceman_vvs','va98saf@gmail.com','Yuganov Konstantin','51\"A\" Sony Krivoy street #6','Chelyabinsk','Chelyabinskaya oblast','RUSSIAN FEDERATION','454048','(514) 804-3839','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 18:40:26',0,NULL,3,1,3,1,NULL,'tripod $15 RR843878319CN\r'),(4760,718912535015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','manur2009','manuel_rivas@vodafone.es','MANUEL RIVAS DEL FRESNO','ARQUITECTO REGUERA 3-6A','OVIEDO','Asturias','SPAIN','33004','629934347','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-14 18:57:11',0,NULL,3,1,4,1,NULL,'背景架（ 白 黑)   1  2m\rbackground support $18 \rYW864489460CN\r'),(4761,619523863001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','little.beef','m@manzin.it','Massimiliano Manzin','Via Giulia 56','Trieste','TS','ITALY','34126','040-575233','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 19:01:32',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r斜臂   1 \rYW864489456CN\r'),(4762,619524368001,110523102158,'62mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1306',2.6,'hermeshine','justinvs','justinvs@sff.net','Justin Stanchfield','62920 Mt Highway 43<br>.','Wise River','MT','UNITED STATES','59762-9708','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 19:02:08',0,NULL,3,1,1,1,NULL,NULL),(4763,718915001015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',12.99,'hutongstore','killachase01','bobmoyler@yahoo.co.uk','bob moyler','34 orford street','LIVERPOOL','Merseyside','UNITED KINGDOM','L15 8HX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-14 19:04:29',0,NULL,3,1,2,1,NULL,'717快装板  1 '),(4764,659006109002,120560203032,'58mm Lens lenscap for Canon Combined shipping discounts',1,'AA1301',2.6,'hermeshine','jorgevalle86-2008','jorgevalle86@yahoo.com','JORGE VALLE DEL CARPIO','Jr. Huallaga 920','Lima','Lima','PERU','Lima1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 19:12:22',0,NULL,8,1,17,0,NULL,NULL),(4765,619531171001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','jorgevalle86-2008','jorgevalle86@yahoo.com','JORGE VALLE DEL CARPIO','Jr. Huallaga 920','Lima','Lima','PERU','Lima1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 19:15:47',0,NULL,0,1,3,0,NULL,'新款内胆包  1\r58mm 镜头盖  canon  1 \r第一次没收到，再发一次'),(4766,619534839001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64.99,'hermeshine','karrfan','christopher@rogueshollow.net','Christopher Brielmaier','62 Broadway St','Kenton','OH','UNITED STATES','43326','(614) 408-3137','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-14 19:23:33',0,NULL,3,1,4,1,NULL,'红头灯   1 欧标转美标的头\r800w 110v  1 \rYW864489445CN\r'),(4767,659026473002,120568891628,'Male-Male 52mm-58mm Macro Combined shipping discounts',2,'AA1212',7.1,'hermeshine','dualiteis','crolke@dualite.com','james cropp','1 dualite ln','williamsburg','OH','UNITED STATES','45176','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 19:56:28',0,NULL,3,1,1,1,NULL,NULL),(4768,619564431001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','terrypope1','tpope1@hotmail.com','Terry Pope','6 S Laflin St<br>Apt 722','Chicago','IL','UNITED STATES','60607-2442','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 20:33:22',0,NULL,3,1,1,1,NULL,NULL),(4769,704900703016,260646700576,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',54.5,'hutongstore','cesmad83','cescoronado@gmail.com','Cesar Coronado Garcia','Calle del Rey 35','San Lorenzo Escorial','Madrid','SPAIN','28200','637822838','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-14 20:55:52',0,NULL,3,1,4,1,NULL,'6663a   1 \rYW864489434CN\r'),(4771,619576578001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','sander_jacobsen','sander@cardinalrg.org','Sander Jacobsen','Hellestadgangen 49','Dal','Dal','NORWAY','2072','+4790826339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 21:00:56',0,NULL,8,1,17,0,NULL,' '),(4772,619576077001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','sander_jacobsen','sander@cardinalrg.org','Sander Jacobsen','Hellestadgangen 49','Dal','Dal','NORWAY','2072','+4790826339','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 21:00:57',0,NULL,3,1,4,1,NULL,'背景架2m ( 白  黑  绿   黄 ）   1\rYW864489423CN\r '),(4773,659054426002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','jl9br','jeffluppinoesposito@gmail.com','Anna McGrady','474 Lambeth Field, apartment 3<br>University of Virginia','Charlottesville','VA','UNITED STATES','22904','(240) 412-3972','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-14 21:05:10',0,NULL,3,1,1,1,NULL,'反光板支架   1\r110cm 5in1    1\r分两票发挂号小包吧 RR843878985CN\rRR843878971CN'),(4774,704697214016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',6,'AA1310',22.68,'hutongstore','paquito05','cesarcheca@gmail.com','César Checa Manrique de Lara','Maria de Molina, 39 Bassat - Ogilvy','Madrid','Madrid','SPAIN','28006','628306690','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 20:57:36',0,NULL,3,1,3,1,NULL,'2m 灯架   2\r双灯头 欧标   2\r反光伞   2\r115w 220v   4\r包    1 \rCP219487801CN\r'),(4775,659062345002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',8.69,'hermeshine','coco.and.me','jlao22@hotmail.com','J L','90 Des Soeurs Grises #705','Montreal','QC','CANADA','H3C 6N1','(514) 510-1823','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 21:15:02',0,NULL,3,1,2,1,NULL,'中号内胆包 canon  1 '),(4776,619587585001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',2,'AKT024',9.74,'hermeshine','amnon2009718','karate1975@gmail.com','Amnon Suodai','6485 Booth St<br>Apt 6B','Rego Park','NY','UNITED STATES','11374-4020','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 21:26:36',0,NULL,3,1,1,1,NULL,'77mm 接口环  2\r广角托架  2 '),(4777,719004513015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','binki737','ebayer@paulbarnes.me.uk','Paul Barnes','Charlton, Church Lane, Bursledon','Southampton,','Hampshire','UNITED KINGDOM','SO31 8AB','07810547754','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-14 21:43:16',0,NULL,3,1,3,1,NULL,'斜臂  1 RR843878115CN\r'),(4778,704932114016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','jacek1702','fotojacek@diginet.ie','Marian Pieciak','11 Laurelmount Avenue Rock Road','Carrigaline','Cork','IRELAND','000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 21:51:41',0,NULL,3,1,4,1,NULL,'2m 灯架   1\r反光板支架   1\rreflector holder   $22 \rYW864489412CN\r'),(4779,659078160002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','triathlonroco','roger_couture@yahoo.com','Roger Couture','344   12 Ave','Pintendre','QC','CANADA','G6C1K7','(418) 835-6016','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 21:53:02',0,NULL,3,1,2,1,NULL,'6662a快装板  1 '),(4780,619624313001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','lostbider','oliverpenny7738@yahoo.com','SZE-HUA WU','8650 Spicewood Springs Rd<br>Ste 122','Austin','TX','UNITED STATES','78759-4310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 23:15:36',0,NULL,3,1,1,1,NULL,NULL),(4781,619586060001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','chmwilki','chmwilki@gmail.com','Morgan Wilkins','1638 E Lindley Rd','Mooresville','IN','UNITED STATES','46158-6575','(317) 831-1832','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 23:18:41',0,NULL,8,1,17,0,NULL,'77mm  cpl   1\r58mm cpl   1\r80cm 5in1    1\r60cm 棚     1 RR843877018CN'),(4782,619585725001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',3,'AB1303',10.02,'hermeshine','chmwilki','chmwilki@gmail.com','Morgan Wilkins','1638 E Lindley Rd','Mooresville','IN','UNITED STATES','46158-6575','(317) 831-1832','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 23:18:43',0,NULL,3,1,1,1,NULL,'58mm 橡胶罩   3\r52mm 橡胶罩    2 '),(4783,659114472002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','zeltser1812','zeltser.iliya@gmail.com','Iliya Zeltser','shapira str.44 app.30<br>postcode.78210','ashkelon','','ISRAEL','78210','(972)054-5889278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 23:42:15',0,NULL,3,1,3,1,NULL,'RR843878645CN\r '),(4784,704983382016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','francislm520','franc520@hotmail.com','Francisco Silva','Travessa Artur Azevedo nº165 Touguinha','Vila do Conde','Porto','PORTUGAL','4480-514','963170764','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-15 00:06:57',0,NULL,3,1,2,1,NULL,'lenspen   2 '),(4785,619480934001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','astro3661','robtaylor3661@comcast.net','Robert Taylor','1645 Galbraith Ln','Kaysville','UT','UNITED STATES','84037-9796','(801) 599-3925','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-15 00:24:24',0,NULL,3,1,1,1,NULL,' '),(4786,619643691001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','paulocarmona1948','paulocarmona@yahoo.com.br','Paulo Carmona','Rua das Jacutingas, 350<br>Parque dos Pássaros','São Bernardo do Campo','São Paulo','BRAZIL','09861-310','55-(11)-43435259','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 00:27:54',0,NULL,3,1,3,1,NULL,'tripod $16 \rYW864489316CN\r'),(4787,619382442001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','spartanof84','matthew_alderdice@yahoo.com.au','Matthew Alderdice','46 Middle St Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0293981243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 01:01:52',0,NULL,8,1,17,0,NULL,NULL),(4788,658853449002,120601700210,' New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',30.9,'hermeshine','spartanof84','matthew_alderdice@yahoo.com.au','Matthew Alderdice','46 Middle St Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0293981243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 01:01:52',0,NULL,3,1,4,1,NULL,'桌面灯   1（38cm 灯架+ 桌面灯头）   \r大力夹球台   2 \rYW864489596CN'),(4790,619675357001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','la-dealer','jraulcastillo@sbcglobal.net','Raul Castillo','1049 E 32nd St','Los Angeles','CA','UNITED STATES','90011-2547','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-15 02:48:41',0,NULL,3,1,1,1,NULL,NULL),(4791,659165660002,120539340436,'New 77mm ring adapter replacement for cokin P series',2,'AA2214',7.1,'hermeshine','davemillr','davemiller@mindspring.com','Dave Miller','6048 Breton Pl','Newark','CA','UNITED STATES','94560','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-15 03:12:43',0,NULL,3,1,1,1,NULL,'77mm 接口环  2 '),(4792,619689368001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','pirineo.i','pirineo.i@gmail.com','Diego Arnedo','5333 Av Casgrain (suite 1001)','Montreal','QC','CANADA','H2T1X3','(514) 214-6454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 03:57:11',0,NULL,3,1,2,1,NULL,'新款内胆包   1 '),(4793,659189137002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.55,'hermeshine','bridgebolt','bridgebolt@yahoo.com','Jaime Rosaria','6121 Willoughby Cir','Lake worth','FL','UNITED STATES','33463-9309','(561) 968-5901','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-15 05:17:06',0,NULL,3,1,1,1,NULL,'72mm 渐变灰   1 '),(4795,619708234001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ijavigarcia','ijavi.garcia@gmail.com','javier garcia cabezudo','passeig urrutia 37 , esc 2 , 3o.2a.','barcelona','Cataluña','SPAIN','08042','935177027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 05:58:48',0,NULL,3,1,2,1,NULL,NULL),(4796,659203867002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','iceman132004','icemanbtnh@hotmail.com','callum taylor','20/9 Hull Dr','Campbellfield','Victoria','AUSTRALIA','3061','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 07:00:36',0,NULL,3,1,3,1,NULL,'sony 单肩包 a1    1 RR843878574CN\r'),(4797,719161102015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','paulb1884','imagebyb@bigpond.com','Paul Burdett','14 Peatling Lane','Twin Waters','Queensland','AUSTRALIA','4564','0419744984','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-15 07:25:06',0,NULL,3,1,2,1,NULL,'45w    2 '),(4798,659207867002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',22.9,'hermeshine','yinszu360','yinszu@hotmail.com','SIMON HUANG','1911 SE 189th Ct','VANCOUVER','WA','UNITED STATES','98683-9770','(360) 901-5660','NoPaymentFailure','CheckoutComplete','Other','2011-01-15 07:31:41',0,NULL,3,1,1,1,NULL,'摄影背心 夏  xl   1 '),(4799,619724677001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','alainice06','gromalain@yahoo.fr','gromy alain','hopital ste marguerite centre hyperbare<br>270 boulevard ste marguerite','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13009','0660892365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 08:00:39',0,NULL,3,1,2,1,NULL,'大号灰卡   1 \r'),(4800,659224002002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','molassy','wormold@hotmail.com','Richard Connors','Kwang-hae Leadville Apt. 102-dong, 1011-ho<br>Nam-gu, Juan 6-dong, 966-3','Incheon','Incheon','KOREA,REPUBLIC OF','402-848','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 09:06:41',0,NULL,3,1,11,1,NULL,'c型大力夹   1 '),(4801,719187040015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',15.5,'hutongstore','emulsion120','exposure.120@hotmail.co.uk','Colin Rogers','63 Yealmpstone Drive Plympton','Plymouth','Devon','UNITED KINGDOM','PL7 1HE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 09:22:59',0,NULL,3,1,2,1,NULL,'单灯头 英标   2 '),(4802,619741182001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','celter','to@kjellevand.no','Tor Ole Kjellevand','Inkognito terrasse 7B','Oslo','','NORWAY','0256','4722558085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 09:30:41',0,NULL,3,1,2,1,NULL,'40cm 棚  1 '),(4803,619778718001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','gigglemonster22','voodoolady70@hotmail.com','Sophie Muir','Unit 3/60 Northernhay Street<br>Reservoir','Melbourne','Victoria','AUSTRALIA','3073','030421961451','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'RR843878469CN\r '),(4804,719249776015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',8.99,'hutongstore','dultius','marcoduz@hotmail.com','Marco Duz','Weipers Centre For Equine Welfare 464 Bearsden Road','Glasgow','Glasgow (City of)','UNITED KINGDOM','G61 1QH','1413305999','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 12:36:29',0,NULL,3,1,2,1,NULL,'防雨罩   1 '),(4805,705169221016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','kegetyss','kegetys@gmail.com','Keijo Ruotsalainen','Piekanankuja 1 C 46','Kuopio','','FINLAND','70820','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-15 12:46:04',0,NULL,3,1,2,1,NULL,'77mm 渐变灰  1 '),(4806,619805391001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','mikelynn2011','mikelynn@nb.sympatico.ca','Michael Steeves','96 Pasadena Dr','Moncton','NB','CANADA','E1G 1H5','(506) 576-9098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 13:29:37',0,NULL,3,1,2,1,NULL,NULL),(4807,658621311002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','super-detka','supra-tatyana@narod.ru','Tatyana Razdobydina','5-2 Pogranichnika Gorkavogo Str. , Apt.8','Sankt-Peterburg','krasnoselskiy rayon','RUSSIAN FEDERATION','198206','+79312443440','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 13:35:26',0,NULL,8,1,17,0,NULL,NULL),(4808,619151542001,110462204958,'Continuous Lighting System：light stand/bulb holder/um',1,'AKT009',60,'hermeshine','super-detka','supra-tatyana@narod.ru','Tatyana Razdobydina','5-2 Pogranichnika Gorkavogo Str. , Apt.8','Sankt-Peterburg','krasnoselskiy rayon','RUSSIAN FEDERATION','198206','+79312443440','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-15 13:36:37',0,NULL,3,1,5,1,NULL,'2m 灯架   2\r双灯头 欧标   2\r反光伞   2\r115w 220v   4\r包    1 \rCP219487801CN\r'),(4809,619809109001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','paxcz007','pavel.repka@gmail.com','Pavel Repka','Podrouzkova 6047','Ostrava - Poruba','Czech Republic','CZECH REPUBLIC','70800','732829841','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 13:39:48',0,NULL,3,1,2,1,NULL,'67mm 环架  1 '),(4810,705196847016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','gunner-g','sirgbolalot@hotmail.co.uk','gbola gbadamosi','7 acworth house barnfield road','woolwhich','London','UNITED KINGDOM','se18 3tw','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 13:57:46',0,NULL,3,1,2,1,NULL,' '),(4811,705216992016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','zecrich67','zecrichardson@hotmail.co.uk','Zechariah Richardson','69, Queen Elizabeth Chase','Rochford','Essex','UNITED KINGDOM','SS4 1JJ','01702544947','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 14:49:58',0,NULL,8,1,17,0,NULL,NULL),(4812,705212870016,260660053692,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',7.8,'hutongstore','zecrich67','zecrichardson@hotmail.co.uk','Zechariah Richardson','69, Queen Elizabeth Chase','Rochford','Essex','UNITED KINGDOM','SS4 1JJ','01702544947','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 14:49:59',0,NULL,8,1,17,0,NULL,NULL),(4813,705213738016,260660054359,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',2.8,'hutongstore','zecrich67','zecrichardson@hotmail.co.uk','Zechariah Richardson','69, Queen Elizabeth Chase','Rochford','Essex','UNITED KINGDOM','SS4 1JJ','01702544947','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 14:49:59',0,NULL,3,1,3,1,NULL,'430肥皂盒  1\rstar8 星光镜  1\rlenspen   1 RR843878530CN\r'),(4814,619840595001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',3,'AE2501',91,'hermeshine','cuba_treasures','gilbertosuarezluis@yahoo.com','Gilberto Suarez','440 W 35th Pl','hialeah','FL','UNITED STATES','33012-5133','(786) 342-5688','NoPaymentFailure','CheckoutComplete','Other','2011-01-15 15:08:41',0,NULL,3,1,4,1,NULL,'反光板支架   3 \rreflector holder   $21\rYW864489401CN\r'),(4815,619621433001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','cosdab','cosdab@hotmail.it','Cosimo Dabanello','De Curtis ,7','Marcianise','CE','ITALY','81025','3392163763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 15:22:15',0,NULL,3,1,2,1,NULL,NULL),(4816,659339619002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','tomernn','tnakar@gmail.com','Tomer Nakar','Geva st. 12','Givatayim','IL','ISRAEL','53316','052-3655882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 15:37:36',0,NULL,3,1,2,1,NULL,'58mm 渐变灰  1 '),(4817,705245394016,260660052183,'New 62mm Ring adapter for Cokin P Series Filter Holder',1,'AA2211',2.39,'hutongstore','taintin0','taintin@btinternet.com','Terry Flood','124,Crompton Ave,, Sprotbrough.','Doncaster','South Yorkshire','UNITED KINGDOM','dn5 8eg','01302784202','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 15:48:42',0,NULL,3,1,2,1,NULL,'62mm 接口环  1 '),(4818,619871409001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','evri4mann','evri4man@gmail.com','Mikhlyayev Yevgeniy','Respubliki 39/4-82','Temirtau','Karagandinskaya obl','KAZAKHSTAN','101400','87053002969','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 16:23:01',0,NULL,3,1,3,1,NULL,'肩架  1 RR843878279CN\r'),(4819,705264405016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','snnpa6','nikolaos@cosmosproductions.com','Nikolaos Papadopoulos','Akrotiri Terian','Mytilini','Lesvos','GREECE','81100','302251047907','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-15 16:25:12',0,NULL,3,1,5,1,NULL,'2mx3m 背景架   1\r3mx6m 绿色背景布  1\r2m 灯架  2\r50-70 棚  欧标  2\r115w 220v   2\r包   1\rCP219487815CN\r\r '),(4820,705275038016,260646700576,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',54.5,'hutongstore','tonomag','antofan@free.fr','Antoine Chez Hughes Delforges','29 Avenue Victor Hugo','Pierrefitte sur Seine','Ile-de-France','FRANCE','93380','0676931989','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-15 16:50:58',0,NULL,3,1,4,1,NULL,'YW864489390CN\r '),(4821,619885316001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',107.96,'hermeshine','criss_t','ibecriss@comcast.net','Christina Payton','418 Buren Pl','INDIANAPOLIS','IN','UNITED STATES','46219','(317) 869-0188','NoPaymentFailure','CheckoutComplete','Other','2011-01-15 16:52:47',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r斜臂  2 \rYW864489386CN\r'),(4822,659392694002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','fmes3058','beaumistral@gmail.com','fernand Messiaen','rue Rousseau 26','Jemeppe sur meuse','','BELGIUM','4101','0494057099','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 17:32:46',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843878177CN\r'),(4823,619904102001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',75,'hermeshine','felixtotuga','corazonrie@yahoo.com','veronica noboa','4/79<br>gould st','campsie','New South Wales','AUSTRALIA','2194','0280653212','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2011-01-15 17:33:45',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r反光板支架   1 \rreflector holder   $22\rYW864489375CN\r'),(4824,659393436002,120564178467,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','migueldeveza2010','migueldeveza@gmail.com','João Miguel Deveza da Silva','Rua Quinta da Nora N 2 - 4 A','Carnaxide','Carnaxide','PORTUGAL','2790 -140','351961509555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 17:34:13',0,NULL,8,1,17,0,NULL,NULL),(4825,705278792016,260660052995,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',8.99,'hutongstore','bombeira2007','rosabva@hotmail.com','Rosa maria santos Guerra','quinta da palmeira rua da oliveira lote 14 fração c 1º dto','albufeira','algarve','PORTUGAL','8200','(00351)914451496','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-15 17:35:57',0,NULL,3,1,2,1,NULL,'90th 肩带  1 '),(4826,619911019001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','mebuy2007','kurt.hestvik@online.no','Kurt Eivind Hestvik','Hasseløyveien 39','Stavanger','RL','NORWAY','4029','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 17:44:19',0,NULL,3,1,3,1,NULL,'2m 灯架  1 白盒 RR843878248CN\r'),(4827,619912356001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','migueldeveza2010','migueldeveza@gmail.com','João Miguel Deveza da Silva','Rua Quinta da Nora N 2 - 4 A','Carnaxide','Carnaxide','PORTUGAL','2790 -140','351961509555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 17:47:14',0,NULL,8,1,17,0,NULL,NULL),(4828,619912684001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','y_s_k','s.jusupov@gmail.com','Sergey Yusupov','190, 31/1, Krylatskaya ulitsa','Moscow','','RUSSIAN FEDERATION','121614','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 17:48:09',0,NULL,3,1,2,1,NULL,'40cm 棚   1 '),(4829,619916913001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','migueldeveza2010','migueldeveza@gmail.com','João Miguel Deveza da Silva','Rua Quinta da Nora N 2 - 4 A','Carnaxide','Carnaxide','PORTUGAL','2790 -140','351961509555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 17:56:31',0,NULL,8,1,17,0,NULL,NULL),(4830,659406138002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','kiamao09','retro1lah@gmail.com','samuel phun','Blk 113, Potong Pasir Ave 1, #13-840','default','','SINGAPORE','350113','96693021','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 18:00:05',0,NULL,8,1,17,0,NULL,''),(4831,659409039002,120664105116,'Promotion EW-78D Lens Hood for Canon 18-200mm flocking',1,'AA3405',9.99,'hermeshine','migueldeveza2010','migueldeveza@gmail.com','João Miguel Deveza da Silva','Rua Quinta da Nora N 2 - 4 A','Carnaxide','Carnaxide','PORTUGAL','2790 -140','351961509555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 18:04:47',0,NULL,8,1,17,0,NULL,NULL),(4832,619924138001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',4,'hermeshine','migueldeveza2010','migueldeveza@gmail.com','João Miguel Deveza da Silva','Rua Quinta da Nora N 2 - 4 A','Carnaxide','Carnaxide','PORTUGAL','2790 -140','351961509555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 18:10:14',0,NULL,3,1,3,1,NULL,'50d眼罩   1\rew-78d 有植绒的   1\ret-65b   1\r58mm 橡胶罩   1\r72mm 橡胶罩    1 RR843878659CN\r'),(4833,719418542015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','adbidonline','andylong1969@googlemail.com','Andrew Long','6 Sancroft Way','Fressingfield','Eye, Suffolk','UNITED KINGDOM','IP21 5QN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 18:13:36',0,NULL,3,1,2,1,NULL,'45w   2 '),(4834,659415454002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','ingeneermk','kolodin69@mail.ru','Mikhail Kolodin','35 Kotrekhova st.<br>appartment 1','Plesetsk','Arkhangel\'skaya oblast','RUSSIAN FEDERATION','164262','818-327-2119','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 18:20:26',0,NULL,3,1,5,1,NULL,'背景架  （ 白）  2m  1 \rCP219487829CN\r'),(4835,619931385001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','kiamao09','retro1lah@gmail.com','samuel phun','Blk 113, Potong Pasir Ave 1, #13-840','default','','SINGAPORE','350113','96693021','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 18:24:48',0,NULL,3,1,3,1,NULL,'绿色摄影背心  canon xxxl   1 \rcanon 摄影背心 xxxl  1\r老款   RR843878415CN\r'),(4837,659450823002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','r1cc4rd0','r.ongaro@libero.it','riccardo ongaro','via quintino alto 38','bergamo','BG','ITALY','24123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 19:27:00',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843878251CN\r'),(4839,619045159001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','nkingh','king_onell@hotmail.com','ng king hung','rua odilon santos nº19 - rio vermelho','salvador','bahia','BRAZIL','41940-350','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 19:49:17',0,NULL,3,1,3,1,NULL,'肩架   1 RR843878217CN\r'),(4840,619997900001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','foltynet','foltynet@gmail.com','Tomer Foltyn','58 Shderot Benyamin','Netanya','','ISRAEL','42314','972-50-5810058','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 20:40:00',0,NULL,3,1,3,1,NULL,'反光板支架   1 RR843878398CN\r'),(4841,620000952001,110499652243,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','don340photography','rawsthorne@shaw.ca','Don Rawsthorne','340 Hartford Ave','Winnipeg','MB','CANADA','R2V0W5','(204) 339-2914','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 20:50:40',0,NULL,8,1,17,0,NULL,NULL),(4842,659489484002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',19.9,'hermeshine','don340photography','rawsthorne@shaw.ca','Don Rawsthorne','340 Hartford Ave','Winnipeg','MB','CANADA','R2V0W5','(204) 339-2914','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 20:50:41',0,NULL,3,1,3,1,NULL,'b座  2\r柔光伞   2 RR843878631CN\r'),(4843,659506098002,120601698567,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','ritchieritchie19','lritchie10@cogeco.ca','MARK RITCHIE','7515 VIVIAN COURT','NIAGARA FALLS','ON','CANADA','L2H 2J6','(905) 357-7224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 21:20:39',0,NULL,3,1,3,1,NULL,'wf1007   1 RR843878486CN\r'),(4844,620025877001,110534333419,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','satyronline','snowter@gmail.com','Carlos alvarez garcia','ibaizabal 14 3ºD','galdakao','País Vasco','SPAIN','48960','657845077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 21:47:25',0,NULL,3,1,2,1,NULL,'柔光伞  1 '),(4845,620026519001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64.99,'hermeshine','giulix99','sy99@hotmail.it','VIALARDI ANDREA','VIA DELLE GINESTRE 16/16','GENOVA','GE','ITALY','16137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 21:50:59',0,NULL,8,1,17,0,NULL,NULL),(4846,659516795002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','giulix99','sy99@hotmail.it','VIALARDI ANDREA','VIA DELLE GINESTRE 16/16','GENOVA','GE','ITALY','16137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 21:50:59',0,NULL,8,1,17,0,NULL,NULL),(4847,620025964001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64.99,'hermeshine','giulix99','sy99@hotmail.it','VIALARDI ANDREA','VIA DELLE GINESTRE 16/16','GENOVA','GE','ITALY','16137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 21:51:00',0,NULL,3,1,4,1,NULL,'红头灯   2\r800w 220v   2\r50-70 柔光棚 塑料卡口  1\rYW864489364CN\r\r '),(4848,659525395002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','2murales','gruber1974@mixmail.com','Guillermo Gruber Herrero','Plaza de Olavide, nº5, 5º C I','Madrid','Madrid','SPAIN','28010','660603402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 22:08:19',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(4849,620046443001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','radiodjontheair','radiodjontheair@aol.com','Evan Nine','4620 SW Keats St','Port Saint Lucie','FL','UNITED STATES','34953','(561) 719-4805','NoPaymentFailure','CheckoutComplete','Other','2011-01-15 22:41:02',0,NULL,3,1,3,1,NULL,'肩架  1 RR843878305CN\r'),(4850,719587963015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','boerkejos','bjorn.pira@skynet.be','Pira Björn','Nieuwstraat 33 3071 Erps-Kwerps','Erps-Kwerps','','BELGIUM','3071','0496743055','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-15 23:26:23',0,NULL,3,1,4,1,NULL,'背景架 （ 白 黑）   1 2m    \rbackground support  $20\rYW864489353CN\r'),(4851,659555983002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','kalimna-kreations','leoniedragon@wideband.net.au','Leonie James','4 Oak Crt','Morwell','Victoria','AUSTRALIA','3840','0351336606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 23:38:50',0,NULL,3,1,2,1,NULL,NULL),(4852,620063717001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','1_d_x_ahi','jonpalomar@hotmail.com','Jon Palomar','Perez Galdos   Nº11    2ºA','Valladolid','Castilla y León','SPAIN','47005','676467581','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 23:39:25',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1 '),(4853,620081153001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','318snoopy','chrisconlin@bellsouth.net','Loretta  Conlin','4864 Tropicana Ave','Cooper City','FL','UNITED STATES','33330-4428','(954) 434-5496','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 00:37:52',0,NULL,3,1,1,1,NULL,'小号内胆包 nikon  1 '),(4854,659573718002,120570270887,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',26.99,'hermeshine','cajx7589','kh_cheung7589@hotmail.com','Kom Hung Cheung','Crooswijksestraat 164','ROTTERDAM','','NETHERLANDS','3034AR','+31648034801','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 00:40:16',0,NULL,3,1,2,1,NULL,'ttl线  canon  1m   1 '),(4855,719617598015,250620017234,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',2.39,'hutongstore','cipher-666','lewis_milnes@yahoo.co.uk','Lewis Milnes','63 Sefton Street','Southport','Merseyside','UNITED KINGDOM','pr8 6sh','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 00:50:51',0,NULL,3,1,2,1,NULL,'49mm 接口环  1 '),(4857,620099342001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','donventa','dontienda@gmail.com','Israel Ramirez Rios','C/ Buen Pastor Nº 276','San Fernando ( Cádiz )','Andalucía Ceuta y Melilla','SPAIN','11100','669959191','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 01:59:35',0,NULL,3,1,4,1,NULL,'tripod  $22\r 打单子的时候注意，这个是电话+34644420242\rYW864489342CN\r'),(4858,620104104001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','9rosee','paypal@kitp.ru','Nikita Pavlov','HaYabok 22','Jerusalem','','ISRAEL','94515','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 02:11:54',0,NULL,3,1,3,1,NULL,'肩架  1\rRR843878296CN\r\r'),(4859,620108789001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','kayakernorth','rickmattatall@gmail.com','Richard Mattatall','2315 Whirlpool St<br>Ste 704','Niagara Falls','NY','UNITED STATES','14305-2413','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 02:31:57',0,NULL,3,1,1,1,NULL,NULL),(4860,620117944001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','remy288','remy333@verizon.net','Bill Remington','12 Robin Vale Dr','North Scituate','RI','UNITED STATES','02857-3011','(401) 228-5990','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 03:12:39',0,NULL,3,1,1,1,NULL,'麂皮  1 '),(4861,620119949001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','pablorwc','pablo206@live.com.ar','Pablo Andres Barraza','Diaz Velez 2263','Benavidez','Buenos Aires','ARGENTINA','1621','47361631','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 03:56:51',0,NULL,3,1,3,1,NULL,'nikon 摄影背心 M 老款  1 RR843878375CN\r'),(4862,620130900001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','megadeth199','segumarc@hotmail.com','Marc Seguin','29 Beaupre','Mercier','QC','CANADA','J6R 2J2','(514) 531-3969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 04:21:40',0,NULL,3,1,2,1,NULL,NULL),(4863,620132199001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','slee2669','lee.seungmin@hotmail.com','Leo Lee','427 Vaughan Road','Toronto','ON','CANADA','M6C2P1','(647) 244-2353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 04:22:46',0,NULL,3,1,2,1,NULL,'52mm 渐变灰  1 '),(4864,620149819001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','fma','sloskier@cox.net','Frank M Andrews','220 S 2nd Ave','HAILEY','ID','UNITED STATES','83333-8431','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 06:16:45',0,NULL,3,1,1,1,NULL,'机身盖/镜头后盖 nikon  1 '),(4865,620167968001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:21:21',0,NULL,8,1,17,0,NULL,NULL),(4866,659664006002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:21:21',0,NULL,8,1,17,0,NULL,NULL),(4867,659664332002,120462263667,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:21:22',0,NULL,8,1,17,0,NULL,NULL),(4868,659664522002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:21:22',0,NULL,8,1,17,0,NULL,NULL),(4869,659664208002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:21:23',0,NULL,8,1,17,0,NULL,NULL),(4870,659665887002,120618815334,'TianYa 52mm ND8 filter New 52 Neutral Density Grey NIB',1,'AA2308',5.7,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:23:12',0,NULL,3,1,3,1,NULL,'天涯 52mm nd8   1\r广角托架  1\r渐变灰  1\r渐变棕  1\r渐变橙   1\r67mm 接口环  1\rRR843876065CN\r\r '),(4871,620182757001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','pmson3','peter.mattsson.mm@telia.com','peter mattsson','björnbärsgatan 3','götene','','SWEDEN','53334','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 09:20:24',0,NULL,3,1,2,1,NULL,NULL),(4872,659687661002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','lelabiff','mrobelin@gmail.com','Morgan Robelin','56 avenue dubrocq','bayonne','Aquitaine','FRANCE','64100','0622221783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 09:49:35',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r反光板支架   1\rreflector holder  $22\rYW864489331CN\r '),(4873,620197808001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','alazaki','the_titan_m@hotmail.com','Marianne Andersen','Thomas Aasgaards gate 25','Kristiansund','Møre og Romsdal','NORWAY','6507','93874049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 10:09:45',0,NULL,3,1,3,1,NULL,'110cm 5in1 反光板  1 RR843878455CN\r'),(4874,659708758002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','collectorrpm','ejordan1949@comcast.net','Earl Jordan','5 Gamache Rd','Derry','NH','UNITED STATES','03038','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 10:46:39',0,NULL,3,1,1,1,NULL,NULL),(4875,719782818015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','jc7xx7','john.carrette@tesco.net','John Carrette','157 High Street','Wetherby','West Yorkshire','UNITED KINGDOM','LS236BH','01937123456','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 11:10:23',0,NULL,3,1,2,1,NULL,NULL),(4876,719810355015,250599384655,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3307',2.9,'hutongstore','jonash0_0','j.ashthorpe@btconnect.com','Jon Ashthorpe','98 Bishops Road','Southampton','Hampshire','UNITED KINGDOM','SO192FE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 12:00:24',0,NULL,3,1,2,1,NULL,NULL),(4877,620269482001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','cocodrieboy','pearson26od@aol.com','John Dixon','4724 Newcomb DR','Baton Rouge','LA','UNITED STATES','70808','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 13:13:18',0,NULL,3,1,1,1,NULL,'60cm 棚  1 '),(4878,620269630001,110534332901,'New Flash Hot Shoe Adapter YN-H3 for Alpha and Minolta',1,'AB3318',7.9,'hermeshine','bikbaeva','alcywork@yandex.ru','Alcy Bikbaeva','Admiral Makarova st., 16/87','Ufa','RF','RUSSIAN FEDERATION','450081','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 13:14:02',0,NULL,5,1,2,1,NULL,'sony 热靴转换  1 '),(4879,620273490001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','cla33fr','cla33@free.fr','Christian LAGARDERE','10, rue de la croix du sable','BRUGES','Aquitaine','FRANCE','33520','06 85 71 67 70','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 13:22:24',0,NULL,8,1,17,0,NULL,''),(4880,659782274002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','jakkefromfinland','jakke1979@hotmail.com','Jari Sietiö','välimaankatu 7 A 22','Tampere','Finland','FINLAND','33500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 13:47:24',0,NULL,3,1,2,1,NULL,'3pcs 滤镜袋  1 '),(4881,705786962016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'AA1310',7.56,'hutongstore','alan_grech','linu@maltanet.net','Alan Grech','International Hotel Investments plc Europa Centre','Floriana','','MALTA','FRN1400','+35679211671','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-16 14:35:08',0,NULL,3,1,2,1,NULL,'lenspen  2 '),(4882,659807298002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','aircruiser1','justin.le@iinet.net.au','Justin Le','UNIT 1, 38 TENNANT ST<br>WELSHPOOL','PERTH','Western Australia','AUSTRALIA','6106','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 14:39:34',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843878163CN\r'),(4883,719899970015,250692242647,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.68,'hutongstore','taffytank','pete.brabham@ntlworld.com','Peter Brabham','12 Meliden Road','Penarth','The Vale of Glamorgan','UNITED KINGDOM','CF64 3UH','02920712322','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 14:44:59',0,NULL,3,1,2,1,NULL,NULL),(4884,719813723015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',125,'hutongstore','maskare','teemu.p.saarinen@gmail.com','Teemu Saarinen','Lahdensivuntie 31 A 11','Hämeenlinna','Oletus','FINLAND','13100','+358415076144','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-16 14:58:29',0,NULL,3,1,4,1,NULL,'717 135高   1 \rYW864489320CN\r'),(4885,659817120002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',19.9,'hermeshine','1436winnie','winniepooh@altrionet.com','JOSEPH POON','1007 Rancho Rd','ARCADIA','CA','UNITED STATES','91006-2225','(626) 445-7505','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 14:59:34',0,NULL,3,1,1,1,NULL,'b座  2 '),(4886,620319896001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','cla33fr','cla33@free.fr','Christian LAGARDERE','10, rue de la croix du sable','BRUGES','Aquitaine','FRANCE','33520','06 85 71 67 70','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 15:01:54',0,NULL,3,1,3,1,NULL,'大力夹球台  2 \r80cm 5in1   1 RR843878954CN\r'),(4887,620329166001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','vlad-limer','vlad.limer@gmail.com','Vlad Limer','zalman shezar<br>3430','kiryat yam','','ISRAEL','29082','+972547588251','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 15:20:06',0,NULL,3,1,3,1,NULL,'40cm 棚  1 RR843878557CN\r'),(4888,705824711016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','lozlozloz21','mouses99@live.com','Lauren Saunders','8 Heron Drive Stansted Abbotts','Ware','Hertfordshire','UNITED KINGDOM','SG12 8TU','01920872688','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 15:36:29',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1 '),(4889,620339923001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','borisjs','sakic@mcmaster.ca','Boris Sakic','150 Charlton St. East<br>apt. 3208','Hamilton','ON','CANADA','L8N 3X3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 15:39:37',0,NULL,3,1,3,1,NULL,'nikon 摄影背心  xl  老款  1 RR843878367CN\r'),(4890,719960171015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3306',2.6,'hutongstore','8159christine','hellocw@btinternet.com','christine wheeler','mayland, low road','strumpshaw','Norfolk','UNITED KINGDOM','NR134HU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 16:12:51',0,NULL,3,1,2,1,NULL,NULL),(4891,659870384002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','luchertolac','lucianacaporaletti@gmail.com','Luciana Caporaletti','Calle Las Hortensias, 2<br>Nueva Andalucía','Marbella','Andalucía Ceuta y Melilla','SPAIN','29660','952811354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 16:30:22',0,NULL,3,1,2,1,NULL,NULL),(4892,620389981001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','undead.demidov','nikolay.demidov@gmail.com','Николай Демидов','Pyatnitskoe shosse, 9, 92','Moskva','','RUSSIAN FEDERATION','125464','926-617-9921','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 16:59:49',0,NULL,8,1,17,0,NULL,NULL),(4893,659841939002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','undead.demidov','nikolay.demidov@gmail.com','Николай Демидов','Pyatnitskoe shosse, 9, 92','Moskva','','RUSSIAN FEDERATION','125464','926-617-9921','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 16:59:50',0,NULL,3,1,2,1,NULL,'82mm 接口环  1\r广角托架   1 '),(4894,705902417016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','ballyroan16','kolettewithak@gmail.com','Kolette Enright','9 Garranbane Green Ballinroad','Dungarvan','Waterford','IRELAND','default','3536402370','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-16 17:12:32',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(4895,720095363015,250620017234,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',2.39,'hutongstore','cainnech','kness@btinternet.com','Kenneth Ness','3 Kingsfield Road Wirksworth','Matlock','Derbyshire','UNITED KINGDOM','DE4 4BP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 18:31:45',0,NULL,3,1,2,1,NULL,'49mm 接口环  1 '),(4896,620379874001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','csurdak','jerk1n@yahoo.com','Chris Surdak','164 Five Points Rd','Rush','NY','UNITED STATES','14543','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 19:00:01',0,NULL,3,1,1,1,NULL,NULL),(4897,620510497001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','triumphron','triumphron@sbcglobal.net','Ron  Maurer','3502 Knollwood Dr','Carlsbad','CA','UNITED STATES','92010-5505','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 19:12:16',0,NULL,3,1,1,1,NULL,'小号内胆包 无字  1 '),(4898,620523995001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','philipped9138','phil-delo@orange.fr','philippe deloffre','37 rue eugène pottier','bobigny','Île-de-France','FRANCE','93000','06.80.85.38.17.','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 19:27:01',0,NULL,3,1,3,1,NULL,'井字扳手  1 RR843878438CN\r'),(4899,706069452016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','jean_vallettacity','jeanmic1982@hotmail.com','JEAN PAUL MICALLEF','80/5 MERCHANTS STR','VALLETTA','ME','MALTA','VLT03','21238757','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-16 19:44:04',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(4901,706075065016,260660050897,'Green.L 52mm Neutral Density ND4 Filter ND 4 New',1,'AE2301',3.85,'hutongstore','ivanko65','bergl@chello.sk','Ivan Bergl','Podzáhradná 49','Bratislava','','SLOVAK REPUBLIC','82106','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-16 19:48:57',0,NULL,3,1,2,1,NULL,NULL),(4902,620543913001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','tolga5484','tolga00@gmail.com','Tolga Tosun','Fethiye Mahellesi FSM Bulvarı<br>Eryıl Ap. kat:2 no:141-3','Bursa','Nilüfer','TURKEY','16140','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 19:49:45',0,NULL,3,1,3,1,NULL,'2m 灯架 红盒  1 RR843878234CN\r'),(4903,720194546015,250599383719,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3305',2.5,'hutongstore','dlee654','dlee654724@aol.com','David Lee','17 Bewick Crescent','Newton Aycliffe','Durham','UNITED KINGDOM','DL5 5LQ','01325312866','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 19:54:12',0,NULL,3,1,2,1,NULL,NULL),(4904,706097041016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',14.5,'hutongstore','s1diddy','sister.suzie@tiscali.co.uk','Suzanne Barber','Isfryn Pencader','Carmarthenshire','Carmarthenshire','UNITED KINGDOM','SA39 9HE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 20:09:24',0,NULL,3,1,3,1,NULL,'摄影背心 夏  xl   1 RR843878441CN\r'),(4905,660112599002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','estopiko','estopiko@hotmail.com','roger uceda molera','pau casals nº 28','sant climent de llobregat','Cataluña','SPAIN','08849','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 21:13:12',0,NULL,3,1,4,1,NULL,'tripod $16 \rYW864489316CN\r'),(4906,620613866001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',9.9,'hermeshine','vivholland','vivandlee@aol.com','VIVIAN HOLLAND','7930 NW 7th St<br>Apt 101','PEMBROKE PINES','FL','UNITED STATES','33024','(954) 966-4408','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 21:34:27',0,NULL,3,1,1,1,NULL,'nikon肩带  黄字  1 '),(4907,620628972001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','shacoshe','shay.te@gmail.com','Shay Tessler','jorden<br>mailbox:542','ein vered','sharon area','ISRAEL','40696','972-502134955','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 22:06:48',0,NULL,3,1,3,1,NULL,'反光板支架  1 RR843878340CN\r'),(4908,719748696015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','bimbolaoduns','adethomasleo@gmail.com','Ade Thomas','7N Goldworthy Gardens 7N Goldworthy Gardens','LONDON','London','UNITED KINGDOM','SE16 2TB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 22:58:44',0,NULL,3,1,3,1,NULL,'斜臂   1 RR843878384CN\r'),(4909,620659076001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','barao1961','amgp@netvisao.pt','Antonio Manuel Gomes Paulino Paulino','R. Alves Redol Nº 72 1º Esq.','Cova da Piedade - Almada','Setúbal','PORTUGAL','2805-071','936494274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 23:06:07',0,NULL,8,1,17,0,NULL,''),(4910,660171018002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','barao1961','amgp@netvisao.pt','Antonio Manuel Gomes Paulino Paulino','R. Alves Redol Nº 72 1º Esq.','Cova da Piedade - Almada','Setúbal','PORTUGAL','2805-071','936494274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 23:11:22',0,NULL,8,1,17,0,NULL,NULL),(4913,719645947015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',4,'AO0005',31.96,'hutongstore','p_ronto','p_ronto@hotmail.com','Panos Rontogiannis','5 Tzoumerkon street Papagos','Athens','Attiki','GREECE','15669','++302106544955','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-16 23:21:41',0,NULL,3,1,3,1,NULL,'1.6x2.1  背景布  4\r黑 灰  绿  蓝   RR843878897CN'),(4914,660173174002,120601698256,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','barao1961','amgp@netvisao.pt','Antonio Manuel Gomes Paulino Paulino','R. Alves Redol Nº 72 1º Esq.','Cova da Piedade - Almada','Setúbal','PORTUGAL','2805-071','936494274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 23:16:36',0,NULL,3,1,3,1,NULL,' 渐变橙  1 \r58mm 环架  1\r渐变棕  1\r渐变灰   1RR843878543CN\r'),(4915,620681213001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','suafcu1','wvt1@sbcglobal.net','walter tun','202 S Cedar Ave','wood dale','IL','UNITED STATES','60191-2210','','NoPaymentFailure','CheckoutComplete','Other','2011-01-17 00:12:57',0,NULL,3,1,1,1,NULL,'井字扳手   1 '),(4916,660195351002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','zahn0010','asebok@sympatico.ca','Anthony Sebok','195 Wynford Drive<br>Apt. #2701','Toronto','ON','CANADA','M3C 3P3','(416) 425-6615','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 00:22:11',0,NULL,3,1,2,1,NULL,'58mm 渐变灰  1 '),(4917,706263480016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','jpdois','saraiva.mr@gmail.com','Mario Rui Saraiva','Rua Cap Jose Vieira Branco, N 3 - 1 Esq','Faro','Algarve','PORTUGAL','8000-239','289803454','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 01:02:36',0,NULL,3,1,2,1,NULL,'lenspen   2 '),(4918,660205229002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','22pke','cesar_senda_r1@hotmail.com','Cesar Moreno','Calle Azorin 35, 4ºA,','Mostoles','Madrid','SPAIN','28935','916131126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 01:06:50',0,NULL,3,1,2,1,NULL,NULL),(4919,620711881001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','tataferchis','ivetestradas@hotmail.com','Ivet Estrada','Morelos Sur 1019 Colonia Constituyentes','Tehuacán','Puebla','MEXICO','75710','1246677','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 01:54:45',0,NULL,3,1,3,1,NULL,'肩架   1 RR843878353CN\r'),(4920,620713618001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','wrestle4garden','eirefresh@yahoo.com','Michele W Brennan','2539 Mayer Lane E','Maplewood','MN','UNITED STATES','55119','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 01:58:24',0,NULL,3,1,1,1,NULL,NULL),(4921,620713435001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','truettanderin','truettanderin@hotmail.com','Truett Standefer','2325 Nashville Pike<br>Apt 928','Gallatin','TN','UNITED STATES','37066-6027','(432) 288-0120','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-17 02:03:39',0,NULL,3,1,1,1,NULL,'301p 一拖三   1 '),(4922,620715609001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','valbraga-2008','valdineia.braga@gmail.com','Roberto Kazuo Otsuki','Rua Walter Fontana, 32<br>Vila Paulista','São Paulo','SP - São Paulo','BRAZIL','04634-045','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 02:05:09',0,NULL,3,1,5,1,NULL,'2mx3m 背景架   1\r申报 $35 \rCP219487832CN\r'),(4923,660229737002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','pddean2011','plddean@gmail.com','P Dean','PO Box 1643','Kernville','CA','UNITED STATES','93238-1643','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-17 02:06:28',0,NULL,3,1,1,1,NULL,' '),(4925,660239678002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','daggetth','daggetth@hotmail.com','Thomas R. Daggett III','57 Fields End Dr','Glenmont','ny','UNITED STATES','12077-2960','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 02:35:16',0,NULL,3,1,1,1,NULL,NULL),(4926,660236607002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','joeg2774','jgalica@nexicom.net','Joe Galica','25 Ottawa Street','Havelock','ON','CANADA','K0L1Z0','(705) 778-7008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 02:35:28',0,NULL,3,1,2,1,NULL,'3pcs 滤镜袋  1 '),(4927,720439062015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','jupiter1uk','indiansinmoscow@googlemail.com','Pete Riches','80c Sinclair Road West Kensington','London','London','UNITED KINGDOM','W14 0NJ','02073716702','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 03:31:00',0,NULL,3,1,2,1,NULL,'58mm 渐变灰  1 '),(4928,620744111001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tool62johans','dennisjohansen@comcast.net','Dennis Johansen','1022 Oakridge Ln','Bountiful','UT','UNITED STATES','84010-2029','(801) 755-8360','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 03:40:19',0,NULL,3,1,1,1,NULL,NULL),(4929,620746861001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','probenurass2b4v','probenurass@hotmail.com','Zack Lowe','2264 byrd mill road','louisa','VA','UNITED STATES','23093','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 03:51:59',0,NULL,3,1,1,1,NULL,NULL),(4930,660267146002,120581161644,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','robl03','beamholder@shaw.ca','Robert Leedham','211 Sunmeadows Cres SE','Calgary','AB','CANADA','T2X3G9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 04:07:11',0,NULL,3,1,3,1,NULL,'爵影碗罩  P1   1 RR843877070CN\r'),(4931,660266676002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','lars583164','larsfalcongreen@hotmail.com','Lars Falcongreen','35 / 40 Boundary Street<br>South Brisbane','Brisbane','Queensland','AUSTRALIA','4101','0412368991','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 04:15:44',0,NULL,3,1,2,1,NULL,'麂皮  1 '),(4932,660272558002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','rma2005','roldan@live.ca','Roldan Castillo','765 Limeridge Rd. East','Hamilton','ON','CANADA','L8W 1A4','(905) 515-8540','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 04:38:40',0,NULL,3,1,3,1,NULL,'肩架   1 RR843878910CN\r'),(4933,620783818001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','mestre_jogador','angello_49@hotmail.fr','Kévin Moisan','21 rue Frédéric Chopin','Saint Sebastien Sur Loire','Pays de la Loire','FRANCE','44230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 07:32:34',0,NULL,3,1,2,1,NULL,NULL),(4934,620784644001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','alexey_gureev','alexey.gureev@gmail.com','Alexey Gureev','30-17<br>Kirova','Murom','Vladimirskaya Oblast','RUSSIAN FEDERATION','602253','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 07:39:15',0,NULL,3,1,3,1,NULL,'肩架   1 RR843878937CN'),(4935,620784009001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',52.99,'hermeshine','billybnugroho','billybnugroho@gmail.com','Billy Nugroho','353 Burwood Highway','Blackburn','Victoria','AUSTRALIA','3131','0388334167','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-17 07:39:37',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r云台   1\r柔光伞   1 RR843878945CN\r'),(4936,620786396001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','dimana-fnet','yeeeti@gmail.com','Dmitry Kharchenkov','Kropotkina, 9b - 14','Voronezh','','RUSSIAN FEDERATION','394030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 07:51:49',0,NULL,3,1,2,1,NULL,'40cm 棚   1 '),(4938,660305626002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','hornyakbalazs','2rok.mail@gmail.com','Hornyák Balázs','Megyeri út 2/a','Kisújszállás','','HUNGARY','5310','+36304536161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 07:54:56',0,NULL,3,1,2,1,NULL,NULL),(4939,720499083015,250599383719,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3305',2.5,'hutongstore','kairimantas','mantaskairys@gmail.com','Mantas Kairys','Vandentiekio 32-16','Vilnius','Lithuania','LITHUANIA','03151','+37062577639','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 08:09:03',0,NULL,3,1,2,1,NULL,NULL),(4940,660308189002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','apacerllo','llodad@yahoo.com','Lawrence Lo, Apacer','386 fairview way<br>suite 102','Milpitas','CA','UNITED STATES','95035','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-17 08:11:56',0,NULL,3,1,1,1,NULL,'c型大力夹  1 '),(4941,720499284015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','sedrik35','pokus4@pobox.sk','Martin Svoboda','Holicska 28','Bratislava 5','Bratislava','SLOVAK REPUBLIC','85105','00421254435052','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 08:13:01',0,NULL,3,1,3,1,NULL,' RR843878883CN'),(4942,660309580002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ppvvld791','ppvvld@mail.ru','Vladimir Popov','ul. Lelushenko 1A kv 28','Rostov-on-Don','','RUSSIAN FEDERATION','344045','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 08:20:49',0,NULL,3,1,2,1,NULL,NULL),(4943,620792084001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','lucialetizia82','lucialetizia.litrico@virgilio.it','lucia letizia litrico','via salvatore Santangelo n°1','san giovanni galermo','CT','ITALY','95123','3489580807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 08:25:22',0,NULL,3,1,2,1,NULL,'大力夹 球台   1 '),(4944,620683597001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',60.67,'hermeshine','zuikoshark','steal86@mail.ru','Aleksey Stepanov','Veresaeva street, 10-34','Moscow','Moscow','RUSSIAN FEDERATION','121357','(903) 281-6220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 08:33:01',0,NULL,3,1,3,1,NULL,'反光板支架   1\r110cm 5in1    1\r分两票发挂号小包吧 RR843878985CN\rRR843878971CN'),(4945,620795901001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','supercompulsivebuyer','pablo.davilafernandez@gmail.com','Pablo Davila','Paseo de la Ermita 43, v20<br>Urb. Pinar de Santa Ana','Pedrezuela','Madrid','SPAIN','28723','656587112','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 08:51:07',0,NULL,3,1,4,1,NULL,'tripod  $22 \rYW864489585CN\r'),(4946,620799559001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','*.digital','angel.3f@gmail.com','David Barrera Martínez','Independencia No. 40<br>Col. Centro','Mixquiahuala','Hidalgo','MEXICO','42700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 09:08:19',0,NULL,5,1,18,0,NULL,NULL),(4947,616897893001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','christiano700','christianoopel@hotmail.com','christiano opel','18 carrigmore terrace saggart<br>citywest','Dublin','Dublin','IRELAND','24','0852050379','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 09:12:26',0,NULL,3,1,2,1,NULL,NULL),(4948,660324725002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','pankaj4318','thepankazz@gmail.com','Pankaj Patil','8116 Coppercreek Dr','Louisville','KY','UNITED STATES','40222-6812','(765) 413-5986','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 09:47:39',0,NULL,3,1,1,1,NULL,NULL),(4950,620817125001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','sass_a_frass_quatch','chrisohare@rogers.com','Twenty-Eight Dollar Films','45 - Eastgate Circle','Whitby','ON','CANADA','l1m 2n4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 10:36:21',0,NULL,3,1,3,1,NULL,'1转4 灯头  2 RR843877021CN\r'),(4951,620814768001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',99,'hermeshine','lucractius','ebay@lucractius.otherinbox.com','Samuel Bishop','Unit 12 / 3 Greenway Street','Perth','Western Australia','AUSTRALIA','6000','','NoPaymentFailure','CheckoutComplete','AU_Express','2011-01-17 11:00:57',0,NULL,3,1,4,1,NULL,'2m灯架   2\r双灯头 澳标   2\r反光伞   2\r包   1 \rlighitng kit  $22\rYW864489574CN\r'),(4952,706421103016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','blithespirit.com','paul@olive-house.co.uk','paul szelesi','221 Burnley Road','Rawtenstall','Lancashire','UNITED KINGDOM','BB4 8LA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 11:13:54',0,NULL,3,1,2,1,NULL,'canon 三角包  1 '),(4953,660347601002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','wildvovan','wildfoxbr@yandex.ru','Vladimir Tshebrov','Aviacionnay 8-45','Bryansk','Russia','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 11:38:44',0,NULL,8,1,17,0,NULL,''),(4954,620828115001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','wildvovan','wildfoxbr@yandex.ru','Vladimir Tshebrov','Aviacionnay 8-45','Bryansk','Russia','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 11:38:45',0,NULL,8,1,17,0,NULL,NULL),(4955,660346857002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','wildvovan','wildfoxbr@yandex.ru','Vladimir Tshebrov','Aviacionnay 8-45','Bryansk','Russia','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 11:38:45',0,NULL,8,1,17,0,NULL,NULL),(4956,660347171002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','wildvovan','wildfoxbr@yandex.ru','Vladimir Tshebrov','Aviacionnay 8-45','Bryansk','Russia','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 11:38:46',0,NULL,3,1,5,1,NULL,'2m 灯架  2\r单灯头  欧标  2\r反光伞  2\r柔光伞  1\rb座    1 \rCP219487775CN\r'),(4958,660347615002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','boerkejos','bjorn.pira@skynet.be','Pira Björn','Nieuwstraat 33<br>3071 Erps-Kwerps','Erps-Kwerps','','BELGIUM','3071','0496743055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 11:29:00',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座  1\r柔光伞   1 RR843879005CN'),(4959,620839953001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','tbr369','tibor@wombatoz.com','TIBOR HEGEDUS','PO Box 87','Hepburn Springs','Victoria','AUSTRALIA','3461','0419369333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 12:18:57',0,NULL,8,1,17,0,NULL,''),(4960,660358793002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','tbr369','tibor@wombatoz.com','TIBOR HEGEDUS','PO Box 87','Hepburn Springs','Victoria','AUSTRALIA','3461','0419369333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 12:18:57',0,NULL,3,1,4,1,NULL,'717ah   1 \r717快装板   1 \rTibor Hegedus\r36 Lakeside Drive\rHepburn Springs VIC 3461\rAustralia\r0419369333\rYW864614992CN\r\r\r'),(4961,720554714015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','brech22','alisonbrech@googlemail.com','Alison Brech','31 Wharf Road','Wraysbury','Middlesex','UNITED KINGDOM','TW19 5JQ','01784481808','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 11:50:27',0,NULL,3,1,2,1,NULL,'倒影板  1 '),(4962,620843572001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','vj-ammonite','vj-ammonite@terra.es','Jesus Plata Mateos','C/ las margaritas, 41 buzon 44<br>Siestamar','Santa eulalia','Baleares','SPAIN','07849','600505906','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 12:32:31',0,NULL,3,1,3,1,NULL,'肩架  1 RR843878999CN\r'),(4965,720594072015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','scottdalkin','scottdalkin@hotmail.co.uk','Scott  Dalkin','4 Falcon Crescent','Flitwick','Bedfordshire','UNITED KINGDOM','MK45 1LY','01525630001','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 14:04:14',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843878870CN\r'),(4966,660388038002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','lotenlooser','stig_lovas@yahoo.no','Stig Lovas','Mellombolgen 77','Oslo','','NORWAY','1157','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 14:10:10',0,NULL,3,1,3,1,NULL,'50-70塑料卡口棚   2 RR843877083CN\r'),(4967,620870720001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','kr5andm','post@sandmark.no','Kristian Sandmark','Tegnestiften 14','Gjøvik','','NORWAY','2821','+4740467177','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 14:16:49',0,NULL,3,1,3,1,NULL,'井字扳手  1 RR843877154CN'),(4968,720602885015,250666859818,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',48.9,'hutongstore','spgxk','kwgo1@hotmail.com','Kazuhiro Watanabe','5707-1 Kamisuwa Oaza','Suwa','Nagano','JAPAN','3920003','(080) 412-4835 ext.: 5','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-17 14:29:48',0,NULL,3,1,6,1,NULL,'2m 灯架  1\r斜臂   1\r50-70 棚    1 \rEE442466426CN\r'),(4972,620879806001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','soozette3','andrea.lacasse@gmail.com','Andrea Lacasse','4600 Wedgewood Blvd<br>Ste X','Frederick','MD','UNITED STATES','21703-7167','(301) 712-6565','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 15:04:38',0,NULL,3,1,1,1,NULL,NULL),(4973,720627943015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','inetarimas','inetuke@yahoo.com','Rimas Trakselis','Slotsgade 6','Horsens','','DENMARK','8700','4560329296','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 15:32:17',0,NULL,3,1,2,1,NULL,'45w   2 '),(4974,660416652002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','demonod','dick_an@hotmail.com','Sherley Nobin','Nicholson road le fou lane','vacoas','mauritius','MAURITIUS','230','+2306971479','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 15:42:36',0,NULL,3,1,2,1,NULL,'大力夹   2 '),(4975,620902940001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','billrees','bill@billrees.com','William Rees','577 Lake Forest Dr.','Bay Village','OH','UNITED STATES','44140','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 16:01:45',0,NULL,3,1,1,1,NULL,'小号内胆包 无字  1 '),(4976,706525338016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',3,'hutongstore','kcobby40','keith.cobby@supplydynamics.net','Keith Cobby','PO Box 113863 416 Al Awir Road, Nadd Al Hamar','Dubai','','UNITED ARAB EMIRATES','0000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 16:29:19',0,NULL,3,1,2,1,NULL,'450d 眼罩   1 '),(4977,660434515002,120626873273,'New wide angle holder for Cokin P series filter',5,'AA2216',19.95,'hermeshine','barao1961','amgp@netvisao.pt','Antonio Manuel Gomes Paulino Paulino','R. Alves Redol Nº 72 1º Esq.','Cova da Piedade - Almada','Setúbal','PORTUGAL','2805-071','936494274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 16:31:30',0,NULL,3,1,3,1,NULL,'广角托架   5 RR843877066CN'),(4978,620916351001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','jderson','jdderson@gmail.com','David Anderson','12350 S Parker Ter','Olathe','KS','UNITED STATES','66061','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 16:38:49',0,NULL,3,1,1,1,NULL,NULL),(4979,660456498002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','mvglorenz25','mlorenz@infonegocio.com','Michael Garcia Lorenz','Universidad Carlos III de Madrid [Q2818029G]<br>Avenida de la Universidad, 30','Leganes','Madrid','SPAIN','28911','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 17:24:12',0,NULL,3,1,2,1,NULL,'广角托架   1 '),(4980,620934402001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','lau.cl','laurent.cloquette@gmail.com','Marcia Kubrusly','Gonçalves Dias 577 apto. 301.','Curitiba','Paraná','BRAZIL','80240340','55 41 8712 6553','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 17:24:27',0,NULL,3,1,2,1,NULL,NULL),(4981,660464558002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','3742giovanni','pettigio@tiscali.it','giovanni petti','viale galvano della volpe n 3','roma','Roma','ITALY','00133','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 17:43:06',0,NULL,3,1,3,1,'RR843877035CN','黑色摄影背心 无字的 厚的    xxxl  1 \r'),(4982,660464230002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','opies1','oscar@thelensdepot.com','Oscar Pastrana','2789 Wrights Rd<br>Ste 1029','Oviedo','FL','UNITED STATES','32765-8528','(407) 964-1075','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 17:43:44',0,NULL,3,1,1,1,NULL,NULL),(4983,720696126015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','drusilla_filth','dru@druwatts.co.uk','Dru Watts','24 Shotley Close Pinewood','Ipswich','Suffolk','UNITED KINGDOM','IP2 9RZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 17:57:36',0,NULL,3,1,2,1,NULL,'1.6x2.1 白色背景布  1 '),(4984,660474192002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','meryjougs','mjgs_04@hotmail.com','Maria Jose Gavilan Sanchez','Avenida Villamayor,<br>40, 4º G','Salamanca','Castilla y León','SPAIN','37007','636756615','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 18:04:47',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843877049CN\r'),(4985,620923939001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','danielzavadszky','zavadszky@gmail.com','Daniel Zavadszky','Av. Rondeau 2396 / Ap. 1001','Montevideo','Montevideo','URUGUAY','11800','09899261190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:21:58',0,NULL,8,1,17,0,NULL,''),(4986,620954220001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.6,'hermeshine','danielzavadszky','zavadszky@gmail.com','Daniel Zavadszky','Av. Rondeau 2396 / Ap. 1001','Montevideo','Montevideo','URUGUAY','11800','09899261190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:21:59',0,NULL,8,1,17,0,NULL,NULL),(4987,620932320001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','danielzavadszky','zavadszky@gmail.com','Daniel Zavadszky','Av. Rondeau 2396 / Ap. 1001','Montevideo','Montevideo','URUGUAY','11800','09899261190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:21:58',0,NULL,8,1,17,0,NULL,NULL),(4988,620954337001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.5,'hermeshine','danielzavadszky','zavadszky@gmail.com','Daniel Zavadszky','Av. Rondeau 2396 / Ap. 1001','Montevideo','Montevideo','URUGUAY','11800','09899261190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:21:59',0,NULL,3,1,3,1,NULL,'77mm  cpl   1\r58mm cpl   1\r80cm 5in1    1\r60cm 棚     1 RR843877018CN文娟'),(4989,620965634001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','jira_d','plamineks@volny.cz','Jiri Durdil','Ceskolipska 400','Praha 9','','CZECH REPUBLIC','19000','+420603744703','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:33:35',0,NULL,8,1,17,0,NULL,NULL),(4990,660484712002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','jira_d','plamineks@volny.cz','Jiri Durdil','Ceskolipska 400','Praha 9','','CZECH REPUBLIC','19000','+420603744703','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:33:36',0,NULL,3,1,2,1,NULL,'品胜3.0膜   1\r40cm 棚   1 '),(4991,660491141002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','solaaris65','solaaris65@hotmail.com','Sebastien Barreau','Res Aramis, 49 rue Brauhauban<br>Etage 2 , Appt 5','Tarbes','Midi-Pyrénées','FRANCE','65000','06?67?36.07.25','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:37:58',0,NULL,3,1,2,1,NULL,'canon 三角包  1 '),(4996,660509517002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','shabashevich86','shabashevich@rambler.ru','Evgeniy Shabashevich','Hameri Haivri<br>521','Qiryat-Gat','','ISRAEL','82252','0527726818','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 19:12:27',0,NULL,3,1,2,1,NULL,NULL),(4997,660527648002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','misstrinity8','virginie_lz@hotmail.com','Virginie LOPEZ','30 route d\'Eguilles<br>villa amadour, bat O','Aix en provence','Provence-Alpes-Côte d\'Azur','FRANCE','13090','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 19:46:02',0,NULL,3,1,3,1,NULL,'斜臂  1 RR843878866CN'),(4998,660577821002,120462363779,'CTR-301 P Wireless Flash Trigger Kit with PC Port ',1,'AKT013',25.8,'hermeshine','cekisieda','cemkastrat@hotmail.com','eda kastrat','ahmet kutsi tecer caddesi 55/d<br>merter/güngören','istanbul','','TURKEY','34010','2125547718','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 21:23:54',0,NULL,3,1,3,1,NULL,'301p 一拖一  1 RR843877106CN'),(4999,660580690002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','argassd','argasd@gmail.com','Skirmantas Rocka','Baltu 6-77','Kaunas','Lithuania','LITHUANIA','lt-48166','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 21:29:36',0,NULL,3,1,3,1,NULL,'115w 220v   1 RR843877052CN'),(5000,706700073016,260660052995,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',8.99,'hutongstore','ptdnice','songkim2000@aol.com','PHAM Tu  Dung','\" Restaurant Fleur de Jade\" 8, rue d\'Italie','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 21:46:44',0,NULL,3,1,2,1,NULL,'90th 肩带  1 '),(5001,660596366002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','alvaro19561','aneira65@yahoo.com','Alvaro Neira','340 NW 19th St<br>Apt 200','boca raton','FL','UNITED STATES','33432','(561) 929-2877','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-17 22:06:33',0,NULL,3,1,1,1,NULL,'800w 110v   5 '),(5002,720856363015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',7.98,'hutongstore','sepotter114','sarah.potter40@ntlworld.com','Sarah Potter','54 Rose Avenue Irlam','Manchester','Lancashire','UNITED KINGDOM','M44 6AG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 22:17:05',0,NULL,3,1,2,1,NULL,'3pcs 滤镜袋   2 '),(5003,621109277001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','bear789tem','kosmo0308@aol.com','terry mewhorter','2109 Holland St','west columbia','SC','UNITED STATES','29169','(803) 394-9927','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 00:17:19',0,NULL,3,1,1,1,NULL,NULL),(5004,618900012001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',13.37,'hermeshine','jedonet','jedott@yahoo.com','J.Edgar Calingacion','#79-17, Yeongcheon-Ri<br>Dongtan-Myeon','Hwaseong City','Gyeonggi-Do','KOREA,REPUBLIC OF','445-813','821051300728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 00:51:16',0,NULL,3,1,11,1,NULL,'lenspen   1\r77mm 环架   1 '),(5005,655102944002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','vinczebalintakos','hhfishebay@gmail.com','Balint Vincze','Semmelweis utca 6.','Gyula','Bekes megye','HUNGARY','5700','0036302199809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 00:55:00',0,NULL,3,1,2,1,NULL,NULL),(5006,660652490002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','qwq1122','zxxb111@gmail.com','mansour albuainasn','Bulding 8448 , Unit 1<br>3886-35514','jubail','','SAUDI ARABIA','35514','+966505903606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 01:12:06',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5007,660653190002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','moxermax','gorkagoikoetxe@hotmail.com','Gorka Goikoetxea Aguirre (Presso Guzzeloni)','Viale Gran Sasso 50','Milano','MI','ITALY','20131','3278592636','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 01:18:18',0,NULL,3,1,4,1,NULL,'6662a   1 \rYW864489552CN\r'),(5008,660655666002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','paganaki','phil_paganias@yahoo.com','Philippos Paganias','Eptalofou 12','Attica','maroussi','GREECE','15124','00306942473896','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 01:23:50',0,NULL,3,1,2,1,NULL,'c型大力夹  1 '),(5009,621126548001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','ferblues70','fernandomblues@gmail.com','David Fernando Miranda','San Miguel Bloque L#35<br>P.O.BOx 312 350','La Paz - Bolivia','La Paz','BOLIVIA','P.O 312 350','2 795762','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 01:26:56',0,NULL,3,1,3,1,NULL,'反光板支架   1 RR843878923CN\r'),(5010,660656687002,120500391259,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',9.25,'hermeshine','leofioravanti','leofioravanti@uol.com.br','Leonardo Fioravanti','R Professor Tranquilli 212 Apto 62','São Paulo','São Paulo','BRAZIL','04126-010','55 11 50849086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 01:27:20',0,NULL,3,1,2,1,NULL,'大号内胆包无字   1 '),(5011,660663183002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ndrlndr','ndrlndr@btinternet.com','Henk-Jan Bussink','230 South Ealing Road<br>1st floor flat','Ealing','London','UNITED KINGDOM','W5 4RP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 01:51:49',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5012,621141548001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','melbastian2','melbastian@yahoo.com','Melanie Bastian','11140 N Alger Rd','Alma','MI','UNITED STATES','48801-9769','(989) 681-4502','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-18 02:28:20',0,NULL,8,1,17,0,NULL,NULL),(5013,621140994001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','melbastian2','melbastian@yahoo.com','Melanie Bastian','11140 N Alger Rd','Alma','MI','UNITED STATES','48801-9769','(989) 681-4502','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-18 02:28:20',0,NULL,3,1,1,1,NULL,'大力夹 球台  2 '),(5014,660257806002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','hasnulyakin2009','marketgarden77@yahoo.co.uk','HASNULYAKIN MOHAMMED','BERJAYA LANGKAWI RESORT<br>BURAU BAY, LANGKAWI','KEDAH','kedah','MALAYSIA','07000','04-9671175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 02:44:26',0,NULL,3,1,2,1,NULL,'90th 肩带  1 '),(5015,660702480002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','skaliboy','ska@xpressionsinforms.com','eliseo gomez','4318 el cebra way','las vegas','NV','UNITED STATES','89121','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 04:37:17',0,NULL,3,1,1,1,NULL,NULL),(5016,621170261001,110532007108,'72mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1303',2.6,'hermeshine','hollywood_ca','george@signaturexavier.com','GEORGE OHAN','1665 N Sycamore Ave<br>Apt 309','Hollywood','CA','UNITED STATES','90028-6062','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 04:37:51',0,NULL,3,1,1,1,NULL,NULL),(5017,620943845001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',32.06,'hermeshine','tkptrt','cparhan@gmail.com','Chandra Parhan','Jl. Kismis No. 15<br>Rancakendal, Cigadung','Bandung','JI','INDONESIA','40191','6285885689861','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 07:02:37',0,NULL,3,1,3,1,NULL,' lenspen   1\r气吹+布   1\r麂皮  4\r58mm 橡胶罩  1\r52mm 橡胶罩  1\r52-58 双阳   1\r58mm +4\rRR843877636CN\r\r\r'),(5018,721013576015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','tauer77','tauer@ktkadan.cz','Pavel Tauer','Klasterecka 1294','Kadan','','CZECH REPUBLIC','43201','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-18 07:58:28',0,NULL,3,1,3,1,NULL,'2m  灯架  1\rb座  1\r柔光伞   1 RR843877450CN\r'),(5019,660735565002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','lukacsa','alukacs@raszputyincat.com','Adrienn Lukacs','Temeto utca 9','Mogyorod','','HUNGARY','2146','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 08:17:57',0,NULL,3,1,3,1,NULL,' RR843877534CN\r'),(5020,706397286016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',133,'hutongstore','houselinen_uk','robertorocco@tiscali.co.uk','R. Miranda','48 Thorpe rd','kingston upon thames','Surrey','UNITED KINGDOM','kt2 5eu','07773712658','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-18 08:47:39',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r4灯头棚  英标   2\r115w 220v   4\r45w 220v   4\r 包   1\rlighting kit  $30\rYW864614955CN\r\r '),(5021,621209056001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','rasskazov_mv','rasskazov.mv@ya.ru','Михаил Рассказов','ул. Осипова, д. 24, кв. 121','Саратов','','RUSSIAN FEDERATION','410010','+79272264040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 08:55:50',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5022,660743399002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ridzuan60','ridzuanismail@gmail.com','Ridzuan Ismail','Fumakilla Malaysia Bhd,<br>Plot No. 256, Tingkat Perusahaan 5, Kawasan Perindustrian Perai 2','Perai','Penang','MALAYSIA','13600','0124930088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 09:02:43',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5023,660749343002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','clwvanzyl','clwvanzyl@gmail.com','Louis van Zyl','24 Ditton road<br>Auclandpark','Johannesburg','Gauteng','SOUTH AFRICA','2006','+27 835928562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 09:45:51',0,NULL,8,1,17,0,NULL,NULL),(5024,621218147001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','clwvanzyl','clwvanzyl@gmail.com','Louis van Zyl','24 Ditton road<br>Auclandpark','Johannesburg','Gauteng','SOUTH AFRICA','2006','+27 835928562','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 09:45:50',0,NULL,8,1,17,0,NULL,NULL),(5025,621216967001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','clwvanzyl','clwvanzyl@gmail.com','Louis van Zyl','24 Ditton road<br>Auclandpark','Johannesburg','Gauteng','SOUTH AFRICA','2006','+27 835928562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 09:45:51',0,NULL,8,1,17,0,NULL,' '),(5026,621216506001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','clwvanzyl','clwvanzyl@gmail.com','Louis van Zyl','24 Ditton road<br>Auclandpark','Johannesburg','Gauteng','SOUTH AFRICA','2006','+27 835928562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 09:45:52',0,NULL,3,1,3,1,NULL,'52mm 镜头盖  nikon  1\r小号镜头筒   1\r90th 镜头筒   1\r机身盖/镜头后盖 nikon   1 RR843877640CN\r'),(5027,621220613001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',61,'hermeshine','bahalam','mehdi@pacbell.net','Mehdi Asgarinejad','61 Shady Ln','Irvine','CA','UNITED STATES','92603-0127','(949) 509-6161','NoPaymentFailure','CheckoutComplete','Other','2011-01-18 09:56:24',0,NULL,8,1,17,0,NULL,''),(5029,660756089002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','bahalam','mehdi@pacbell.net','Mehdi Asgarinejad','61 Shady Ln','Irvine','CA','UNITED STATES','92603-0127','(949) 509-6161','NoPaymentFailure','CheckoutComplete','Other','2011-01-18 10:07:30',0,NULL,3,1,4,1,NULL,'反光板支架  2 \r斜臂  1 \rreflector holder   $20\rYW864614981CN\r'),(5030,660763944002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','ntlbd','ntlbd@dezzanet.net.au','Paul Ellis','73 Oriole Drive','Werribee','Victoria','AUSTRALIA','3030','0397341717','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 10:46:32',0,NULL,3,1,3,1,NULL,'sony 单肩包  a1  1 RR843877579CN\r'),(5031,660689527002,120639724081,'Continuous Lighting kit Red head 800w with bulb+stand ',1,'AKT060',110,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 10:58:27',0,NULL,3,1,3,1,NULL,'红头灯  1\r800w 220v 灯泡  1\r2m 灯架 红盒   1 \r不好包就分开发吧RR843877551CN\rRR843877525CN\r'),(5032,660768742002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','emarinas','enmarinas@yahoo.es','Enrique Mariñas','Anabel Segura 7<br>2ª planta NEC Iberica','Alcobendas','Madrid','SPAIN','28108','649179235','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 11:41:12',0,NULL,3,1,3,1,NULL,'肩架 1 RR843877494CN\r'),(5033,721084437015,250599921846,'New 52mm 52 Ring adapter and Holder for Cokin P Series ',1,'AKT018',3.62,'hutongstore','rwdfoote','robinfoote@hotmail.com','Robin Foote','87, Hanover Terrace','Brighton','East Sussex','UNITED KINGDOM','BN2 9SP','07970319759','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-18 12:41:51',0,NULL,3,1,2,1,NULL,'52mm环架  1 '),(5034,660797033002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','talamer','talamer2000@hotmail.com','Talal AlAamer','Villa 203 Road 1009 Block 110','Hidd','','BAHRAIN','100','(973) 366-3609 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 13:13:55',0,NULL,3,1,2,1,NULL,NULL),(5035,706964052016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','margaret841955','margaretdunlop@tiscali.co.uk','Josh Dunlop','Easdale Towpath','Shepperton','Surrey','UNITED KINGDOM','TW179LL','01932223783','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-18 13:38:15',0,NULL,3,1,2,1,NULL,'canon 三角包  1 '),(5036,660806025002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',40,'AA1310',219.6,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 13:50:34',0,NULL,3,1,3,1,NULL,'lenspen  40 拆包装 RR843877619CN'),(5037,660809030002,120564178883,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','mentepoluida','rodrigosantiago2005@gmail.com','Rodrigo Santiago','Rua Helena Vaz da Silva nº13-6ºA','Lisboa','Lisboa','PORTUGAL','1750-405','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 13:57:26',0,NULL,3,1,2,1,NULL,'ND8   1 '),(5038,618396654001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',139.88,'hermeshine','adeje_dario','dario_adeje@hotmail.com','Dario Bascones Carrodeguas','Residencial Los Abalos nº1 El Galeon','Adeje','Canarias','SPAIN','38670','617441150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 14:02:15',0,NULL,3,1,4,1,NULL,'背景架  （白）   2m   1\r一转四 灯头  1\r115w 220v  2\r2m 灯架   1\r单灯头  2  欧标\r反光伞   1\rlighting kit  $25\rYW864614922CN\r\r '),(5040,660817873002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','yankeerutter','yankeerutter@aol.com','GEORGE RUTTER','395 Essex St<br>Centerville Woods APT#102B','Beverly','MA','UNITED STATES','01915','(978) 998-4719','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 14:29:56',0,NULL,3,1,1,1,NULL,'lenspen   2 '),(5042,619974688001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',2,'AE3403',74.9,'hermeshine','dinmarisa','dinaelmarcela@hotmail.com','Dinael Andrade de Lima','Rua Joaquim Ferreira Gomes 685<br>bloco D apt 21','Sumare','Sao Paulo','BRAZIL','13171120','19-3873-9623','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 14:53:55',0,NULL,3,1,5,1,NULL,'2m 弹簧灯架  2 \r红盒\rCP219487421CN\r'),(5043,621291175001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','chitalina','denisesaura@gmail.com','Denise Bernardes Chaves','Rua Visconde de Nacar, 1200 / 105 Bairro Centro','Curitiba','PR','BRAZIL','80410-201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 14:54:08',0,NULL,3,1,5,1,NULL,'2m x 3m 背景架   1 \rCP219487727CN\r'),(5044,718766276015,250692240197,'Remote Control Cord for Nikon D300s/D200/D700​/D3 MC-30',1,'AA2220',2.89,'hutongstore','vichento0','vianton@hotmail.com','David Anton Rovira','Ruperto Chapi, 16-5','Elche','Alicante','SPAIN','03201','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-18 15:28:30',0,NULL,3,1,2,1,NULL,'优永佳 b    1  N1  '),(5045,660838802002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 15:39:53',0,NULL,8,1,17,0,NULL,'肩架   1 '),(5046,621306179001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 15:43:05',0,NULL,8,1,18,0,NULL,NULL),(5050,721175560015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',24.95,'hutongstore','kumi-tarzan','kumitarzan@gmail.com','Markus Lehtinen','Lounaankatu 1 a 13','Lahti','','FINLAND','15150','+358407438006','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-18 16:51:07',0,NULL,3,1,3,1,NULL,'肩架  1 RR843877503CN\r'),(5051,621338522001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','lostbider','oliverpenny7738@yahoo.com','SZE-HUA WU','8650 Spicewood Springs Rd<br>Ste 122','Austin','TX','UNITED STATES','78759-4310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 17:16:46',0,NULL,3,1,1,1,NULL,NULL),(5052,660872108002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','serg204','k2041@bezeqint.net','Sergei Katsov','Tapuah 3/8','Arad','-Israe','ISRAEL','80700','972-050-493-4474','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 17:16:46',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞    1 RR843877962CN\r'),(5053,660874657002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 17:20:05',0,NULL,3,1,3,1,NULL,'肩架    1\r580肥皂盒  1\r52mm 接口环   1\r52mm +8   1\r77mm 环架   1\r58mm 环架  1\rND2/4/8   1\r RR843877843CN\r'),(5054,660875797002,120601699344,'JueYing Lambency Flash Diffuser for 430EX F36AM P2',1,'AB3308',22,'hermeshine','kirillk09','kkirsanov2@gmail.com','Kirill Kirsanov','Dzhambula street 221, apt. - 17','Almaty','','KAZAKHSTAN','050009','+77776876333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 17:25:27',0,NULL,3,1,3,1,NULL,'碗罩  P2   1 RR843877565CN\r'),(5055,621348260001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','ivanhurba1976','ivanhurba@gmail.com','Ivan José Hurtado Barón','Carmenes de Rolando n 33','Granada','Andalucía Ceuta y Melilla','SPAIN','18011','958208210','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 17:40:17',0,NULL,3,1,3,1,NULL,'肩架  1 RR843877432CN\r'),(5056,660889351002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',4,'AA1310',21.96,'hermeshine','arildberdahl','arild.berdahl@gmail.com','Arild Berdahl','Leitetunet 17<br>H0201','Bodø','','NORWAY','8009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 17:57:44',0,NULL,3,1,3,1,NULL,'lenspen   4 RR843877653CN\r'),(5057,707064418016,260687503075,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',28.99,'hutongstore','dadoomars','daddoo@orange.fr','Decourdemanche Daniel','29 traverse Olive','Marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13013','0491705288','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-18 17:58:15',0,NULL,3,1,3,1,NULL,'3m 横杆   1 RR843877548CN\r'),(5058,621375630001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','tipsinartok','catchthewind@shaw.ca','Lindsay Wilson','12-815 Lodi Avenue','Victoria','BC','CANADA','V8Z 6T3','(250) 483-3453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 18:42:18',0,NULL,3,1,2,1,NULL,NULL),(5059,660919252002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 19:00:37',0,NULL,3,1,3,1,NULL,'100-150 5in1  反光板  1 RR843877605CN\r'),(5060,721252597015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',3.5,'hutongstore','2010ish','ish.ib@hotmail.co.uk','Ismail Ibrahim','23, Malmesbury Road','Gloucester','Gloucestershire','UNITED KINGDOM','GL4 6BH','01452534723','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-18 19:14:40',0,NULL,3,1,2,1,NULL,'2m 灯架  2\r单灯头  2\r反光伞   2\rCP219487744CN\r\r '),(5061,660929332002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT061',73.3,'hermeshine','yu_yong','yu_yong@hotmail.com','yu_yingli yu','1605 26 st.se.','calgary','AB','CANADA','T2A5W5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 19:20:53',0,NULL,3,1,5,1,NULL,'2m 灯架  2\r4灯头棚  英标   2\r115w 220v   4\r45w 220v   4\r 包   1\rlighting kit  $30\rYW864614955CN\r\r '),(5062,621419545001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','micky62910','mickadubruck@hotmail.fr','mickael dubruck','163 rue de loosthoucq','eperlecques','Nord-Pas-de-Calais','FRANCE','62910','0321936579','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 20:11:11',0,NULL,3,1,4,1,NULL,'2m 灯架  1 白盒 RR843878248CN\r'),(5063,621434180001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','jgim7923','shop@surfmaktub.com','Juan Manuel Giménez','Rambla Turo 12, primero segunda','Montgat','Cataluña','SPAIN','08390','660171552','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 20:40:12',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r斜臂   1\r50-70 棚    1 \rEE442466426CN\r'),(5064,660970460002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','grahamjbell','graham@bell1.demon.co.uk','Graham Bell','1440 N Gardner St<br>Apt 201','Los Angeles','CA','UNITED STATES','90046-4153','(323) 697-6944','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 20:44:27',0,NULL,3,1,1,1,NULL,'2m 灯架  1\r反光板支架  1 \rYW864614966CN\r'),(5065,660973501002,120536002412,'New Neoprene Camera Neck Strap for D80 D90 D300 D700',1,'AB1403',9.9,'hermeshine','aykut2011','aykut_erk@hotmail.com','aykut erken','kurtulus mah.<br>turgut sok.no:1','izmir','bergama','TURKEY','35700','+905424820530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 20:51:11',0,NULL,3,1,2,1,NULL,'nikon 肩带  黄字   1 '),(5066,621442410001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',2,'AC1301',17.38,'hermeshine','fotofog712','fotofog@yahoo.com','Fernando Orrego','Juan de Luigi  3675','Santiago','Metropolitana','CHILE','7830063','5622216999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 20:58:27',0,NULL,3,1,2,1,NULL,'中号内胆包 无字   2 '),(5067,721318950015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.5,'hutongstore','jamie1178','jamie@hutchin6.orangehome.co.uk','james hutchin','35 Danesbower Lane Blofield','Norwich','Norfolk','UNITED KINGDOM','NR13 4LP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-18 21:01:40',0,NULL,3,1,2,1,NULL,'2m 灯架  1\r云台   1\r柔光伞   1 RR843878945CN\r'),(5068,660979403002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','emretunali','emrekarizma_1992@hotmail.com','Emre Tunalı','İnkılap Mah. Harputlu Cad. No:22','Bergama','İzmir','TURKEY','35700','5079509376','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 21:06:03',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r云台   1\r柔光伞   1 RR843877980CN\r'),(5069,620595318001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',53.94,'hermeshine','junglistic_maxim','ebay_junglistic@mail.ru','Mogildea Maxim','A. Xenopol 11','Chisinau','','MOLDOVA, REPUBLIC OF','MD-2051','079844160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 21:14:22',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座  1\r柔光伞   1 RR843879005CN'),(5070,621457434001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',107.96,'hermeshine','sezeryadigar10','sezeryadigar@hotmail.com','Sezer Yadigar','telsiz mah. 85/10 sk. no:2 d:3<br>zeytinburnu','istanbul','Marmara','TURKEY','34025','+905556848606','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 21:34:01',0,NULL,3,1,3,1,NULL,'2m 灯架  2\r斜臂  2\r发两个国内小包挂号 RR843877415CN\rRR843878968CN\r'),(5071,621461886001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','igabi600','gl6600@gmail.com','Gabriel Leventhal','Radak 10/4<br>Azza 30/4','Jerusalem','','ISRAEL','92382','(026) 274-042','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 21:45:56',0,NULL,3,1,3,1,NULL,'国内小包挂号 RR843877976CN\r'),(5072,621466033001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','bubble_wrap21','bubble_wrap21@hotmail.com','Alisha Lange','6480 Troy Sidney Rd','Piqua','OH','UNITED STATES','45356-9213','','NoPaymentFailure','CheckoutIncomplete','Other','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'反光板支架  1 RR843877361CN\r'),(5073,661006480002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','kovic123','kimkovic@optusnet.com.au','Kim Kovic','178 A\'Beckett Road','Narre Warren Nth','Victoria','AUSTRALIA','3804','0397968869','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 22:13:11',0,NULL,8,1,17,0,NULL,''),(5074,661013146002,120605577790,'New thicken Non Woven Fabric Backdrop 3m x 2m(10 x7 ft)',1,'AO0018',35,'hermeshine','mariettapm82','mariettapm@hotmail.com','MARIA PEREZ MARTIN','CALLE ZARAGOZA, 21-5','TORRENT','Comunidad Valenciana','SPAIN','46900','656903644','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 22:27:12',0,NULL,3,1,3,1,NULL,'2mx3m 白色背景布 厚的  1RR843877596CN\r '),(5075,621478640001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','lesrechinsp','paul.menager@gmail.com','Menager Paul','18 rue gérald thiboutôt','blainville','QC','CANADA','J7C0G4','(514) 815-3989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 22:32:12',0,NULL,3,1,2,1,NULL,'40cm 棚 1 '),(5076,621480249001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','phwocean','pyroskater00@yahoo.com','Weston Sheldon','1400 Hancock Blvd<br>LEAVE PACKAGE AT OFFICE','Daytona Beach','FL','UNITED STATES','32114-5648','(404) 735-5107','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 22:37:16',0,NULL,3,1,1,1,NULL,NULL),(5077,621482571001,110409866856,'77mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1307',3.79,'hermeshine','kovic123','kimkovic@optusnet.com.au','Kim Kovic','178 A\'Beckett Road','Narre Warren Nth','Victoria','AUSTRALIA','3804','0397968869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 22:44:38',0,NULL,8,1,17,0,NULL,NULL),(5078,621485389001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','kovic123','kimkovic@optusnet.com.au','Kim Kovic','178 A\'Beckett Road','Narre Warren Nth','Victoria','AUSTRALIA','3804','0397968869','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 22:55:16',0,NULL,3,1,4,1,NULL,' canon D8 单肩包  1 \r77mm 橡胶罩    1\r摄影背心 canon 黑色薄款 xxl    1\rbag  $20\rYW864489600CN\r'),(5079,621486731001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','qwq1122','zxxb111@gmail.com','mansour albuainasn','Bulding 8448 , Unit 1<br>3886-35514','jubail','','SAUDI ARABIA','35514','+966505903606','NoPaymentFailure','CheckoutIncomplete','OtherInternational','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'== '),(5080,661023630002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ollazc','cont3stant@hotmail.com','Oliver Tsupsman','Kaluri 20','Haapsalu','Läänemaa','ESTONIA','90502','+37253653162','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 22:59:49',0,NULL,3,1,2,1,NULL,' '),(5081,621495477001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cgro9131','chantalgrondin@tlb.sympatico.ca','Chantal Grondin','4, chemin du Lac Sport','Lac St-Paul','QC','FRANCE','j0w1k0','819 585 2347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 23:27:10',0,NULL,3,1,2,1,NULL,NULL),(5082,661035922002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','rachelmlewis87','armywife32808@aol.com','Rachel Lewis','5546 McCullough Dr<br>Apt B','Colorado Springs','CO','UNITED STATES','80902-1632','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 23:41:23',0,NULL,3,1,1,1,NULL,'60cm 2in1   1 '),(5084,661053254002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','foltynet','foltynet@gmail.com','Tomer Foltyn','58 Shderot Benyamin','Netanya','','ISRAEL','42314','972-50-5810058','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 00:47:29',0,NULL,3,1,3,1,NULL,'斜臂  1 RR843877429CN\r'),(5085,661063956002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT055',126,'hermeshine','gajanandi','gaja@live.ca','RAJAKULENTHIRAN POOPALU','1906- 320 DIXON ROAD','ETOBICOKE','ON','CANADA','M9R 1S8','(416) 877-8846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 01:28:37',0,NULL,3,1,5,1,NULL,'RR843877755CN '),(5086,661062448002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','jamal2588','jamalross@hotmail.com','Jamal Ross','28 Winchester House<br>Beaufort street','London','London','UNITED KINGDOM','Sw3 5bj','07950870422','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 01:50:08',0,NULL,3,1,4,1,NULL,'717ah   1 \rball head  $20\rYW864614933CN\r'),(5087,661074035002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','dave77177','dave7717@hotmail.com','David Leblanc','222 Ottawa<br>app 2','cowansville','QC','CANADA','J2K2C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 02:04:13',0,NULL,3,1,2,1,NULL,'50cm 棚  1 '),(5088,621541212001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','xoselaf','xoselaf@yahoo.es','José Luis Álvarez Fernández','C./ M. R. Sinde, 17','A Guarda','Galicia','SPAIN','36780','660212816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 02:32:12',0,NULL,3,1,2,1,NULL,'717ah   1 \rball head  $20\rYW864614933CN\r'),(5089,661080348002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','evets','s_t_e_v_e_h@hotmail.com','Stephen Hurne','203 Park St','south Melbourne','Victoria','AUSTRALIA','3205','0431600170','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 02:38:17',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r反光板支架  1 \rYW864614966CN\r'),(5090,621551254001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ckshene','shene@acm.org','Ching-Kuang Shene','19226 Copper Ridge Road','Houghton','MI','UNITED STATES','49931','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 03:12:43',0,NULL,3,1,1,1,NULL,NULL),(5092,621558723001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',52.99,'hermeshine','spillnermail','marko.peter@yahoo.com','Peter Marko','Unit 25, 27-51 Charles Street','Melbourne/Bentleigh East','Victoria','AUSTRALIA','3165','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-19 03:47:30',0,NULL,3,1,3,1,NULL,'3m 横杆   1 RR843877548CN\r'),(5093,621562328001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','dopeynsleepy','briand917@gmail.com','Brian Doyle','74 S 3rd St<br>Apt 1','Brooklyn','NY','UNITED STATES','11211-5103','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 04:10:39',0,NULL,8,1,17,0,NULL,'2mx3m 白色背景布 厚的  1RR843877596CN\r '),(5094,621562277001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','dopeynsleepy','briand917@gmail.com','Brian Doyle','74 S 3rd St<br>Apt 1','Brooklyn','NY','UNITED STATES','11211-5103','','NoPaymentFailure','CheckoutComplete','Other','2011-01-19 04:10:39',0,NULL,3,1,3,1,NULL,'2m 灯架  2\r斜臂  2\r发两个国内小包挂号 RR843877415CN\rRR843878968CN\r'),(5095,621563636001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','helias007','heliasfotografo@hotmail.com','Elias Huaman Corterreal','Jr Hermenegildo Rojas 125<br>distrito Carabayllo','Lima','Lima','PERU','51','5440277','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 04:10:44',0,NULL,3,1,3,1,NULL,'RR843877755CN '),(5096,621570208001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','sjursen','kent.erik@sjursendesign.no','Kent-Erik Sjursen','Bekkefaret 3','Mo i Rana','Nordland','NORWAY','8618','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 04:50:50',0,NULL,3,1,3,1,NULL,'2m 灯架  2\r4灯头棚  英标   2\r115w 220v   4\r45w 220v   4\r 包   1\rlighting kit  $30\rYW864614955CN\r\r '),(5097,661119963002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','pedry85','dcpedry@gmail.com','Daniel Pedry','1959 Wellington Ln<br>Unit 4','Vista','CA','UNITED STATES','92081-7930','(760) 672-7208','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 05:44:20',0,NULL,3,1,1,1,NULL,NULL),(5099,661120675002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','h.k.pikal','hubert@pikal.com','H.K.Pikal - Clay River Studio','906 Koerner Ln','Austin','TX','UNITED STATES','78721','','NoPaymentFailure','CheckoutComplete','Other','2011-01-19 05:48:00',0,NULL,3,1,4,1,NULL,'tripod  $20\rYW864614970CN\r '),(5100,621585403001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','anderson*calvin','anderson.calvin@gmail.com','Calvin Anderson','6331 Hollywood Blvd','Los Angeles','CA','UNITED STATES','90028-6321','(323) 960-3500 ext.: 0000','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 06:37:18',0,NULL,3,1,1,1,NULL,NULL),(5102,661138584002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','nnazmy','ayob.nazmy@gmail.com','AYOB NAZMY NANYAN','20/70 Grange Boulevard','Bundoora','Victoria','AUSTRALIA','3083','0430788084','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-19 07:50:22',0,NULL,3,1,4,1,NULL,'tripod $16 \rYW864614944CN\r'),(5103,621606821001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','maccess8','m.kastner@gmx.at','Markus Kastner','Mitterdörfl 31','Bad Kreuzen','','AUSTRIA','4362','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 08:52:24',0,NULL,3,1,2,1,NULL,'单灯头 欧标 1 '),(5104,660302026002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','cubicwarlock','cubicwizard@gmail.com','Shilin Alexandr','800-letiya Moscow str., house 14, flat 93','Moscow','Moscow','RUSSIAN FEDERATION','127247','+79031513000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 09:15:21',0,NULL,3,1,3,1,NULL,' RR843877675CN'),(5107,721545589015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','luigi73452','l.burgi@tin.it','Luigi Filippo Burgi','Via Lombardia 66','Corgeno - Vergiate','Varese','ITALY','21029','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-19 10:08:33',0,NULL,3,1,2,1,NULL,'45w   2'),(5109,621622873001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tomsnetwork','tomi.jelic@gmail.com','Tomislav Jelić','Trg Republike 1','Županja','Slavonija','CROATIA','32270','00385032845640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 10:13:14',0,NULL,8,1,17,0,NULL,NULL),(5110,621623195001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tomsnetwork','tomi.jelic@gmail.com','Tomislav Jelić','Trg Republike 1','Županja','Slavonija','CROATIA','32270','00385032845640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 10:14:48',0,NULL,3,1,2,1,NULL,'55mm 橡胶罩   2 '),(5111,661167650002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','hildham','hamin@hildgrim.com','Hamin Mousavi','Spangatan 1B LGH1701','Malmo','','SWEDEN','21144','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 10:25:08',0,NULL,3,1,3,1,NULL,' \rRR843877790CN\r'),(5112,661168074002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','macratus','peter@macadam.se','Peter Adamsson','Mölledalsgatan 41','Malmö','','SWEDEN','212 40','+46705417441','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 10:25:50',0,NULL,3,1,3,1,NULL,' RR843877809CN\r'),(5114,621634706001,110534333294,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',9.69,'hermeshine','tictac7775','laura.grassi@gmail.com','Massimiliano Cappello','via De Amicis 71','Sedriano','Milano','ITALY','20018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 11:10:18',0,NULL,3,1,2,1,NULL,NULL),(5116,661184524002,120601699795,'New 3 filters & Ring holder set 4 Cokin System P Series',1,'AKT026',22.8,'hermeshine','georgebwmf','gcrook13@hotmail.com','George  Z Hantzis','Dilvoi 13-15 Byron','Athens','Greece','GREECE','16232','010 - 7629640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 11:41:23',0,NULL,3,1,2,1,NULL,'72mm 环架  1\r渐变灰  + ND4 + ND8  '),(5117,621648386001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','tommy1919ros','sergeyyurchenkoros@gmail.com','Sergey Yurchenko','Komarova 11, flat 109','Rostov-on-Don','RU','RUSSIAN FEDERATION','344092','(863) 235-68-34','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 12:08:06',0,NULL,3,1,2,1,NULL,'品胜3.0 膜  1 '),(5118,621651122001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',5.9,'hermeshine','pwords','sgani@mail25.com','Sohail Gani','9003 Hampton Landing Dr E','Jacksonville','FL','UNITED STATES','32256','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 12:19:34',0,NULL,3,1,1,1,NULL,'万用柔光罩  1\r新的，我来吧 '),(5119,661194800002,120461606047,'New 64\" Pro metal Tripod FT-6662A with Ballhead Bag',1,'AE1601',61,'hermeshine','surfer_jokin','surfer_jokin@hotmail.com','jokin guinea fernandez','KUKADA Bizenta Mogel 8 bajo','Vitoria','País Vasco','SPAIN','01008','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 12:23:12',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864489622CN\r'),(5120,621651131001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','g8chu','g8percy@gmail.com','Wai Yin Chu','4/72-74 Carlisle Street<br>St Kilda','Melbourne','Victoria','AUSTRALIA','3182','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 12:25:13',0,NULL,3,1,2,1,NULL,'气吹+ 布  1 '),(5122,661196161002,120497752222,'62mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1304',4.35,'hermeshine','acgenealogy','brianhildick@talktalk.net','Brian Hildick','52,Coniston Rd.,','Barnehurst, Bexleyheath','Kent','UNITED KINGDOM','DA7 6PY','01322332293','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2011-01-19 12:27:51',0,NULL,3,1,2,1,NULL,NULL),(5123,721615013015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','yl3bf','yl3gbf@one.lv','Janis Bruders','O.Kalpaka 99A, flat 4','Liepaja','','LATVIA','LV3405','(371)29495926','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-19 13:57:22',0,NULL,3,1,3,1,NULL,' RR843877715CN\r'),(5124,661233793002,120564178467,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','fkaviani50','fk1002000@yahoo.com','Fred Kaviani','117c South Route 70','Marlton','NJ','UNITED STATES','08053-3024','(856) 396-2490','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 14:45:27',0,NULL,3,1,1,1,NULL,NULL),(5126,661234197002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','tdllondru','ferranitu@gmail.com','Ferran Pérez','c. Sant Narcis 16, 1º 1ª','Argentona','Cataluña','SPAIN','08310','937560942','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 14:49:16',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864489633CN\r'),(5127,661260031002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','danibram','nemz00@gmail.com','Daniel Biedma Ramos','CLur gorri 28 3D','Barañain','Navarra','SPAIN','31010','948074685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 16:06:44',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5128,661264851002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','airmel','mooney56u@aol.com','Mark Lester','6197 Palau St','Cypress','CA','UNITED STATES','90630','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 16:19:54',0,NULL,3,1,1,1,NULL,NULL),(5129,621733073001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','krokys2010','bivibo@yandex.ru','VITALIY BILYK','vul. Konyakina 14a/85','Lutsk','','UKRAINE','43023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 16:56:37',0,NULL,3,1,2,1,NULL,NULL),(5130,621736909001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','popihmt','popihmt@hotmail.com','Hugo Mañez Tamariz','Avda/ Sierra de Aralar<br>nº21 / 2º C','san Sebastián','País Vasco','SPAIN','20014','617222008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 17:05:36',0,NULL,3,1,2,1,NULL,NULL),(5131,621737655001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','orlando-42','mtansley@mtansley.ca','Michael Tansley','43 Tudor Avenue','Ajax','ON','CANADA','L1S 2A2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 17:07:21',0,NULL,3,1,2,1,NULL,'大号灰卡   1 '),(5132,621762278001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cdmira01','corbinmiranda@aol.com','Corbin Miranda','5701 Delhi Rd<br>Seton Hall Box #329','Cincinnati','OH','UNITED STATES','45233-1669','(502) 457-9845','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 18:07:47',0,NULL,3,1,1,1,NULL,NULL),(5134,661320941002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','marina7345','marinamitsakaki@hotmail.com','Marina Mitsakaki','Dahliastraat 40','Eindhoven','','NETHERLANDS','5644 PP','0031657032377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 18:38:36',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5135,661322565002,120581555897,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','athalakian','gathalakian@yahoo.fr','gerard athalakian','68628 J St','Cathedral City','CA','UNITED STATES','92234-2015','(760) 202-7478','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 18:40:46',0,NULL,3,1,1,1,NULL,'77接口环  1 '),(5136,621795985001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','stparadox1','z.man2@centrum.cz','Zdenek Konecny','Slunecna 16','Hodonin','','CZECH REPUBLIC','69501','042 739 131 135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 19:19:38',0,NULL,3,1,2,1,NULL,NULL),(5137,661368626002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','christian26042010','christian@olsendesign.com','Christian Olsen','Rue schaub 6','Genève','','SWITZERLAND','1202','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 20:14:06',0,NULL,3,1,4,1,NULL,'717AH   1 \rballhead  $20\rYW864489644CN\r'),(5138,621832437001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','johnypr07','jonathan_mora7@hotmail.com','Andress Bourasseu','Ruiz Velviz  #118<br>Rio Piedras','San Juan','PR','PUERTO RICO','00917','(787) 675-2897','NoPaymentFailure','CheckoutComplete','Other','2011-01-19 20:36:26',0,NULL,3,1,8,1,NULL,'2m 灯架  2\r50-70 棚   2\r115w 110v   2 \r包   1\rCP219487713CN\r'),(5139,661382036002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','rover46','ferz46@mail.ru','Konstantin Grachev','240, korp. 1649','Zelenograd','Moscow','RUSSIAN FEDERATION','124365','74997172781','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 20:43:04',0,NULL,8,1,17,0,NULL,''),(5140,621835225001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','rover46','ferz46@mail.ru','Konstantin Grachev','240, korp. 1649','Zelenograd','Moscow','RUSSIAN FEDERATION','124365','74997172781','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 20:43:05',0,NULL,3,1,3,1,NULL,' 2m 灯架 1\rb座   1\r柔光伞   1 \r80cm 5in1    1\rRR843877772CN\r未发出去，燕文退回来了2月18日，等客户问退钱吧。\r'),(5141,621844184001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','aleksey_fotograf','zaharov-aleksey-foto@yandex.ru','Aleksey Zakharov','Polesskaja 12/42','Orjol','RU','RUSSIAN FEDERATION','302028','74862457518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 20:59:30',0,NULL,3,1,2,1,NULL,' '),(5142,621844646001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.9,'hermeshine','thiagomu','tsframos@hotmail.com','THIAGO RAMOS','RUA JOSE VARGAS DE FIGUEIREDO<br>NUMBER 46','VARRE-SAI','RIO DE JANEIRO / RJ','BRAZIL','28375000','(22)3843-3321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 21:00:18',0,NULL,3,1,2,1,NULL,'大力夹  2 '),(5144,721830974015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','brianw7537','wilkinson150@btinternet.com','BRIAN WILKINSON','22 BUDDLE ST','CONSETT','Durham','UNITED KINGDOM','DH87JX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-19 21:01:56',0,NULL,3,1,2,1,NULL,NULL),(5145,707683977016,260675928086,'New Small Camera bag lens case D2 for Canon 500D 450D',1,'AO0033',5,'hutongstore','idlm2010','idlm2010@hotmail.com','David Alonso','C Andres Benito 24','Zaragoza','Aragón','SPAIN','50016','976588792','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-19 21:31:12',0,NULL,3,1,2,1,NULL,'canon 小包  1 '),(5148,621865439001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',2,'AA2101',70,'hermeshine','lakesdales','info@thelakesanddales.com','Simon Wells','The Sheiling<br>Thornton in Lonsdale','Ingleton','North Yorkshire','UNITED KINGDOM','LA6 3PB','01524241906','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 21:49:58',0,NULL,3,1,3,1,NULL,'nikon 老款摄影背心 xl \r2\rRR843876159CN\r'),(5149,661423132002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','vakomin','vadim.mynyaylovsky@gmail.com','Vadim Mynyaylovsky','7b-12 Shoalej Shimshon','Kfar Saba','','ISRAEL','44391','972-526989867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 22:11:47',0,NULL,3,1,3,1,NULL,'50-70 棚  塑料卡口  1 \rRR843877724CN\r'),(5150,621880996001,110464615814,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',8.69,'hermeshine','bredb71','bre_7171@yahoo.com','bryan balzomo','6925 Haskell Ave<br>Apt 109','van nuys','CA','UNITED STATES','91406-5076','(818) 300-7523','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 22:34:06',0,NULL,3,1,1,1,NULL,'中号内胆包 无字   1 '),(5151,661437648002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','nigelflus','nigelflus@yahoo.es','NIGEL FELIX LORENZO O´FLAHERTY','AVENIDA TANAUSU Nº21','LOS LLANOS DE ARIDANE','','SPAIN','38760','699089808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 22:52:16',0,NULL,3,1,4,1,NULL,'tripod $16 \rYW864489655CN\r'),(5152,661450044002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','nina-0047','ninae-k@online.no','nina karlsen','godøynes','tverlandet','bodø','NORWAY','8050','004790293266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 23:33:55',0,NULL,3,1,3,1,NULL,'50-70 棚  塑料卡口  1  \rRR843877738CN\r'),(5153,707740408016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','thepishkin','chrisx2@gofree.indigo.ie','Chris Slattery','4 Hill View Woodlawn','Killarney','Co Kerry','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-19 23:48:13',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(5154,621903705001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','modelbear','ebay@modelbear.com','Pierre Lacroix','39-2296 Orient Park Dr.','Gloucester','ON','CANADA','K1B4N6','(613) 834-5550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 23:51:48',0,NULL,3,1,2,1,NULL,NULL),(5155,621908201001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','hideriders','zzpapi@gmail.com','HIDEAKI KODAMA','7811 Kew Forest Ln<br>Apt 3DA','FOREST HILLS','NY','UNITED STATES','11375-6171','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-20 00:11:32',0,NULL,3,1,1,1,NULL,'40cm  棚  1 '),(5156,661460675002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','fbk43','fbkerr@tds.net','Francis B. Kerr','406 N Grove Blvd','Kingsland','GA','UNITED STATES','31548','(912) 729-4103','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 00:15:01',0,NULL,3,1,1,1,NULL,' '),(5158,621920381001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',4.4,'hermeshine','dsims9t','dsims@sleekworks.com','David Sims','1450 Springfield Dr<br>Apt 146','Chico','CA','UNITED STATES','95928-7313','(707) 321-6237','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 01:04:33',0,NULL,3,1,1,1,NULL,' '),(5159,661478920002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','bnbjones291','bnbjones29@hotmail.com','Benjamin Jones','683 Chestnut St','Liberty Center','OH','UNITED STATES','43532-9779','(419) 613-7022 ext.: 20','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 01:29:50',0,NULL,3,1,1,1,NULL,'90th 肩带  1 '),(5160,661484927002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','fa1len_ange1','davidgwon@hotmail.com','Joon Gwon','6001C 194th St<br>Apt 3C','FRESH MEADOWS','NY','UNITED STATES','11365-2812','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-20 01:54:02',0,NULL,3,1,1,1,NULL,'canon 三角包  1 '),(5161,621938801001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','ozricsfan','ozr1csfan@yahoo.com.au','Mr. A G Boyd','55 LOWAN Avenue<br>ph: 0418373709','TEMPLESTOWE LOWER','Victoria','AUSTRALIA','3107','0418373709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 02:34:34',0,NULL,3,1,2,1,NULL,NULL),(5162,661497863002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','844-223-5287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 02:45:10',0,NULL,3,1,5,1,NULL,'2m 灯架 2\rb座   2\r柔光伞  2 \rCP219487700CN\r'),(5163,661490746002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','bigrexj','rexdjohnson@gmail.com','Rex D. Johnson','1050 Techwood Dr NW<br>C/O Turner Broadcasting Systems, Inc. Ste 300','Atlanta','GA','UNITED STATES','30318-5604','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 03:10:19',0,NULL,3,1,1,1,NULL,' '),(5164,661506878002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','anissang','anissangarcia@gmail.com','anissa garcia','5933 Amos Ave','Lakewood','CA','UNITED STATES','90712-1322','(562) 972-2099','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 03:22:18',0,NULL,3,1,1,1,NULL,NULL),(5165,621956000001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','pukeko2','fulcher@xtra.co.nz','mike fulcher','16 Putter Place<br>Howick','Auckland','','NEW ZEALAND','2013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 03:45:32',0,NULL,3,1,2,1,NULL,'72mm 橡胶罩   1 '),(5166,621966745001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fieldmouth','love@remus.dti.ne.jp','Masaharu Noguchi','2-73-3 Higashionari','Saitama City','Saitama','JAPAN','331-0814','(048)663-3139','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 04:46:59',0,NULL,3,1,3,1,NULL,'肩架  1 \rRR843877769CN\r'),(5167,661530424002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','fugenie','fugenie@gmail.com','Eiji Iwakawa','3-30-14, CoreCity Nakano Sakaue 702<br>Honcho, Nakano-ku','Tokyo','Tokyo','JAPAN','164-0012','0351566986','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 05:31:31',0,NULL,3,1,2,1,NULL,'c型夹   1 '),(5169,661533730002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','jmil5514','miller.j914@yahoo.com','joshua miller','1498 BOX CIRCLE','winder','GA','UNITED STATES','30680','(404) 839-7036','NoPaymentFailure','CheckoutComplete','Other','2011-01-20 05:50:34',0,NULL,3,1,3,1,NULL,'肩架  1 \rRR843877857CN\r'),(5171,621977422001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',171.9,'hermeshine','kittynlucy','samieami@uqconnect.net','Samantha Whittaker','5 Henry Court','Glasshouse Mountains','Queensland','AUSTRALIA','4518','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 07:19:32',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r双灯头 澳标  2\r反光伞  2\r包  1\r背景架 2m （ 白 黑 绿）  1\rlighting kit  $30\rYW864489714CN\r\r '),(5172,621988440001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','ulti1980','pavel.marintsev@gmail.com','pavel marintsev','26 mkr., dom 2, kv.82','aktau','','KAZAKHSTAN','130000','+77013042266','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 07:19:57',0,NULL,3,1,5,1,NULL,'背景架 （ 白）  2m  1\r布是1.6x3m的\r2m 灯架  2\r50-70 棚欧标  2\r115w 220v   2\r包   1\r CP219487673CN\r'),(5173,661552182002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ad_riano','adrianotorii@hotmail.com','Adriano Leite','Av. 11 de Junho, 875<br>(apto 122)','São Paulo','São Paulo','BRAZIL','04041-053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 08:03:34',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5174,722032837015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','ninjastyle.7930','natachiavecsi@hotmail.co.uk','Natachia Vecsi','6 Greenacre Close','Herne Bay','Kent','UNITED KINGDOM','CT6 7EP','07930390322','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-20 08:43:23',0,NULL,3,1,4,1,NULL,'背景架（ 白， 黑 ，灰） 2m   1 \rbackground support\r $22\rYW864489294CN\r'),(5175,661558684002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','qwq1122','zxxb111@gmail.com','mansour albuainasn','Bulding 8448 , Unit 1<br>3886-35514','jubail','','SAUDI ARABIA','35514','+966505903606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 08:44:05',0,NULL,5,1,18,0,NULL,'== '),(5176,622004300001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','paradoo','chipie_md@hotmail.com','Panuwat  Triwatcharaporn','17     Dej-udom  Rd.<br>Naimueng  sub-district.','Mueng','Nakornrachasima','THAILAND','30000','(+66)44255834','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 09:02:00',0,NULL,3,1,2,1,NULL,NULL),(5177,722041864015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','greeceathens','6972999050@mycosmos.gr','GEORGE STRATOS','3 SOURI STREET-EUROBANK Syntagma','ATHENS','','GREECE','10557','306972999050','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-20 09:26:11',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r云台   1\r柔光伞   1 RR843876255CN\r'),(5178,661567666002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','iereminciucc','iereminciuc_catalin@yahoo.com','Ignat Vladimir','B-dul. I.C. Bratianu, NR. 61C, Bl. MA4, Sc. B, Et.2, Ap.25','Constanta','Constanta','ROMANIA','900247','0040722679517','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 09:47:36',0,NULL,3,1,2,1,NULL,NULL),(5179,661578988002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',19.9,'hermeshine','linaboard78','linarellomarco@tiscali.it','marco linarello','via barengo, 1','agnellengo di momo','NO','ITALY','28015','3938929816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 10:34:23',0,NULL,3,1,2,1,NULL,'b座   2 '),(5180,661586666002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 11:08:47',0,NULL,3,1,3,1,NULL,'反光板支架  1\r2m灯架  1 RR843876180CN\r'),(5181,661591973002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','belia74','debeli74@hotmail.com','Carlos Daniel Cejas Rodero','Pablo Picasso 2 dto 9<br>Pablo Picasso 2 dto 9','Caleta de Fuste - Antigua','Canarias','SPAIN','35610','','NoPaymentFailure','CheckoutIncomplete','OtherInternational','0000-00-00 00:00:00',0,NULL,8,1,17,0,NULL,''),(5182,622036727001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',52.99,'hermeshine','rusty270173','rusty_sandy1@bigpond.com','Russell Brigg','48 Cobb St Nth','Murgon','Queensland','AUSTRALIA','4605','0741683773','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-20 11:48:17',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r云天  1\r柔光伞   1 RR843876193CN\r'),(5183,622048021001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','belia74','debeli74@hotmail.com','Carlos Daniel Cejas Rodero','Pablo Picasso 2 dto 9<br>Pablo Picasso 2 dto 9','Caleta de Fuste - Antigua','Canarias','SPAIN','35610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 12:35:50',0,NULL,3,1,4,1,NULL,'2m 灯架  1\rb座  1\r柔光伞    1 \r2m x3m 背景架   1 \rlighting kit  $25\rYW864489703CN\r'),(5184,661602738002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','helperi','seppo.helpio@iki.fi','Seppo Helpiö','Salomaantie 5 H 57','Valkeakoski','Pirkanmaa','FINLAND','37630','0400632565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 12:23:37',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座  1\r柔光伞   1 RR843876202CN\r'),(5185,661610155002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',8,'AA1310',43.92,'hermeshine','fulviopp74','fulviopp@gmail.com','FULVIO PARMEJJANI','RUA HERMETO GUILHERME, 35<br>PQ XANGRILA','CAMPINAS','SP','BRAZIL','13098604','551932570422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 13:18:14',0,NULL,3,1,3,1,NULL,'lenspen  8 RR843876278CN\r'),(5186,707979111016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','fsmsteve','allwrights@hotmail.co.uk','stephen allwright','23 Vicarage close','Langford','Bedfordshire','UNITED KINGDOM','SG18 9QS','01462700767','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 15:33:03',0,NULL,3,1,2,1,NULL,''),(5187,722149533015,250599421678,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'AA1303',1.88,'hutongstore','bernard0368','bernard0368@yahoo.ie','Bernard Roche','25 Belfry Square City West','Dublin ','Dublin','IRELAND','d24','0868547474','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-20 15:43:32',0,NULL,3,1,2,1,NULL,NULL),(5188,622105843001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','aircruiser1','justin.le@iinet.net.au','Justin Le','UNIT 1, 38 TENNANT ST<br>WELSHPOOL','PERTH','Western Australia','AUSTRALIA','6106','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 16:10:27',0,NULL,3,1,3,1,NULL,'2m 灯架  1 RR843876304CN\r'),(5189,622108549001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','zgman77','zgerman@live.com','Zoltan German','1122 Pierce Ave<br>Fl 2','Bronx','NY','UNITED STATES','10461-1525','(646) 350-5736','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 16:17:25',0,NULL,3,1,1,1,NULL,'\r'),(5190,661551963002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',71.9,'hermeshine','ladybugie*','lu.desousa@gmail.com','Luciana de Sousa','Rua São Clemente 10, ap. 409, Botafogo','Rio de Janeiro','RJ','BRAZIL','22260-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 16:28:51',0,NULL,3,1,5,1,NULL,'红头灯  1   800  110  6 \rCP219487660CN\r'),(5191,622134614001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','shaharstroh','shaharstroh@gmail.com','Shahar Stroh','45 Hicks St<br>Basement Level','Brooklyn','NY','UNITED STATES','11201','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 17:30:47',0,NULL,3,1,1,1,NULL,'\r'),(5192,661695425002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','busterml2010','matthijs@liethof.net','Matthijs Liethof','Horizon 32','ELST GLD','','NETHERLANDS','6661PA','0651088990','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r斜臂   1\r50-70 棚    1 \rEE442466426CN\r'),(5194,622163588001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','janaka44','janaka44@gmail.com','JANAKA PEIRIS','IFS R&D INTERNATIONAL<br>501, GALLE ROAD','COLOMBO-6','','SRI LANKA','00600','94727855424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 18:42:35',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5195,661750208002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','erin5296','erin.conley@yahoo.ca','erin','11 beach drive','furry creek','BC','CANADA','v0n3z1','(604) 880-8244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 19:42:03',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5196,622197860001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mo_tord','tord_cj@hotmail.com','Christer Johansson','Saltfjellveien 28','Mo i Rana','Rana','NORWAY','8613','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 19:57:14',0,NULL,3,1,3,1,NULL,'反光板支架   1 RR843876162CN\r'),(5197,661760877002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','coppernico','peace4pr@yahoo.com','Jaime Ruiz','PMB 162 - Box 80,000','Isabela','PR','UNITED STATES','00662','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 20:05:15',0,NULL,3,1,1,1,NULL,'小号内胆包 canon  1 '),(5198,661787387002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','oshten','o_s_h@list.ru','Sergey Skritskiy','Pionerskaya st. 379/2-98<br>Republic Adygea','Maykop','RU','RUSSIAN FEDERATION','385011','79094711069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 21:03:37',0,NULL,3,1,2,1,NULL,'麂皮  2 '),(5199,661784444002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','sercan.akar','sercanakar@hotmail.com','Sercan Akar','Mesrutiyet Mah. Ruzgarlimese Cami alti<br>Ugur Market','Zonguldak','Merkez','TURKEY','67030','(372) 253 - 5679','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 21:15:08',0,NULL,3,1,2,1,NULL,'canon 三角包   1 '),(5200,708166733016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','pennyblackcat','ianandrew.perry@ntlworld.com','Ian A Perry','90 Smithies Moor Lane','Batley','West Yorkshire','UNITED KINGDOM','WF17 9AN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 21:44:05',0,NULL,3,1,2,1,NULL,NULL),(5201,661802010002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','omnialx','alexcahiz+ebay@gmail.com','Alexander Cahiz','18 Alcott St<br>Apt 1','Allston','MA','UNITED STATES','02134-1420','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-20 21:54:44',0,NULL,3,1,1,1,NULL,'c型夹   2 '),(5202,708179435016,260660053110,'New IR Remote Control for Pentax K10D K20D K200D',1,'AA2205',2.75,'hutongstore','frankdthebruce','fdpatton@hotmail.com','frank patton','206 burnfield road','glasgow','Glasgow (City of)','UNITED KINGDOM','g43 1eb','07873339907','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 22:09:44',0,NULL,3,1,2,1,NULL,'红外5in1  1 '),(5203,622259310001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','slerberonline','slerber@online.no','Steinar Lerberg','Ørretveien 8<br>3322','Darbu','Buskerud','NORWAY','3322','95222367','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 22:17:57',0,NULL,3,1,3,1,NULL,'nikon 原装背心 xl   1 RR843876128CN\r'),(5204,722361045015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','cristinarosianu','cristina_rosianu@yahoo.com','Cristina Rosianu','16 Canterbury Road','Watford','Hertfordshire','UNITED KINGDOM','WD171QT','07583117798','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 22:23:41',0,NULL,3,1,2,1,NULL,'45w  2 '),(5205,661827450002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','sermiloumax','sergelambert100@videotron.ca','Serge Lambert','3010 Cousineau','Montréal','QC','CANADA','H4K1P2','(514) 334-5356','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'新款黑色厚的背心 无字的 xxxl   1 RR843876247CN\r'),(5207,661830277002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','pboom','pverboom@ns.sympatico.ca','Paul Verboom','3237 Connolly Steet','Halifax','NS','CANADA','B3L 3P6','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 22:58:47',0,NULL,5,1,18,0,NULL,NULL),(5208,661831583002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','surachaij','jiddey@hotmail.com','Surachai Jiwapibantanakit','46 Florence St','nutley','NJ','UNITED STATES','07110','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 23:04:16',0,NULL,3,1,1,1,NULL,NULL),(5209,708207910016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','housefromhell2010','jony212@live.co.uk','Christine stephens','6 coker way','chard','Somerset','UNITED KINGDOM','ta20 1bf','0146062907','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 23:22:47',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(5210,661838660002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','kilar73','ksoth2000@gmail.com','Félix Rodríguez Garrucho','C/ Los Toros, 18','Espera (Cádiz)','Andalucía Ceuta y Melilla','SPAIN','11648','689853581','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 23:29:07',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864489692CN\r'),(5212,661841816002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','gtrblitz','pan.allen@gmail.com','Wei-Feng Chuang','88 Grandview Way. Apt 901','North York','ON','CANADA','M2N6V6','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 23:37:48',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876295CN\r'),(5213,708213995016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',5.9,'hutongstore','fraxinus256','ian.thompson01@gmail.com','Ian Thompson','9 Bramley Court Kelsall','Tarporley','Cheshire','UNITED KINGDOM','CW6 0RF','07798838308','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 23:40:56',0,NULL,3,1,2,1,NULL,'大力夹  1 '),(5214,661843386002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','lechuck_spain','cjimeno@gmail.com','Carlos Jimeno Jiménez','C/ Tembleque 134, 7º A','Madrid','Madrid','SPAIN','28024','649133137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 23:47:14',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843876233CN\r'),(5215,622287979001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','hey_danny','danzekevideo@yahoo.com','Dan Mizicko','1821 Sodom Hutchings Rd NE','Vienna','OH','UNITED STATES','44473-9724','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 23:56:11',0,NULL,3,1,1,1,NULL,NULL),(5216,661850147002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','igasparini','alfonsojtr@bol.com.br','Ineli A. Gasparini','Rua Dr. Goulart Penteado, 85 - Apto. 72 - Vl. Diva','Sao Paulo','SP','BRAZIL','03351090','551126717542','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 00:11:20',0,NULL,3,1,3,1,NULL,'斜臂  1 RR843876216CN\r\r'),(5217,661852016002,120601700210,' New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',30.9,'hermeshine','igasparini','alfonsojtr@bol.com.br','Ineli A. Gasparini','Rua Dr. Goulart Penteado, 85 - Apto. 72 - Vl. Diva','Sao Paulo','SP','BRAZIL','03351090','551126717542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 00:17:05',0,NULL,3,1,3,1,NULL,'桌面灯  1 RR843876114CN\r'),(5218,661862439002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','orenjuz','vintageversion@yahoo.com','SK Indra Rukmana','Jl. Kopo Bihbul Km 6.5 No. 20/18','Bandung','West Java','INDONESIA','40225','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 00:59:03',0,NULL,3,1,3,1,NULL,'2m 灯架   1\r反光板支架   1 RR843876220CN\r'),(5219,622306146001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11,'hermeshine','maxs212','maxs212@013.net.il','Maxim Shevtsov','Eilat 26/3','Holon','','ISRAEL','58309','(972) 544750774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 01:10:38',0,NULL,3,1,3,1,NULL,'lenspen\r2 RR843876264CN\r'),(5220,661868427002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','armin0889','yaboyice01@yahoo.com','Armin Alic','226 Oakwood Dr','Casselberry','FL','UNITED STATES','32707','(407) 462-3885','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 01:23:49',0,NULL,3,1,1,1,NULL,'lenspen  1 '),(5221,722424427015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3311',5.2,'hutongstore','drrobe','robert.kos@gmail.com','Robert Kos','Polanskova 3','Ljubljana','','SLOVENIA','1000','+38631210765','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 01:38:59',0,NULL,3,1,2,1,NULL,'62mm 渐变灰  1 '),(5222,622316770001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','fredy_declercq','fredy_declercq@uol.com.br','Frederic Declercq','Rua Doutor José Gustavo Bush 155<br>apart.: 101-A  bairro:Morumbi','São Paulo','SP','BRAZIL','05705-190','+55-11-96257763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 01:54:04',0,NULL,3,1,2,1,NULL,'72mm 橡胶罩   1 '),(5224,722435067015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','mikeyb999','mikeyb8999@yahoo.com','Michael Bradley','3 Dunsuvinish Drive','Portstewart','Londonderry','UNITED KINGDOM','BT557EW','02870836704','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-21 02:07:35',0,NULL,3,1,4,1,NULL,'背景架 （ 白 黑） 2m   1\rYW864489681CN\r '),(5225,622320659001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','xyren_poh','jenner.alagao@gmail.com','Jenner Alagao','49-D Nueva Ecija St.<br>Bago Bantay, Quezon City','Quezon City','Metro Manila','PHILIPPINES','1105','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 02:09:46',0,NULL,3,1,2,1,NULL,'52mm 渐变灰  1 '),(5227,661891435002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','niteskie','jweedop@gmail.com','Jade Weedop','756 E 60 S','American Fork','UT','UNITED STATES','84003-2247','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-21 02:53:57',0,NULL,3,1,1,1,NULL,'c型夹   1 '),(5228,707927422016,260660050674,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',16.99,'hutongstore','liboltoc','thibault.dentel@caboche.fr','Thibault Dentel','La Grateliere','Saint Pierre du Chemin','Pays de la Loire','FRANCE','85120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-20 12:59:38',0,NULL,3,1,2,1,NULL,'717 手柄  1 '),(5229,661903226002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','crowtalks','jim@jimbussell.net','james bussell','365 doe creek loop','sparta','TN','UNITED STATES','38583','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 03:43:44',0,NULL,3,1,1,1,NULL,NULL),(5230,661907339002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','lpknight','lpkni@yahoo.com','LOUIS KNIGHT','403 Hilltop Rd','GLENNVILLE','GA','UNITED STATES','30427','(912) 654-4243','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 04:04:24',0,NULL,3,1,1,1,NULL,'lenspen   1 '),(5231,661905422002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 04:10:34',0,NULL,8,1,17,0,NULL,NULL),(5232,661908754002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 04:14:18',0,NULL,3,1,1,1,NULL,NULL),(5233,622349850001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','bandeparker2010','bandeparker@telus.net','Brian Parker','165 McTavish Cresent','Fort McMurray','AB','CANADA','T9K 2N9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 04:26:30',0,NULL,3,1,3,1,NULL,'2m 灯架  1 RR843876410CN\r'),(5235,622355818001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','pachunino','chichogonzalez@gmail.com','ariel gonzalez','zeballos 5451','avellaneda','buenos aires','ARGENTINA','1875','42068337','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 05:03:36',0,NULL,3,1,3,1,NULL,'2m 灯架 红盒  1 RR843876508CN\r'),(5236,661920504002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','blumelus','blumelus@yahoo.com','Melanie Leandro','1190 28th st','oakland','CA','UNITED STATES','94608-4442','(786) 395-2155','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-21 05:20:46',0,NULL,3,1,1,1,NULL,'canon 三角包 1 '),(5237,622363401001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','lozhkinsn','lozhkin@mail.ru','SERGEY LOZHKIN','STEPANA KUVYKINA ST<br>BLDG 11/2, 19','UFA','BASHKORTOSTAN','RUSSIAN FEDERATION','450103','+79050000004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 05:56:38',0,NULL,3,1,2,1,NULL,'大号灰卡  1 '),(5238,622369307001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',4,'AE1302',39.2,'hermeshine','sifiszach','zackouria@gmail.com','Zacharias Andreadakis','Profiti Ilia 7','Chania','Chalepa','GREECE','73133','0030-6947891285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 06:36:23',0,NULL,3,1,3,1,NULL,'单灯头  欧标  4 RR843876423CN'),(5239,661931427002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',2,'AA2217',17.96,'hermeshine','yanis_novikov','gespenst@inbox.ru','Yanis Novikov','Pantusovskaya,80','Kostroma','kostroma','RUSSIAN FEDERATION','156011','(915) 922-8596','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 06:37:29',0,NULL,3,1,2,1,NULL,'小号灰卡  2 '),(5240,622369847001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','theartharindra','harindra.art@gmail.com','Harindra Nishshanka','30/1, Godellawaththa,<br>Mahawila','Panadura','Western','SRI LANKA','12500','0094773040696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 06:40:30',0,NULL,8,1,17,0,NULL,' '),(5241,622367313001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','fred97127','fpasbeau@gmail.com','Frederic PASBEAU','73 rue des maraichers','PARIS','Île-de-France','FRANCE','75020','06 15 11 72 82','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 06:40:50',0,NULL,3,1,4,1,NULL,'tripod $22 \rYW864489670CN\r'),(5242,622370434001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','theartharindra','harindra.art@gmail.com','Harindra Nishshanka','30/1, Godellawaththa,<br>Mahawila','Panadura','Western','SRI LANKA','12500','0094773040696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 06:44:34',0,NULL,3,1,2,1,NULL,'58mm  uv   1\r58mm 橡胶罩  1 '),(5243,622389865001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','nestand','nest_and@mail.ru','Andrey Nesterenko','Konstitucii Str. h.9 of.61','Krasnoyarsk','','RUSSIAN FEDERATION','660049','89029425450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 08:45:50',0,NULL,3,1,2,1,NULL,NULL),(5244,722420418015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',180.3,'hutongstore','kidsplanet24','contact1@kidsplanet24.com','MJmark Ltd.','17 Kestrel Road','Hereford','Herefordshire','UNITED KINGDOM','HR2 7TN','07815179574','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 09:37:13',0,NULL,3,1,4,1,NULL,'2m x3m 背景架  1\r3mx6m 绿色背景布  1\r2m 灯架  2\r50-70 棚 英标  2\r115w 220v  2\r包  1\r一转四灯头   2 \rlighting kit  $30\rYW864489773CN\r'),(5245,622400476001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','sir_pashka','sir.pashka@gmail.com','Pavel Laptev','pr. Stroiteley 98-132','Penza','Penza region','RUSSIAN FEDERATION','440071','89022046293','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 09:43:32',0,NULL,3,1,2,1,NULL,NULL),(5247,722540974015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',3,'AA3308',10.14,'hutongstore','sookonn','indrek.polakes@mail.ee','Indrek Polakes','Kärberi 52-11','Tallinn','Harjumaa','ESTONIA','13919','56453066','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 09:59:48',0,NULL,3,1,2,1,NULL,NULL),(5248,622405253001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','yiannists','tsounet@yahoo.com','Ioannis tsouratzis','Davaki 9<br>Alimos','Athens','','GREECE','17455','6937977698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 10:04:41',0,NULL,3,1,2,1,NULL,'45   2 '),(5249,722545682015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.49,'hutongstore','kostaschatzoglou','kchatzoglou@gmail.com','Kostas Chatzoglou','Aristotelous 4 ','Agios Athanasios Thessaloniki','προεπιλογή','GREECE','57003','030 6974370745','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 10:17:31',0,NULL,3,1,2,1,NULL,'大号灰卡   1 '),(5250,622412167001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','karsimodo','marcel.kars@gmail.com','Marcel Kars','Moddermanstraat 26','Leiden','','NETHERLANDS','2313GR','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 10:36:44',0,NULL,3,1,3,1,NULL,'摄影背心  nikon  xxl  1\r老款 黑色 RR843874776CN\r'),(5251,661974662002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','compramc','mario.chorolqui@gmail.com','Mario Chorolqui','Marcos Sastre<br>5630','Ciudad de Buenos Aires','Buenos Aires','ARGENTINA','1408','+541131281161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 10:41:32',0,NULL,3,1,2,1,NULL,'50cm 棚  1 '),(5252,622411827001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','pinballwizard4who','kendyberaldo@yahoo.com.br','Kendy Beraldo','Rua Afonso de Freitas, 350 apto 21','Sao Paulo','Sao Paulo','BRAZIL','04006-905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 10:53:06',0,NULL,8,1,17,0,NULL,''),(5253,661974608002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','pinballwizard4who','kendyberaldo@yahoo.com.br','Kendy Beraldo','Rua Afonso de Freitas, 350 apto 21','Sao Paulo','Sao Paulo','BRAZIL','04006-905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 10:53:07',0,NULL,3,1,2,1,NULL,'倒影板   1 \r58mm canon 镜头盖  2 '),(5254,722556464015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3311',5.2,'hutongstore','howarda2005','howard.allum@orange.fr','howard allum','4 Rue du Patis','la roche bernard','Bretagne','FRANCE','56130','02 23 10 18 56','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 10:57:24',0,NULL,3,1,2,1,NULL,'62mm 渐变灰  1 '),(5255,622417413001,110583709805,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',25,'hermeshine','indexofvoid','voidindex@gmx.at','Andreas Danzer','Fichtnergasse 12','Wien','','AUSTRIA','1130','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 10:59:53',0,NULL,3,1,3,1,NULL,'58mm CPL+ND8+Macro+4 +Gradual grey+filter case \rRR843875290CN\r'),(5257,708377420016,260660054646,'Wireless Remote Control Cord for Canon 50D/40D/ 5D 5DII',1,'AA3210',11.47,'hutongstore','neilscott100','neilscott@jntservicios.com','Neil Scott','Calle Venus 21, Las Colinas Nord','Olivella','Barcelona','SPAIN','08818','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 11:11:14',0,NULL,3,1,2,1,NULL,'爵影无线c3  1 '),(5258,622429754001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','stephane_rp_91','slesmond@free.fr','Stéphane Lesmond','7, allée Cézanne','Les Ulis','Ile de France','FRANCE','91940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 11:55:56',0,NULL,3,1,2,1,NULL,'大力夹 球台  1 '),(5259,661992136002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','glauco.stephan','glstephan@gmail.com','Glauco Stephan','Charles Astor, 247','Sao Paulo','Sao Paulo','BRAZIL','04118050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 12:01:38',0,NULL,3,1,2,1,NULL,NULL),(5260,722574382015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',5.5,'hutongstore','cragonator','cragonator@hotmail.com','Craig Harris','60 Canterbury Way','Exmouth','Devon','UNITED KINGDOM','EX8 5QQ','01395273727','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 12:02:12',0,NULL,3,1,2,1,NULL,'中号内胆包  canon  1 '),(5261,661992889002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',3,'AO0034',27,'hermeshine','rdvru','r-dimka@mail.ru','Dima Rebrov','Simonovskiy val 7-1-86','Moscow','Russia','RUSSIAN FEDERATION','109044','+79266298181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 12:05:02',0,NULL,3,1,3,1,NULL,'canon 三角包  2 RR843876763CN\r'),(5262,622441681001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','0572marcel61','m.vaanhold@ziggo.nl','Marcel Vaanhold','twickel 61','raalte','','NETHERLANDS','8103 HJ','0572-357187','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 12:51:48',0,NULL,3,1,3,1,NULL,'摄影背心  绿色 薄  nikon  xxxl  1 RR843876785CN\r'),(5263,722591848015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','tyrone1854','digital.photography@ntlworld.com','Tyrone Williams','Top Flat 30 Tydraw Street','Port Talbot','Neath Port Talbot','UNITED KINGDOM','SA13 1BT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 12:59:08',0,NULL,3,1,2,1,NULL,NULL),(5264,622448824001,110464610859,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',5.6,'hermeshine','administratsia','kumi51@yandex.ru','Evgeny Frolov','Zelionaya st. 29','Kurganinsk','Krasnodarsky kray','RUSSIAN FEDERATION','352430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 13:14:14',0,NULL,3,1,2,1,NULL,NULL),(5265,708414422016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','pawelgro','variatiadelecta@wp.pl','Pawel Grochola','1 Frederick House Woodthorpe Road','Ashford','Surrey','UNITED KINGDOM','TW15 2SA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 13:18:33',0,NULL,8,1,17,1,NULL,''),(5266,722599164015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','pawelgro','variatiadelecta@wp.pl','Pawel Grochola','1 Frederick House Woodthorpe Road','Ashford','Surrey','UNITED KINGDOM','TW15 2SA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 13:20:57',0,NULL,3,1,3,1,NULL,'一转四灯头  1 \r1.6x3m 蓝色背景布  1 \rRR843875255CN\r'),(5267,722601083015,250599932668,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'AKT006',41,'hutongstore','poblitto','sedo@isand.sk','Pro Building Development / Pavol Sedo','Venturska 16','Bratislava','','SLOVAK REPUBLIC','81101','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 13:32:03',0,NULL,3,1,3,1,NULL,'天涯10片装 + 72mm 环架  1 \r优永佳  re-a  c3   1 RR843874847CN'),(5269,722605852015,250692240149,'Remote Control Cord For Canon 5D Mark II 50D 40D RS-80N',1,'AA2219',2.89,'hutongstore','poblitto','sedo@isand.sk','Pro Building Development / Pavol Sedo','Venturska 16','Bratislava','','SLOVAK REPUBLIC','81101','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 13:44:22',0,NULL,8,1,17,0,NULL,''),(5271,622464621001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','wortango','wortango@aol.com','BRIAN WORMAN','43 MEADOW DRIVE,  BISCOVEY','PAR','Cornwall','UNITED KINGDOM','PL24 2HL','01726812368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 14:12:58',0,NULL,3,1,2,1,NULL,NULL),(5272,622474461001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','fotosforo','pablosannazzaro@hotmail.com','pablo sebastian sannazzaro fernandez','la peña 80 traspando','siero','Asturias','SPAIN','33518','637168968','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 14:46:27',0,NULL,3,1,2,1,NULL,'单灯头 欧标  1 '),(5273,622496158001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 15:52:00',0,NULL,8,1,17,0,NULL,NULL),(5274,622493069001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 15:52:01',0,NULL,3,1,1,1,NULL,'52mm 橡胶罩   2 \r58mm 镜头盖 canon  1'),(5275,622514201001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','n0_exit','lene-@bk.ru','Elena Prosolupova','Akademika Anokhina<br>463 kv.13','Moscow','','RUSSIAN FEDERATION','119571','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 16:42:35',0,NULL,3,1,2,1,NULL,NULL),(5276,620918658001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',32.97,'hermeshine','mougios1983','1983mougios@gmail.com','Antonis Hadjinicolaou','Stimfalidon 1A','Larnaca','Larnaca','CYPRUS','6046','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 16:50:56',0,NULL,3,1,3,1,NULL,'1.6x2.1 背景布  3\r白色， 黑色， 蓝色   RR843876661CN\r\r'),(5277,622521834001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','2009darko2009','dhero@koncarsp.hr','Darko HERO','Davorina Bazjanca3A','ZAGREB','','CROATIA','1000','0038513836809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 17:14:22',0,NULL,3,1,2,1,NULL,NULL),(5278,662097596002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','drakenman','donyeager@gmail.com','Don Yeager','2153 Aberdeen Cir','Murfreesboro','TN','UNITED STATES','37130','(615) 473-6242','NoPaymentFailure','CheckoutComplete','Other','2011-01-21 17:40:47',0,NULL,3,1,1,1,NULL,'sf18 for nikon （ sb800）  1 '),(5279,622524367001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','xlorke','dariuzas@gmail.com','Darius Zvirzdinas','Debreceno st. 90-14','Klaipeda','','LITHUANIA','LT-94156','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 17:57:15',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876692CN\r'),(5280,662109658002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ejamga','erica.goya@gmail.com','Erica','Tres Arroyos 2964 7°C','Ciudad de Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1416','45826554','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 18:13:30',0,NULL,3,1,2,1,NULL,NULL),(5281,622443615001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','gasnur','gasnur@aol.com','Ralph','531 Valley Rd','Oxford','NJ','UNITED STATES','07863-3359','','NoPaymentFailure','CheckoutComplete','Other','2011-01-21 18:21:57',0,NULL,3,1,1,1,NULL,'摄影背心 nikon  xl   1\r老款 黑色 厚   '),(5283,622565330001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','pavlinbl4','x79046309437@gmail.com','Evgeniy Pavlenko','Narodnogo Opolchenija 141 - 70','St.Petersburg','','RUSSIAN FEDERATION','198217','7533440','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 18:46:05',0,NULL,3,1,3,1,NULL,'肩架   1 RR843876689CN\r'),(5284,708562542016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','bickyz','abudhathoki@gmail.com','Bicky','University Tutorial College 12 Friar Street','Reading','Berkshire','UNITED KINGDOM','RG1 1DB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 19:05:14',0,NULL,3,1,2,1,NULL,NULL),(5285,622575621001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','photoengineering','clementhun@gmail.com','Clement Hun','530/ 20 Montague Road','South Brisbane','Queensland','AUSTRALIA','4101','0433898990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 19:08:51',0,NULL,3,1,2,1,NULL,'大力夹  球体  1 '),(5286,662138533002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','jagonik','jagogalpin@hotmail.com','Juan Antonio Ortega','Micaela Aramburu,4','El Puerto de Santa Maria','Andalucía Ceuta y Melilla','SPAIN','11500','956853328','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 19:15:06',0,NULL,3,1,2,1,NULL,'柔光伞  1 '),(5287,622597542001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tomsnetwork','tomi.jelic@gmail.com','Tomislav Jelic','J.J. Strossmayera 51','Bosnjaci','Croatia (Hrvatska)','CROATIA','32275','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 19:58:14',0,NULL,8,1,17,0,NULL,NULL),(5288,622598595001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tomsnetwork','tomi.jelic@gmail.com','Tomislav Jelic','J.J. Strossmayera 51','Bosnjaci','Croatia (Hrvatska)','CROATIA','32275','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 20:00:09',0,NULL,3,1,2,1,NULL,'55mm 橡胶罩   2 '),(5289,662159492002,120601698256,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','rhayton','richhayton@me.com','Richard Hayton','Unit 1d<br>23 Emily Place','Auckland','North Island','NEW ZEALAND','1010','0064 9 5736567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 20:02:03',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(5291,622611716001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','pantux','artshea61@yahoo.com','Arthur Shea','Box 336','Boyle','AB','CANADA','T0A 0M0','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 20:31:08',0,NULL,3,1,3,1,NULL,'摄影背心 nikon xxxl   1\r老款 黑色 厚    RR843876729CN\r'),(5293,722811570015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.99,'hutongstore','bvladov','boyan.vladov@itrade.bg','Boyan Vladov','Apostol Karamitev Str. 2, Entr. V, fl.2, ap.3','Sofia','Bulgaria','BULGARIA','1172','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 20:54:05',0,NULL,3,1,2,1,NULL,'3pcs 滤镜袋  1 '),(5294,662182572002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','pepepotamo64','marcovadanero@gmail.com','Marco Varela Adanero','Pablo Iglesias 57','Gijón','Asturias','SPAIN','33205','985130752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 20:56:58',0,NULL,3,1,2,1,NULL,'40cm 棚  1 '),(5296,662192342002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','lgmus','lgmkin@gmail.com','Nikita Mikhalkov','17/10/18, Otkritoe shosse','Moscow','','RUSSIAN FEDERATION','107143','79265684211','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 21:19:50',0,NULL,3,1,2,1,NULL,'50cm 棚  1 '),(5298,722844959015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','bartlondyn','bartlondyn@o2.pl','Daria Szwarc','Studio 3.4 50 Carnwath Road','London','London','UNITED KINGDOM','SW6 3EG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 22:02:52',0,NULL,3,1,2,1,NULL,NULL),(5299,662214601002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lsteacherls','lwreggitt@mts.net','Laureen M Wreggitt','16 Egerton Rd','Winnipeg','MB','CANADA','R2M 2V5','(204) 231-0759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 22:20:04',0,NULL,3,1,2,1,NULL,NULL),(5301,662234487002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rebyun','rebyun1@yahoo.com','Rob Byun','777 Via Colinas','Westlake Village','CA','UNITED STATES','91362-5043','(805) 990-5415','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 23:22:57',0,NULL,3,1,1,1,NULL,NULL),(5302,622676741001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','nachet70','ncabanes@gmail.com','José Ignacio Cabanes','C/ Lillo Juan, 104, 4 B','San Vicente del Raspeig (Alicante)','Comunidad Valenciana','SPAIN','03690','649242223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 23:37:44',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1 '),(5304,662254298002,120601698793,'Canon 58mm Reverse Adapter 50mm 1.4 40D 7D 5DII Macro',1,'AA1208',4.4,'hermeshine','lav1105','velez_68@yahoo.com','LUIS VELEZ','PO Box 1166','SAN SEBASTIAN','PR','UNITED STATES','00685','(787) 429-0661','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 00:40:33',0,NULL,8,1,17,0,NULL,NULL),(5305,662254469002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lav1105','velez_68@yahoo.com','LUIS VELEZ','PO Box 1166','SAN SEBASTIAN','PR','UNITED STATES','00685','(787) 429-0661','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 00:40:32',0,NULL,3,1,1,1,NULL,'canon -58mm 反接环  1\r58mm canon 镜头盖  1 '),(5306,662269855002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','8e-chen8','felix.erner@gmail.com','Felix Erner','5300 W Baseline Rd<br>Apt 148','Hillsboro','OR','UNITED STATES','97123-6415','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-22 01:51:26',0,NULL,3,1,1,1,NULL,'58mm 渐变灰  1 '),(5307,622731733001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','namipasa','myjunkdownloads@gmail.com','Nate Larson','41303 N Palm Springs Trl','San Tan Valley','AZ','UNITED STATES','85140-4236','(602) 694-6873','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 03:54:06',0,NULL,3,1,1,1,NULL,NULL),(5308,622734842001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','lion14615','macdang73@gmail.com','Hoang Dang','2190 Glenridge Rd','EUCLID','OH','UNITED STATES','44117','(216) 692-2106','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 04:18:06',0,NULL,3,1,1,1,NULL,NULL),(5309,622737789001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','ennaialan','zmyjewel@yahoo.com','Romeo Alan','171B Edgedale Plains #09-448','default','','SINGAPORE','822171','6585188889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 04:34:51',0,NULL,3,1,11,1,NULL,'canon-58mm 反接环  1 '),(5311,722989143015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','rojinbahrain','rojlambert@hotmail.com','ROGER F LAMBERT','61 THE MEADOWS','SEDGEFIELD','Co DURHAM','UNITED KINGDOM','TS212DW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 07:36:47',0,NULL,3,1,2,1,NULL,'45w  2 '),(5312,662345794002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','kn_wa','kam@kamplaza.com','Kam Ngai','2 Coogee Street','Mount Hawthorn','Western Australia','AUSTRALIA','6016','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 09:14:16',0,NULL,3,1,4,1,NULL,'2m 灯架 1\r反光板支架  1 \rYW864489762CN\r'),(5313,661977491002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','xylocain','gr_lim@web.de','Ingenieurbüro Pickel','Herbsttal 2','Happurg','','GERMANY','91230','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 09:46:14',0,NULL,8,1,17,0,NULL,NULL),(5315,622416012001,110534332881,'CTR-301P Wireless Flash Trigger 2 Receiver SB800 580EX',1,'AKT001',41.9,'hermeshine','xylocain','gr_lim@web.de','Ingenieurbüro Pickel','Herbsttal 2','Happurg','','GERMANY','91230','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 09:48:19',0,NULL,3,1,3,1,NULL,'301p 一拖二  1\r50-70 塑料卡口棚  1 RR843876635CN\r'),(5317,708824437016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','johnrichs','john@do1thingwell.com','John Richards','23 Trevor Close','Hayes','Kent','UNITED KINGDOM','BR27NS','02084622713','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 09:59:41',0,NULL,3,1,2,1,NULL,NULL),(5319,662360956002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','alexandrlos','los.alexandr@gmail.com','Alexandr Los','1 Oktyabr\'skaya<br>ap. 9','Vishneviy','Kiev Region','UKRAINE','08132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 10:21:09',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5320,662370825002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','rbpai','rajasekhr@gmail.com','Rajasekhar B Pai','APT 303, Vedhas Vantage Apts, PLOT No. 204,<br>SURVEY OF INDIA SOCIETY, Near 100 Ft ROAD, MADHAPUR,','HYDERABAD','Andhra Pradesh','INDIA','500081','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 11:18:32',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5321,662383088002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','hickoryswitch2u','oleyone@gmail.com','Mr. R. E. Olsen','4794 S Route 62','Kennedy','NY','UNITED STATES','14747','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-22 11:59:51',0,NULL,3,1,1,1,NULL,'c型夹   1 '),(5322,723061187015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'AC2302',4.5,'hutongstore','sim007on','plestenjaksimon@gmail.com','Simon Plestenjak','Vrzdenec 44/B','Horjul','','SLOVENIA','1354','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-22 12:03:40',0,NULL,3,1,2,1,NULL,'小号内胆包nikon  1 '),(5323,662398613002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nueaszeb','bazsi@jelenet.info','Balázs Csapó','Winkelstrasse 6a','Sulgen','','SWITZERLAND','8583','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 12:51:17',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座  1\r柔光伞  1 RR843876613CN\r'),(5325,662407407002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','flylynx38','flylynx@gmail.com','Evgeny Kodnevskiy','Sovetskaya 124B-4','Irkutsk','Irkutskaya oblast\'','RUSSIAN FEDERATION','664047','+79149134970','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 13:17:52',0,NULL,3,1,2,1,NULL,' '),(5326,622854513001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','imrak1','viper83@bk.ru','Shaposhnikov Alexey','Botkina 5-78','Rybinsk','YAROSLAVL REGION','RUSSIAN FEDERATION','152919','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 13:46:23',0,NULL,3,1,2,1,NULL,NULL),(5328,723112450015,250615147105,'YongNuo Flash Battery Pack 8*AA for Nikon Flash SB900',1,'AB3311',32.99,'hutongstore','*sue23*','sueandarthur@googlemail.com','Arthur Garlick','in4tek ltd 20 Barrington Road','Altrincham','Cheshire','UNITED KINGDOM','WA14 1HB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 14:26:56',0,NULL,3,1,3,1,NULL,'sf18 sb900   1 RR843876817CN\r'),(5329,622868945001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','2begolfer','eglide02@yahoo.com','scott behnke','2621 Gemini Rd','green bay','wi','UNITED STATES','54311-4611','(920) 639-0045','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 14:28:59',0,NULL,3,1,1,1,NULL,'6663a 快装板  1 '),(5330,622872008001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','gregaudet','gpaudet@yahoo.com','Gregory Audet','5262 Shephard Rd','Brown City','MI','UNITED STATES','48416','(810) 837-1262','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 14:39:32',0,NULL,8,1,17,0,NULL,NULL),(5331,622875408001,110544584989,'16chan Wireless  Control Cord for Canon 40D 50D 5D 5DII',1,'AA3204',18.5,'hermeshine','gregaudet','gpaudet@yahoo.com','Gregory Audet','5262 Shephard Rd','Brown City','MI','UNITED STATES','48416','(810) 837-1262','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 14:47:52',0,NULL,3,1,1,1,NULL,'爵影无线 C3   1\r77mm 镜头盖 canon  2 '),(5332,622879637001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',5.6,'hermeshine','madbury','bobc@hopper.unh.edu','bob champoux','291 Mast road<br>Cole Hall/ Thompson School/UNH','Durham','NH','UNITED STATES','03824','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 14:59:32',0,NULL,3,1,1,1,NULL,NULL),(5334,662443682002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dorikvolodymyr','inozemtsev@ukr.net','Volodymyr Inozemtsev','7 Sechenova str., ap.3','Kyiv','','UKRAINE','03127','+380672381125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 15:07:59',0,NULL,3,1,2,1,NULL,NULL),(5339,708947284016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','woodalbert','albert.wood1@btopenworld.com','Albert Wood','14 Woodstock Court Bowesfield Crescent','Stockton on tees','Cleveland','UNITED KINGDOM','TS17 0XH','07881930902','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 15:46:45',0,NULL,3,1,2,1,NULL,'1.6x3m 背景布 白色  1 '),(5340,622898051001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','inna22088','ofizer22088@rambler.ru','Ilya Ustinov','Naberegnaya reki Ufy 71-134','Ufa','Bashkortostan','RUSSIAN FEDERATION','450105','+79177621450','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 15:57:31',0,NULL,8,1,17,0,NULL,NULL),(5342,662459752002,120601699242,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',11.34,'hermeshine','inna22088','ofizer22088@rambler.ru','Ilya Ustinov','Naberegnaya reki Ufy 71-134','Ufa','Bashkortostan','RUSSIAN FEDERATION','450105','+79177621450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 15:57:30',0,NULL,8,1,17,0,NULL,NULL),(5343,662459344002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','inna22088','ofizer22088@rambler.ru','Ilya Ustinov','Naberegnaya reki Ufy 71-134','Ufa','Bashkortostan','RUSSIAN FEDERATION','450105','+79177621450','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 15:57:30',0,NULL,3,1,5,1,NULL,'2mx3m 背景架  1\r3mx6m 绿色背景布 1\r2m 灯架  4\r50-70 棚 欧标  2\r双灯头  欧标  2\r反光伞  2\r115w 220v  2\r包  2\rNG128   1\rCP219487599CN\r\r '),(5344,622911613001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','yury1356','nerof@mail.ru','Yury Oganesov','Tuhachevskogo 3/9-45','Stavropol','','RUSSIAN FEDERATION','355040','+79624503370','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 16:23:24',0,NULL,3,1,5,1,NULL,'2mx3m背景架  1 \rCP219487608CN\r'),(5346,662459144002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','red-hot-seven','schwarz.friedrich@arcor.de','friedrich schwarz','schillerstr. 35','heuchelheim','','GERMANY','35452','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 15:51:08',0,NULL,3,1,2,1,NULL,'大力夹  1 '),(5347,662455544002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 15:39:18',0,NULL,3,1,2,1,NULL,'c型夹   1 '),(5349,662451500002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','rotel54','fam.r.hunziker@bluewin.ch','Hunziker Rolf','Tannmättli 6','Tägerig','','SWITZERLAND','5522','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 15:46:30',0,NULL,3,1,3,1,NULL,'摄影背心  canon  xl  1\r老款 RR843876905CN\r'),(5350,622933487001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','77danas','t.danas@gmail.com','Violeta Blaziene','Pasirvincio k. Sirvintu sen. 1','Sirvintos','','LITHUANIA','19129','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 17:15:56',0,NULL,3,1,2,1,NULL,'40cm 棚  1 '),(5351,723216058015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','dwynnep','dwynnepercival@msn.com','dwynne percival','108 Chaucer Road Parson Cross','Sheffield','South Yorkshire','UNITED KINGDOM','S5 9QL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 17:41:12',0,NULL,3,1,2,1,NULL,NULL),(5352,723217361015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',3.5,'hutongstore','loveccz2009','p.prichy@seznam.cz','Pavel Přichystal','hnevotinska 46','Olomouc','Olomoucky kraj','CZECH REPUBLIC','77900','723611151','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-22 17:43:15',0,NULL,8,1,17,0,NULL,NULL),(5353,723218192015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','loveccz2009','p.prichy@seznam.cz','Pavel Přichystal','hnevotinska 46','Olomouc','Olomoucky kraj','CZECH REPUBLIC','77900','723611151','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-22 17:44:39',0,NULL,3,1,2,1,NULL,'62mm cpl   1\r72mm cpl   1 '),(5354,662513163002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','zalkor72','zalkor72@hotmail.com','Jose Antonio Garcia Sosa','Pasaje Miramar del Palo, 2, 3ºA','Malaga','Malaga','SPAIN','29017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 17:52:26',0,NULL,3,1,2,1,NULL,NULL),(5355,622963117001,110544584989,'16chan Wireless  Control Cord for Canon 40D 50D 5D 5DII',1,'AA3204',18.5,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 18:10:05',0,NULL,5,1,18,1,NULL,'爵影无线 C3   1 '),(5356,723233422015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','chrischr15','fu33yhead@sky.com','Chris Flowers','21 Downsview Road','Horsham','East Sussex','UNITED KINGDOM','RH12 4PF','01403210927','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 18:11:17',0,NULL,3,1,2,1,NULL,'机身盖/镜头后盖 canon   1 '),(5358,723257507015,250599985982,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',3.98,'hutongstore','chr1s57','christopher.ariss@ntlworld.com','Christopher Ariss','18 Turmore Dale','Welwyn Garden City','Hertfordshire','UNITED KINGDOM','AL8 6HS','01707372477','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 18:49:31',0,NULL,3,1,2,1,NULL,'中号镜头筒   1 '),(5359,622986539001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','vicenza67','yosemite@virgilio.it','LOVATO LUCIANO','VIA MARANI 44','(VI)','VICENZA','ITALY','36100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 18:57:55',0,NULL,3,1,3,1,NULL,'2m 灯架 红盒  1 RR843876644CN\r'),(5360,662551392002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','colinjane','colinjmurphy@sky.com','colin murphy','105 langdale road','runcorn','Cheshire','UNITED KINGDOM','WA75PR','01928573705','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 19:07:35',0,NULL,3,1,2,1,NULL,'6662a 快装板  1 '),(5361,662556681002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','mj_amaro','maurojamaro@gmail.com','MAURO DE JESUS AMARO','R. JOÃO BAPTISTA D\'ALASCIO, 75<br>AP 302 BLOCO A','FLORIANÓPOLIS','SC','BRAZIL','88080-145','(11) 9112-4025','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 19:20:41',0,NULL,3,1,3,1,NULL,'sf18 nikon （ sb800）  1 RR843876851CN\r'),(5362,623001560001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','no_fake_shemps','hurdg@chartermi.net','Greg Hurd','105 Barry St.','Alpena','MI','UNITED STATES','49707','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 19:26:58',0,NULL,3,1,1,1,NULL,NULL),(5364,662566794002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','cricrihydro','fardoche26@hotmail.com','LAPORTE CHRISTIAN','1827 MARMIER APP.6','LONGUEUIL','QC','CANADA','J4K 4T3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 19:39:11',0,NULL,3,1,3,1,NULL,'斜臂 1 RR843876560CN\r'),(5365,662576555002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','jornlyder','jolohans@me.com','Jørn Lyder Hansen','Heslebergveien 6a','Vollen','Norway','NORWAY','1390','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 20:04:51',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876627CN\r'),(5366,623022122001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','a5tippmann','rwd1960@gmail.com','Robert W Dawes','350 Walker Dr','vienna','Il','UNITED STATES','62995-2638','(618) 658-2273','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 20:10:01',0,NULL,3,1,1,1,NULL,NULL),(5368,723289960015,250599920440,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.39,'hutongstore','jodhi_d','jo_dymond@hotmail.com','Jo Dymond','Keepers Cottage Cricket St Thomas','Chard','Somerset','UNITED KINGDOM','TA20 4DE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 19:42:17',0,NULL,3,1,2,1,NULL,'77mm 接口环  1 '),(5369,662590879002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','bigkahuna-2008','lakuzich@charter.net','larry kuzich','4112 S Otter Creek Rd','la salle','MI','UNITED STATES','48145-9728','(734) 243-6461','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 20:30:56',0,NULL,8,1,17,1,NULL,''),(5370,662591994002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bigkahuna-2008','lakuzich@charter.net','larry kuzich','4112 S Otter Creek Rd','la salle','MI','UNITED STATES','48145-9728','(734) 243-6461','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 20:33:04',0,NULL,3,1,1,1,NULL,'canon 镜头后盖/机身盖  1 \r58mm 镜头盖 canon  1 '),(5372,622986420001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 20:44:54',0,NULL,8,1,17,0,NULL,NULL),(5373,622976271001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 20:44:55',0,NULL,3,1,3,1,NULL,'反光板支架   1\r中号镜头筒   1 RR843876675CN\r'),(5374,623042427001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','anato01','smart2bay@yandex.ru','Anatoliy Alekseev','86 Golovatogo Str.','Krasnodar','ru','RUSSIAN FEDERATION','350004','+7(903)4538945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 21:24:21',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876701CN\r'),(5375,623061085001,110566021477,'TianYa ND8 Filter for Cokin P Series Neutral Density',1,'AA2325',7.2,'hermeshine','mio_cz','miroslav.sitner@gmail.com','Radka Durcikova','Rabasova 3195/43','Usti nad Labem','','CZECH REPUBLIC','40011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 21:41:23',0,NULL,3,1,2,1,NULL,'ND 8   1 '),(5376,662620883002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','a.smart.kid','j.arenas@me.com','Jesus Arenas Mesa','Aragon, 576, 4-1','Barcelona','Barcelona','SPAIN','08026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 21:43:36',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864489821CN\r'),(5378,662633962002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','leahav91','leander_91@hotmail.com','Leander Håvik','Ørevikvegen 37','Haugesund','Rogaland','NORWAY','5515','95261902','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 22:14:27',0,NULL,3,1,3,1,NULL,' RR843876715CN\r'),(5379,623076773001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',2,'AB2401',27.98,'hermeshine','atttmobile','davidnorwood2010@yahoo.com','Zhi Pei','1357 Calle Wilson<br>Apt 402','San Juan','PR','UNITED STATES','00907-2234','','NoPaymentFailure','CheckoutComplete','Other','2011-01-22 22:26:28',0,NULL,3,1,1,1,NULL,'90th 镜头筒   2 '),(5380,661024558002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','kiddiboy','janoveiversen@mac.com','Jan-Ove Iversen','Kraakstadveien 21 A','SKI','','NORWAY','1400','004790568338','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 23:01:09',0,NULL,3,1,4,1,NULL,'2m 灯架  2\rb座  2\r柔光伞   2\rlight stand  $20 \rYW864489832CN\r'),(5381,623091457001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','aepanebianco','alexandre.panebianco@uol.com.br','Alexandre Panebianco','Rua Afonso Braz<br>473 - 9 andar','São Paulo','São Paulo','BRAZIL','04511-011','551138493066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 23:06:24',0,NULL,3,1,2,1,NULL,'77mm 环架  1 '),(5383,623160263001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','juan3412','juan.a.martinez@am.sony.com','Juan Martinez','1762 Clinton Rd','Hewitt','NJ','UNITED STATES','07421-2601','(973) 853-5628','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-23 03:40:51',0,NULL,3,1,1,1,NULL,NULL),(5384,623209610001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','eradnort','trondaret@gmail.com','Trond Are Thomassen','Vågsveien','Hjørungavåg','Møre og Romsdal','NORWAY','6063','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 08:42:45',0,NULL,3,1,3,1,NULL,'反光板支架  1 RR843876573CN\r'),(5385,623213872001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','alnikos','al_nikos@hotmail.com','Nicolas Ortiz Vaquerizas','Paseo Xavier Azqueta nº 3 bajos 1ª','Sant Cugat del Valles','Cataluña','SPAIN','08173','616727883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 09:00:39',0,NULL,3,1,2,1,NULL,NULL),(5386,623216046001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','1atom','dautov100@rambler.ru','Vadim Dautov','ul. Zheleznodorozhnaya d.31 kv. 8','Yugorsk','HMAO','RUSSIAN FEDERATION','628260','+7-902-8254794','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 09:14:06',0,NULL,3,1,2,1,NULL,NULL),(5387,623224808001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','ruby0185','n.j.bergmann@windowslive.com','Jürg N. Bergmann','Strickweg 12','Gränichen','','SWITZERLAND','5722','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 09:43:05',0,NULL,3,1,3,1,NULL,'原装nikon 背心 xl  1 RR843876803CN\r'),(5389,623228465001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','monona33','margolin33@seznam.cz','Monika Vecerova','V drahach','V drahach 133','Bohunovice','CZECH REPUBLIC','78314','773543133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 09:51:39',0,NULL,3,1,3,1,NULL,'45w 4 RR843876882CN\r'),(5390,623261989001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','nerevar1988','nerevaro@gmail.com','Paulius Venckus','Laukininku 8-12','Klaipeda','Klaipeda','LITHUANIA','95140','+37066265417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 11:24:04',0,NULL,3,1,3,1,NULL,'nikon 单肩包  D1  1 RR843876834CN\r'),(5391,622914914001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','katufi4ek','katestar017@mail.ru','Dave Geoghegan','Unit B15<br>South City Business Centre','Tallaght 24','Dublin','IRELAND','default','0079063378278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 11:24:50',0,NULL,3,1,2,1,NULL,NULL),(5393,723627269015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','bikesprint','coops595@hotmail.com','Paul Cooper','117 Ewell by pass','Epsom','Surrey','UNITED KINGDOM','KT172PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 12:05:46',0,NULL,3,1,2,1,NULL,'45w  2 '),(5394,662841712002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',2,'AKT056',106,'hermeshine','plant305','plantmo@bigpond.com','Norman Plant','30 Henry Sutton Cct<br>Dunlop','Canberra','Australian Capital Territory','AUSTRALIA','2615','0262595662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 12:13:52',0,NULL,3,1,4,1,NULL,'2m 灯架   2\r反光板支架  2 \rreflector holder  $28\rYW864489843CN\r'),(5395,722145451015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','rufus_blackwell','rufusfxblackwell@yahoo.co.uk','Rufus Blackwell','Rushes Post Production 66 old compton st','london','London','UNITED KINGDOM','W1D4UH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 12:22:37',0,NULL,3,1,2,1,NULL,'45w  2  '),(5396,723643015015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','hkggfs2010','hkggfs@gmail.com','William Yeung','48 Shieldhill Court','Carluke','South Lanarkshire','UNITED KINGDOM','ML8 5GL',' 07919093811','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 12:35:37',0,NULL,3,1,2,1,NULL,NULL),(5397,723642820015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','binzius','rimvydasm@gmail.com','Rimvydas Masalis','S. Zukausko str. 18-4','Vilnius','Vilnius','LITHUANIA','08234','+37061222828','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 12:36:15',0,NULL,3,1,2,1,NULL,NULL),(5398,723644646015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','spartan1876','terryowens100@hotmail.com','TERRY OWENS','28 DYFED NORTHCLIFFE','PENARTH','The Vale of Glamorgan','UNITED KINGDOM','CF64 1DX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 12:38:44',0,NULL,3,1,2,1,NULL,NULL),(5399,723644439015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.58,'hutongstore','pumalives','ianbowers@usa.net','Ian Bowers','3 Melbourne Square Leconfield','Beverley','East Riding of Yorkshire','UNITED KINGDOM','HU17 7LG','07947822012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 12:38:51',0,NULL,3,1,2,1,NULL,NULL),(5400,723649538015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','ogpog','paypal@timfy.ie','Tim Wood','Middle Cottage Culliagh Beg','Leenane','Galway','IRELAND','default','09542912','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 12:49:24',0,NULL,3,1,2,1,NULL,NULL),(5403,723657286015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.99,'hutongstore','arunas167','arunas_stanaitis@yahoo.co.uk','Arunas Stanaitis','Cullenwood 12','Mountmellick','Laois','IRELAND','default','0876927596','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 13:04:23',0,NULL,3,1,2,1,NULL,'6662a 快装板  1 '),(5404,662861529002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','osco1955','fabiosbest+ebay@gmail.com','Fabio Coppini','Via del Colle n° 26','Prato','PO','ITALY','59100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 13:04:41',0,NULL,3,1,3,1,NULL,'2m灯架  1\rb座  1\r柔光伞  1 RR843876658CN\r'),(5406,723671510015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',68,'hutongstore','scottlet','scott@ethosuk.org.uk','Scott van Looy','21 Gainsborough House Cassilis Road','London','London','UNITED KINGDOM','E14 9LQ','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-23 13:33:05',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r50-70 棚  英标  2\r包   1 \rlighting kit  $26\rYW864489854CN\r'),(5407,709470473016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','roksan74','mj74uk@yahoo.co.uk','Mark Ellis','7 Boultham Park Road','Lincoln','Lincolnshire','UNITED KINGDOM','LN67BE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 14:10:53',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1 '),(5408,662895001002,120486048007,'New Timer Remote Control for Canon EOS 450D 400D 350D',1,'AA3221',47,'hermeshine','idomingozz','macdocz@me.com','Dmitry Danilov','Smolnaya str. 12<br>TBSS Ltd.','Moscow','Russia','RUSSIAN FEDERATION','125493','(985) 4111082','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 14:20:49',0,NULL,3,1,3,1,NULL,'MC-C1   1 RR843876848CN\r'),(5410,723704083015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','emidio_santos','emidio_santos@hotmail.com','Emidio Santos','Praceta Moreira Feio torre 2 - 2º D','Stº. António dos Cavaleiros - Loures','Loures','PORTUGAL','2670-121','916656178','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 14:28:34',0,NULL,3,1,3,1,NULL,'斜臂   1 RR843876587CN\r'),(5411,662901673002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 14:35:42',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876600CN\r'),(5412,709504169016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','7_zab','vinyl.prime@gmail.com','Alexander Zabotkin','Akademgorodok, 27-32','Krasnoyarsk','','RUSSIAN FEDERATION','660036','9029225317','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 15:09:28',0,NULL,3,1,2,1,NULL,NULL),(5413,622485484001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',4,'hermeshine','nickieruss','nickieruss@aol.com','Nickie Russell','736 Lee Road 304','Marianna','AR','UNITED STATES','72360-8432','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-23 15:12:37',0,NULL,3,1,1,1,NULL,'450D 眼罩  1 '),(5414,723770425015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',7.98,'hutongstore','kona1508','royst1968@gmail.com','Royston Palmer','Gwyndir Coolnacon,Clonroche','Enniscorthy','Wexford','IRELAND','ROI','0876892479','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 16:08:38',0,NULL,3,1,2,1,NULL,'3pcs 滤镜袋  2 '),(5415,623413795001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','alcachi','javier.lopez.cacheiro@gmail.com','Javier Lopez Cacheiro','CESGA Avda. de Vigo s/n<br>Campus Sur','Santiago de Compostela','Galicia','SPAIN','15705','655547687','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 16:41:08',0,NULL,3,1,4,1,NULL,'6663a   1 \rtripod $15\rYW864489865CN\r'),(5416,662980470002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','bunaaleksandar','aleksandarbunevski@yahoo.com','Aleksandar Bunevski','Prilepska 53A/8','Bitola','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','7000','+38970562350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 16:58:04',0,NULL,8,1,17,0,NULL,NULL),(5417,623422589001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','bunaaleksandar','aleksandarbunevski@yahoo.com','Aleksandar Bunevski','Prilepska 53A/8','Bitola','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','7000','+38970562350','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 16:58:04',0,NULL,8,1,17,0,NULL,NULL),(5418,662979082002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','bunaaleksandar','aleksandarbunevski@yahoo.com','Aleksandar Bunevski','Prilepska 53A/8','Bitola','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','7000','+38970562350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 16:58:05',0,NULL,8,1,17,0,NULL,NULL),(5419,662979934002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','bunaaleksandar','aleksandarbunevski@yahoo.com','Aleksandar Bunevski','Prilepska 53A/8','Bitola','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','7000','+38970562350','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 16:58:05',0,NULL,3,1,5,1,NULL,'斜臂   1\r52mm 镜头盖 nikon  1\r反光板支架  1\r50-70 塑料卡口棚   1 \r看看重量？   2448\rCP219487611CN\r'),(5420,723815862015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','hcleslie','hcleslie@hotmail.com','Hui Chai','19 Parsons Close','Aldershot','Hampshire','UNITED KINGDOM','GU11 2EU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 17:11:04',0,NULL,3,1,2,1,NULL,NULL),(5421,662994660002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','alekseyvk','avkonovalov@bk.ru','ALEXEY KONOVALOV','7 Chuksin tupik st. Apt. 45','Moscow','','RUSSIAN FEDERATION','127206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:14:56',0,NULL,8,1,17,0,NULL,NULL),(5422,623437061001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','alekseyvk','avkonovalov@bk.ru','ALEXEY KONOVALOV','7 Chuksin tupik st. Apt. 45','Moscow','','RUSSIAN FEDERATION','127206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:14:56',0,NULL,8,1,17,0,NULL,NULL),(5423,622919381001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',2,'AA2217',17.98,'hermeshine','alekseyvk','avkonovalov@bk.ru','ALEXEY KONOVALOV','7 Chuksin tupik st. Apt. 45','Moscow','','RUSSIAN FEDERATION','127206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:14:57',0,NULL,8,1,17,0,NULL,NULL),(5424,622920066001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','alekseyvk','avkonovalov@bk.ru','ALEXEY KONOVALOV','7 Chuksin tupik st. Apt. 45','Moscow','','RUSSIAN FEDERATION','127206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:14:57',0,NULL,8,1,17,0,NULL,NULL),(5425,622919448001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','alekseyvk','avkonovalov@bk.ru','ALEXEY KONOVALOV','7 Chuksin tupik st. Apt. 45','Moscow','','RUSSIAN FEDERATION','127206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:14:58',0,NULL,3,1,5,1,NULL,'倒影板  1\r60cm 棚  1\r小号灰卡  2\r桌面灯   2\r45w   2 \rCP219487625CN\r\r'),(5426,662998739002,120571006893,'Green.L 67mm Neutral Density ND8 Filter  67 D90 D300s',1,'AE2312',6.7,'hermeshine','tom6667','tlink100@gmail.com','Thomas Link','1976 Topeka Cir','Sparks','NV','UNITED STATES','89434','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-23 17:18:12',0,NULL,3,1,1,1,NULL,NULL),(5427,663001229002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','tie1103','tie@stagezoom.net','Milan Skrob','Susilovo nam. 53','Rousinov','','CZECH REPUBLIC','68301','+420776181460','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 17:21:32',0,NULL,3,1,3,1,NULL,' RR843876595CN\r'),(5428,623457710001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','leonbos27','leonbos@absamail.co.za','Leon Boshoff','P.O. Box 186<br>Garsfontein','Pretoria','Gauteng','SOUTH AFRICA','0042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:40:53',0,NULL,3,1,2,1,NULL,NULL),(5429,623464701001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','cscruzmoreira','cscmoreira@gmail.com','Cláudia Moreira','Rua de S. Pedro N.º 239','Paços de Ferreira','Porto','PORTUGAL','4595-032','+351255872912','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:49:40',0,NULL,3,1,2,1,NULL,'大力夹 球台  1 '),(5430,723864049015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','brice2971','bricester@hotmail.com','Simon Brice','1 Redwoods','Hertford','Hertfordshire','UNITED KINGDOM','SG14 3BT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 17:53:36',0,NULL,3,1,2,1,NULL,NULL),(5431,709643880016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','blackdwarrf','r.palacz@yahoo.ie','Rafal Palacz','Apt. 9 Chapel Meaws Chapel Lane','Sallins','Kildare','IRELAND','default','0851575073','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 18:03:15',0,NULL,3,1,2,1,NULL,NULL),(5433,623484397001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mrpikkusika','nordstrom.joakim@suomi24.fi','Joakim Nordström','Tavastilankatu 8 D 27','Turku','','FINLAND','20610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 18:12:35',0,NULL,3,1,2,1,NULL,'45w   2 '),(5434,663042382002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','v--a--n','alex.n.vereshchagin@gmail.com','Aleksandr N Vereshchagin','Karla Marksa str. 70-30','Berdsk','Novosibirsk region','RUSSIAN FEDERATION','633004','+79137187142','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 18:13:49',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876525CN\r'),(5436,623486461001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','highlife!','miller-time@shaw.ca','Brett Slutker','2444 Harmon Road','West Kelowna','BC','CANADA','V1Z 3A9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 18:14:37',0,NULL,3,1,2,1,NULL,NULL),(5437,709666721016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','vvvsk','vvvsk.mail@googlemail.com','Vojtech Pisca','49 Ferndene Bradley Stoke','BRISTOL','Avon','UNITED KINGDOM','BS32 9DG','07845474515','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 18:24:30',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1 '),(5438,623557083001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','asalaqeel','hajs_400@hotmail.com','aqeel salmman','p.o.box 13666<br>dammam 31414','adammam','','SAUDI ARABIA','31414','00966506052299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 19:31:07',0,NULL,3,1,2,1,NULL,'72mm 橡胶罩   1 '),(5439,663071465002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','deeneshen','incu_bus_17@yahoo.co.uk','Deeneshen Sabapathee','Mootoo Lane<br>Allee Brillant','Vacoas','','MAURITIUS','0000','+2304903234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 19:44:20',0,NULL,3,1,3,1,NULL,'60cm 闪光灯棚   1 RR843876896CN\r'),(5440,663097824002,120462263667,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','asgeirkolberg','akolberg@start.no','Asgeir Kolberg','Verven 34','Drammen','','NORWAY','3041','004795060443','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 20:05:55',0,NULL,3,1,2,1,NULL,'渐变棕    1 '),(5441,663154953002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','braveheart1804','gordon-shumway1@gmx.de','Mike Braune','Am Stadtblick 32','Magdeburg','','GERMANY','39128','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 20:18:35',0,NULL,3,1,3,1,NULL,'摄影背心 canon xl 1\r老款 RR843876777CN\r'),(5443,663154424002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','vertten','aldusvertten@gmail.com','Alfredo Del Busto Tarancon','C/ Esteve Victoria 5-1','Valencia','Valencia','SPAIN','46006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 20:24:39',0,NULL,8,1,17,1,NULL,' \r'),(5444,663133221002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','vertten','aldusvertten@gmail.com','Alfredo Del Busto Tarancon','C/ Esteve Victoria 5-1','Valencia','Valencia','SPAIN','46006','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 20:24:40',0,NULL,3,1,3,1,NULL,'肩架   1 \r机身盖/镜头后盖  canon  1\rRR843876511CN'),(5445,623620351001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','peterzsolt1976','peterzsolti@freemail.hu','Péter Zsolt','Derkovits 54. 1/3','Miskolc','','HUNGARY','3529','0036306543456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 20:44:55',0,NULL,3,1,2,1,NULL,NULL),(5446,709836485016,260660053613,'New Rainproof & Warm Protector for 7D 550D 5D D700 D90',1,'AA3102',12.99,'hutongstore','kumi-tarzan','kumitarzan@gmail.com','Markus Lehtinen','Lounaankatu 1 a 13','Lahti','','FINLAND','15150','+358407438006','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 21:05:04',0,NULL,3,1,3,1,NULL,'防寒罩   1 RR843876794CN\r'),(5447,663188960002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','ddav9357','tutucute_creations@yahoo.com','Debbie Davis','PO Box 204<br>306 East Main Street','Fouke','AR','UNITED STATES','71837-0204','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-23 21:08:27',0,NULL,3,1,1,1,NULL,NULL),(5448,724083723015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','dennisbf20','dennis@byrne-fraser.com','dennis byrne-fraser','59 belvere ave','blackpool','Lancashire','UNITED KINGDOM','FY42LW','01253408943','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 21:23:17',0,NULL,3,1,2,1,NULL,'镜头后盖/机身盖 canon  1 '),(5449,663225888002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','soegnen_123','soegnen@gmail.com','Rasmus Søgnen','C.J. Hambrosvei 48','Bergen','Hordalan','NORWAY','5148','55168248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 22:15:51',0,NULL,3,1,2,1,NULL,NULL),(5450,663230291002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','gigistella10','debibobi@gmail.com','Deborah Besana','27 Noel Road<br>Acton','London','London','UNITED KINGDOM','W3 0JD','0754076780','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 22:22:20',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876750CN\r'),(5451,663232032002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','berrynate','nbninja8@yahoo.com','Nate Berry','1533 S Main St<br># 1188','Winston Salem','NC','UNITED STATES','27127-2738','(336) 816-6653','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-23 22:26:49',0,NULL,3,1,1,1,NULL,NULL),(5452,623690845001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','zephyr064','martin.lee@rogers.com','Yam Lee','423 Avondale Ave.','Ottawa','ON','CANADA','K2A 0S1','(613) 729-4936','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 23:00:38',0,NULL,3,1,3,1,NULL,'摄影背心 nikon xxl  1\r老款 黑 厚   RR843876732CN\r'),(5453,663266269002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','arronio','_f_i_l_e_m_o_n_@terra.es','Antonio Ramos','C/ O Rio, 8, Entlo','Burela','Lugo','SPAIN','27880','982581000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 23:55:37',0,NULL,3,1,2,1,NULL,'广角托架   1 '),(5455,724175754015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','manleypursuits','carl_and_laura@hotmail.com','Carl Manley','Network Rail James Forbes House 2/C/130','27 Great Suffolk Street','London','UNITED KINGDOM','SE1 0NS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 00:20:14',0,NULL,3,1,3,1,NULL,'斜臂   1 RR843876746CN\r'),(5456,623724024001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','jocelynpritchard','pritchard.jocelyn@gmail.com','Jocelyn Pritchard','28 Bells Blvd','Jan Juc','Victoria','AUSTRALIA','3228','0352612345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 00:40:16',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1\rJocelyn Pritchard\r91B Pokfulam Road\rPokfulam\rHong Kong Island\rHong Kong\r '),(5457,724185237015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',3.59,'hutongstore','bodruz','bodruz@hotmail.com','Bodruz Zaman','93 Upney Lane','Barking','London','UNITED KINGDOM','IG11 9LD','07951729209','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 00:46:04',0,NULL,3,1,2,1,NULL,'小号镜头筒   1 '),(5458,623728083001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.9,'hermeshine','caroleott','ceott@bendbroadband.com','Daniel Ott','19670 Manzanita Ln','Bend','OR','UNITED STATES','97702','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-24 00:52:02',0,NULL,3,1,1,1,NULL,'大力夹  2 '),(5459,623779011001,110562231928,'Camera shoulder bag nova 4 with raincover 4 D300s D700',1,'AO0025',40.99,'hermeshine','timi_ppt','timi.wong-yut@mail.pf','Timi Wong Yut','41 rue du bon pasteur<br>Papeete - Island of Tahiti','PAPEETE','French Polynesia','FRENCH POLYNESIA','98714','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 03:28:42',0,NULL,3,1,3,1,NULL,'nikon N4  单肩包  1 RR843874855CN'),(5460,623792446001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',75,'hermeshine','mercamerca','matthew.mercadante@gmail.com','Matthew Mercadante','5 Malua cres','Mill Park','Victoria','AUSTRALIA','3082','','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2011-01-24 04:23:33',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r反光板支架  1 \rYW864489924CN\r'),(5461,623795725001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','smolinkabkru','smolinka@bk.ru','Smolina Natalia','20 Safonova st, app#70','Vladivostok','Primorye','RUSSIAN FEDERATION','690011','89025066887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 04:47:33',0,NULL,8,1,17,0,NULL,NULL),(5462,623795916001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','smolinkabkru','smolinka@bk.ru','Smolina Natalia','20 Safonova st, app#70','Vladivostok','Primorye','RUSSIAN FEDERATION','690011','89025066887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 04:47:33',0,NULL,3,1,3,1,NULL,'倒影板  1\r40cm 棚  1 RR843874612CN'),(5463,623803469001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',10,'AE3102',100,'hermeshine','des2653','des@lensartphotography.com.au','Desmond McMillan','41 O\'Loughlan street','Ormond','Victoria','AUSTRALIA','3204','0395786884','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-24 05:24:14',0,NULL,3,1,3,1,NULL,'大力夹 10 RR843874572CN'),(5464,663374369002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','dendome60','dkpez@platinum.ca','Denise Pezderic','Box 1114','Claresholm','AB','CANADA','T0L 0T0','(403) 687-2149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 06:20:40',0,NULL,3,1,2,1,NULL,'b座   1 '),(5466,623813776001,110566021028,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','ralphonline','ralph95@hotmail.com','Ralph Reynolds','16 Fredericksburg Dr','Middletown','DE','UNITED STATES','19709','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 06:33:41',0,NULL,3,1,1,1,NULL,NULL),(5467,623814220001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',2,'AA2120',64,'hermeshine','v.kolyshev','berliozz@gmail.com','Victor Kolyshev','c/o Eastbiz Corp., 2964 Columbia St., Suite # 26961','Torrance','CA','UNITED STATES','90503','7 926 503 3850','NoPaymentFailure','CheckoutComplete','Other','2011-01-24 06:36:23',0,NULL,3,1,3,1,NULL,'Kolyshev Victor\rLubereckiy r-on\rOzernaya d.4, kv.3\rKorenevo Moscow region 140052\rRussian Federation\r RR843874816CN'),(5468,663376985002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','armenak*84','armenak84@mail.ru','Armenak Baghdasaryan','David Beki str. 90','Yerevan','Erebuni','ARMENIA','0008','(374)91010024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 06:38:47',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5469,623814739001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',4,'AB2214',4.5,'hermeshine','tinandrew','andrewtran@tinandrew.com','Andrew Tran','27450 Tourney Rd<br>Suite 130','Valencia','CA','UNITED STATES','91355-1851','(661) 799-7912','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 06:39:51',0,NULL,3,1,1,1,NULL,' '),(5470,663379506002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','keith_thum','keith@ridocolor.com','THUM TZY YIN','6795, Jalan Raja Uda','Butterworth','Penang','MALAYSIA','12300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 06:55:43',0,NULL,3,1,10,1,NULL,'2m 灯架 2\rb座  2\r柔光伞  2 \r递四方专线\rBJ8723007\r'),(5471,623817778001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',2,'AA1210',8.8,'hermeshine','yinyifanivan','yinyifan0324@hotmail.com','yifan yin','816 Peace Portal Dr','Blaine','WA','UNITED STATES','98230-4010','(778) 317-3323','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 07:06:11',0,NULL,3,1,1,1,NULL,NULL),(5476,623844367001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','ki-po','p62@ya.ru','Kirill Poltava','Prajskaya 15-58','Volgograd','','RUSSIAN FEDERATION','400005','89023644298','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 09:40:07',0,NULL,3,1,3,1,NULL,'2m 灯架  白盒  1 RR843874643CN'),(5472,724314392015,250692240685,'TianYa NEUTRAL DENSITY ND8 Filter replaces for Cokin P',1,'AA2325',4.65,'hutongstore','mip69hoganas','mip69@hotmail.com','263Michael Persson','Tulpangatan 6','Höganäs','','SWEDEN','263 33','+46 42 352266','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 08:23:53',0,NULL,8,1,17,0,NULL,NULL),(5473,710073719016,260660054522,'TianYa NEUTRAL DENSITY ND4 Filter replaces for Cokin P',1,'AA2324',4.65,'hutongstore','mip69hoganas','mip69@hotmail.com','263Michael Persson','Tulpangatan 6','Höganäs','','SWEDEN','263 33','+46 42 352266','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 08:25:21',0,NULL,3,1,2,1,NULL,'ND4  1\rND8   1 '),(5474,623831731001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','h_o_h_o_l','www.dvdtechnik@dvdtechnik.com','Yuriy Davidenko','94 Chervonoarmiyska Street, Ap. 117','Kiev','Kiev','UKRAINE','03150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 08:29:13',0,NULL,3,1,3,1,NULL,' RR843874569CN'),(5475,663399224002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','martinsubrt','mar_s@centrum.cz','Martin Šubrt','Příčná 254/5','Bolatice','','CZECH REPUBLIC','74723','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 08:53:29',0,NULL,3,1,3,1,NULL,'115w 220v   4 \rRR843875034CN\r'),(5477,663266714002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',40.89,'hermeshine','motopittabay','scemo_chi_scrive@hotmail.it','marco pittaluga','via franco antolini 10/16','genova','GE','ITALY','16143','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 09:40:11',0,NULL,3,1,3,1,NULL,'斜臂  1\rcanon 三角包   1 RR843874657CN'),(5478,724351213015,250599421678,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'AA1303',1.88,'hutongstore','joa.net','joakim@3dwired.com','Joakim Brodendal','Lyngenvägen 2','Falkenberg','Halland','SWEDEN','SE31171','+4634697075','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 10:49:54',0,NULL,3,1,2,1,NULL,' '),(5479,659353954002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','deboe034','w.g.m.deboer@wxs.nl','willy de boer','schuttersdreef 68','elsloo','','NETHERLANDS','6181 ds','046-4379963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 11:09:58',0,NULL,3,1,2,1,NULL,'小号灰卡   1 '),(5480,623862549001,110445658830,'YONGNUO LCD Timer Remote Control for Sony RM-S1AM A700',1,'AA3223',48.9,'hermeshine','istomin2010','svi76@mail.ru','Sergey Istomin','Nikolaeva, b. 4, f. 65','Moscow','','RUSSIAN FEDERATION','123100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 11:14:14',0,NULL,3,1,3,1,NULL,'mc-s1   1 RR843874626CN'),(5481,663426903002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',3,'AE1401',109.5,'hermeshine','crunchgmbh','info@crunch.ch','Daniel Kunz','Mattenstrasse 90<br>CRUNCH GmbH','Biel','','SWITZERLAND','2503','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 11:31:54',0,NULL,3,1,4,1,NULL,'肩架  3 \rYW864489913CN\r'),(5482,663380701002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','joe_rocket_1','joerocket63@shaw.ca','Joel Macapagal','103 Tallman St.','Winnipeg','MB','CANADA','R2R 2P7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 11:42:32',0,NULL,3,1,2,1,NULL,'6662a 快装板  2 '),(5484,623276745001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',36.89,'hermeshine','konkolas1987','konkolas@gmail.com','Audrius Reipa','chemiku 15-10','Jonava','LT','LITHUANIA','55240','863720224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 11:51:12',0,NULL,3,1,3,1,NULL,'双灯头 欧标  1\r45w  2 RR843874630CN'),(5485,663440806002,120601699795,'New 3 filters & Ring holder set 4 Cokin System P Series',1,'AKT026',22.8,'hermeshine','pepepotamo64','marcovadanero@gmail.com','Marco Varela Adanero','Pablo Iglesias 57','Gijón','Asturias','SPAIN','33205','985130752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 12:04:10',0,NULL,3,1,3,1,NULL,'ND2/4/8  + 52mm环架  1 RR843874802CN\r'),(5487,722914734015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',54.89,'hutongstore','rogerse1471','rogerse@hotmail.com','Edmund Rogers','49 Hazel Drive','Ferndown','Dorset','UNITED KINGDOM','BH22 9SP','07941462656','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-24 12:14:31',0,NULL,3,1,4,1,NULL,'背景架  （ 白 ） 2m  1\r1.6x2.1m 绿色背景布  1 \rbackground support   \r$22\rYW864489946CN\r'),(5489,623890137001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','aupov','aupovy@yandex.ru','Денис Аюпов','Лежневская<br>211Б-134','Иваново','Ивановская обл','RUSSIAN FEDERATION','153038','+79612462681','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 12:53:00',0,NULL,3,1,2,1,NULL,' '),(5490,724388160015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',13.9,'hutongstore','sampos2','sampo.salmi@gmail.com','sampo  salmi','kivakatu 14a9','lahti','hame','FINLAND','15210','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 12:57:14',0,NULL,3,1,2,1,NULL,'50cm  棚     1 '),(5491,623899522001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','vacarciucalexandru','quizzical@inbox.ru','Vacarciuc Alexandru','Alba-Iulia 89/1 ap.15','Chisinau','Republic of Moldova','MOLDOVA, REPUBLIC OF','MD2071','(+373) 69441029','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 13:30:07',0,NULL,3,1,3,1,NULL,'肩架   1 RR843874759CN\r'),(5492,663474156002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','jacques_bay','zpiljak@gmail.com','Zarko Piljak','Zagrebacka 3','Zlatar','','CROATIA','49250','0038549467613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 14:07:03',0,NULL,8,1,17,0,NULL,''),(5493,663480203002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','shuricat','poyanov@gmail.com','Alexander Poyanov','pr. Solidarnosti, d. 10, korp. 3, kv. 18','St. Petersburg','RU','RUSSIAN FEDERATION','193312','+7 921 1888935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 14:30:24',0,NULL,3,1,2,1,NULL,NULL),(5494,663483391002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','jacques_bay','zpiljak@gmail.com','Zarko Piljak','Zagrebacka 3','Zlatar','','CROATIA','49250','0038549467613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 14:36:13',0,NULL,8,1,17,0,NULL,NULL),(5495,623917974001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','jacques_bay','zpiljak@gmail.com','Zarko Piljak','Zagrebacka 3','Zlatar','','CROATIA','49250','0038549467613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 14:36:14',0,NULL,3,1,3,1,NULL,'柔光伞   1\r反光伞  1\r大力夹   1 RR843874833CN'),(5496,623919340001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','yosigur84','yosi1984@gmail.com','Yossi Gurovich','Harav Naria','Rishon Lzion','israel','ISRAEL','75751','0523556450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 14:37:48',0,NULL,3,1,2,1,NULL,'RS-C1   1 '),(5497,623931429001,110583278297,'TianYa 77mm CPL filter New 77 Circular Polarizing C-PL',1,'AA2307',7.1,'hermeshine','serrol77','serzunov@yandex.ru','Sergey Erzunov','ul. Pravdy, 2-56','Volgograd','','RUSSIAN FEDERATION','400127','89177288981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:16:54',0,NULL,8,1,17,0,NULL,NULL),(5498,663436601002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','serrol77','serzunov@yandex.ru','Sergey Erzunov','ul. Pravdy, 2-56','Volgograd','','RUSSIAN FEDERATION','400127','89177288981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:18:32',0,NULL,8,1,17,0,NULL,NULL),(5499,623852537001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.5,'hermeshine','serrol77','serzunov@yandex.ru','Sergey Erzunov','ul. Pravdy, 2-56','Volgograd','','RUSSIAN FEDERATION','400127','89177288981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:18:33',0,NULL,8,1,17,0,NULL,NULL),(5500,663439710002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.2,'hermeshine','serrol77','serzunov@yandex.ru','Sergey Erzunov','ul. Pravdy, 2-56','Volgograd','','RUSSIAN FEDERATION','400127','89177288981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:18:34',0,NULL,3,1,3,1,NULL,'72mm uv   1\r77mm uv   1\r72mm cpl   1\r天涯 77mm cpl   1 \rRR843875445CN\r'),(5501,663500855002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',3,'AA2217',26.94,'hermeshine','highflyer_gfs','highflyer_gfs@yahoo.com.br','Gustavo Fujinami Sugawara','Av. Miguel Stefano 379 ap 141','Sao Paulo','SP','BRAZIL','04301010','11 8253 8082','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:30:16',0,NULL,3,1,3,1,NULL,'小号灰卡   3 \rRR843874983CN'),(5502,663501422002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','irenep23','ipidal@teleline.es','Irene Pidal Miranda','Martí Costa, 1, 5ºA','Palma de Mallorca','Baleares','SPAIN','07013','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 15:32:06',0,NULL,8,1,17,0,NULL,NULL),(5503,623934476001,110566021028,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','irenep23','ipidal@teleline.es','Irene Pidal Miranda','Martí Costa, 1, 5ºA','Palma de Mallorca','Baleares','SPAIN','07013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:32:07',0,NULL,8,1,17,0,NULL,NULL),(5504,663491951002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','irenep23','ipidal@teleline.es','Irene Pidal Miranda','Martí Costa, 1, 5ºA','Palma de Mallorca','Baleares','SPAIN','07013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:32:08',0,NULL,3,1,4,1,NULL,'52mm 镜头盖  nikon   1\r防寒罩   1\r6662a   1 \rtripod  $16\rYW864489961CN\r'),(5505,623938213001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','carlbovee','carlhbovee@hotmail.com','carl h bovee','7023 Baywood Dr','tampa','FL','UNITED STATES','33637-6463','(813) 445-1301','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 15:39:47',0,NULL,3,1,1,1,NULL,NULL),(5506,623943610001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','jaymusclerussell','calgarydeluxe@hotmail.com','Jay Russell','6130 3st SE','Calgary','AB','CANADA','T2H1K4','(403) 692-3845','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 15:55:47',0,NULL,3,1,5,1,NULL,'2m 灯架  1\r斜臂   1 \rCP219487449CN\r'),(5507,724474999015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 16:38:20',0,NULL,8,1,17,0,NULL,NULL),(5508,724474755015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 16:38:21',0,NULL,8,1,17,0,NULL,NULL),(5509,710230502016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 16:38:20',0,NULL,8,1,17,0,NULL,' '),(5510,724474535015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',3.5,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 16:38:22',0,NULL,3,1,3,1,NULL,'62mm cpl   1\r67mm cpl   1\r58mm cpl   1\r72mm cpl   1 \rRR843874745CN\r'),(5511,662605329002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',11.34,'hermeshine','*euazteca*','cotz@euazteca.com','EUAZTECA C/O ANHE20','2098 HARVEST RD<br># A055','SAN DIEGO','CA','UNITED STATES','92154-7609','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 17:03:35',0,NULL,3,1,1,1,NULL,'NG128   1 '),(5512,663431399002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','mybloodygore','bobxcorex@yahoo.com','Bobby Wallad','komplek Budi Indah blok A43','cimahi utara','jawa barat','INDONESIA','40415','6281321132328','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 17:09:45',0,NULL,3,1,2,1,NULL,' '),(5514,663546905002,120458029512,'Marco O Flash o-flash Ring Light For SB800 SB600 F160 ',1,'AO0026',38.49,'hermeshine','imustbeasailor','mark.duehmig@encompassfilmworks.com','Mark Duehmig','938 Langdon Ct','Annapolis','MD','UNITED STATES','21403-2811','(410) 263-2622','NoPaymentFailure','CheckoutComplete','Other','2011-01-24 17:30:46',0,NULL,8,1,17,0,NULL,NULL),(5515,623976061001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','imustbeasailor','mark.duehmig@encompassfilmworks.com','Mark Duehmig','938 Langdon Ct','Annapolis','MD','UNITED STATES','21403-2811','(410) 263-2622','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 17:30:46',0,NULL,3,1,1,1,NULL,'O-FLASH 160   1\r77 环架   1 '),(5518,623986645001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','percecus','khaledmfmg@yahoo.com','Khaled M AlGhanem kwi 17058','14729 182nd St','Springfield Gardens','NY','UNITED STATES','11413-4028','718 553 8740','NoPaymentFailure','CheckoutComplete','Other','2011-01-24 17:46:30',0,NULL,3,1,1,1,NULL,'sf18-canon   1 '),(5519,724517276015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',68,'hutongstore','chrismcparker','chrismcparker@yahoo.com','Chris Parker','14 Meadow View Frampton Cotterell','Bristol','Avon','UNITED KINGDOM','bs36 2ng','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-24 17:56:24',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r50-70 棚英标  2\r包   1 \rlighting kit  $25\rYW864489972CN\r'),(5520,623992484001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','coriumtech','ale@coriumtech.com','Anthony Le-Engineer','235 constitution dr','menlo park','CA','UNITED STATES','94025-1108','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 17:57:56',0,NULL,3,1,1,1,NULL,'40cm 棚   1 '),(5521,724520230015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','evet_nurse','sldifford@googlemail.com','Shannon Difford','8 Verriers','North Petherton','Somerset','UNITED KINGDOM','TA6 6SX','01278662843','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-24 18:00:14',0,NULL,3,1,4,1,NULL,'背景架 （ 白 黑） 2m  1\rYW864490005CN\rbackgroundsupport  $22 '),(5522,663585568002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','cekisieda','cemkastrat@hotmail.com','eda kastrat','ahmet kutsi tecer caddesi 55/d<br>merter/güngören','istanbul','','TURKEY','34010','2125547718','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 18:50:31',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r反光板支架   1 RR843874691CN\r'),(5524,710311288016,260646728395,'New thicken Non Woven Fabric Backdrop 3m x 2m(10 x7 ft)',1,'AO0018',23.9,'hutongstore','tomaspaypal123','tomas.dolejsi@fotoradce.cz','Tomas Dolejsi','Pod Radnici 3183','Havlickuv Brod','','CZECH REPUBLIC','58001','(0420) 737164334','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 19:09:56',0,NULL,3,1,3,1,NULL,'白色的厚的3m x2m 背景布   1 RR843874762CN'),(5525,663622731002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','cmcg2366','caitmcgill@yahoo.com','Caitlin McGill','94A S 6th Ave','Clarion','PA','UNITED STATES','16214-2032','(724) 316-8736','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 19:57:41',0,NULL,3,1,1,1,NULL,NULL),(5526,624066857001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','alexjap','alex_olson_oki@hotmail.com','Alex Olson','19 Pena Parda','La Herradura, granada','','SPAIN','18697','628077459','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 20:19:22',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r斜臂   1 \rboom arm    $20\rYW864489950CN\r'),(5527,663639814002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','davidfge75','davidfge@gmail.com','david Fdez de Gamarra','Calle Comercio 17, Bajo C','Legutiano','País Vasco','SPAIN','01170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 20:28:52',0,NULL,3,1,4,1,NULL,'2m 灯架   2\rb座   2\r柔光伞  2\rlight stand  $20 \rYW864489983CN\r'),(5528,623912696001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','snap_to_it','duffie81@yahoo.com','Casandra Cross','14 Walker ave','Bradford','PA','UNITED STATES','16701-1229','(814) 598-9259','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 20:29:56',0,NULL,3,1,1,1,NULL,NULL),(5529,624090832001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','perjorgen','pjsoerbo@online.no','per jørgen sørbø','Kirkeveien 11','Kjøllefkord','finnmark','NORWAY','9790','004741308733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:07:49',0,NULL,8,1,17,0,NULL,NULL),(5530,663654334002,120626873273,'New wide angle holder for Cokin P series filter',2,'AA2216',7.98,'hermeshine','perjorgen','pjsoerbo@online.no','per jørgen sørbø','Kirkeveien 11','Kjøllefkord','finnmark','NORWAY','9790','004741308733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:07:50',0,NULL,8,1,17,0,NULL,NULL),(5531,663657627002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','perjorgen','pjsoerbo@online.no','per jørgen sørbø','Kirkeveien 11','Kjøllefkord','finnmark','NORWAY','9790','004741308733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:07:51',0,NULL,8,1,17,0,NULL,NULL),(5532,663656334002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','perjorgen','pjsoerbo@online.no','per jørgen sørbø','Kirkeveien 11','Kjøllefkord','finnmark','NORWAY','9790','004741308733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:07:51',0,NULL,8,1,17,0,NULL,NULL),(5533,624081034001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','perjorgen','pjsoerbo@online.no','per jørgen sørbø','Kirkeveien 11','Kjøllefkord','finnmark','NORWAY','9790','004741308733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:07:52',0,NULL,3,1,3,1,NULL,'67mm 环架  1 \r渐变灰  1\r72mm cpl   1\r广角托架   2\r67mm 镜头盖  nikon   1RR843874731CN\r'),(5535,724653938015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',52,'hutongstore','sherrykey123','sherryk@hotmail.co.uk','sherriden key','60 Corby Park North Ferriby','Nr Hull','Humberside','UNITED KINGDOM','HU14 3AY','01482631886','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 21:27:12',0,NULL,3,1,4,1,NULL,'2m 灯架  2\rb座  2\r柔光伞  2\rlight stand  $20 \rYW864489994CN\r'),(5536,661846342002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','stlkrush','glennb91111@yahoo.com','GLENN BILLINGSLEY','25 Lee Ave','FERGUSON','MO','UNITED STATES','63135-2951','(314) 524-3214','NoPaymentFailure','CheckoutComplete','Other','2011-01-24 21:32:18',0,NULL,3,1,1,1,NULL,'sony 背心  xxxl   1\r新款 黑 厚   '),(5538,624105204001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',3,'AB2214',4.5,'hermeshine','izidororenato','renato.carlos.izidoro@gmail.com','Renato Izidoro','r. Genebra, 143<br>Pq. Novo Oratório','Santo André','São Paulo','BRAZIL','09260-260','55-11-44792647','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:37:41',0,NULL,3,1,2,1,NULL,'品胜3.0 膜  3 '),(5539,663676466002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','mjcecchini','maurice_cecchini@hotmail.com','Maurice J Cecchini','1739 Shady Leaf Dr','Valrico','FL','UNITED STATES','33596-6130','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 21:39:13',0,NULL,3,1,1,1,NULL,NULL),(5541,710410848016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','mr-butters','unclesond@gmail.com','Toby Maloy','18 Kingfisher Drive Sandhills','Leighton Buzzard','Bedfordshire','UNITED KINGDOM','LU7 4SG','07828463466','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 21:41:40',0,NULL,5,1,18,1,NULL,'sf18-canon  1 '),(5542,724665190015,250692237477,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',7.75,'hutongstore','marco_sartori','m_sartori@alice.it','Maurizio Sartori','Via Bodoni,13','Verona','VR','ITALY','37131','340-9227445','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 21:47:06',0,NULL,8,1,17,0,NULL,NULL),(5543,724659292015,250599969315,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',12.99,'hutongstore','marco_sartori','m_sartori@alice.it','Maurizio Sartori','Via Bodoni,13','Verona','VR','ITALY','37131','340-9227445','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-24 21:47:07',0,NULL,3,1,3,1,NULL,'单灯头 欧标  1\r115w 220v   1 \rRR843875048CN\r'),(5544,624111173001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','tonytiger321','tony.tiger321@ntlworld.com','ANTHONY JOHNSON','12 RECREATION CLOSE','FELIXSTOWE','Suffolk','UNITED KINGDOM','IP11 9BE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:51:50',0,NULL,3,1,2,1,NULL,'star6   1 '),(5545,624112302001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','andreysuchkov','fiap-sas@rambler.ru','Andrey Suchkov','ul.Parovoznaya<br>10-28','Orel','','RUSSIAN FEDERATION','302029','+7-910-302-7820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:54:35',0,NULL,8,1,17,0,NULL,NULL),(5546,663686363002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','andreysuchkov','fiap-sas@rambler.ru','Andrey Suchkov','ul.Parovoznaya<br>10-28','Orel','','RUSSIAN FEDERATION','302029','+7-910-302-7820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 22:03:08',0,NULL,3,1,2,1,NULL,'52mm 镜头盖  nikon   1\r72mm 橡胶罩   1 '),(5547,663686975002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','tkhagapsu','desperado.mail@gmail.com','Timur Tkhagapsu','ul. Budennogo d.480','Krasnodar','','RUSSIAN FEDERATION','350038',' 8918-348-0690','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 22:05:50',0,NULL,3,1,5,1,NULL,'2m 灯架  1\r斜臂  1 RR843874674CN改号了\rCP219636956CN\r'),(5548,663687600002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','karduc2','karduc@hotmail.com','pedro angel ducar legua','monasterio de veruela  28/30','alagon','Aragón','SPAIN','50630','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 22:06:19',0,NULL,3,1,3,1,NULL,'2m灯架 1\r云台   1\r柔光伞   1 RR843874714CN\r'),(5549,624117743001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','stevea1957','stevea57@gmail.com','Stephen Armstrong','6 Leeside Road','North Avoca','New South Wales','AUSTRALIA','2260','0409982202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 22:08:48',0,NULL,3,1,2,1,NULL,'小号镜头筒   1 '),(5550,663688789002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 22:11:30',0,NULL,3,1,3,1,NULL,'100-150 反光板  1 RR843874665CN'),(5551,624119345001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',4.4,'hermeshine','klemgor','klemen977@gmail.com','klemen gorup','kobdilj 34','default','štanjel','SLOVENIA','6222','00386 31 273 279','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 22:14:07',0,NULL,3,1,2,1,NULL,' '),(5554,710435415016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','garrapiu','kelpalacin@hotmail.com','Miquel Palacin Alonso','Av. Bisbe Iglesies 48b 3º-1ª','Tremp  ( LLeida)','Cataluña','SPAIN','25620','629723788','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 22:28:58',0,NULL,3,1,2,1,NULL,'77mm 渐变灰  1 '),(5555,624124631001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','kiphoto2011','kilmer.ribeiro@hotmail.com','KILMER RIBEIRO','RUA TREVISO 501 APTO 02','SIDERÓPOLIS','SANTA CATARINA','BRAZIL','88860-000','(48) 8416-0072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 22:29:28',0,NULL,3,1,2,1,NULL,NULL),(5556,663708192002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','sandren10','sandren_82@hotmail.com','Thurairatnam Uthayachandran','Rødetvet veien 9c','Oslo','OSlo','NORWAY','0955','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 23:11:07',0,NULL,3,1,3,1,NULL,'摄影背心  canon  m  1\r老款  RR843874780CN\r'),(5557,621489335001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','robin0onibus','robin159951@gmail.com','Mohammad Hossain','76 Silvio Ave','Toronto','ON','CANADA','M1K1V3','(647) 244-3683','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,NULL),(5559,724695852015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','ealpozo','alpozo@cajamar.es','Antonio Luis Pozo Marín','Avd José Antonio, 16','Tíjola','Almeria','SPAIN','04880','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 23:36:04',0,NULL,3,1,2,1,NULL,'一转四灯头   1 '),(5560,624156029001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','assmoll','quintosarvin@yahoo.com','arvinquintos','apartment #5 G. Dochall building 4 ewing st.','hamilton','','BERMUDA','hm17','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 00:12:17',0,NULL,3,1,2,1,NULL,NULL),(5561,663727767002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','p_ronto','p_ronto@hotmail.com','Panos Rontogiannis','5 Tzoumerkon street<br>Papagos','Athens','Attiki','GREECE','15669','++302106544955','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 00:13:39',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5562,663730513002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','michele2310','mshirer23@yahoo.com','MICHELE SHIRER','432 CENTER STREET','GRATIOT','OH','UNITED STATES','43740','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-25 00:22:23',0,NULL,3,1,1,1,NULL,NULL),(5563,624153512001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','pixel-photo','fern49@gmail.com','Fernand Larochelle','5292 rue des Violettes','Charlesbourg','QC','CANADA','G1G 1N4','(418) 260-9423','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 00:46:29',0,NULL,3,1,2,1,NULL,NULL),(5564,624165140001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','shoeskate05','skateshoe05@hotmail.com','erick martinez','575 ivy street','san francisco','CA','UNITED STATES','94102','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-25 00:47:22',0,NULL,3,1,1,1,NULL,'麂皮  1 '),(5565,661048854002,120568071825,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','susantorudy','rudy.sto@gmail.com','Rudy Susanto','Apartemen Gading Mediterania Residences Tower A/19AG<br>Jl.Boulevard BGR Kelapa Gading','Jakarta','DKI Jakarta','INDONESIA','14250','+628179993920','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 00:48:14',0,NULL,3,1,2,1,NULL,NULL),(5566,663743729002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','iankoning','bamiballetje@gmail.com','Ian Koning','Bernadottelaan 232','HAARLEM','','NETHERLANDS','2037GX','0613349568','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 01:03:04',0,NULL,3,1,3,1,NULL,'肩架  1 RR843874705CN'),(5568,663744714002,120568071854,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','johnlx-2008','postc@seznam.cz','Jaroslav Lhotsky','Fabianova 511/2','Prague 5','Czech Republic','CZECH REPUBLIC','15000','+420739358514','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 01:07:04',0,NULL,3,1,5,1,NULL,'2m  灯架  2\r双灯头  欧标  2\r反光伞   2\r包    1 \rCP219487470CN\r'),(5569,624195990001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','nathanivy','americanivy@gmail.com','Ryan Ivy','3127 Josephine St','Denver','CO','UNITED STATES','80205-4152','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-25 02:46:35',0,NULL,3,1,1,1,NULL,' '),(5571,663793056002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','jjelicich','jjelicich@citipointe.com.au','Verona Saints','PO BOX 2141','Mansfield BC','Queensland','AUSTRALIA','4122','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 04:14:30',0,NULL,3,1,3,1,NULL,' 肩架   1RR843874688CN'),(5573,663805038002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','deefadug','duggy@exemail.com.au','doug woods','24 Atami Crescent','Corio','Victoria','AUSTRALIA','3214','0352757636','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 05:13:34',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5574,624226557001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','t.u.k.a','2-ka@mail.ru','Arthur Zakirov','103 Lunacharskogo Str. App. 48.','Perm','Permskiy Kray','RUSSIAN FEDERATION','614015','+79655658152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 05:14:59',0,NULL,3,1,3,1,NULL,'40cm 棚  1 RR843874728CN\r'),(5575,710562233016,260660054471,'TianYa Gradual Gray Plexigl Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 05:56:55',0,NULL,8,1,17,0,NULL,NULL),(5576,724817398015,250692240685,'TianYa NEUTRAL DENSITY ND8 Filter replaces for Cokin P',1,'AA2325',4.65,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 05:56:56',0,NULL,8,1,17,0,NULL,NULL),(5577,724816918015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.39,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 05:56:56',0,NULL,8,1,17,0,NULL,NULL),(5578,724816786015,250599920440,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.39,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 05:56:56',0,NULL,8,1,17,0,NULL,NULL),(5579,710561677016,260660052780,'New Circular Polarizing C-PL CPL Filters for Cokin P',1,'AA2326',10.99,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 05:56:57',0,NULL,3,1,3,1,NULL,'cpl  1\r77mm 接口环  1\r52mm 接口环  1\rnd8   1\r渐变灰   1 .\rRR843874966CN\r'),(5580,624221997001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',2,'AA1314',5.98,'hermeshine','robinmaness2009','kiwedin@gmail.com','Robin Maness','1060 Chippewa cres','Sarnia','ON','CANADA','N7T8A7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 06:32:40',0,NULL,3,1,2,1,NULL,'机身盖/镜头后盖 nikon  2 '),(5582,724828381015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',13.9,'hutongstore','perugorria','pedro_etxaniz@donostia.org','Pedro Echaniz Rojo','Apartado 35','Pasaia','Euskadi','SPAIN','20110','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 06:59:07',0,NULL,3,1,2,1,NULL,'50cm 棚  1 '),(5583,624243987001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','lantal007','lantal87@optusnet.com.au','Laurie Antal','8 Garfield Ave','Kurralta Pk','South Australia','AUSTRALIA','5037','0882935856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 07:15:21',0,NULL,3,1,2,1,NULL,NULL),(5585,663826368002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','t_isoviita','tapio_isoviita@hotmail.com','Tapio Isoviita','Lestikatu 4b','Kankaanpää','','FINLAND','38700','0405271406','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 07:41:14',0,NULL,3,1,2,1,NULL,NULL),(5586,624251366001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.5,'hermeshine','michelaterreur','achvend@orange.fr','Michel Berger','3 allée des serins','St Gilles','Réunion','REUNION','97434','0262245104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 08:03:46',0,NULL,3,1,2,1,NULL,NULL),(5587,624250522001,110566021586,'TianYa New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','gohher','hher@hknews.co.kr','Her Sung Ho','Kuro 5-Dong 23-2<br>Kuro-Goo','Seoul','','KOREA,REPUBLIC OF','152-838','82-2-3282-1812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 08:09:37',0,NULL,8,1,17,0,NULL,NULL),(5588,624250441001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','gohher','hher@hknews.co.kr','Her Sung Ho','Kuro 5-Dong 23-2<br>Kuro-Goo','Seoul','','KOREA,REPUBLIC OF','152-838','82-2-3282-1812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 08:09:38',0,NULL,8,1,17,0,NULL,NULL),(5589,624249954001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','gohher','hher@hknews.co.kr','Her Sung Ho','Kuro 5-Dong 23-2<br>Kuro-Goo','Seoul','','KOREA,REPUBLIC OF','152-838','82-2-3282-1812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 08:09:38',0,NULL,8,1,17,0,NULL,NULL),(5590,624249780001,110566019079,'Full Set 52mm-77mm 7 Adapter Ring Filter Holder 4 cokin',1,'AKT025',25.98,'hermeshine','gohher','hher@hknews.co.kr','Her Sung Ho','Kuro 5-Dong 23-2<br>Kuro-Goo','Seoul','','KOREA,REPUBLIC OF','152-838','82-2-3282-1812','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 08:09:39',0,NULL,8,1,17,0,NULL,NULL),(5591,624250231001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','gohher','hher@hknews.co.kr','Her Sung Ho','Kuro 5-Dong 23-2<br>Kuro-Goo','Seoul','','KOREA,REPUBLIC OF','152-838','82-2-3282-1812','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 08:09:39',0,NULL,3,1,3,1,NULL,'渐变灰  渐变橙  渐变蓝 \rND2   ND4  ND8 \r6PCS滤镜袋  1\r52-77mm 接口环 + 托架  1\r82mm 接口环   1\rstar6  1\rstar8   1 .\rRR843874881CN\r'),(5592,724845284015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.49,'hutongstore','manninej1979','manninej@gmail.com','Jarno Manninen','Arkkitehdinkatu 38 A 12','Tampere','Pirkanmaa','FINLAND','33720','+358447552901','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 08:28:58',0,NULL,8,1,17,0,NULL,''),(5593,710589382016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','manninej1979','manninej@gmail.com','Jarno Manninen','Arkkitehdinkatu 38 A 12','Tampere','Pirkanmaa','FINLAND','33720','+358447552901','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 08:28:59',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞  1 \rRR843876919CN\r'),(5594,724844941015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','manninej1979','manninej@gmail.com','Jarno Manninen','Arkkitehdinkatu 38 A 12','Tampere','Pirkanmaa','FINLAND','33720','+358447552901','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-25 08:28:59',0,NULL,3,1,3,1,NULL,'大号灰卡  1 \r80cm 5in1  反光板  1\rRR843875051CN\r\r '),(5595,663837470002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gagan.aries','gagan.aries@gmail.com','Gagan Bhatia','Zynga Game Network India Private Limited<br>5th floor, Esquire Center, No.9 MG Road','Bangalore','KA','INDIA','560001','919916222288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 08:48:59',0,NULL,3,1,2,1,NULL,'fangbo1234 '),(5596,724853437015,250606688659,'New IR Remote Control for Pentax K10D K20D K100D',1,'AA2205',2.75,'hutongstore','kissmukk','szentesi.adam@gmail.com','Adam Szentesi','Keszkeno u 1.','Budapest','','HUNGARY','1131','+36-1-3706090','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 09:12:20',0,NULL,3,1,2,1,NULL,'红外遥控 5in1   1 '),(5598,663661188002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','pavlo7032','pasha@graphiteconcept.com','Pavlo Kasprevych','79 Ak.Koroleva str. apt. 23','Odessa','Odessa','UKRAINE','65122','+380503164586','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 10:53:22',0,NULL,3,1,3,1,NULL,'碗罩  p4   1 \rRR843874970CN\r'),(5600,663832132002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',3,'AO0005',38.4,'hermeshine','maisy_mouse66','bodger4@optusnet.com.au','Carey Donoghoe','7 Weiske Street','Narre Warren, Melbourne','Victoria','AUSTRALIA','3805','0423565015','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-25 10:48:28',0,NULL,3,1,3,1,NULL,'1.6x2.1  绿色  粉色  浅蓝 黄色    背景布  4 \rRR843875167CN\r'),(5601,621626461001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','chandler_furt','chandler_furtado@hotmail.com','Chandler Furtado / Roberta LIns','2 Putnam St','Nashua','NH','UNITED STATES','03064-2548','(603) 785-9414','NoPaymentFailure','CheckoutComplete','Other','2011-01-26 01:03:33',0,NULL,3,1,1,1,NULL,'nikon 摄影背心 L   1\r老款 黑 '),(5604,623789257001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','darkwinner','darkwinner@hotmail.com','Victor Campos','1014 W Harvard St','Champaign','IL','UNITED STATES','61821-2533','','NoPaymentFailure','CheckoutComplete','Other','2011-01-27 02:16:44',0,NULL,3,1,3,1,NULL,' RR843875431CN\r'),(5605,622285919001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','progresia','sorocan.irina@gmail.com','Irina Sorocan','Moldova (republic of), Chisinau, str. Piata Garii 2, apt. 9','Chisinau','','MOLDOVA, REPUBLIC OF','2001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-27 16:41:10',0,NULL,5,1,18,0,NULL,NULL),(5606,706950264016,260660052995,'New Genuine Nikon 90th Anniversary Camera Neck Strap',2,'AB1402',17.98,'hutongstore','shilzo','ub3r.shilzo@gmail.com','James Shilingis','6 Frances Green Springfield','Chelmsford','Essex','UNITED KINGDOM','CM1 6EG','07545592682','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-28 07:16:58',0,NULL,5,1,18,0,NULL,NULL),(5612,724610228015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','ibtisam-7','ibti-7@hotmail.com','Ibtisam Sadegh','Le monde, 56, censu busuttil','Iklin','Malta','MALTA','IKL1021','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-29 13:32:32',0,NULL,5,1,18,0,NULL,NULL),(5614,620584741001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',11,'AA1309',26.6,'hermeshine','ynovikov','portsmann@gmail.com','YURI NOVIKOV','Dunaisky prospekt 24, 48','St.Petersburg','-','RUSSIAN FEDERATION','196158','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-30 01:20:54',0,NULL,5,1,18,0,NULL,NULL),(5624,680261173002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','ottawaronin','manjiro@gmail.com','John Tajima','112 Monterey Dr','Ottawa','ON','CANADA','K2H 7A8','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 03:33:56',0,NULL,3,1,3,1,NULL,' 黑色的厚的 xl sony 背心 \r  1\rRR843870876CN\r8\r '),(5625,640230290001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','1086_kloda','waldemar_kloda@yahoo.ca','WALDEMAR KLODA','26 HARJOLYN DR','TORONTO','ON','CANADA','m9b3t9','(416) 232-1086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 04:28:42',0,NULL,3,1,2,1,NULL,NULL),(5626,680292879002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT055',126,'hermeshine','o.g.s.ofilms','kgosidintsi@gmail.com','OREEDITSE KGOSIDINTSI','P O BOX 70593','GABORONE','','BOTSWANA','00267','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 06:27:05',0,NULL,3,1,5,1,NULL,'欧标转美标头  2\r申报$5  gift\rCP219487545CN\r'),(5627,680297154002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','stparadox1','z.man2@centrum.cz','Zdenek Konecny','Slunecna 16','Hodonin','','CZECH REPUBLIC','69501','042 739 131 135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 06:47:53',0,NULL,3,1,2,1,NULL,NULL),(5628,640256459001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','rs-rons-shop','tzrohn@gmail.com','Yaron Tsezana','Hamaagal 36','Ramat-Gan','Israel','ISRAEL','52472','(972)523631847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 07:09:27',0,NULL,3,1,3,1,NULL,' RR843871029CN\r'),(5629,730163121016,260646700576,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',54.5,'hutongstore','palabe-h','palabe61@gmail.com','László Papp','Dózsa György utca 15/A','Balatonfüred','','HUNGARY','8230','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-01 07:10:35',0,NULL,3,1,5,1,NULL,' CP219487554CN\r'),(5630,730174866016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',2,'AC3301',19.56,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 08:11:57',0,NULL,8,1,17,0,NULL,NULL),(5631,744989967015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',127,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-01 08:11:59',0,NULL,8,1,17,0,NULL,NULL),(5632,744990199015,250692239361,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',77,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-01 08:11:59',0,NULL,3,1,4,1,NULL,'80cm 反光板  5in 1  2\r背景架2mx 1.6m（白）  1\r灯架  2m  4\r50-70 棚  欧标   2\r双灯头  欧标   2\r反光伞  2\r115w 220v   4\r包   2\rlighting kit  $30\rYW864870620CN'),(5633,640277164001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','guessouzbak','gui_ome@live.fr','guillaume aguilar','3 rue rougeot','chalon sur saone','Bourgogne','FRANCE','71100','0685229509','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 09:02:19',0,NULL,3,1,4,1,NULL,'background $20 \rYW864870594CN'),(5634,680346062002,120568984657,'Wireless Flash Trigger set CTR-301 P CTR-301P w/PC Sync',1,'AKT013',25.8,'hermeshine','controlaltsup','alex.monjas@gmail.com','Sonia Soriano de Dios','Palex Medical<br>Francesc Viñas, 5','Sant Cugat del Valles','Barcelona','SPAIN','08174','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 10:54:12',0,NULL,3,1,3,1,NULL,' RR843871240CN\r'),(5635,680350917002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','fieraz','fieraz@gmail.com','Pedro Ferrer Martino','PABLO GARNICA, 53D1ºC','TORRELAVEGA','Cantabria','SPAIN','39300','606354535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 11:15:20',0,NULL,3,1,2,1,NULL,NULL),(5636,640325161001,110468046436,'Wireless Flash Trigger set CTR-301 P CTR-301P w/PC Sync',2,'AKT013',51.6,'hermeshine','enriched92','libra-oha@hotmail.com','Hong An Ong','Boon Lay Drive Blk 268a #13-584','default','Boon Lay Drive','SINGAPORE','641268','+65- 96753274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 12:32:58',0,NULL,3,1,3,1,NULL,' RR843871253CN\r'),(5637,680374529002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','kobayashi516','k516k516.10@gmail.com','koichiro kobayashi','kamitsuruma 6-29-3','minami-ku sagamihara-shi','Kanagawa','JAPAN','252-0302','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 12:49:32',0,NULL,3,1,3,1,NULL,' RR843871236CN\r'),(5638,680384168002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 13:24:01',0,NULL,3,1,2,1,NULL,NULL),(5639,745100755015,250599929225,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',8.99,'hutongstore','juvinar','juvinar22@yahoo.com','juvinar santiago','9 cabot green ducie road','lawrence hill','Bristol','UNITED KINGDOM','bs5 0ar','01173730712','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-01 14:17:48',0,NULL,3,1,2,1,NULL,'ND8   1\r77MM 环架  1 '),(5640,640358070001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','slava-svg','svg2003@inbox.ru','Slava Gordienko','Tchaikovskogo 23, kv 48','Blagoveschensk','','RUSSIAN FEDERATION','675025','+79246736884','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 14:36:04',0,NULL,3,1,2,1,NULL,NULL),(5641,680409319002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','linaboard78','linarellomarco@tiscali.it','marco linarello','via barengo, 1','agnellengo di momo','NO','ITALY','28015','3938929816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 14:49:55',0,NULL,3,1,4,1,NULL,'YW864870561CN '),(5642,640363191001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',6,'AB1301',20.04,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-01 14:51:15',0,NULL,8,1,17,0,NULL,''),(5645,730204079016,260660055197,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','moeras1980','moeras1@hotmail.com','anton moerland','crooswijck 2','St-Annaland','','NETHERLANDS','4697 CM','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 15:25:36',0,NULL,3,1,2,1,NULL,' '),(5646,745020954015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',7.5,'hutongstore','moeras1980','moeras1@hotmail.com','anton moerland','crooswijck 2','St-Annaland','','NETHERLANDS','4697 CM','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 15:25:35',0,NULL,3,1,2,1,NULL,''),(5647,640378410001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',6,'AB1301',20.04,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-01 15:49:31',0,NULL,3,1,1,1,NULL,'  橡胶遮光罩 52mm  12'),(5657,745262264015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'AA3314',3.82,'hutongstore','bibmas_hoff','bibmas@get2net.dk','Thomas Hoff','Tangevej 10','Skovlunde','','DENMARK','2740','(+45) 44538747','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 19:36:44',0,NULL,3,1,2,1,NULL,'绿叶 CPL  67mm    1\r绿叶 CPL  77mm   1'),(5656,730435293016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','bibmas_hoff','bibmas@get2net.dk','Thomas Hoff','Tangevej 10','Skovlunde','','DENMARK','2740','(+45) 44538747','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 19:36:44',0,NULL,8,1,17,0,NULL,NULL),(5650,680451481002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','kitae42','j.kim2@yahoo.com','HAE SOOK KIM','1395 Tomah Dr','FRISCO','TX','UNITED STATES','75034-0962','(551) 486-2820','NoPaymentFailure','CheckoutComplete','Other','2011-03-01 16:53:01',0,NULL,3,1,1,1,NULL,'老款 厚  m '),(5651,640412669001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','mhmarkham','meenahar@yahoo.com','Meena Hari','25 Juneberry Ave','Markham','ON','CANADA','L3s 4B1','(905) 294-5286','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 17:14:37',0,NULL,3,1,2,1,NULL,NULL),(5652,640452356001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','gethomeb4dark','maixue.barrow@gmail.com','Michelle Barrow','Box  3904','Banff','AB','CANADA','T1L 1E4','4939510490','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 18:43:49',0,NULL,3,1,2,1,NULL,' '),(5654,640460358001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','ibico1974','kenneth.augdal@gmail.com','Kenneth Augdal','Ishavsvegen 69B','Tromsø','Troms','NORWAY','9010','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 19:05:11',0,NULL,3,1,3,1,NULL,' RR843871165CN\r'),(5655,680512937002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','explorer1969','frode.edvindsen@yahoo.no','Frode Edvindsen','Odvar Solbergs Vei 216','Oslo','Oslo','NORWAY','0973','004792807077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 19:08:10',0,NULL,8,1,17,0,NULL,NULL),(5658,640463195001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','misc_items_2010','ebay-sales@talknflirt.com','Ricky Gamble','1 Flanders Row<br>Railway Road','Wisbech','Cambridgeshire','UNITED KINGDOM','PE13 2UP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 19:37:32',0,NULL,3,1,2,1,NULL,NULL),(5659,680360965002,120536002597,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',3,'AB1407',23.67,'hermeshine','ynovikov','portsmann@gmail.com','YURI NOVIKOV','Dunaisky prospekt 24, 48','St.Petersburg','-','RUSSIAN FEDERATION','196158','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 20:05:09',0,NULL,3,1,3,1,NULL,' RR843871179CN\r'),(5660,640510149001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','j_b_luo','j_b_luo@hotmail.com','Jiabin Luo','32 Yellow Birchway','North York','ON','CANADA','M2H 2T3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 20:36:00',0,NULL,3,1,2,1,NULL,NULL),(5661,640510267001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','cadlp','mr.clean2@verizon.net','David L. Pinckney','81 Corinne Dr','Newbury Park','CA','UNITED STATES','91320','(805) 796-9894','NoPaymentFailure','CheckoutComplete','Other','2011-03-01 20:36:14',0,NULL,8,1,17,0,NULL,NULL),(5662,680557143002,120566694530,'Neoprene Protector Camera Cover  for Nikon Size: Large ',1,'AC1303',9.25,'hermeshine','cadlp','mr.clean2@verizon.net','David L. Pinckney','81 Corinne Dr','Newbury Park','CA','UNITED STATES','91320','(805) 796-9894','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-01 20:36:14',0,NULL,3,1,1,1,NULL,'摄影背心 Nikon  xxxl  老款 厚  黑   1\r大号内胆包 nikon    1 '),(5663,745318550015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',13.9,'hutongstore','marshia31','pepsoua@hotmail.com','Maria Panagiotou','P.O.BOX 70705','Limassol','Cyprus','CYPRUS','3802','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 21:00:12',0,NULL,3,1,2,1,NULL,' '),(5664,640535157001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','valla34','osquarmm@yahoo.es','Oscar Montero Muñoz','C/ Manuel Jimenez El Alguacil, 1, 9, 1B','Pinto','Madrid','SPAIN','28320','655462124','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 21:29:25',0,NULL,3,1,4,1,NULL,' YW864870572CN'),(5665,680593731002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','explorer1969','frode.edvindsen@yahoo.no','Frode Edvindsen','Odvar Solbergs Vei 216','Oslo','Oslo','NORWAY','0973','004792807077','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 21:45:31',0,NULL,8,1,17,0,NULL,NULL),(5666,640545353001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','explorer1969','frode.edvindsen@yahoo.no','Frode Edvindsen','Odvar Solbergs Vei 216','Oslo','Oslo','NORWAY','0973','004792807077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 21:50:14',0,NULL,3,1,4,1,NULL,'双灯头 欧标   1\r115w 220v   2\r2m 灯架  2\rb座   2\r柔光伞   2 \rYW864870583CN'),(5667,640568774001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',2,'AA1307',5,'hermeshine','j-ric117','jandon@centurylink.net','jan richardson','29180 engoe rd','washburn','WI','UNITED STATES','54891-4899','(715) 373-5427','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-01 22:55:07',0,NULL,3,1,1,1,NULL,NULL),(5668,745389283015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','minimalteq','marcinkielek0@wp.pl','Marcin Kielek','53 Degrees North Unit 428, Retail Park 3, Blanchardstown Centre','Dublin','Dublin','IRELAND','15','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 23:19:44',0,NULL,3,1,2,1,NULL,NULL),(5669,640610568001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','apcpnp00','tprice@uaw.net','Anthony Price','13130 Dartmouth St','Oak Park','MI','UNITED STATES','48237-1632','(248) 548-1226','NoPaymentFailure','CheckoutComplete','Other','2011-03-02 01:24:20',0,NULL,3,1,1,1,NULL,'摄影背心 nikon 老款 厚  xxxl   1 '),(5670,745432169015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','copelinter','ricoplin@googlemail.com','Richard Copeland','69 Delamere RD Bedworth','Nuneaton','Warwickshire','UNITED KINGDOM','CV12 8SG','02476314961','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-02 01:28:17',0,NULL,3,1,2,1,NULL,NULL),(5671,680663798002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','palenquej','jpalenque@hotmail.com','javier palenque','16575 SW 100th Ter','MIAMI','FL','UNITED STATES','33196-1026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-02 01:21:47',0,NULL,3,1,1,1,NULL,NULL),(5672,730638802016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'AA1311',3.5,'hutongstore','remiaus','akestanolatienes@gmail.com','Jon Ribera Medina','betolaza num.7bis bajo dcha','Bilbo','País Vasco','SPAIN','48002','689708226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-02 03:48:55',0,NULL,3,1,2,1,NULL,'气吹+ 布   1 '),(5673,680710690002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','hot_teg','lukepenfold@hotmail.com','Luke Penfold','14 Candlebark Close','Hampton Park','Victoria','AUSTRALIA','3976','0397997317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 04:22:03',0,NULL,3,1,4,1,NULL,'reflector holder   \r$20 \rYW864870550CN'),(5674,640660032001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','malaka_is','malaka.indrajith@gmail.com','Malaka Indrajith','260/25 B, Depot Road,','Katubedda','Western','SRI LANKA','10400','+94777335273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 05:04:22',0,NULL,3,1,2,1,NULL,NULL),(5675,640606044001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','lucialetizia82','lucialetizia.litrico@virgilio.it','lucia letizia litrico','via salvatore Santangelo n°1','san giovanni galermo','CT','ITALY','95123','3489580807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 05:56:00',0,NULL,3,1,2,1,NULL,' '),(5676,680727462002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','pinballwizard4who','kendyberaldo@yahoo.com.br','Kendy Beraldo','Rua Afonso de Freitas, 350 apto 21','Sao Paulo','Sao Paulo','BRAZIL','04006-905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 05:58:08',0,NULL,3,1,5,1,NULL,'放2个欧标头 \rCP226630830CN'),(5677,640668298001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','realzordrek','zordrek@gmail.com','Peter Gorbik','Azattyk 5a-10','Atyrau','','KAZAKHSTAN','060002','7122328248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 06:09:00',0,NULL,3,1,2,1,NULL,NULL),(5678,640675496001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','o.g.s.ofilms','kgosidintsi@gmail.com','OREEDITSE KGOSIDINTSI','P O BOX 70593','GABORONE','','BOTSWANA','00267','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 06:44:40',0,NULL,3,1,5,1,NULL,' CP226630826CN'),(5679,640691609001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','wil_buan','wil_buan@hotmail.com','Wilfredo Buan','1270 N Marine Corps Dr<br>STE 101 PMB 481','Tamuning','GU','GUAM','96913-4331','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-02 08:19:03',0,NULL,3,1,1,1,NULL,NULL),(5680,680752692002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','zs-dedan','zsdedan@gmail.com','Yuriy Artyomov','Novaya 5-19','Zverosovkhoz, Pushkinsky','Moscow Region','RUSSIAN FEDERATION','141214','+79067512597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 08:20:56',0,NULL,8,1,17,0,NULL,NULL),(5681,745536554015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','pdrozda','pdrozda@gmail.com','Peter Drozda','Stalicova 3','Kosice','','SLOVAK REPUBLIC','04012','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-02 08:23:28',0,NULL,3,1,2,1,NULL,NULL),(5682,640692789001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','zs-dedan','zsdedan@gmail.com','Yuriy Artyomov','Novaya 5-19','Zverosovkhoz, Pushkinsky','Moscow Region','RUSSIAN FEDERATION','141214','+79067512597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 08:26:02',0,NULL,3,1,2,1,NULL,NULL),(5683,680789923002,120601700533,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','jarsjoseantonio','jars.diablo@gmail.com','jose antonio ruiz sanchez','hurb los altos manzana 5 nº73','torrevieja','Comunidad Valenciana','SPAIN','03185','661067167','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 11:09:00',0,NULL,3,1,4,1,NULL,'欧标 \rlighting kit  $30\rYW864870653CN\r'),(5684,680814883002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','sylvain286','sylricha@bell.net','Sylvain Richard','697 du Moulin','Magog','QC','CANADA','J1X 5Z5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 12:45:29',0,NULL,3,1,3,1,NULL,' RR843871372CN\r'),(5685,640753170001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',2,'AA3314',13,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 12:50:45',0,NULL,8,1,17,0,NULL,NULL),(5686,680815670002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',2,'AA3313',12,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 12:50:47',0,NULL,8,1,17,0,NULL,NULL),(5687,640753138001,110407881132,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',2,'AA3308',11.2,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 12:50:48',0,NULL,8,1,17,0,NULL,NULL),(5688,640753145001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',2,'AA3310',11.2,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 12:50:49',0,NULL,3,1,3,1,NULL,'绿叶 CPL  77mm   2\r 绿叶 CPL 72mm  2\r绿叶 CPL  52mm  2\r绿叶 CPL  58mm  2\rRR843872452CN\r\r'),(5689,680818700002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','hasnahhasim','munirahasim@yahoo.com.my','Hasnah Hasim','No. 6549 , Kampung Guar Kohor , Jalan Changloon','Kodiang','Kedah','MALAYSIA','06100','0195471500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 12:59:48',0,NULL,3,1,2,1,NULL,NULL),(5690,680821493002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','richwhillock','ctsatellites@gmail.com','James Richmond Whillock','3900 Hillcrest Ln','Mobile','AL','UNITED STATES','36693-2832','(251) 666-6030','NoPaymentFailure','CheckoutComplete','Other','2011-03-02 13:09:42',0,NULL,3,1,1,1,NULL,'XL  老款'),(5691,680826352002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','e-paul-info','abrim@op.pl','Pawel Abramczyk','1A DEANWOOD AVE.<br>TOGHER','CORK','','IRELAND','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 13:28:01',0,NULL,8,1,17,0,NULL,' '),(5692,680825724002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','e-paul-info','abrim@op.pl','Pawel Abramczyk','1A DEANWOOD AVE.<br>TOGHER','CORK','','IRELAND','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 13:28:01',0,NULL,3,1,2,1,NULL,'渐变灰  1\r72mm 环架   1 '),(5693,745643400015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','ywetka83','ywetka@gmail.com','Iveta Tonhauserova','Madridska 3','Kosice','','SLOVAK REPUBLIC','04013','+421911266303','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-02 14:08:52',0,NULL,3,1,3,1,NULL,' RR843871457CN\r'),(5694,680839942002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','rotel54','fam.r.hunziker@bluewin.ch','Hunziker Rolf','Tannmättli 6','Tägerig','','SWITZERLAND','5522','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 14:13:41',0,NULL,3,1,3,1,NULL,'xxl   老款\rRR843871267CN\r'),(5695,730814419016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-02 15:09:28',0,NULL,8,1,17,0,NULL,NULL),(5696,745659157015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-02 15:09:28',0,NULL,8,1,17,0,NULL,NULL),(5697,730814108016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-02 15:09:29',0,NULL,3,1,4,1,NULL,'背景架2m x 3m  1\r 背景布 3x6 绿色  1\r灯架  2m  2\r柔光箱 50-70cm 单灯头  2   欧标\r115w 5500k 灯泡  220v  2\r包  1\r100-150 5in1 反光板  1\r1转4 灯头   1\rlighting kit   $30\rYW864870642CN\r\r\r'),(5698,680876900002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','hifromrussia','darkvision@inbox.ru','Sergey Pavlov','37.  Marshala Tyhachevskogo st.<br>app. 98','Saint Petersburg','','RUSSIAN FEDERATION','195067','+7(812)6574842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 16:02:46',0,NULL,3,1,2,1,NULL,NULL),(5699,680893167002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 16:47:26',0,NULL,8,1,17,0,NULL,NULL),(5700,640828516001,110533631256,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 16:47:25',0,NULL,8,1,17,0,NULL,NULL),(5701,640828291001,110532007553,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 16:47:27',0,NULL,8,1,17,0,NULL,NULL),(5702,640827869001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 16:47:27',0,NULL,3,1,3,1,NULL,'大力夹云台  1\rc型大力夹  1\r橡胶遮光罩 77mm   1\r气吹 + 布    1\r RR843871386CN\r'),(5703,680896251002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','waltsidney','sid@ivivo.tv','sidney dulev','26 moshe sneh st.<br>0546655114','tel-aviv','ISRAEL','ISRAEL','69350','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 16:52:45',0,NULL,3,1,3,1,NULL,'\rRR843871823CN\r '),(5704,680911281002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','bert593','bert.h@rogers.com','Bert Hoferichter','137 Green Briar Road','Alliston','ON','CANADA','L9R1X9','(705) 435-6960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 17:28:37',0,NULL,3,1,2,1,NULL,'渐变灰   1 '),(5705,640845262001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','holcdt','clop98@hotmail.com','Martin Piche','54 Rte. Petite Manic','Saint-Rosaire','QC','CANADA','G0Z 1K0','(819) 758-9235','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 17:28:56',0,NULL,3,1,3,1,NULL,' RR843871390CN\r'),(5706,640852060001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','giselenp','ginardino@gmail.com','Gisele N Pereira','R. Carlos Pioli 133','Curitiba','PR','BRAZIL','80520-170','(041)8855-6239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 17:52:43',0,NULL,3,1,2,1,NULL,NULL),(5707,745773459015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',2.39,'hutongstore','badgerdid','dave@todayspics.co.uk','david didcote','103 alrewas road kings bromley','burton on trent','staffordshire','UNITED KINGDOM','de13 7hp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-02 18:43:42',0,NULL,8,1,17,0,NULL,NULL),(5708,745773164015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'AKT024',3.62,'hutongstore','badgerdid','dave@todayspics.co.uk','david didcote','103 alrewas road kings bromley','burton on trent','staffordshire','UNITED KINGDOM','de13 7hp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-02 18:43:43',0,NULL,3,1,2,1,NULL,'方形滤镜接口环 67mm   1\r方形滤镜接口环 77mm  1\r方形滤镜 镜片卡座   1'),(5709,680917525002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','gumanist','de_rulette@pisem.net','Alexey Podenko','str. Respubliki 90 / 283','Tyumen','Tymenskaya','RUSSIAN FEDERATION','625048','+79222670687','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 18:58:51',0,NULL,3,1,3,1,NULL,' RR843871369CN\r'),(5710,640889370001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','anirathrix','anirathrix@hotmail.com','RATTHA BURANADILOK','48/27<br>Moo.5','Bangkruai District','Nontaburee','THAILAND','11130','(66)865293539','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 19:18:52',0,NULL,3,1,3,1,NULL,' RR843871409CN\r'),(5711,745793012015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','acher1972','pjhtroop@hotmail.co.uk','Paul Troop','108 Langham Rd','Blackburn','Lancashire','UNITED KINGDOM','bb1 8dp','01254605400','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-02 19:21:59',0,NULL,3,1,4,1,NULL,'背景架 （ 白 黑） 1  2m的 \rYW864870631CN\r'),(5712,640902740001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','progrita','o_fr10@yahoo.fr','Volha Yurkevich','8 Mazurova street, app. 83','Gomel','','BELARUS','246006','+375296639995','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 19:29:46',0,NULL,3,1,3,1,NULL,' RR843871338CN\r'),(5713,640920359001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-02 20:06:17',0,NULL,3,1,1,1,NULL,'橡胶遮光罩 52mm   10'),(5714,680990473002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','nebojsa977','radivoj.crni@gnb.ca','Radivoj Crni','457 Kings College Rd','Fredericton','NB','CANADA','E3B2G4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 20:18:19',0,NULL,3,1,2,1,NULL,NULL),(5715,680997758002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 20:22:35',0,NULL,3,1,4,1,NULL,'欧标 YW864870605CN\r'),(5716,680985791002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',46.99,'hermeshine','kimikocraft','sophie_pelletier_284@hotmail.com','sophie pelletier','492 rue bernard','dundee','NB','CANADA','E8E1W1','(506) 826-1802','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 20:23:22',0,NULL,3,1,3,1,NULL,' RR843871341CN\r之前发错了     从新给发一票\rRR843872316CN\r'),(5717,681013405002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','bagawiya','bagawiyadesigns@gmail.com','Michele-Anne Hamilton','20 Charlton Rd<br>Townhouse # 2','Kingston 8','St Andrew','JAMAICA','West Indies','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 20:53:07',0,NULL,3,1,2,1,NULL,' '),(5718,681014188002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','beagle5858','morales@zahav.net.il','Svetlana Zohar','Hatarshish 6','Maale Adumim','israel','ISRAEL','98451','+972523818998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 20:54:27',0,NULL,3,1,2,1,NULL,NULL),(5719,640953526001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',4,'AE3103',39.2,'hermeshine','meir_1','meirberko@gmail.com','meir berkovich','3/5 carmel st\'<br>Ahozot hanasi','Rehovot','','ISRAEL','76305','972-54-2399652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 21:11:34',0,NULL,3,1,3,1,NULL,' RR843871355CN\r'),(5720,681023286002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','s.j.r.j','the_ravent_el_angel_maldito@hotmail.com','salvador j. rueda jaime','c antonio postigo jimenez nº 5','mijas ( pueblo )','Andalucía Ceuta y Melilla','SPAIN','29650','659548819','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 21:15:05',0,NULL,3,1,4,1,NULL,' YW864870675CN\r'),(5721,745877635015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.58,'hutongstore','usernameraymond*','xgadsby@hotmail.co.uk','K Gadsby','61 Burton Street','Melton Mowbray','Leicestershire','UNITED KINGDOM','LE131AF','07973506463','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-02 21:22:29',0,NULL,3,1,2,1,NULL,NULL),(5722,640208958001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','konik232','exploit232@yandex.ru','Alexander Konik','B.Sadovaya, 139/150 - 16','Saratov','','RUSSIAN FEDERATION','410054','79272771871','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 21:32:20',0,NULL,3,1,5,1,NULL,' CP226630790CN\r'),(5723,640980425001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','murp81011','murp8101@bears.unco.edu','Ryan Murphy','2730 W Wesley Ave<br>Apt 5','Denver','CO','UNITED STATES','80219-5900','(719) 661-7360','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-02 22:15:01',0,NULL,3,1,1,1,NULL,' '),(5724,681057037002,120618815235,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'AA2301',5.7,'hermeshine','jay.chan','hopextreme@hotmail.com','Jay Chan','Blk 157 Jalan Teck Whye #16-119<br>Singapore 680157','default','','SINGAPORE','680157','65 93665229','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 22:27:39',0,NULL,3,1,11,1,NULL,NULL),(5725,681069378002,120461614281,'JJC Hand Strap Grip  HS-1 Nikon D40 D60 Canon 450D',1,'AB1408',6.99,'hermeshine','bjohund','bjhund@online.no','Bjørnar Hundseth','Bjørnstjerne Bjørnsons veg 63','Molde','','NORWAY','6412','(+47) 45865854','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 23:06:45',0,NULL,3,1,2,1,NULL,NULL),(5726,745617309015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','moizora','moizora@hotmail.com','domingo santana santana','ceramista alicia martin fernandez 4','las palmas de gran canaria','Canarias','SPAIN','35018','655 777397','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-02 23:18:59',0,NULL,3,1,2,1,NULL,' '),(5727,641004950001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','moudat','daoust.m@sympatico.ca','Manon Daoust','109, Place Fontainebleau','Saint-Lambert','QC','CANADA','J4S 1X6','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 23:29:14',0,NULL,3,1,3,1,NULL,'RR843871315CN\r '),(5728,641027934001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.6,'hermeshine','lucascdrosa','lucascrosa@gmail.com','Lucas Rosa','Rua Dr. Carlos Norberto, 15','Socorro','São Paulo','BRAZIL','13960-000','019 3895-6759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 01:00:45',0,NULL,3,1,2,1,NULL,NULL),(5729,641039410001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','ioques','mar.ioques@gmail.com','Mário Marques','Pça Portela nº17, 11º (Atelier) Esq Laranjeiro','ALMADA','ALMADA','PORTUGAL','2810 - 270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 01:46:40',0,NULL,3,1,3,1,NULL,' 第一次发丢了，再发一次挂号小包\r刘\rRA117728586CN\r'),(5730,641051023001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','cinthiamake','cinthiadesign@hotmail.com','cinthia ferreira','rua atibaia 500 apto 44 - valparaiso','santo andré','sao paulo','BRAZIL','09060110','551144269253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 02:34:33',0,NULL,3,1,2,1,NULL,NULL),(5731,641053712001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',91.58,'hermeshine','zero-2010','zero868@gmail.com','mohammed  mazeed','al waha-Sector2-Street8-house22<br>tel:55870555 P.O.BOX.3105 CODE NO.01003','al Jahra','Kuwait','KUWAIT','01003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 03:21:55',0,NULL,3,1,3,1,NULL,'柔光伞   1\r45w 220v   2\r40cm 棚   1\r50-70 单灯头棚   1\r单灯头   1\r\rRR843871899CN\r\r '),(5732,681143888002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',4,'AA2106',140,'hermeshine','dgtesurf09','dgtesurf@yahoo.com.ph','Harry Jones Delos Santos','26 Katada St.','Dumaguete','negros oriental','PHILIPPINES','6200','0352252200','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 03:37:17',0,NULL,8,1,17,0,NULL,''),(5733,681144588002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',3,'AA2106',105,'hermeshine','dgtesurf09','dgtesurf@yahoo.com.ph','Harry Jones Delos Santos','26 Katada St.','Dumaguete','negros oriental','PHILIPPINES','6200','0352252200','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 03:40:15',0,NULL,3,1,6,1,NULL,'摄影背心 canon M 老款  4 \r摄影背心 canon xl 老款  3  \r4.468\rEE389037458CN\r'),(5734,641073256001,110519774429,'Pro FANCIER WF-531T Tripod with 593H 6662a Upgraded NEW',1,'AE1101',79,'hermeshine','lpg2004_123','lpg2004@msn.com','Leonardo Peñate Giacometto','Calle 127B#14A-12 Apto 402','Bogota','Cundinamarca','COLOMBIA','00000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 04:09:47',0,NULL,7,0,18,0,NULL,NULL),(5735,681153636002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ceewuu20','ceewuu@gmail.com','ceee wuuu','1414 25th ave','san francisco','CA','UNITED STATES','94122-3318','(415) 200-7720','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-03 04:21:45',0,NULL,3,1,1,1,NULL,NULL),(5736,641077588001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.8,'hermeshine','superman_celica','jerry_clc@yahoo.com','Big Dog Style','2730 Skyview Ridge Ct','houston','TX','UNITED STATES','77047','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-03 04:31:47',0,NULL,3,1,3,1,NULL,' RR843871576CN\r'),(5737,681160105002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','catokusanagi','trainer_cato@hotmail.com','Juan Antonio Alvarez S.','Av De los Reyes #44<br>Seccion Parques','Cuautitlan Izcalli','Estado de Mexico','MEXICO','54720','5538039347','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 04:57:10',0,NULL,3,1,3,1,NULL,' RR843871324CN\r'),(5738,681166035002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bakar72','alexander.bakiev@gmail.com','Aleksandr Bakiev','kv 3, dom 5, Truda sq.','Volzhsky','Volgograd region','RUSSIAN FEDERATION','404121','79616666001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 05:27:24',0,NULL,3,1,2,1,NULL,NULL),(5739,681172276002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',20.99,'hermeshine','kassrakalantari','kassrak@gmail.com','kassra kalantari','1613 salal crescent','Coquitlam','BC','CANADA','v3e2y3','(778) 285-9291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 06:08:35',0,NULL,3,1,3,1,NULL,''),(5740,681173581002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','caposaure','capcav@neuf.fr','Gilles Bangratz','8 rue du moulin','HILSENHEIM','Alsace','FRANCE','67600','0388859493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 06:16:02',0,NULL,3,1,3,1,NULL,'\rRR843871956CN\r'),(5741,681182764002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','nurken2008','nurken@ya.ru','Nurken Kshibayev','Lenina str., 24-5','Karaganda','','KAZAKHSTAN','100000','+7-7212-569180','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 07:16:40',0,NULL,3,1,2,1,NULL,NULL),(5742,681185714002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','peredaarias','alberto_p40@hotmail.com','Alberto Pereda Arias','Paseo de la Democracia 6','Arganda del Rey','Madrid','SPAIN','28500','627370139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 07:31:58',0,NULL,3,1,4,1,NULL,' YW864870616CN\r'),(5743,681188905002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',5,'AA1205',12.95,'hermeshine','jaroslawkurek','jaroslaw.kurek@poczta.neostrada.pl','Jarosław Kurek','Kalinowa 1<br>skr.poczt. 84','Nadarzyn','mazowieckie','POLAND','05-830','22 7398568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 07:49:53',0,NULL,3,1,3,1,NULL,' RR843871580CN\r'),(5744,681199986002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','palagorn2006','plgorn@hotmail.com','Palagorn Raybumrung','888/104 Panuch Village<br>Pracharajbumpen Road,Samseannok,','Huaikhang','Bangkok','THAILAND','10320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 08:48:49',0,NULL,3,1,3,1,NULL,' \rRR843871766CN\r'),(5745,641120164001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','sprinred','alxbruce@yahoo.com','Alex Bruce','7823 Garfield Drive','Delta','BC','CANADA','V4C4C9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 08:49:15',0,NULL,3,1,5,1,NULL,' CP226630812CN\r'),(5746,641124348001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','buyedv','u-need_pro@hotmail.com','wuttikrai sritawai','20 soi.6<br>Ratyindee Road.','hadyai','songkhla','THAILAND','90110','+66869622227','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 09:10:14',0,NULL,3,1,8,1,NULL,'\rCP226630772CN\r'),(5747,681206949002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','mackey2340','rizekookir@hotmail.com','david mackey','3045 Shauna Dr','highland','CA','UNITED STATES','92346-1738','(909) 864-0974','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-03 09:46:08',0,NULL,3,1,1,1,NULL,'LK028586475CN '),(5748,746098358015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',2.39,'hutongstore','kobiastangelov','astangelov@gmail.com','kobi astangelov','yekutiel adam 28','or yehuda','israel','ISRAEL','60352','(792) 547127770','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-03 09:46:57',0,NULL,3,1,2,1,NULL,NULL),(5790,641492784001,110583278199,'TianYa 58mm CPL filter New 58 Circular Polarizing C-PL',1,'AA2303',5.9,'hermeshine','sonex-mike','kurilenkom@gmail.com','Mihail Kurilenko','Kirova 72/14','Pyatigorsk','RU','RUSSIAN FEDERATION','357500','+78793390387','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 04:37:42',0,NULL,3,1,2,1,NULL,NULL),(5749,641141580001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','maespbandrey','mae_spb@mail.ru','ANDREY MIKHAYLOV','Savushkina<br>133-1-44','Saint-Petersburg','Leningradskaya oblast','RUSSIAN FEDERATION','197374','+79117588434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 10:40:55',0,NULL,3,1,2,1,NULL,NULL),(5750,641149782001,110523102266,'67mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1307',2.6,'hermeshine','corzab72','corzab@dodo.com.au','Corie Blackley','30 Victoria St','Korumburra','Victoria','AUSTRALIA','3950','0403051761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 11:05:42',0,NULL,3,1,2,1,NULL,NULL),(5751,681231890002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','joneff51','desmo450@hotmail.com','John Farrell','12 Light Place<br>Colonel Light Gardens','Adelaide','South Australia','AUSTRALIA','5041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 11:16:16',0,NULL,3,1,2,1,NULL,NULL),(5752,641154194001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','the-collezioni','luarecollezioni@gmail.com','Luare Collezioni','PO BOX 400652','Hesperia','CA','UNITED STATES','92340','','NoPaymentFailure','CheckoutIncomplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,NULL),(5753,681245864002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','xarmene','mnrtzs@yahoo.gr','Charalampos Meneretzis','pindou 36','PARALIA DISTOMOU','GU','GREECE','32003','2267042737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 12:15:42',0,NULL,3,1,2,1,NULL,NULL),(5754,641166249001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jweg01','j.gilbert@unb.ca','John Gilbert','2 Conc. 6','Chepstow','ON','CANADA','N0G 1K0','(519) 901-2190','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,NULL),(5756,681274083002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE3104',29.04,'hermeshine','kennyken72385','jacky_mong@yahoo.com','Kenneth King','150A Freelon St','San Francisco','CA','UNITED STATES','94107-1625','(415) 240-9531','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-03 14:40:49',0,NULL,3,1,1,1,NULL,NULL),(5757,681288310002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','glenardh301','glenardh@yahoo.com','glenard hall','323 Madison St','frederick','MD','UNITED STATES','21701-6317','(301) 663-3668','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-03 14:44:05',0,NULL,3,1,1,1,NULL,NULL),(5758,746186852015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','pilesofstones','jmwf@me.com','John Fowles','40 Styebank Lane Rothwell','Leeds','West Yorkshire','UNITED KINGDOM','LS26 0HW','07801286332','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 14:23:56',0,NULL,3,0,18,1,NULL,NULL),(5759,681304843002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','niruddikasuraj','niruddik@ovi.com','Suraj silva','1224, Rajamalwatha Road,<br>Batharamulla, Sri Lanka','Colombo','','SRI LANKA','10120','0094772394757','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 15:36:50',0,NULL,3,1,2,1,NULL,NULL),(5760,681319960002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','samguedes','samuelg.fotografia@gmail.com','Samuel Guedes','Avenida Campinas<br>Chácara do Visconde','Taubaté','São Paulo','BRAZIL','12050-760','+5512 8866-5222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 16:27:29',0,NULL,3,1,3,1,NULL,' RR843871837CN\r'),(5761,731327308016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','mfherbalist','maudfreemantle@hotmail.com','Oscar Freemantle','708 marketgate Bond St S','Bristol','Avon','UNITED KINGDOM','BS1 3PG','07875417713','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 17:05:15',0,NULL,3,1,2,1,NULL,NULL),(5762,681338559002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','meckpomm2002','meckpomm2005@web.de','Kurt Berndt','Fritz Peters   Str. 7','Altentreptow','','GERMANY','17087','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 17:09:46',0,NULL,3,1,2,1,NULL,NULL),(5763,681340058002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','alinakiter','alinenok85@inbox.ru','Roman Pichshev','ulica Askarova, dom1, kv.29','Shymkent','Yuzhno-Kazahstanskaya oblast','KAZAKHSTAN','160019','8 (7252) 40 81 02','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 17:22:12',0,NULL,3,1,3,1,NULL,' RR843871721CN\r'),(5764,641259928001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','fotopomohnikartem','fotopomohnik@mail.ru','Artem Zabolotskikh','Kluchevoy poselok 41-57','Izhevsk','Udmurtia','RUSSIAN FEDERATION','426063','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 17:21:25',0,NULL,3,1,3,1,NULL,' RR843871718CN\r'),(5765,681362445002,120500391259,'Neoprene Protector Camera Cover Case for Canon Nikon L',5,'AC1302',46.25,'hermeshine','jlocatell','jlocatell@gmail.com','Julio Locatelli','Lima 1261<br>Sistemas San Juan','Buenos Aires','CABA','ARGENTINA','1138','5411 43701153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 18:06:37',0,NULL,3,1,3,1,NULL,'RR843871735CN\r '),(5766,745233296015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','bayser2008','contact.infopages@googlemail.com','Nick Pace','24 delaware drive','St leonards on sea','East Sussex','UNITED KINGDOM','tn377tj','01424756840','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 18:59:34',0,NULL,3,1,2,1,NULL,NULL),(5767,731454120016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',4,'AA3312',14.32,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 19:09:02',0,NULL,8,1,17,0,NULL,' '),(5768,746326433015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',4,'AA3314',15.28,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 19:13:57',0,NULL,3,1,3,1,NULL,'绿叶 CPL  77mm  4 \r绿叶 CPL  67mm  4\rRR843872364CN\r'),(5770,641355909001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','jamepong','pong_canon@hotmail.com','Kasemsant Sungsumal','75/27 aisarapap Rd.<br>soi aisarapap39','Bangkok','Bangkoknoi bangkok','THAILAND','10700','0832328999','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 20:47:00',0,NULL,3,1,3,1,NULL,' RR843871854CN\r'),(5771,641357352001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','u3b54','ajt@laudachoir.org','Adrian Taylor','Hordle Walhampton School<br>Walhampton','Lymington','Hampshire','UNITED KINGDOM','SO415ZG','07919883080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 20:50:41',0,NULL,8,1,17,0,NULL,NULL),(5772,641356048001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','u3b54','ajt@laudachoir.org','Adrian Taylor','Hordle Walhampton School<br>Walhampton','Lymington','Hampshire','UNITED KINGDOM','SO415ZG','07919883080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 20:50:42',0,NULL,8,1,17,0,NULL,NULL),(5773,641356282001,110523102158,'62mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1306',2.6,'hermeshine','u3b54','ajt@laudachoir.org','Adrian Taylor','Hordle Walhampton School<br>Walhampton','Lymington','Hampshire','UNITED KINGDOM','SO415ZG','07919883080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 20:50:42',0,NULL,8,1,17,0,NULL,NULL),(5774,641357098001,110523102341,'77mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1309',2.6,'hermeshine','u3b54','ajt@laudachoir.org','Adrian Taylor','Hordle Walhampton School<br>Walhampton','Lymington','Hampshire','UNITED KINGDOM','SO415ZG','07919883080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 20:50:42',0,NULL,3,1,3,1,NULL,'NIKON 镜头盖 52mm  2\rNIKON 镜头盖 62mm  1\rNIKON 镜头盖 77mm  1\rRR843871783CN\r'),(5775,681468816002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','glentaylormt','glentaylor_mt@hotmail.com','Glen Taylor','127 St.Jude<br>Trieq il Htajriet','Mosta','ME','MALTA','3062','21412542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 21:41:05',0,NULL,3,1,3,1,NULL,' RR843871845CN\r3月12号换单\rRA012916032CN \r太长了，没发出去，等客户问就说丢了退钱给他\r'),(5776,681477879002,120601700533,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','bbohnet716','bbohnet18@gmail.com','Brandon Bohnet','4423 109 A Avenue','Edmonton','AB','CANADA','T6A 1S3','(178) 071-6823 ext.: 5','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,5,1,NULL,'庄海峰 bbohnet716\rCP226334942CN'),(5777,681481963002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','prdanv','danielvojta@gmail.com','Daniel Vojta','657 Viewcrest Ter','Burlington','WI','UNITED STATES','53105-1641','(262) 763-3915','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-03 22:13:29',0,NULL,3,1,1,1,NULL,' '),(5778,641396673001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','tool62johans','dennisjohansen@comcast.net','Dennis Johansen','1022 Oakridge Ln','Bountiful','UT','UNITED STATES','84010-2029','(801) 755-8360','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-03 22:22:32',0,NULL,3,1,1,1,NULL,NULL),(5779,641406965001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','lte5280','uqmhrd@yahoo.es','José Ramón Otero Yñiguez de la Torre','C De Las Pozas nº 173 P2 2ºA','San Lorenzo de El Escorial','Madrid','SPAIN','28200','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 22:52:04',0,NULL,3,0,3,1,NULL,'xxxl  尼康 老款  1 \rRR843871939CN\r'),(5780,746477583015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',2,'AA1314',4.4,'hutongstore','mikeand2244','mikeholoanderson@aol.com','Michael Anderson','4 Borrowdale Avenue','Harrow','Middlesex','UNITED KINGDOM','HA37PZ','02084279685','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 23:58:26',0,NULL,3,1,2,1,NULL,NULL),(5781,641428855001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.5,'hermeshine','djuca60','casablancabar@clix.pt','julio silva','rua amorim rosa 44 3º esq','tomar','','PORTUGAL','2300-450','+351919913040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 00:12:08',0,NULL,3,1,2,1,NULL,' '),(5782,681546987002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','man_from_utopia_72','manfromutopia@hotmail.com','Ivan Blecker','37 Arjay Trail','Brampton','ON','CANADA','L6X 4M4','(905) 455-4486','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 01:47:21',0,NULL,3,1,3,1,NULL,' RR843871797CN\r'),(5783,681546860002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','lng22392','lng22392@aol.com','lauryn guerrieri','1200 Galapago St<br>Apt 712','denver','CO','UNITED STATES','80204-3572','(303) 518-8909','NoPaymentFailure','CheckoutComplete','Other','2011-03-04 01:54:19',0,NULL,3,1,3,1,NULL,' RR843871806CN\r'),(5784,641459294001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','trunaza','spokeword@yahoo.com','Andre Coleman','1793 Juniper Lake Rd','DeFuniak Springs','FL','UNITED STATES','32433-5203','(850) 951-0856','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-04 02:12:46',0,NULL,3,1,1,1,NULL,' 575'),(5785,681214948002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',5.99,'hermeshine','moojack123','jackmut114@gmail.com','Nuttaphon Rujinark','41/17 Royal Park Buliding, Room 308, Phaholyothin 8 rd.<br>Samsen Nai, Phayathai','Bangkok','','THAILAND','10400','(+66) 819372816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 02:20:03',0,NULL,3,1,2,1,NULL,NULL),(5786,681562729002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','jbooblian','julesrb@paradise.net.nz','Julian Butler','176 Clyde Street<br>Island Bay','Wellington','','NEW ZEALAND','6023','6449721599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 02:44:28',0,NULL,3,1,2,1,NULL,NULL),(5787,641473455001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','kerryn09','kerrynobrien@oracletelecom.net.au','Kerryn O\'Brien','19 Gladstone Street','Paddington','Queensland','AUSTRALIA','4064','0412706067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 03:13:57',0,NULL,8,0,17,0,NULL,NULL),(5788,641190358001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',12.49,'hermeshine','kerryn09','kerrynobrien@oracletelecom.net.au','Kerryn O\'Brien','19 Gladstone Street','Paddington','Queensland','AUSTRALIA','4064','0412706067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 03:13:58',0,NULL,3,0,3,1,NULL,'1.6x2.1m 背景布 3   黑 白 灰  \r麂皮   1\rRR843871942CN\r'),(5789,746541562015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','foxbat404','aj404my@yahoo.com','AHMAD JAMALUDIN','750,JALAN NESAN 4','KUALA TERENGGANU','TERENGGANU','MALAYSIA','20000','609-6226763','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-04 03:17:32',0,NULL,3,1,2,1,NULL,NULL),(5791,681591676002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',4,'AB1402',55.6,'hermeshine','yocom_bro','yoko.aditya@yahoo.com','yoko aditya','boulevard artha gading blok A6B no.30/31<br>kelapa gading','jakarta','jakarta utara','INDONESIA','14240','+6221 93377334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 04:50:57',0,NULL,3,1,3,1,NULL,' RR843871810CN\r'),(5792,641515373001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','placdarms','filips@vilande.com','Filips Baumanis','Paplakas iela 24','Priekule','Priekules novads','LATVIA','lv-3434','+371 26368537','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 06:59:22',0,NULL,3,1,2,1,NULL,NULL),(5793,641518816001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','yocom_bro','yoko.aditya@yahoo.com','yoko aditya','boulevard artha gading blok A6B no.30/31<br>kelapa gading','jakarta','jakarta utara','INDONESIA','14240','+6221 93377334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 07:24:30',0,NULL,5,1,18,0,NULL,NULL),(5794,681630343002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','mrpiewee','mrpiewee@hotmail.com','Piewee Mulder','Hemelstraat 26','Sint Jansteen','','NETHERLANDS','4564 BB','0114322870','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 08:39:58',0,NULL,3,1,3,1,NULL,' RR843872041CN\r'),(5795,641537325001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','vadkozvin','vadkoz@mail.ru','vadim kozlovsky','po box 8152<br>artynow st 559','Vinnitsya','Vinnitsya reg','UKRAINE','21050','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 09:04:16',0,NULL,3,1,3,1,NULL,'\rRR843872276CN\r'),(5797,641548200001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','markes1987','victormarques_@hotmail.com','Victor Marques Fernandez','c/ eloy reigada nº33   1º','Bembibre','Castilla y León','SPAIN','24300','690656923','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 09:54:08',0,NULL,3,1,4,1,NULL,' YW864870804CN\r'),(5798,641342352001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','kilichenko','ukrban@ua.fm','Yuriy Kilichenko','Filatova street,  52,  flat 39','Odessa','','UKRAINE','65074','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 10:08:26',0,NULL,3,1,2,1,NULL,NULL),(5799,681658473002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','duszekjack','jacek.splawski@gmail.com','Jacek Splawski','25 Raheen Close<br>Springfield, Tallaght','Dublin','Dublin','IRELAND','24','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 10:46:10',0,NULL,8,1,17,0,NULL,NULL),(5800,681659675002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','falconetti10','falcondiets@yahoo.co.uk','Pedro Falcon Marrero','Calle del cedro, 12<br>La Jaca','Arico','Santa Cruz de Tenerife','SPAIN','38588','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 10:51:42',0,NULL,3,1,2,1,NULL,NULL),(5801,641569173001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','rocter1963','razvodovskij@gmail.com','Nadezda Razvodovska','Cialkovska 14-41','Daugavpils','','LATVIA','LV-5410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 11:25:50',0,NULL,3,1,2,1,NULL,NULL),(5802,681670275002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 11:38:11',0,NULL,8,1,17,0,NULL,NULL),(5803,641570896001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 11:38:11',0,NULL,3,1,3,1,NULL,'52,55,58,62,67,72,77mm 接口环    一套\r普通托架   1\r广角托架   1 \rRR843872395CN'),(5804,681656241002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','romanfilatov','lubsay@ya.ru','roman filatov','ул.Горького д.27 кв.11','Волжский','Волгоградская область','RUSSIAN FEDERATION','404122','+7 903 315 36 05','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 11:45:05',0,NULL,3,1,3,1,NULL,' RR843872320CN\r'),(5805,681680484002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','abclolo','lolotaula@hispavista.com','manuel mesa bermudez','ventura rodriguez 7, 6º 3º','barcelona','Cataluña','SPAIN','08035','934280738','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 12:16:34',0,NULL,3,1,4,1,NULL,'lighting kit  $20 \rYW864870793CN\r'),(5806,641612403001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',10,'AA3305',36,'hermeshine','elpeladoedu','enocetti@adinet.com.uy','EDUARDO NOCETTI','AVDA  RONDEAU  1470','MONTEVIDEO','','URUGUAY','11100','59829029106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 14:07:09',0,NULL,3,1,3,1,NULL,' RR843872347CN\r'),(5807,731841945016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','zalaegerszegi','musikband@mail.ru','Vladislav Zarudniy','48 Marksa Str., App. 45 48 Marksa Str., App. 45','Obninsk','Kaluga Region','RUSSIAN FEDERATION','249039','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-04 14:31:38',0,NULL,3,1,2,1,NULL,' '),(5808,641624146001,110566020611,'NEW GGS LCD Screen Protector for Canon EOS 450D 500D',1,'AB2209',7.2,'hermeshine','ketu2','infoketu@gmail.com','Manuel López Guerra','Av. Irlanda<br>13B, 2ºB','Toledo','Castilla-La Mancha','SPAIN','45005','630507741','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 14:44:26',0,NULL,3,1,2,1,NULL,' '),(5809,681755432002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','roniofek','roniofek22@gmail.com','ron ofek','post box: 300','rinatia','israel','ISRAEL','73165','972-54-6520766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 16:17:34',0,NULL,3,1,2,1,NULL,NULL),(5810,641653128001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','tomoco318','jesusinarejos1@hotmail.com','Jesus Inarejos Carcelen','Avda. Manuel de Falla Nº 7D Pta 14<br>Valencia','Valencia','Valencia','SPAIN','46015','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 16:19:33',0,NULL,3,1,3,1,NULL,'RR843873002CN\r\r'),(5811,641679827001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','safrikacz','kacka.tobi@gmail.com','Amifox Reality, Katerina Tobolova','Ruska 87/11','Ostrava','Czech Republic','CZECH REPUBLIC','703 00','774 279 730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 17:20:59',0,NULL,3,1,2,1,NULL,NULL),(5812,641684220001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','vladislav630','zyryanov@agni.phys.iit.edu','Vladislav Zyryanov','7951 Stewart Dr','Darien','IL','UNITED STATES','60561-5934','(630) 985-1306','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-04 17:32:53',0,NULL,3,1,1,1,NULL,NULL),(5813,681784786002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','risaku','el_dani206@hotmail.com','DANIEL MARTI MARTINEZ','C/ sant antoni, 28','sant cugat sesgarrigues','Cataluña','SPAIN','08798','606242442','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 17:33:06',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864870782CN\r'),(5814,731947952016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','gray_cozmec','cozmec@gmail.com','Giannis Gkantos','Hatzimallousi 27','Naousa','Imathia','GREECE','59200','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-04 18:24:05',0,NULL,3,1,3,1,NULL,' RR843872262CN\r'),(5815,641707116001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','klong09','avalino@yahoo.com','Al Valino','112 Pinery Trail','Scarborough','ON','CANADA','M1B 6C1','(647) 567-2200','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 18:25:45',0,NULL,8,1,17,0,NULL,NULL),(5816,731958635016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',2,'AE2501',43,'hutongstore','battlesurf','plata.mejor@gmail.com','Andrea Battaglia','San Lorenzo n 77','Pisa','PI','ITALY','56127','3931843375','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-04 18:57:42',0,NULL,3,1,4,1,NULL,' YW864870771CN\r'),(5817,641708058001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','klong09','avalino@yahoo.com','Al Valino','112 Pinery Trail','Scarborough','ON','CANADA','M1B 6C1','(647) 567-2200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 18:27:41',0,NULL,3,1,3,1,NULL,'RR843872965CN '),(5818,641739512001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.95,'hermeshine','jakub.pavlinec','pavlinec@centrum.cz','Jakub Pavlinec','Rantirovska 28','Jihlava','','CZECH REPUBLIC','58605','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 19:33:49',0,NULL,3,1,2,1,NULL,NULL),(5819,681832522002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jfue6178','josemanviolin@hotmail.com','José Manuel Fuentes Martín','San Marcos 17 Bajo 3','Segovia','Castilla y León','SPAIN','40003','645063836','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 19:19:29',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864870760CN\r'),(5820,681851128002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','todos1alexweb','sashaburtsev@gmail.com','Alexander Burtsev','Ul.Gagarina, 14/6','Novozybkov','Bryanskaya obl','RUSSIAN FEDERATION','243020','+7 952 964 68 19','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 20:00:27',0,NULL,3,1,2,1,NULL,NULL),(5821,641754551001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cjaaronxx92','cjaaron16@yahoo.com','calvin a. mosley jr.','15571 Bow String St','victorville','CA','UNITED STATES','92394-6716','(760) 912-0877','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-04 20:06:52',0,NULL,3,1,1,1,NULL,NULL),(5822,681863693002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','nexus19841984','ozfoto@telefonica.net','Javier Jiménez León','Aeronave 9 (Estudio Fotográfico)','Madrid','Madrid','SPAIN','28042','913058172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 20:26:18',0,NULL,8,1,17,0,NULL,NULL),(5823,641771088001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','nexus19841984','ozfoto@telefonica.net','Javier Jiménez León','Aeronave 9 (Estudio Fotográfico)','Madrid','Madrid','SPAIN','28042','913058172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 20:45:16',0,NULL,8,1,17,0,NULL,NULL),(5824,681874030002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','wildvovan','wildfoxbr@yandex.ru','Vladimir Tshebrov','Aviacionnay 8-45','Bryansk','Russia','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 20:50:44',0,NULL,3,1,3,1,NULL,' RR843872245CN\r'),(5825,681860645002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','nexus19841984','ozfoto@telefonica.net','Javier Jiménez León','Aeronave 9 (Estudio Fotográfico)','Madrid','Madrid','SPAIN','28042','913058172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 20:21:27',0,NULL,8,1,17,0,NULL,' '),(5826,641777984001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','jleo123','jleo@comcast.net','John Leonard','21 Overbrook Pkwy','Wynnewood','PA','UNITED STATES','19096','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-04 20:59:00',0,NULL,3,1,1,1,NULL,NULL),(5827,732058611016,260660052780,'New Circular Polarizing C-PL CPL Filters for Cokin P',1,'AA2326',10.99,'hutongstore','gillandjoeb','joebarnett41@gmail.com','JOE BARNETT','1 THE OLD RECTORY FLATS BOUGHTON ALUPH','ASHFORD','Kent','UNITED KINGDOM','TN25 4HS','01233638988','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-04 21:41:46',0,NULL,3,1,2,1,NULL,NULL),(5828,681895414002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','goldberg99','valtec99@gmail.com','Maxim Melnikov','Liteyniy pr. 11 kv. 27','Saint-Petersburg','','RUSSIAN FEDERATION','191187','0079219658671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 21:51:52',0,NULL,3,1,2,1,NULL,NULL),(5829,641804931001,110445658116,'New YONGNUO  LCD Timer Remote Control  for Nikon MC-DC1',1,'AA3219',48.9,'hermeshine','sexy6670','gangster3866@mail.ru','Poul Savelyev','Arhangelskaya str.<br>11a-301','Vologda','Vologodskaya obl','RUSSIAN FEDERATION','160032','+79218294798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 22:06:40',0,NULL,3,1,3,1,NULL,'RR843872982CN '),(5830,681912924002,120644812661,'New Camera shoulder bag a1 for Nikon D80 D90 D3000',1,'AO0030',27.9,'hermeshine','dimadnk','dnk_dimon@te.net.ua','Dima Kupinets','50/2, Shishkina Str., app. 49','Odessa','','UKRAINE','65088','8-067-4890676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 22:24:15',0,NULL,3,1,3,1,NULL,' RR843872293CN\r'),(5831,681919905002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','bluesmansur','ramrif@hotmail.com','Ramón Rivera Freire','San Antonio,6 1º C','ALGECIRAS','Cadiz','SPAIN','11201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 22:43:29',0,NULL,3,1,2,1,NULL,NULL),(5832,746984011015,250692242647,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.68,'hutongstore','cheesygrins49','sue@cheesygrins.co.uk','Sue Butcher','49 Firglen drive','Yateley','Hampshire','UNITED KINGDOM','GU46 7TR','01252653323','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-04 23:03:02',0,NULL,3,1,2,1,NULL,NULL),(5833,681938061002,120461006671,'Digital SLR Camera Raincover rain cover for Nikon Canon',1,'AA3101',17.99,'hermeshine','ophermaoz10','ophermaoz@gmail.com','Opher Maoz','Hanevi\'im 11 aprtment 3','Tel Aviv','Israel','ISRAEL','64356','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 23:41:31',0,NULL,3,1,3,1,NULL,' RR843872302CN\r'),(5834,681907430002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','latigresa81','guidrycl@hotmail.com','Christie L. Guidry Stryk','10972 Solitude Cir','Anchorage','AK','UNITED STATES','99515','(713) 562-6377','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-04 23:47:04',0,NULL,3,1,1,1,NULL,NULL),(5835,681952364002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','siorcpablo','inspbs00@ucv.udc.es','Pablo Blanco Sampedro','Avda. Castrelos 228 - 5ºD (Atico D)<br>Atico D - 5ºD','Vigo','Pontevedra','SPAIN','36210','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 00:35:26',0,NULL,3,1,4,1,NULL,' YW864870756CN\r'),(5836,681947302002,120568072824,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','ml777ml777','mariusl1@bezeqint.net','marius leizer','igael yadin 49/28<br>Tel 972[0]577637799','mod\'in','Israel','ISRAEL','71720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 00:44:37',0,NULL,3,1,2,1,NULL,NULL),(5837,732133170016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.39,'hutongstore','jorabr','jorgen@ribbingsfors.se','Jörgen Abrahamsson','Fyrvaktarkroken 42, 1tr','Stockholm','Enskededalen','SWEDEN','SE-121 32','070-3312321','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-05 01:07:56',0,NULL,8,1,17,0,NULL,NULL),(5838,747025286015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.39,'hutongstore','jorabr','jorgen@ribbingsfors.se','Jörgen Abrahamsson','Fyrvaktarkroken 42, 1tr','Stockholm','Enskededalen','SWEDEN','SE-121 32','070-3312321','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-05 01:09:17',0,NULL,3,1,2,1,NULL,'方形滤镜接口环 55mm  1\r方形滤镜接口环 52mm   1'),(5839,641859701001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','adro3429','alland@pacific.net','Allan Droyan','445 N Harold St','Fort Bragg','CA','UNITED STATES','95437-3305','(707) 964-2130','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 01:22:14',0,NULL,3,1,1,1,NULL,NULL),(5840,681969087002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','oresmaux56','jean-charles-caullery@hotmail.fr','Jean-Charles Caullery','Le vieux Beffroi<br>6, rue du chapeau de violettes','AMIENS','Picardie','FRANCE','80000','06.06.85.84.30','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 01:41:36',0,NULL,3,1,3,1,NULL,' RR843872214CN\r'),(5841,681981487002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','bernardogaetani','manager@gamerz.com.br','Bernardo Gaetani','Rua da Bahia<br>Número 2577 APTO 102 - Lourdes','Belo Horizonte','Minas Gerais','BRAZIL','30160-012','5503132212892','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 02:44:26',0,NULL,3,1,2,1,NULL,NULL),(5842,641911462001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','300671igor','sizov71@yandex.ru','IGOR SIZOV','LV-1029<br>ROSTOKAS STREET 16-18','RIGA','','LATVIA','LV-1029','+37129110168','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 05:50:37',0,NULL,3,0,3,1,NULL,'nikon 老款背心 xl   1\rRR843872228CN\r\r'),(5843,641915731001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','ahinojos','anniebhinojos@yahoo.com','Peter Hinojos','15346 Lookout Rd','Apple Valley','CA','UNITED STATES','92307-2175','(760) 946-5577','NoPaymentFailure','CheckoutComplete','Other','2011-03-05 06:21:00',0,NULL,3,0,1,1,NULL,'nikon 老款背心 L 1 \r'),(5844,641751746001,110523102293,'72mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1308',51.1,'hermeshine','ayukov','asv@ayukov.com','Sergey Ayukov','ul. Krzhizhanovskogo, d.5, korp.1, kv.54','Moscow','','RUSSIAN FEDERATION','117292','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 06:32:43',0,NULL,3,0,3,1,NULL,'反光伞  1\r 77mm 镜头盖  nikon   1\r72mm 镜头盖  nikon   1\r115w 220v    1\r77mm nd8    1\r单灯头  欧标   1\r\r77ND8 发了天涯的\rRR843872979CN\r\r\r'),(5845,641919909001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','fbphuket','frank@krabibiz.com','Frank Baganz','314/13 Moo 2<br>T. Ao Nang A. Muang','Krabi','Krabi','THAILAND','81000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 06:46:48',0,NULL,8,1,17,0,NULL,NULL),(5846,682030132002,120605585602,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',86.9,'hermeshine','fbphuket','frank@krabibiz.com','Frank Baganz','314/13 Moo 2<br>T. Ao Nang A. Muang','Krabi','Krabi','THAILAND','81000','','NoPaymentFailure','CheckoutComplete','AU_OtherInternational','2011-03-05 06:48:34',0,NULL,3,0,6,1,NULL,'2mx3m 背景架  1\r3mx6m 白色背景布   1 \rEMS 外地\rEE389037475CN\r'),(5847,641923384001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','helias007','heliasfotografo@hotmail.com','Elias Huaman Corterreal','Jr Hermenegildo Rojas 125<br>distrito Carabayllo','Lima','Lima','PERU','51','5440277','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 07:09:23',0,NULL,3,1,3,1,NULL,' RR843872188CN\r'),(5848,682036465002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','gedrasas','gstugas@gmail.com','Giedrius Stugas','Ežero 3 - 41','Šiauliai','','LITHUANIA','77142','37061283598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 07:27:08',0,NULL,3,1,2,1,NULL,'欧标 '),(5849,641936684001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','peroni_es','correu.por@gmail.com','Pere Onieva','Av. Barcelona 108 6-2','IGUALADA','SPAIN','SPAIN','08700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 08:20:27',0,NULL,3,1,2,1,NULL,'欧标 '),(5850,682047193002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','excentric_projects','gmdkjpc@gmail.com','Daniel Johnston','4085 Canary Palm Circle','Plant City','FL','UNITED STATES','33566','(813) 494-1551','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-05 08:24:25',0,NULL,3,1,1,1,NULL,NULL),(5851,641943416001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','duszekjack','jacek.splawski@gmail.com','Jacek Splawski','25 Raheen Close<br>Springfield, Tallaght','Dublin','Dublin','IRELAND','24','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 08:49:40',0,NULL,8,1,17,0,NULL,' '),(5852,641951150001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','antiskeptic','gnikelyk@gmail.com','Kyle King','320 W Polk St<br>Apt 2','Houston','TX','UNITED STATES','77019-4462','','NoPaymentFailure','CheckoutComplete','Other','2011-03-05 09:22:49',0,NULL,3,1,1,1,NULL,'注意是nikon 原厂的那款 '),(5853,641958050001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 09:50:44',0,NULL,3,1,5,1,NULL,' CP226630707CN\r'),(5854,681615074002,120601699362,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','bandarar','srilankanwilds@gmail.com','T Bandara Ranathunge','246, Yatihalagala, Kandy<br>Sri Lanka','Kandy','Central','SRI LANKA','2000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 09:50:54',0,NULL,3,1,3,1,NULL,' RR843872205CN\r'),(5855,641963338001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1308',2.6,'hermeshine','nexus19841984','ozfoto@telefonica.net','Javier Jiménez León','Aeronave 9 (Estudio Fotográfico)','Madrid','Madrid','SPAIN','28042','913058172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 10:09:42',0,NULL,3,1,4,1,NULL,'72mm 镜头盖 nikon  1\r2m 灯架  1\r反光板支架   1\r80cm 5in1 反光板   1\r双灯头  欧标    1 \rlighting kit  $20\rYW864870745CN\r'),(5856,682089581002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','rdr5377','renaud.derosa@club-internet.fr','Renaud de Rosa','47 rue Cantagrel<br>App. 23','Paris','Ile-de-France','FRANCE','75013','0145837761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 11:13:41',0,NULL,3,1,2,1,NULL,NULL),(5857,732326946016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','ltgeordy','type_r@email.si','Dean Sopic','Na izvir 3','Pobegi','Koper','SLOVENIA','6276','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-05 13:13:20',0,NULL,3,1,3,1,NULL,'看看是否2kg以下 \rRR843872112CN\r'),(5858,682134202002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','dkarakou_86','dkarakou@hotmail.com','Dimos Karakousis','S.Oikonomou 6','Alexandroupoli','','GREECE','68100','+306942611591','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 13:43:47',0,NULL,8,1,17,0,NULL,NULL),(5859,642026990001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','dkarakou_86','dkarakou@hotmail.com','Dimos Karakousis','S.Oikonomou 6','Alexandroupoli','','GREECE','68100','+306942611591','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 13:45:04',0,NULL,3,0,5,1,NULL,'背景架  （ 白  黑）   1\r2m 宽的 \rCP226630715CN\r'),(5860,682136098002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','samduran','samduran@yahoo.com','Samuel Duran','9925 NW 116th Way','Medley','FL','UNITED STATES','33178','(786) 282-6204','NoPaymentFailure','CheckoutComplete','Other','2011-03-05 13:49:46',0,NULL,3,1,3,1,NULL,' RR843872126CN\r'),(5861,642057220001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',2,'AE2401',67,'hermeshine','4580190101801800','itzik_sbg@walla.com','itzik sabag','ir ganim<br>hasaifan 2 24','Jerusalem','ir ganim hasaifan 2-24','ISRAEL','0504447673','0504447673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 15:10:14',0,NULL,3,1,3,1,NULL,'欧标 RR843872231CN\r'),(5862,642085239001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','tornis','vadim57@apollo.lv','Vadims Mozeiko','sia VECPILS<br>Pernavas 39-1a','RIGA','','LATVIA','LV1009','371 29541619','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 16:15:19',0,NULL,3,1,2,1,NULL,NULL),(5863,642092382001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','eolajos','olajose@vnet.hu','Edit Olajos','8 Vass Str','Hodmezovasarhely','-','HUNGARY','6800','+36304722363','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 16:35:20',0,NULL,3,1,5,1,NULL,'欧标 \rCP226630724CN\r'),(5864,747344161015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','causeanddeffect','harris.ssaa@tiscali.co.uk','Stephen Harris','2, Birney Edge, Darras Hall,','Ponteland,','Northumberland,','UNITED KINGDOM','NE20 9jj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-05 17:16:18',0,NULL,3,1,2,1,NULL,NULL),(5865,682244903002,120568891628,'Male-Male 52mm-58mm Macro Combined shipping discounts',1,'AA1212',3.8,'hermeshine','victormff','vmmfdpjc@yahoo.com','Victor Fernandez','11804 Rockaway Beach Blvd<br>Apt 2','Rockaway Park','NY','UNITED STATES','11694-1916','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 18:01:34',0,NULL,8,1,17,0,NULL,'\r\r'),(5866,642134019001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','victormff','vmmfdpjc@yahoo.com','Victor Fernandez','11804 Rockaway Beach Blvd<br>Apt 2','Rockaway Park','NY','UNITED STATES','11694-1916','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 18:01:35',0,NULL,3,1,2,1,NULL,'52mm 橡胶罩   1\r52-58 双阳环   1 \r新地址：\rVictor Fernandez\r7-A Rue du Moulin\rDrummondville, QC \rJ2B5N1\r(819) 479-3136\rCanada\r\r819-479-3136'),(5867,747386577015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'AA3314',3.82,'hutongstore','hana2491','hannah.teasdale@hotmail.co.uk','Hannah Teasdale','1 William Close Stubbington','Fareham','Hampshire','UNITED KINGDOM','PO14 2PQ','01329668862','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-05 18:23:38',0,NULL,3,1,2,1,NULL,NULL),(5868,642150909001,110583278199,'TianYa 58mm CPL filter New 58 Circular Polarizing C-PL',1,'AA2303',5.9,'hermeshine','davorbalavor','djanjatovic@yahoo.com','Davor Janjatovic','Trg Kralja Zvonimira 6','Koprivnica','Croatia','CROATIA','48000','38598304989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 18:29:20',0,NULL,3,1,2,1,NULL,NULL),(5869,682274934002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','mogensmoldaw','moldaw@mail.tele.dk','Mogens Rasmussen','Majsvej 48','Nyborg','dk','DENMARK','5800','65303846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 19:00:45',0,NULL,8,1,17,0,NULL,NULL),(5870,682271098002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','mogensmoldaw','moldaw@mail.tele.dk','Mogens Rasmussen','Majsvej 48','Nyborg','dk','DENMARK','5800','65303846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 19:00:46',0,NULL,8,1,17,0,NULL,NULL),(5871,642159812001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','mogensmoldaw','moldaw@mail.tele.dk','Mogens Rasmussen','Majsvej 48','Nyborg','dk','DENMARK','5800','65303846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 19:00:46',0,NULL,8,1,17,0,NULL,NULL),(5872,682274431002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','mogensmoldaw','moldaw@mail.tele.dk','Mogens Rasmussen','Majsvej 48','Nyborg','dk','DENMARK','5800','65303846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 19:00:47',0,NULL,3,1,2,1,NULL,'CANON 镜头盖  58mm  1 \r橡胶遮光罩 58mm  1\r绿叶 UV  67mm  1\r机身盖/镜头后盖  Canon  1'),(5873,682289942002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','mountfako','photolancing@aol.com','Victor Ngaling','4221 Heritage Drive','Vadnais Heights','MN','UNITED STATES','55127','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 19:26:38',0,NULL,3,1,1,1,NULL,NULL),(5874,642230004001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','allioli','anagroid@hotmail.com','Adrián Navarro Grossón','C/ Maximiliano Thous Nº15, Pª4','Valencia','Comunidad Valenciana','SPAIN','46009','635694355','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 21:06:20',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864870734CN\r'),(5875,682344946002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','bogopolsky1','bog.vadim@gmail.com','vad bogopolsky','motzkin 21 ap 10','netanya','israel','ISRAEL','42460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 21:15:49',0,NULL,3,1,3,1,NULL,' RR843872259CN\r'),(5876,682378545002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',9.8,'hermeshine','z950069','j.spaulding@comcast.net','Judith B. Spaulding','1836 Avenida Martina','Roseville','CA','UNITED STATES','95747','(916) 903-8884','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 23:23:54',0,NULL,8,1,17,0,NULL,' '),(5877,642282816001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','z950069','j.spaulding@comcast.net','Judith B. Spaulding','1836 Avenida Martina','Roseville','CA','UNITED STATES','95747','(916) 903-8884','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 23:23:55',0,NULL,8,1,17,0,NULL,NULL),(5878,682402602002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','z950069','j.spaulding@comcast.net','Judith B. Spaulding','1836 Avenida Martina','Roseville','CA','UNITED STATES','95747','(916) 903-8884','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 23:44:46',0,NULL,3,1,1,1,NULL,'CANON 镜头盖  58mm  4\r lenspen    1\r橡胶遮光罩 58mm    1\r'),(5879,682421121002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','monwong2001','monwong@afs.org','Monwong Bhadharavit','369 Ladprao 101<br>Wangthonglang','Bangkok','BKK','THAILAND','10310','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 00:46:07',0,NULL,3,1,3,1,NULL,'77mm +8 换成 +4的\r77mm ND8 换成 天涯的77mm ND8\rRR843872165CN\r'),(5880,642309762001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',3,'AE2501',91,'hermeshine','ruyguerra','ruyguerra1958@hotmail.com','Ruy Guerra','Rua Itapiru, 264 apto 34','Sao Paulo','SP','BRAZIL','04143-010','11-8613-6907','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 00:59:04',0,NULL,8,1,17,0,NULL,'3个都要盒子，整个包在一起 \r看重量，如果小于2kg，就小包挂号'),(5881,682426785002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','miroslaw6402','tolo171@gmail.com','miroslaw krekora','969 logan ave','toronto','ON','CANADA','m4k 3e6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 01:06:44',0,NULL,3,1,2,1,NULL,' '),(5882,642317800001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','darkobulat','darkobul@gmail.com','Darko Bulatovic','4831 Reservoir Rd NW','Washington','DC','UNITED STATES','20007-1543','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 01:28:56',0,NULL,3,1,1,1,NULL,' '),(5883,747605135015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','jimbo_kent_uk','jimbo_kent@hotmail.com','Jim Buckley','98 Kingswood Road','Gillingham','Kent','UNITED KINGDOM','ME7 1DX','07884230057','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-06 01:34:16',0,NULL,3,1,3,1,NULL,' RR843872174CN\r'),(5884,682435920002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',10,'AA1310',54.9,'hermeshine','ruyguerra','ruyguerra1958@hotmail.com','Ruy Guerra','Rua Itapiru, 264 apto 34','Sao Paulo','SP','BRAZIL','04143-010','11-8613-6907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 01:42:51',0,NULL,3,1,5,1,NULL,'反光板支架  3 \rlenspen  10\r3个反光板支架和lenspen都要盒子，整个包在一起 \r看重量，已经超过2KG\rCP226630738CN\r'),(5885,682446527002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','lthurmon','lthurmon@gmail.com','Lauren Thurmon','202 Appleby Rd','Port Wentworth','GA','UNITED STATES','31407-1108','(912) 966-1584','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 02:27:08',0,NULL,3,1,1,1,NULL,NULL),(5886,682461005002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','iselocj','erjalandoon@yahoo.ca','Erlinda Jalandoon','3600 Kilby Court','Richmond','BC','CANADA','V6X 3M9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 03:19:55',0,NULL,3,1,2,1,NULL,NULL),(5887,682482458002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','bconnors7773','wconnors5@comcast.net','William Connors','312 W Ethel Ave','Lombard','IL','UNITED STATES','60148','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 04:52:55',0,NULL,3,1,1,1,NULL,NULL),(5888,682026454002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',2,'AC1302',18.5,'hermeshine','zbali68','kesuma13@gmail.com','Zuhairi Ali','13, Jalan 7/4<br>Bandar Tasik Kesuma','Beranang','Selangor','MALAYSIA','43700','0129161651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 06:05:37',0,NULL,3,1,2,1,NULL,NULL),(5889,642420887001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','balaboshka','marinamaleryan@yahoo.com','Marina Maleryan','ulica 120 Divizii, d.7, kv.43','Gatchina','Leningradskaya oblast','RUSSIAN FEDERATION','188306','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 09:23:10',0,NULL,3,1,2,1,NULL,NULL),(5890,642451748001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','semircok','gurnik@gmail.com','Martin Gurnik','Farska 59','Huncovce','Slovakia','SLOVAK REPUBLIC','05992','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 10:43:32',0,NULL,3,1,2,1,NULL,NULL),(5891,747773334015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',15.5,'hutongstore','freestyle2009','oystein.sorli@mimer.no','Øystein Sørli','Fjellstad 26','Hildre','','NORWAY','6272','97461256','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-06 10:48:15',0,NULL,3,1,2,1,NULL,'欧标 '),(5892,642467781001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',2,'AB1303',6.68,'hermeshine','stlg07','stntid@gmail.com','Sherif Tadros','1 Gipps Avenue','Little Bay','New South Wales','AUSTRALIA','2036','0432649565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 11:23:05',0,NULL,3,1,2,1,NULL,NULL),(5893,642475506001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','kimeline','post@tjelde.no','Kim Tjelde  Fauskrud','Brukroveien 260','Brottum','Brottum','NORWAY','2372','+4741641798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 11:43:02',0,NULL,3,1,2,1,NULL,NULL),(5894,642263266001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',17.16,'hermeshine','ozlemusta','ozleem@gmail.com','Ozlem Usta','Nortel Netas<br>Alemdag C. No:171 Umraniye','Istanbul','','TURKEY','34768','+905358964872','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 11:19:10',0,NULL,3,1,2,1,NULL,'反光板  80cm 5合1   1\r肥皂盒 580ex      1 '),(5895,682592287002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','police024','david.givord@chello.fr','GIVORD David','le moulin','rivolet','Rhône-Alpes','FRANCE','69640','04.26.74.03.86.','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 11:40:20',0,NULL,3,1,4,1,NULL,'light $20 \r欧标\rYW864870723CN\r'),(5896,642488169001,110419742422,'Green.L 67mm Neutral Density ND8 Filter ND 8 67',1,'AE2312',6.7,'hermeshine','titsumi','titsumi.forever@gmail.com','Ильин Андрей (Ilgin Andrey)','Королевка д. 8, кв. 129 (Korolevka 8-129)','Смоленск (Smolensk)','Россия г Смоленск (Russia, Smolensk)','RUSSIAN FEDERATION','214039','(951)715-1827','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 12:16:42',0,NULL,3,1,2,1,NULL,NULL),(5897,642499050001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','yoyomadness','jon@yoyomadness.com','jon carreiro','21 lands end way','swansea','MA','UNITED STATES','02777-2909','(508) 496-6092','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 12:43:45',0,NULL,3,1,1,1,NULL,NULL),(5898,642501559001,110422380084,'Aluminium Lightweight 68\" Camera Monopod BALL HEAD New',1,'AE1604',23,'hermeshine','vitorseagull','vitor.seagull@gmail.com','Luiz Vitor Vieira','Rua Novo Cruzeiro n °46 apto 301<br>Vila Valqueire','Rio de Janeiro','Rio de Janeiro','BRAZIL','21330-240','5521-246-40753 ','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-06 12:52:04',0,NULL,3,1,3,1,NULL,' RR843872130CN\r'),(5899,642511365001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','starsapphire04','starsapphire04@yahoo.com','Ada Lajara','214 Bautista Compd Cor. Felix Y. Manalo St.<br>San Isidro Cainta Rizal','Cainta','Rizal','PHILIPPINES','1900','022492484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 13:15:34',0,NULL,3,1,2,1,NULL,NULL),(5900,642497998001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','sakuramizuki','psycho_lunatic_poet@hotmail.com','Khatleen Minerve','Royal Road Valetta, Hemraz Road.','Dagotiere','','MAURITIUS','230','9325435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 12:41:23',0,NULL,3,1,2,1,NULL,NULL),(5901,682641445002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','csabi1965','forster.st@gmail.com','Csaba Vass','Rozsafa 19.','Salgotarjan','','HUNGARY','3104','003620','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 13:40:18',0,NULL,8,1,17,0,NULL,' '),(5902,642524609001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','csabi1965','forster.st@gmail.com','Csaba Vass','Rozsafa 19.','Salgotarjan','','HUNGARY','3104','003620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 13:42:44',0,NULL,8,1,17,0,NULL,NULL),(5903,642525772001,110534333419,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','csabi1965','forster.st@gmail.com','Csaba Vass','Rozsafa 19.','Salgotarjan','','HUNGARY','3104','003620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 13:45:40',0,NULL,8,1,17,0,NULL,NULL),(5904,682645181002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','csabi1965','forster.st@gmail.com','Csaba Vass','Rozsafa 19.','Salgotarjan','','HUNGARY','3104','003620','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 13:48:00',0,NULL,3,1,5,1,NULL,'2m 灯架  2\r双灯头 欧标  2\r反光伞  2\r柔光伞  2\r45w   2\r115w 220v   2\r包  1\r CP226630741CN\r'),(5905,642528671001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','pup3k01','bigbelly@seznam.cz','Ondřej Gongala','Výškovická 100','Ostrava','Moravskoslezsky kraj','CZECH REPUBLIC','70030','777057048','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 13:57:25',0,NULL,3,1,5,1,NULL,' CP226630755CN\r'),(5906,682675491002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','talnisim','talnisim@gmail.com','Tal Nisim','Reading 6/c','Tel Aviv','','ISRAEL','69022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 14:53:11',0,NULL,3,1,3,1,NULL,' RR843872381CN\r'),(5907,682687159002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','batatinharj10','batatinharj@gmail.com','Vanessa Muniz','Rua Ibituruna, 43 Bloco 1 apt 505<br>Maracanã','Rio de Janeiro','Rio de Janeiro','BRAZIL','20271-021','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 15:16:11',0,NULL,3,1,3,1,NULL,' RR843872109CN\r'),(5908,682690358002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','martinyelvira','martin.rodriguez@hispeed.ch','Elvira Navas','Fuessmattli 4 b','Ottenbach','','SWITZERLAND','8913','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 15:25:52',0,NULL,3,1,4,1,NULL,'lighting kit \r$30 \r欧标\rYW864870712CN\r'),(5910,642591113001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','wflame','nick.gulyaev@gmail.com','Nikolay Gulyaev','Tsiolkovskogo 3/3 - 8','Lipetsk','','RUSSIAN FEDERATION','398032','9046850305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 15:58:03',0,NULL,3,1,2,1,NULL,NULL),(5911,642601460001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',56.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 16:12:09',0,NULL,3,1,8,1,NULL,' CP226630698CN\r'),(5912,642616561001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','eddy_dc','info@eddydc.be','Eddy De Coster','Ricardplein 17','Deinize','','BELGIUM','9800','32498391890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 16:35:52',0,NULL,3,1,2,1,NULL,' '),(5913,642620025001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','dominiquej999','cbrdoom@free.fr','Dominique julian','4, place des lilas','Montpellier','Languedoc-Rousillon','FRANCE','34070','06 62 62 96 22','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 16:40:22',0,NULL,3,1,2,1,NULL,NULL),(5914,682741613002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',20.99,'hermeshine','andrewdem','for_shoping@mail.ru','Andriy Demyanenko','Bogdana Hmelnitskogo st. 33-17','Pereyaslav-Hmelnitskiy','Kievska oblast','UKRAINE','08400','063-960-28-47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 16:47:06',0,NULL,3,1,3,1,NULL,' RR843872157CN\r'),(5915,682802379002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',2,'AC3302',23.96,'hermeshine','jaylasf','vcr@usa.com','Jay Ho','6871 Camrose Dr','Hollywood','CA','UNITED STATES','90068','(310) 926-7596','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 18:03:02',0,NULL,3,1,1,1,NULL,NULL),(5916,682847231002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','mebuy2007','kurt.hestvik@online.no','Kurt Eivind Hestvik','Hasseløyveien 39','Stavanger','RL','NORWAY','4029','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 18:50:24',0,NULL,3,1,2,1,NULL,NULL),(5917,682499583002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','rookietsai','davidtsai2004@yahoo.com','David Tsai','42848 Fontainebleau Park Ln','Fremont','CA','UNITED STATES','94538-3935','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 19:05:31',0,NULL,3,1,1,1,NULL,NULL),(5918,642711458001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','cla33fr','cla33@free.fr','Christian LAGARDERE','10, rue de la croix du sable','BRUGES','Aquitaine','FRANCE','33520','06 85 71 67 70','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 18:31:39',0,NULL,3,1,3,1,NULL,' RR843872143CN\r'),(5919,748161944015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.58,'hutongstore','redlub','kbmanden@yahoo.dk','kjeld jensen','bispevangen 2','ballerup','','DENMARK','2750','+4550238682','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-06 19:22:19',0,NULL,3,1,2,1,NULL,NULL),(5920,682921391002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','mellogabriel','mellogabriel@yahoo.com.br','Gabriel Mello','Rua Leandro Dupret, 364 Ap. 142<br>Vila Clementino','São Paulo','São Paulo','BRAZIL','04025-011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 20:03:36',0,NULL,3,1,2,1,NULL,NULL),(5921,682235347002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',20.99,'hermeshine','spaz1921','puntapalma@gmail.com','salvio paz lorenzo','c/ general yague nº 20  2ºa','los llanos de aridane','Canarias','SPAIN','38760','638809816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 20:45:08',0,NULL,3,1,3,1,NULL,' RR843872069CN\r'),(5922,733320468016,260677592103,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',49.99,'hutongstore','0208patee','nogamatstudio@hotmail.com','stephen yeboah','2 kenley gardens thornton heath','london','Surrey','UNITED KINGDOM','cr77dd','02086892665','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-06 20:49:02',0,NULL,3,1,4,1,NULL,'light  $18\r需要控制在2kg以下 \r\r英标\rYW864870701CN\r'),(5923,683008455002,120486048007,'New Timer Remote Control for Canon EOS 450D 400D 350D',1,'AA3221',47,'hermeshine','chupachules','bronikita@gmail.com','reyes fernandez hernandez','base aerea de gando 802 escuadron','aeropuerto gran canaria','Canarias','SPAIN','35230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 22:02:44',0,NULL,3,1,3,1,NULL,' RR843872072CN\r'),(5924,642887824001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','gunsooo','gunnargj@gmail.com','Gunnar Geir Johannsson','Kjarrholmi 32','Kopavogur','','ICELAND','200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 22:06:44',0,NULL,8,1,17,0,NULL,NULL),(5925,642887032001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','gunsooo','gunnargj@gmail.com','Gunnar Geir Johannsson','Kjarrholmi 32','Kopavogur','','ICELAND','200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 22:06:44',0,NULL,8,1,17,0,NULL,NULL),(5926,642886881001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','gunsooo','gunnargj@gmail.com','Gunnar Geir Johannsson','Kjarrholmi 32','Kopavogur','','ICELAND','200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 22:06:45',0,NULL,3,1,3,1,NULL,'单灯头   欧标  2\r45w   2\r倒影板   1 \rRR843872086CN\r'),(5927,683013248002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','garym165','smclean31@cogeco.ca','Gary','McLean<br>123 Kingham Road','Acton','ON','CANADA','L7J1S3','(519) 929-9255','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 22:11:13',0,NULL,3,1,3,1,NULL,' RR843872090CN\r'),(5928,642891581001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','boskebaba','andras.solymos@yahoo.fr','Andras Solymos','147 Rue de Rennes','Paris','Île-de-France','FRANCE','75006','06.60.27.71.44.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 22:14:09',0,NULL,3,1,2,1,NULL,'欧标 '),(5929,683033332002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','tampa_investigator','denispizza@yahoo.com','Denis J. Pizza','7108 Dove Meadow Trl','Lakeland','FL','UNITED STATES','33810-8840','(813) 650-3100','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 22:58:22',0,NULL,3,1,1,1,NULL,NULL),(5930,683042259002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','miririguiver','miririguiver@hotmail.com','Luiz Henrique Boulhosa','Rua Rodrigues Guião, 95','São Paulo','São Paulo','BRAZIL','05429030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 23:15:20',0,NULL,3,1,2,1,NULL,NULL),(5931,683079138002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','zyberman','greeno-b@rogers.com','Bryan Greenough','7700 Pine Valley Drive<br>Unit 4A','Woodbridge','ON','CANADA','L4L2X4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 00:53:52',0,NULL,3,1,2,1,NULL,NULL),(5932,642988869001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','waxen','carlhebert1967@gmail.com','carl hebert','27 castle hill dr','bethel','CT','UNITED STATES','06801-1202','','NoPaymentFailure','CheckoutComplete','Other','2011-03-07 02:31:55',0,NULL,3,1,1,1,NULL,NULL),(5933,683136125002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ahmadta','tauseeph@gmail.com','Tauseef Ahmad','Chubb Insurance Company of Canada, 15th floor, Mail room<br>1 Adelaide Street East','Toronto','ON','CANADA','M5C 2V9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 03:18:56',0,NULL,3,1,3,1,NULL,' RR843872015CN\r'),(5934,643014946001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','noapro1','alohacam@hotmail.com','NOA Production','324 Ilimalia Loop','Kailua','HI','UNITED STATES','96734','','NoPaymentFailure','CheckoutComplete','Other','2011-03-07 03:50:14',0,NULL,3,1,3,1,NULL,' RR843872024CN\r'),(5935,643020292001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','berny1er','berny1er@hotmail.com','Guillaume Bernier','89, rue des Flocons','Rimouski','QC','CANADA','G5N 5V6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 04:09:23',0,NULL,3,1,3,1,NULL,' RR843872355CN\r'),(5936,683149139002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',4,'AO0014',31.6,'hermeshine','cmu2008','lzelinski50@hotmail.com','Lisa Zelinski','4121 W 14 Mile Rd','Royal Oak','MI','UNITED STATES','48073-1542','(989) 339-1701','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-07 04:10:26',0,NULL,3,1,1,1,NULL,NULL),(5939,683171836002,120451412743,'67mm 67 mm Macro +8 Close-Up Close Up Filter',1,'AE3226',8.5,'hermeshine','sazema2010','sasa.vranic@gmail.com','Saša Vranić','Bulevar Kulina Bana 28D','Zenica','Bosnia and Herzegovina','BOSNIA AND HERZEGOVINA','72000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 05:53:52',0,NULL,3,1,2,1,NULL,NULL),(5940,683186190002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','*.digital','angel.3f@gmail.com','David Barrera Martínez','Independencia No. 40<br>Col. Centro','Mixquiahuala','Hidalgo','MEXICO','42700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 07:20:57',0,NULL,5,0,18,0,NULL,NULL),(5941,683208829002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT061',73.3,'hermeshine','istokka','admoccia@alice.it','antonio chiacchio','via gramsci 55','frattaminore','NA','ITALY','80020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 09:18:23',0,NULL,8,1,17,0,NULL,'\r'),(5942,683210646002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',2,'AKT040',149.8,'hermeshine','istokka','admoccia@alice.it','pasquale saviano','via GRAMSCI 55','Frattaminore','NA','ITALY','80020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 09:22:11',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r单灯头 欧标  2\r反光伞  2\r4灯头棚  4  欧标 \rlight stand  $25\rYW864870874CN\r'),(5943,748560318015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','philipqs','pdlmatthews@gmail.com','Philip Matthews','2 Ballagh Wood Donadea','Naas','Kildare','IRELAND','4','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-07 09:36:59',0,NULL,3,1,3,1,NULL,' RR843873020CN\r'),(5944,733636843016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','falsifysa3s','falsify@hotmail.co.uk','Dean Cook','17 Lothersdale Stonydelph','Tamworth','Staffordshire','UNITED KINGDOM','B77 4HT','01827896147','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-07 10:41:59',0,NULL,3,1,4,1,NULL,'lighting kit  $30\r英标 \rYW864870863CN\r'),(5945,683236194002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','jarosgabor','jarosg@gmail.com','Jaros Gábor','3200 Gyöngyös, Gólya u. 125.','Gyöngyös','Heves','HUNGARY','3200','36203283223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 11:07:52',0,NULL,8,1,17,0,NULL,NULL),(5946,683235023002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','jarosgabor','jarosg@gmail.com','Jaros Gábor','3200 Gyöngyös, Gólya u. 125.','Gyöngyös','Heves','HUNGARY','3200','36203283223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 11:07:52',0,NULL,8,1,17,0,NULL,NULL),(5947,683233543002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','jarosgabor','jarosg@gmail.com','Jaros Gábor','3200 Gyöngyös, Gólya u. 125.','Gyöngyös','Heves','HUNGARY','3200','36203283223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 11:07:53',0,NULL,3,1,2,1,NULL,'渐变灰  1\r3片装滤镜袋  1\r广角托架    1 '),(5948,683240018002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','folooop','foolop@gmail.com','filip bejtner','Carrero Juan Ramon 10 ,4b','madrid','Madrid','SPAIN','28025','600018384','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 11:24:25',0,NULL,3,1,3,1,NULL,' RR843873047CN\r'),(5949,683246469002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',4,'AE3102',31.56,'hermeshine','duszekjack','jacek.splawski@gmail.com','Jacek Splawski','25 Raheen Close<br>Springfield, Tallaght','Dublin','Dublin','IRELAND','24','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 11:51:08',0,NULL,3,1,4,1,NULL,'大力夹   4\r反光板支架   1\r斜臂   1 \rLIGHTING KIT  $25\rYW864870852CN\r'),(5950,683261485002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA3205',3.5,'hermeshine','hakon87','pedromolina87@gmail.com','Pedro Molina Blázquez','C/ V Centenario nº1 - 1ºE','Badajoz','Extremadura','SPAIN','06007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 12:49:04',0,NULL,8,0,17,0,NULL,''),(5951,683263800002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','pattama1','vorasak1@gmail.com','vorasak Sombatpiboon','152(1364/62) Trok. Kitao<br>Krungthonburi Rd. Soi 4, Banglumphulang','Klongsan,','Bangkok','THAILAND','10600','(668) 168-4253 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 12:59:02',0,NULL,3,1,2,1,NULL,NULL),(5952,683268579002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','yphotographer112','mtbleb97@hotmail.com','Tyler Berge','9464 Dakota Rd','Bloomington','MN','UNITED STATES','55438-1709','(952) 356-9275','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-07 13:13:56',0,NULL,3,1,1,1,NULL,NULL),(5953,683268553002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','hakon87','pedromolina87@gmail.com','Pedro Molina Blázquez','C/ V Centenario nº1 - 1ºE','Badajoz','Extremadura','SPAIN','06007','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 13:14:13',0,NULL,3,1,4,1,NULL,'红外遥控 canon  1 \rtripod $16 \rYW864870841CN\r'),(5954,733698534016,260660052995,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',8.99,'hutongstore','yveskwijibo74','yveskwijibo@gmail.com','dantinne yves','rue des noyers 7','liege','','BELGIUM','4000','0485453192','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-07 13:53:36',0,NULL,5,0,18,0,NULL,NULL),(5955,683282017002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','luckywebsoft','tomaspenalver@gmail.com','tomas peñalver garcia','puerta de hierro 85 b<br>buzon 21','santiago de la ribera','Murcia','SPAIN','30720','968 18 25 10','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 14:01:19',0,NULL,3,1,2,1,NULL,NULL),(5956,683284076002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','prince3737','theshot@roadrunner.com','Prince Edwards','153-B  HWY . 42-west','ahoskie','NC','UNITED STATES','27910','(252) 642-5009','NoPaymentFailure','CheckoutComplete','Other','2011-03-07 14:21:21',0,NULL,3,0,1,1,NULL,'xxl \r没减库'),(5957,683293350002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','denybarboza','denyzinho@gmail.com','Jordana Brizolara','Rua Ver. Severo Ribeiro, 912<br>Três Vendas','Pelotas','Rio Grande do Sul','BRAZIL','96020-620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 14:38:54',0,NULL,3,1,3,1,NULL,' RR843873104CN\r'),(5958,683305040002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','kiznito','jmanuelmorante@gmail.com','jose manuel nuñez morante','pl/ jazmin nº5 6ºd','alcala de henares','Madrid','SPAIN','28803','679786781','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 15:18:11',0,NULL,3,0,3,1,NULL,'\rRR843873149CN\r'),(5959,683316971002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','t_brique','t_brique@yahoo.com','Thomas Brique','48 rue de Chabrol','Paris','Île-de-France','FRANCE','75010','09.54.75.64.44','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 15:51:00',0,NULL,3,1,2,1,NULL,NULL),(5960,643189017001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',5,'AB1301',16.7,'hermeshine','sadthachai','snoom@hotmail.com','Ms.Rapee Yamsang','36<br>Chiang Mai-Lamphun Rd T.watket','Muang Chiangmai','Chiangmai','THAILAND','50000','0899559145','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 16:11:54',0,NULL,3,1,3,1,NULL,' RR843873095CN\r'),(5961,643210273001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','cperaltam','cperaltam@gmail.com','Carlos Peralta Martinez','Calz. Nva. Tulyehualco-Xochimilco 20-A<br>Nativitas Manantiales','Mexico City','Mexico','MEXICO','16450','+52 55 21570902','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 17:12:09',0,NULL,8,1,17,0,NULL,NULL),(5962,643217256001,110531023440,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',4,'hermeshine','antiloop695','arild.k@loqal.no','Arild Kirkaune','Rihåggåveien.4','Eggkleiva','Skaun','NORWAY','7355','+4740291975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 17:21:34',0,NULL,3,1,2,1,NULL,NULL),(5963,748751945015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','fedleo','effelle@gmail.com','Federico Leoni','Via San Benedetto, 9','Assisi','Perugia','ITALY','06081','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-07 17:52:52',0,NULL,3,1,2,1,NULL,NULL),(5964,643280450001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','kdrandgaard','kristine_daland@hotmail.com','Kristine Daland Randgaard','Toraldåsen 50','4886 Grimstad','Grimstad','NORWAY','4886','-47 908 53 555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 19:36:06',0,NULL,3,1,2,1,NULL,NULL),(5965,683422332002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','gulbrandtang','gulbrand.tangen@c2i.net','Gulbrand Tangen','Brennivegen 45','Algarheim','','NORWAY','2056','+4763976867','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 19:45:28',0,NULL,3,1,3,1,NULL,'\rRR843873152CN\r'),(5966,643292554001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','wayne1hurford','waynehurford@hotmail.com','Wayne Hurford','Box  291','Squamish','BC','CANADA','V8B0A3','(604) 892-4964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 19:53:30',0,NULL,3,1,2,1,NULL,NULL),(5967,683477122002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','bakhalah','ahmed-bakhalah@hotmail.com','Ahmed Salem Bakhalah','P.O.Box 255701<br>Mobile: 00966562424334','Riyadh','','SAUDI ARABIA','11353','00966562424334','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 21:33:34',0,NULL,3,1,3,1,NULL,'\rRR843873135CN\r'),(5968,643346386001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ldaemg1','enmigar@hotmail.com','Enrique Miralles García','eras nº 75','yuncos','Castilla-La Mancha','SPAIN','45210','606883247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 21:41:12',0,NULL,3,1,2,1,NULL,NULL),(5969,683494632002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','pochifon','po_chi81@hotmail.com','alfonso sanchez diez','calle cardenal cisneros 18 1ºb','leon','Castilla y León','SPAIN','24010','659717158','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 22:06:05',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864870830CN\r'),(5970,643365309001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','bakhalah','ahmed-bakhalah@hotmail.com','Ahmed Salem Bakhalah','P.O.Box 255701<br>Mobile: 00966562424334','Riyadh','','SAUDI ARABIA','11353','00966562424334','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 22:29:17',0,NULL,3,0,3,1,NULL,'分两票发   RR843873308CN\rRR843873210CN'),(5971,643369598001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','dellm640','dellemail@seznam.cz','Ilja Mašík','Na výsluní 25','Prague','','CZECH REPUBLIC','10000','608861086','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 22:40:48',0,NULL,3,1,3,1,NULL,' RR843873016CN\r'),(5972,643370547001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','scotty3da','scott3d@westnet.com.au','Scott Butler','140 Targo Road','Girraween','New South Wales','AUSTRALIA','2145','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 22:43:28',0,NULL,8,1,17,0,NULL,' '),(5973,643370348001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','scotty3da','scott3d@westnet.com.au','Scott Butler','140 Targo Road','Girraween','New South Wales','AUSTRALIA','2145','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 22:43:28',0,NULL,8,1,17,0,NULL,NULL),(5974,643370054001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','scotty3da','scott3d@westnet.com.au','Scott Butler','140 Targo Road','Girraween','New South Wales','AUSTRALIA','2145','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 22:43:29',0,NULL,3,1,2,1,NULL,' 机身盖/镜头后盖  Nikon  1\rNIKON 镜头盖 52mm  1\r绿叶 渐变镜 52mm  1'),(5975,748951627015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1307',5.16,'hutongstore','cjpxyz','les573@aol.com','mark parvin','42 High Street,','Felling,','Tyne and Wear','UNITED KINGDOM','NE10 9LT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-07 23:22:10',0,NULL,3,1,2,1,NULL,NULL),(5976,643382186001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','fabio_drak','fabiojz@gmail.com','Fabio Zimmer','Jose Risseto 26','Curitiba','Parana','BRAZIL','82015010','32723050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 23:30:30',0,NULL,3,1,2,1,NULL,NULL),(5977,683531411002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','le_juki','jukkatallinen@gmail.com','Jukka Tallinen','Toppilansaarentie 3 B 19','Oulu','-','FINLAND','90510','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 23:44:04',0,NULL,3,1,3,1,NULL,' RR843873078CN\r'),(5978,734008909016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','whyte187','d_o_a_187@hotmail.com','Steven Whyte','11 Mitchell Drive','Rutherglen','Glasgow (City of)','UNITED KINGDOM','G733QP','01415698153','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-08 00:01:25',0,NULL,3,1,2,1,NULL,NULL),(5979,643398437001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','oceoke','oceoke01@gmail.com','Miguel Angel Ruiz Santaella','Avda. del Mediterraneo nº 7 2º I<br>Salobreña (Granada)','Salobreña   (Granada)','Andalucía Ceuta y Melilla','SPAIN','18680','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 00:19:07',0,NULL,3,1,3,1,NULL,' RR843873064CN\r'),(5980,748977576015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',1,'AA1314',2.2,'hutongstore','alllans','allan.smith@gmx.co.uk','Allan Smith','18 Vancouver Drive London Rd','Crawley','West Sussex','UNITED KINGDOM','RH11 7UR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-08 00:35:40',0,NULL,3,1,2,1,NULL,NULL),(5981,643404403001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','cperaltam','cperaltam@gmail.com','Carlos Peralta Martinez','Calz. Nva. Tulyehualco-Xochimilco 20-A<br>Nativitas Manantiales','Mexico City','Mexico','MEXICO','16450','+52 55 21570902','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 00:41:18',0,NULL,3,1,3,1,NULL,'717快装板   2\rRR843873081CN\r'),(5982,683551001002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','itsjed','jed.delacruz@gmail.com','Jed De La Cruz','3 Distin Ave.','Toronto','ON','CANADA','M8Z3R6','(416) 201-0093','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 00:52:25',0,NULL,3,1,3,1,NULL,' RR843873033CN\r'),(5983,748997762015,250600522522,'Remote Control Cord Shutter Nikon D80 D70s​ MC-DC1 ',1,'AA3208',2.98,'hutongstore','gialys','gialys@yahoo.it','gioacchino ballo','VIA UGO SOLI 9','PALERMO','Palermo','ITALY','90128','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-08 01:40:11',0,NULL,8,1,17,0,NULL,NULL),(5984,748994823015,250631211627,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',8,'hutongstore','gialys','gialys@yahoo.it','gioacchino ballo','VIA UGO SOLI 9','PALERMO','Palermo','ITALY','90128','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-08 01:40:12',0,NULL,3,1,2,1,NULL,'80cm 2in1   反光板   1\rRS-N2    1'),(5985,643466774001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','farozzi','tarute@hotmail.com','Fatima Jantasri','5/1836 Moo 10 Bangtalad Pakkred','Nontaburi','','THAILAND','11120','+66865190501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 04:45:46',0,NULL,8,1,17,0,NULL,' '),(5986,682187000002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','espiritkiller','andrematos@virtualmagic.com.br','Andre de Matos Alves','Rua Travessa da Imprensa, 128<br>Jardim Aliança','Osasco','São Paulo','BRAZIL','06236-180','+55 11 35994110','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 05:46:34',0,NULL,3,1,2,1,NULL,'espiritkiller'),(5987,643490393001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','kupriha','kuprik13@gmail.com','Анжелика Куприянова','пр.Яковлева<br>дом 6, корп.2, кв.16','Чебоксары','Чувашская Республика','RUSSIAN FEDERATION','428029','89603051616','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 07:17:02',0,NULL,3,1,5,1,NULL,'背景架 白黑 \rCP226630675CN\r'),(5988,683640342002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','borisovna_e','borisovna.e@gmail.com','Елена Богданова','Полярные зори, 19-23','Мурманск','Мурманская область','RUSSIAN FEDERATION','183039','+79537599911','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 07:17:06',0,NULL,3,1,3,1,NULL,' RR843873206CN\r'),(5989,643495097001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','rexina09','mihkel.tiitus@atlet.se','Mihkel Tiitus','Lilla Bällskärsgatan 12','Hisings Backa','','SWEDEN','42244','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 07:44:20',0,NULL,3,1,2,1,NULL,'绿叶 UV  67mm  1\r绿叶 UV  55mm   1'),(5990,643494074001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',3.3,'hermeshine','rexina09','mihkel.tiitus@atlet.se','Mihkel Tiitus','Lilla Bällskärsgatan 12','Hisings Backa','','SWEDEN','42244','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 07:38:13',0,NULL,8,0,17,0,NULL,NULL),(5991,749100360015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','bonini42','paul.bonini@googlemail.com','Paul Bonini','12 Rimu Street Kaka Point','Balclutha','South Otago','NEW ZEALAND','9271','6434128667','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-08 08:16:51',0,NULL,3,1,6,1,NULL,'白 黑  \rEE389037501CN\r\r'),(5992,643507303001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','honkyhog','danceup@aol.com','Jerry Hill','2420 SE 6th St','Pompano Beach','FL','UNITED STATES','33062','(954) 785-1536','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-08 08:50:03',0,NULL,3,1,3,1,NULL,' 580\rRR843873886CN\r'),(5993,643516952001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','glentaylormt','glentaylor_mt@hotmail.com','Glen Taylor','127 St.Jude<br>Trieq il Htajriet','Mosta','ME','MALTA','3062','21412542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 09:33:00',0,NULL,3,1,5,1,NULL,' 2.864\rCP226334806CN\r'),(5994,643382091001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','mona.1789','av96739-1@comtv.ru','Ananyev Andrey','S RADONEZHSKOGO ST 8-76','MOSKVA','','RUSSIAN FEDERATION','105120','(919)9681789','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 09:51:39',0,NULL,3,1,3,1,NULL,' RR843873943CN\r'),(5995,749125380015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','superamble','alessandro.chiurco@yahoo.it','Alessandro Chiurco','Via G. Cassiani 82','Spezzano Albanese','CS','ITALY','87019','0981953517','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-08 09:52:42',0,NULL,3,1,2,1,NULL,NULL),(5996,683675797002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','philippe3904','philippe.henchoz@unige.ch','Philippe Henchoz-Corcelle','64, Rue de la Louvatière','St Jean de Gonville','Rhône-Alpes','FRANCE','01630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 10:11:14',0,NULL,3,1,3,1,NULL,' RR843873926CN\r'),(5997,643529732001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','bakhalah','ahmed-bakhalah@hotmail.com','Ahmed Salem Bakhalah','P.O.Box 255701<br>Mobile: 00966562424334','Riyadh','','SAUDI ARABIA','11353','00966562424334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 10:31:23',0,NULL,3,1,2,1,NULL,NULL),(5998,683690267002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','quera1','pr.pregardien@skynet.be','René PREGARDIEN','Rue M. Body, 51','Grâce-Hollogne','','BELGIUM','4460','0475770122','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 11:14:46',0,NULL,3,1,4,1,NULL,'light head  $16 \rYW864870896CN\r\r'),(5999,683683909002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','borichka','boris@ceva-dsp.com','Boris Shpitser','CEVA DSP<br>2(D) Maskit St.','Herzelia','','ISRAEL','46120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 11:31:07',0,NULL,3,1,3,1,NULL,' RR843873869CN\r'),(6000,683698551002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','kobayashi516','k516k516.10@gmail.com','koichiro kobayashi','kamitsuruma 6-29-3','minami-ku sagamihara-shi','Kanagawa','JAPAN','252-0302','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 11:48:31',0,NULL,3,1,3,1,NULL,' RR843873912CN\r'),(6001,643543999001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','leewojones','koliwo@hotmail.com','COLIN ABAYOMI','52 RUSSELL ROAD<br>NORTHOLT','LONDON','London','UNITED KINGDOM','UB54QS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 11:31:30',0,NULL,3,1,2,1,NULL,NULL),(6002,683691331002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','elxanders','svirin@pochtamt.ru','Alexander Svirin','18/1-1 Sverdlova st','Yakutsk','','RUSSIAN FEDERATION','677005','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 12:24:18',0,NULL,3,1,5,1,NULL,'\rCP226630667CN\r'),(6003,643558884001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','kuchticek','kuchtik@yahoo.com','Marek Petrovic','Racianska 65','Bratislava','SC','SLOVAK REPUBLIC','83102','0903132267','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 12:29:21',0,NULL,3,1,2,1,NULL,NULL),(6004,643580176001,110566021028,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','kreyno','kreynold@energen.com','karen reynolds','449 Oneal Dr','Hoover','AL','UNITED STATES','35226-1646','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-08 13:49:44',0,NULL,8,1,17,0,NULL,NULL),(6005,643579980001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','kreyno','kreynold@energen.com','karen reynolds','449 Oneal Dr','Hoover','AL','UNITED STATES','35226-1646','','NoPaymentFailure','CheckoutComplete','Other','2011-03-08 13:49:45',0,NULL,3,0,3,1,NULL,' 摄影背心 绿色薄 nikon  XXXL  1\r防寒罩     1\rRR843874008CN\r'),(6006,643583694001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','l0sgleb','losgleb@mail.ru','Gleb Loskutov','Lenina st., 31-96','Krasnogorsk','Moscow region','RUSSIAN FEDERATION','143404','(916) 4423492','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-08 14:14:30',0,NULL,3,1,2,1,NULL,NULL),(6007,683740718002,120618815235,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'AA2301',5.7,'hermeshine','gescon77','alvaro.delallaverodriguez@t-gestiona.com','ALVARO RODRIGUEZ','CARLOS MARTIN ALVAREZ 31 3ºD','MADRID','Madrid','SPAIN','28018','918477995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 14:25:41',0,NULL,8,1,17,0,NULL,NULL),(6008,683739231002,120451408213,'52mm 52 mm Macro +4 Close-Up Close Up Filter',1,'AE3215',6.5,'hermeshine','gescon77','alvaro.delallaverodriguez@t-gestiona.com','ALVARO RODRIGUEZ','CARLOS MARTIN ALVAREZ 31 3ºD','MADRID','Madrid','SPAIN','28018','918477995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 14:29:59',0,NULL,8,1,17,0,NULL,NULL),(6009,643588766001,110534332949,'Green.L 52mm Neutral Density ND4 Filter 52 D40 18-55mm',1,'AE2301',5.8,'hermeshine','gescon77','alvaro.delallaverodriguez@t-gestiona.com','ALVARO RODRIGUEZ','CARLOS MARTIN ALVAREZ 31 3ºD','MADRID','Madrid','SPAIN','28018','918477995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 14:30:00',0,NULL,3,1,2,1,NULL,' 天涯 cpl 52mm   1\r绿叶近摄镜 +2  52mm  1\r绿叶 ND4  52mm  1'),(6010,643598362001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','sereivax','rodolfo.xavier@mail.telepac.pt','Rodolfo Xavier','R. José Eduardo César nº 4, 1º and letra D/E','Torres Vedras','Torres Vedras','PORTUGAL','2560-680','+351963707228','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 14:52:40',0,NULL,3,0,3,1,NULL,'XXL \rRR843873991CN\r'),(6011,683751504002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','peroni_es','correu.por@gmail.com','Pere Onieva','Av. Barcelona 108 6-2','IGUALADA','SPAIN','SPAIN','08700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 15:01:47',0,NULL,3,1,2,1,NULL,'欧标  '),(6012,683753822002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','sabretex','pmiv@juno.com','Robert Shary','2102 Pecos St<br>Ste 10','San Angelo','TX','UNITED STATES','76901-3061','(325) 947-1281','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-08 15:09:43',0,NULL,3,1,1,1,NULL,NULL),(6013,683757869002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','farozzi','tarute@hotmail.com','Fatima Jantasri','5/1836 Moo 10 Bangtalad Pakkred','Nontaburi','','THAILAND','11120','+66865190501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 15:23:12',0,NULL,3,1,2,1,NULL,' '),(6014,643611600001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','prince3737','theshot@roadrunner.com','Prince Edwards','153-B  HWY . 42-west','ahoskie','NC','UNITED STATES','27910','(252) 642-5009','NoPaymentFailure','CheckoutComplete','Other','2011-03-08 15:37:30',0,NULL,3,0,1,1,NULL,'xxl '),(6015,683781991002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','torpedoruso','antonio23666@hotmail.com','Antonio López','C/Ravel nº1 portal 4º 5ºA','Almeria','Andalucía Ceuta y Melilla','SPAIN','04007','679170103','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 16:33:53',0,NULL,3,1,3,1,NULL,' RR843873988CN\r'),(6016,749288574015,250600521662,'Remote Control Cord Shutter Nikon D300/D200/D700​ MC-30',1,'AA3207',2.98,'hutongstore','crag67','michaelcraig67@hotmail.com','M Craig','141 Ribbleton Avenue','Preston','Lancashire','UNITED KINGDOM','PR26YS','07876790728','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,' '),(6017,683803764002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','iceaxe23','iceaxe23@wi.rr.com','Daniel Yaris','26100 60th st','Salem','WI','UNITED STATES','53168-9246','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-08 17:30:58',0,NULL,3,1,1,1,NULL,NULL),(6018,643660681001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','raf_ceron','alexceron@gmail.com','Rafael Alexander Cerón Rodríguez','Calle Industria, 43<br>Planta Baja','Santa Maria de Palautordera','Cataluña','SPAIN','08460','938482962','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-08 17:53:59',0,NULL,3,1,2,1,NULL,NULL),(6019,643667997001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','alexer1','rozen@te.net.ua','Oleg Rozentsvayg','Nezhinskaya Str3, apt 44','Odessa','UA','UKRAINE','65023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 18:06:31',0,NULL,3,1,3,1,NULL,' RR843873974CN\r'),(6020,683826149002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','r1cc4rd0','r.ongaro@libero.it','riccardo ongaro','via quintino alto 38','bergamo','BG','ITALY','24123','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 18:23:59',0,NULL,3,1,3,1,NULL,' RR843873965CN\r'),(6021,683847112002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','tickhed75','tickhed@gmail.com','Tiffany Melke','1745 Piper Cir SE','Atlanta','GA','UNITED STATES','30316-2253','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-08 19:08:12',0,NULL,3,1,1,1,NULL,NULL),(6022,683851132002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','haghne1','iness_gv@hotmail.com','Inés García Villegas','Cno/ El Jaraque Nº9','Granada','Andalucía Ceuta y Melilla','SPAIN','18620','647214083','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 19:16:43',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864870900CN\r'),(6023,643711614001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','nimuravka1','nimuravka@mail.ru','Ekaterina Dang','Severnaya 48-11','Odintsovo','Moskovskaya oblast','RUSSIAN FEDERATION','143000','+7 926 5377557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 19:35:19',0,NULL,3,1,2,1,NULL,NULL),(6024,643718232001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','matisko2006','mmatisko@pronet.sk','Milan Matisko','Moyzesova 56','Lucenec','','SLOVAK REPUBLIC','98401','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 19:49:51',0,NULL,3,1,2,1,NULL,NULL),(6025,643719874001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fotografitty','pablojmutal@yahoo.com.ar','Pablo Javier Mutal','Felix Frias Esq. San Clemente . BºPriv. San Alfonso<br>Lote 06 Mzna.35','Córdoba','Saldán','ARGENTINA','5149','03543-496695','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 19:53:41',0,NULL,3,1,3,1,NULL,' RR843873930CN\r'),(6026,643722132001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',5.9,'hermeshine','ralfygurl','ralfygurl@yahoo.com','Christy Reed','203 S Chestnut St','Forney','TX','UNITED STATES','75126-9528','(318) 376-1481','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-08 19:56:07',0,NULL,3,1,1,1,NULL,'新的那个，找不到问我 '),(6027,643729917001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','casillas65','carpaumar@gmail.com','juan manuel casillas delgado','calle universidad hispalense 8','osuna','SEVILLA','SPAIN','41640','629017397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 20:13:46',0,NULL,3,1,2,1,NULL,NULL),(6028,643737098001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','yanaiamir','yanaiamar@gmail.com','Yanai Amar','Yoseftal 22','Ramla','','ISRAEL','72412','(972)525444404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 20:29:19',0,NULL,3,1,2,1,NULL,NULL),(6029,643740622001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.95,'hermeshine','irijasan','neribi@gmail.com','Neringa Lavrenove','Rugiu 14-14','Vilnius','','LITHUANIA','08419','+37061075100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 20:33:04',0,NULL,3,1,2,1,NULL,NULL),(6030,749424759015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','eufrat666','nihkeily.jees@gmail.com','Jussi Saarivuori','Teiskontie 8 B 6','Tampere','','FINLAND','33540','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-08 21:04:45',0,NULL,3,1,3,1,NULL,' RR843873957CN\r'),(6031,683913078002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','brokenbmx','brokenbmx@hotmail.com','Gripfruit Joey Terwindt','Hazeleger 189','Cuijk','NB','NETHERLANDS','5431HS','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 21:19:36',0,NULL,3,1,3,1,NULL,'\rRR843873360CN\r'),(6032,749432524015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.28,'hutongstore','hifinut11','thiam.chung@gmail.com','Thiam Chung','11 Manor Close Costock','Loughborough','Leicestershire','UNITED KINGDOM','LE12 6XH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-08 21:18:40',0,NULL,3,1,2,1,NULL,NULL),(6033,643781266001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','alessio_1927','alessio.macri@email.it','Alessio Macrì','via Brembate 21','roma','RM','ITALY','00188','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 22:10:47',0,NULL,3,1,2,1,NULL,'欧标 '),(6034,734478974016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','ethiopia1.123','empressmenan@yahoo.com','Ife','APARTMENT 27, PLACIDO 34 RYLAND STREET','BIRMINGHAM B16 8DB','West Midlands','UNITED KINGDOM','B16 8DB','07930137656','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-08 22:30:20',0,NULL,3,1,4,1,NULL,'英标 \rlighting  kit   $30\rYW864870922CN\r'),(6035,643795320001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','roger_awright','roger.b8@hotmail.com','Roger Becker','Nossa senhoras das Graças, 95','porto alegre','Rio Grande do sul','BRAZIL','90660-170','55-51-33078878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 22:48:46',0,NULL,3,1,2,1,NULL,'接口环尺寸 67mm '),(6036,683946016002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','paluk_fr','psubot@free.fr','SUBOTKIEWIEZ Patrick','30 AVENUE DE L\'HERS','BAZIEGE','Haute garonne','FRANCE','31450','0562711235','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 22:41:08',0,NULL,3,1,4,1,NULL,'欧标   背景布白色 \rlighting  kit  $30\rYW864870911CN\r'),(6037,683970488002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 01:55:39',0,NULL,3,1,3,1,NULL,' '),(6038,643847562001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','diyaudioprojects','ebay@diyaudioprojects.com','Giovanni Militano','806-1305 Taylor Avenue','Winnipeg','MB','CANADA','R3M 2K6','(204) 475-3819','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 02:06:41',0,NULL,3,1,2,1,NULL,' '),(6039,684022812002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','malicegarden','malicegarden@yahoo.com','Katharina Raczew','Dietrichsteingasse 9/13','Vienna','','AUSTRIA','1090','(423) 304-4772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 03:13:41',0,NULL,3,1,2,1,NULL,NULL),(6040,643894061001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','imababo','o_j_4_me@yahoo.com','Carlos Ruiz','67105 Garbino Rd','Cathedral City','CA','UNITED STATES','92234-3479','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-09 05:39:13',0,NULL,3,1,1,1,NULL,NULL),(6041,745284361015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','osbourne91','mmc7373@hotmail.com','Michael Crichton','153 Marion Street','Leichhardt','New South Wales','AUSTRALIA','2040','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 07:30:59',0,NULL,3,1,2,1,NULL,NULL),(6042,734525518016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','michaelq66','michael.quinlivan@irishbroadband.net','Michael Quinlivan','329 O\'Malley Park Southill','Limerick City','Limerick','IRELAND','default','0872311815','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 07:40:49',0,NULL,3,1,4,1,NULL,' \rYW864870933CN\r'),(6043,643915832001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','smpimages2011','ops@smpimages.com.au','Scott Powick','P.O.Box 4243 The Pines centre','Elanora','Queensland','AUSTRALIA','4221','0406996773','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 07:52:25',0,NULL,3,0,3,1,NULL,'XXXL \rRR843873719CN\r'),(6044,684097893002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','floppy6518','floppy_fisico@hotmail.com','Mario Diaz Fernandez','C Acanto Nº11<br>Edificia A Planta Baja','Madrid','Madrid','SPAIN','28045','659340342','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 09:44:27',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864870992CN\r'),(6045,749670104015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','ola.fvs.pettersson','ola.pettersson@gmail.com','Ola Pettersson','Platmyntsgatan 31','GOTEBORG','','SWEDEN','41479','+46707301122','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 10:26:29',0,NULL,3,1,3,1,NULL,' RR843873515CN\r'),(6046,749141346015,250692236332,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',33.58,'hutongstore','nyquist2011','clocchiatti.dario@gmail.com','Dario Clocchiatti','Via Leonardo da Vinci 14/4','Tavagnacco','UD','ITALY','33010','0432660857','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 10:34:58',0,NULL,3,0,3,1,NULL,'nikon -52mm 反接环  1\rcanon -52mm 反接环  1\r52-58mm  双阳环  1\r52mm 接口环  1\r58mm 接口环  1\r67mm 接口环  1\r77mm 接口环 + 托架  1\rND 2  / 4 / 8     1\r申报： photography accessories  33.58 GBP\r\r申报一定要这么做！\rRR843873753CN\r\r\r\r '),(6047,643956365001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','kristoffer554','kkagentur@msn.com','Kristoffer Klok','Holmkaervej 96','Trige','','DENMARK','8380','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 10:58:22',0,NULL,3,1,2,1,NULL,'欧标 '),(6048,643953371001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','elhelado','specialist1982@mail.ru','Yulia Tveritinova','Zhivopisnaya ulitsa, dom 8, kvartira 41','Balashiha','Moscow region','RUSSIAN FEDERATION','143905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 11:09:47',0,NULL,3,1,2,1,NULL,NULL),(6049,643963651001,110658456901,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0034',9,'hermeshine','wilgo_1981','wilgo_1981@hotmail.com','Javier Gutierrez','calle 20 no 21 - 41','bucaramanga','','COLOMBIA','018000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 11:28:11',0,NULL,3,1,2,1,NULL,'nikon 三角包   1 '),(6050,684145571002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','photobuf','tomandsusan@bellsouth.net','Tommy Jennings','1489 Good Hope Rd','Lake','MS','UNITED STATES','39092','','NoPaymentFailure','CheckoutComplete','Other','2011-03-09 12:57:47',0,NULL,3,0,1,1,NULL,'L '),(6051,684160241002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','kir231','kir2@inbox.ru','Konstantin  Kirilov','CHaykovskogo 41A (company kashtan)','Sochi, RU','Krasnodarskiy kray','RUSSIAN FEDERATION','354071','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 13:48:11',0,NULL,8,1,17,0,NULL,NULL),(6052,644001473001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','kir231','kir2@inbox.ru','Konstantin  Kirilov','CHaykovskogo 41A (company kashtan)','Sochi, RU','Krasnodarskiy kray','RUSSIAN FEDERATION','354071','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 13:49:24',0,NULL,3,1,5,1,NULL,'套装再加上一个肩架 \r欧标\rCP226334823CN\r'),(6053,643948522001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','d.irina1975','dumon74.13@gmail.com','Savel\'evu Vladimiru','Proletarskaja dom 7a  kv 12','Kaluzhskaja obl','g Kirov','RUSSIAN FEDERATION','249440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 13:52:57',0,NULL,3,1,2,1,NULL,NULL),(6054,644009217001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','kulakovdarko','kulakov.darko@gmail.com','Darko Kulakov','Marshal Tito 117','Negotino','Negotino','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','1440','+38970368087','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 14:15:35',0,NULL,3,1,2,1,NULL,' '),(6055,684180302002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','graf131313','m.prishep@gmail.com','Maksim Prishep','Rokossovskogo 48-4','Bobryisk','','BELARUS','213811','375295428036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 14:51:49',0,NULL,3,1,3,1,NULL,' RR843873427CN\r'),(6056,684182929002,120568072824,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','if_denis','djdenis@ukr.net','Denys Romanchuk','2200 State Rt 10<br>Ste 104','Parsippany','NJ','UNITED STATES','07054-5305','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-09 15:00:11',0,NULL,3,1,1,1,NULL,NULL),(6057,684183886002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','mandymo_06','mandagray88@gmail.com','Amanda Gray','211 Goingsnake st','Tahlequah','OK','UNITED STATES','74464-2907','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-09 15:02:04',0,NULL,3,1,1,1,NULL,' '),(6058,734813643016,260677592103,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',49.99,'hutongstore','daveyfuggles','dave@davelaing.co.uk','david laing','104 the northern road','liverpool','Merseyside','UNITED KINGDOM','L232RH','07702290657','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-09 16:09:48',0,NULL,3,1,4,1,NULL,'英标 \r不控制重量了， 2.5kg以下就可以，包好点\rlight head  $20\rYW864870966CN\r'),(6059,749800727015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','hatititi','i.hatvani@hotmail.com','ifj. Hatvani Istvan','Alispan utca 70','Erd','Erd','HUNGARY','2030','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-09 16:24:25',0,NULL,3,1,3,1,NULL,' RR843873679CN\r'),(6060,734823834016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'AA1311',3.5,'hutongstore','quasar6903','stefang@sz.inetg.bg','Stefan Georgiev','Sv. Kniaz Boris 93, floor 7, office 4','Stara Zagora','SZ','BULGARIA','6000','(359) 888261706','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 16:50:06',0,NULL,8,1,17,0,NULL,NULL),(6061,749812232015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','quasar6903','stefang@sz.inetg.bg','Stefan Georgiev','Sv. Kniaz Boris 93, floor 7, office 4','Stara Zagora','SZ','BULGARIA','6000','(359) 888261706','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 16:50:06',0,NULL,8,1,17,0,NULL,NULL),(6062,749808349015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',47,'hutongstore','quasar6903','stefang@sz.inetg.bg','Stefan Georgiev','Sv. Kniaz Boris 93, floor 7, office 4','Stara Zagora','SZ','BULGARIA','6000','(359) 888261706','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 16:50:07',0,NULL,8,1,17,0,NULL,NULL),(6063,749803842015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',52,'hutongstore','quasar6903','stefang@sz.inetg.bg','Stefan Georgiev','Sv. Kniaz Boris 93, floor 7, office 4','Stara Zagora','SZ','BULGARIA','6000','(359) 888261706','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-09 16:50:08',0,NULL,3,1,5,1,NULL,'2m 灯架  2\rb座   2\r柔光伞  2\r50-70 单灯头  棚   2  欧标\r45w    2\r气吹 + 布    1 \rCP226334885CN\r'),(6064,749828083015,250599919893,'New 72mm Ring adapter for Cokin P Series Filter Holder',1,'AA2213',2.39,'hutongstore','the_dooku','k.bari@btconnect.com','Khalid Bari','5 Walsingham Close','Luton','Bedfordshire','UNITED KINGDOM','LU2 7AP','07939532123','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-09 17:18:44',0,NULL,3,1,2,1,NULL,NULL),(6065,644095632001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','dinoromano71','bernardinoromano@libero.it','AUSIELLO CARMINE','VIA NAZIONALE 372','TORRETTE DI MERCOGLIANO','AV','ITALY','83013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 18:08:09',0,NULL,3,1,2,1,NULL,'欧标 '),(6066,644134186001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','aneshravidas','anesh.r@telkomsa.net','Kamraj Ravidas','P.O.Box 516,Port Shepstone','South Africa','Kwazulu-Natal','SOUTH AFRICA','4240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 19:26:12',0,NULL,3,1,2,1,NULL,NULL),(6067,684312082002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','hilitkacoon11','hilitkacoon@gmail.com','hilit kacoon','nachal uriah 11/1<br>ramat beit shemesh','ramat beit shemesh','','ISRAEL','90945','029951456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 20:26:00',0,NULL,3,1,3,1,NULL,'分两个小包发 \rRR843873444CN\rRR843873461CN\r'),(6068,644176453001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','bglytle','blytle@ups.com','Brooke Lytle','15 Ogden Ter','Butler','NJ','UNITED STATES','07405','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-09 20:45:36',0,NULL,3,1,1,1,NULL,NULL),(6069,684350355002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','danywise','danieira2@hotmail.it','Daniele Grassi','via pellico 7/e','bareggio','MI','ITALY','20010','347-0404265','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 21:13:23',0,NULL,8,1,17,0,NULL,NULL),(6070,684349822002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',111.98,'hermeshine','danywise','danieira2@hotmail.it','Daniele Grassi','via pellico 7/e','bareggio','MI','ITALY','20010','347-0404265','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 21:13:23',0,NULL,3,1,4,1,NULL,'斜臂   1\r闪光的柔光箱   60cm  2\rlight kit  $20\r YW864870955CN\r'),(6071,684358304002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.2,'hermeshine','richardenbridge','edith.richard@enbridge.com','Edith Richard','289 Scout Street','Ottawa','ON','CANADA','K2C 4E7','(613) 792-4123','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,NULL),(6072,684370660002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','844-223-5287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 21:54:53',0,NULL,3,1,5,1,NULL,'CP226334810CN\r '),(6073,684328946002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','guitzai','sylvainguitz@hotmail.fr','Sylvain Guitz','6, rue francois pinton','Paris','Ile de France','FRANCE','75019','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 22:06:11',0,NULL,3,1,2,1,NULL,NULL),(6074,750014751015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',52,'hutongstore','sammie13584','samuli.miettinen@gmail.com','samuli miettinen','laajavuorenrinne 3 c 38','vantaa','Vantaa','FINLAND','01620','358405208834','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-09 22:27:39',0,NULL,3,1,4,1,NULL,'light kit  $20 \rYW864870944CN\r'),(6075,644240318001,110426879616,'JJC JN-22 Neoprene Lens Case 95x150mm for 28-85 lens',1,'AC2202',8.99,'hermeshine','slava-grebenkin','xyz100@mail.ru','Vyacheslav Grebenkin','Korpys 449, kv. 68','Moscow, Zelenograd','','RUSSIAN FEDERATION','124498','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 23:34:56',0,NULL,3,1,2,1,NULL,' '),(6076,684417029002,120570270785,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','varie001','jaidevwarrier@gmail.com','jaidev varieth','1401 red hawk cir<br>Apt M101','Fremont','CA','UNITED STATES','94538-4749','(205) 239-7852','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 00:11:14',0,NULL,8,1,17,0,NULL,NULL),(6077,684416824002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','varie001','jaidevwarrier@gmail.com','jaidev varieth','1401 red hawk cir<br>Apt M101','Fremont','CA','UNITED STATES','94538-4749','(205) 239-7852','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 00:11:15',0,NULL,8,1,17,0,NULL,NULL),(6078,684416903002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','varie001','jaidevwarrier@gmail.com','jaidev varieth','1401 red hawk cir<br>Apt M101','Fremont','CA','UNITED STATES','94538-4749','(205) 239-7852','NoPaymentFailure','CheckoutComplete','Other','2011-03-10 00:11:15',0,NULL,3,1,3,1,NULL,'2m 灯架   1\rb座    1\r柔光伞   1\r反光伞   1\rNG200     1 \rRR843873529CN\r'),(6079,684427686002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 01:00:40',0,NULL,3,1,3,1,NULL,' RR843873532CN\r'),(6080,644281729001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.9,'hermeshine','wenfasiluy','wenfasiluy@yahoo.com','SILVANA  DOS SANTOS','11 Pillot Pl','WEST ORANGE','NJ','UNITED STATES','07052-5205','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 02:14:42',0,NULL,8,1,17,0,NULL,NULL),(6082,644289320001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','wenfasiluy','wenfasiluy@yahoo.com','SILVANA  DOS SANTOS','11 Pillot Pl','WEST ORANGE','NJ','UNITED STATES','07052-5205','','NoPaymentFailure','CheckoutComplete','Other','2011-03-10 02:50:39',0,NULL,3,1,1,1,NULL,' 67  UV     1     \rSF-18  SB900     1'),(6083,750107437015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-10 03:04:17',0,NULL,7,0,18,0,NULL,'bought by jiangang. No need for shipping'),(6084,644295205001,110534333114,'Green.L 72mm Neutral Density ND4 Filter 72 D90 D300s',1,'AE2306',7.3,'hermeshine','miniatures_on_jazz','cellaga@msn.com','conrad ellaga','60 laguna grande ct','monterey','CA','UNITED STATES','93940-4046','(831) 375-2912','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 03:10:06',0,NULL,3,1,1,1,NULL,NULL),(6085,683965761002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','batatinharj10','batatinharj@gmail.com','Joanna Azevedo','Rua Carlos de Vasconcelos, n°148 apt 405','Rio de Janeiro','Rio de Janeiro','BRAZIL','20521-050','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 03:20:49',0,NULL,3,1,3,1,NULL,' RR843873435CN\r'),(6086,684473910002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','esdrasrioosbr','esdrasrioos@gmail.com','Esdras Rios Baia','Rua Ataulfo Alves,30','Guarulhos','Sao Paulo','BRAZIL','0712150','551164085467','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 03:48:18',0,NULL,3,1,5,1,NULL,'申报 gift  $43 \r\r灯泡要110v的\rCP226334871CN\r'),(6087,644330603001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','zaldy101972','zlucillo@mcdermott.com','Zaldy Lucillo','Jebel Ali Freezone<br>Between 7th and 8th Roundabout','default','Dubai','UNITED ARAB EMIRATES','PO Box 3098','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 06:32:16',0,NULL,3,1,3,1,' RA117714074CN',' CP226334845CN\r重包一下,发两个小包\r背景架 2m宽的（ 白 黑） 1\rRA022497065CN\rRA022947159CN\r'),(6088,642862739001,110533632263,'New Timer Remote Control for Canon EOS 5DMarkII 40D 7D',3,'AA3222',137.7,'hermeshine','videograph903','videograph@e1.ru','Андрей Тюменцев','Repina, 80-148','Ekaterinburg','Sverdlovsk region','RUSSIAN FEDERATION','620043','+79221139762','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 08:23:11',0,NULL,3,1,3,1,NULL,' RR843873603CN\r'),(6089,684525045002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','via4in1via4in1','killa_bee@mail.ru','Sergey Slobodenyuk','Kronshtadtskiy bulvar<br>House 23 Building 1 Flat 47','Moscow','','RUSSIAN FEDERATION','125493','+79647637482','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 08:36:31',0,NULL,3,1,3,1,NULL,'新地址：\r Dmitry Nikiforov\rSvobody Street, House 44, Flat 33\rChelyabinsk\rRussia\r454091\rRR843873563CN\r\r\r'),(6090,684532789002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','miles_tones','jvermie@tiscali.nl','Jerry Vermie','Plevier 95','Hoorn','The Netherlands','NETHERLANDS','1628EX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 09:13:50',0,NULL,3,1,2,1,NULL,NULL),(6091,750192903015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','philipqs','pdlmatthews@gmail.com','Philip Matthews','128 Rathgar Road<br>Rathgar','Dublin 6','Dublin','IRELAND','6','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-10 09:15:06',0,NULL,3,1,3,1,NULL,'RR843873585CN\r '),(6092,684495720002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',7.49,'hermeshine','frozyfrost','err0rfrost@gmail.com','Vladimir Kurganov','Sagymbaya<br>264-14','Bishkek','Bishkek','KYRGYZSTAN','720010','+996555323076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 09:53:55',0,NULL,3,1,3,1,NULL,'RR843873577CN\r '),(6093,684546290002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','assafk888','assafkonebay@gmail.com','Assaf Krintza','Pashosh<br>2','Nes Ziona','shfela','ISRAEL','70400','97289657852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 10:14:50',0,NULL,3,1,2,1,NULL,' '),(6094,750238443015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','where2b','nesmeryova@aol.com','George Talbot','17 Groom Crescent','Wandsworth','London','UNITED KINGDOM','SW18 3JB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-10 11:50:12',0,NULL,3,1,2,1,NULL,NULL),(6095,644419254001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','khaliq.ahmad','p10past10@hotmail.com','Khaliq Ahmad','No.7, Spg 274, Kg. Lambak, Jln Pasir','Bandar Seri Begawan','','BRUNEI DARUSSALAM','BB2715','6738815945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 13:18:37',0,NULL,3,1,3,1,NULL,'RA022490969CN\r '),(6096,508942312003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',2,'AA3205',7,'hermeshine','cmfialho','cmsfialho@gmail.com','Carlos Fialho','Rua Joao Crisostomo de Sa, 9, RC-B','Queluz','','PORTUGAL','2745-030','+351918788231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 13:36:18',0,NULL,3,0,2,1,NULL,NULL),(6097,750289840015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1604',16,'hutongstore','rimakbud2009','rimakbud@gmail.com','Rimma Akbudak','Chernyshevsky 49-58','Almetyevsk','Tatarstan','RUSSIAN FEDERATION','423465','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-10 14:24:36',0,NULL,3,0,3,1,NULL,'wf1003    1 \rRA022490986CN\r'),(6098,750295245015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','dyxopelnikow','dyxopelnikov@mail.ru','Духопельников Андрей','пос. Темерницкий, Степная 18, кв1','Ростов-на-Дону','','RUSSIAN FEDERATION','344114','89045010132','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-10 14:34:12',0,NULL,3,1,3,1,NULL,'RR843873489CN\r '),(6099,684611459002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','vitality-lv','cekc@cekc.lv','Vitalijs Kartupelis','Friedrich-Garves-Str. 2','Bremen','','GERMANY','28199','0049 1701793733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 14:45:34',0,NULL,3,1,2,1,NULL,NULL),(6100,644444713001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','bubbleforshoping','bubbleforshop@gmail.com','Sirichi Srimahattarchi','21/13 Moo 7 Soi Rattanasakha<br>T.Maehei','A.Muang','Chiangmai','THAILAND','50100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 14:46:10',0,NULL,8,1,17,0,NULL,NULL),(6101,644443536001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.9,'hermeshine','kurilovden','red.fox@list.ru','Denis Kurilov','Novokosinskaya 27, 130','Moacow','Moscow','RUSSIAN FEDERATION','111673','9261552567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 14:52:47',0,NULL,3,1,2,1,NULL,NULL),(6102,644449151001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',45.8,'hermeshine','bubbleforshoping','bubbleforshop@gmail.com','Sirichi Srimahattarchi','21/13 Moo 7 Soi Rattanasakha<br>T.Maehei','A.Muang','Chiangmai','THAILAND','50100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 15:00:17',0,NULL,3,1,6,1,NULL,'柔光箱 60-60cm  四灯头  1 \r灯架  2m   1\r斜臂       1\rEE389037515CN\r'),(6103,735310196016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','irina_ale26','kaktusmoy@hotmail.com','Irina Ale','2100 Cropsey Ave<br>Apt 4D','Brooklyn','NY','UNITED STATES','11214-6431','(347) 578-2643','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-10 15:19:30',0,NULL,3,1,4,1,NULL,'灯泡是110v的 \rlighting kit  $30\rYW864871025CN   查'),(6104,644472449001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','sandyg211','sandy_goh88@yahoo.com.sg','Sandy Goh','Blk 212 Pasir Ris St 21<br>#06-234','default','','SINGAPORE','510212','+6593869837','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 16:12:31',0,NULL,3,1,11,1,NULL,NULL),(6105,644480525001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','sotaventear','pedroteruel@hotmail.com','Pedro Teruel Molina','Avda. Santa Clara 15, Edf.Oasis 6-D','Lorca','Murcia','SPAIN','30800','670204207','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 16:35:25',0,NULL,3,1,2,1,NULL,NULL),(6106,644504473001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','kellyannimal','kellyannimal.ebay@gmail.com','kellyann creelman','2948 1/2 B St','San Diego','CA','UNITED STATES','92102-2212','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 17:37:00',0,NULL,3,1,1,1,NULL,NULL),(6107,684684989002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','pinartal','pina.artal.antonio@gmail.com','Antonio Pina Artal','Matilde Sangüesa, 26. 2ºB','Zaragoza','Aragón','SPAIN','50015','669273222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 17:53:57',0,NULL,3,1,2,1,NULL,NULL),(6108,644512765001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','sexycarmelqt','sexycarmelqt2c@gmail.com','Ashley Settles','2507 Farmcrest Dr #1228','HERNDON','VA','UNITED STATES','20171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 17:58:01',0,NULL,3,1,1,1,NULL,NULL),(6109,750397605015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','sokko-sasu','sasu.riikonen@gmail.com','Sasu Riikonen','Hämeenpuisto 40 A 23','Tampere','','FINLAND','33200','+358456711627','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-10 18:14:06',0,NULL,3,1,3,1,NULL,'RR843873492CN\r '),(6110,684696435002,120639724081,'Continuous Lighting kit Red head 800w with bulb+stand ',1,'AKT060',110,'hermeshine','aod21ink','angelofdeath21ink@yahoo.com','Brandon Vickers','3109 Sheffield St','Irving','TX','UNITED STATES','75062-4316','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-10 18:20:15',0,NULL,3,0,4,1,NULL,'2m 灯架  红盒的   1\r红头灯  欧标转美标   1\r800w  110v     1 \rYW864871036CN\r'),(6111,644545497001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','pddl2010','uy.pablo@gmail.com','Pablo Diego','Uruguayana 3159','Montevideo','Montevideo','URUGUAY','11800','+59822042238','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 19:05:08',0,NULL,3,0,3,1,NULL,'xxl \rRA022496992CN\r'),(6112,750464518015,250599424460,'72mm Snap-on Front Cap for Nikon 72mm Filters Lens New',1,'AA1308',1.88,'hutongstore','tonyfdrake','anthony@drake4.orangehome.co.uk','ANTHONY DRAKE','31 CAVENDISH AVENUE<br> NORTHUMBERLAND HEATH','ERITH ','Kent','UNITED KINGDOM','DA81EP','01322446855','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-10 20:02:05',0,NULL,3,1,2,1,NULL,NULL),(6113,684779826002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','micheldesouza','micheldsouza@gmail.com','Michel Souza UD - Ramal 320','Rua do Russel, 434 - 5º Andar<br>Gloria','Rio de Janeiro','RJ','BRAZIL','22210-010','(+55) 21 9653 3202','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 21:08:06',0,NULL,3,1,3,1,NULL,'RR843873501CN\r'),(6114,644633600001,110580765864,'Background Support & Light Kit 3m x 6m 10 x 20 ft white',1,'AKT038',224,'hermeshine','leahubogdan','leahubogdan1@yahoo.com','leahu BOGDAN','cuza voda nr 31 ap 7','oradea','bihor','ROMANIA','410097','0040758069663','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 22:11:03',0,NULL,8,1,17,0,NULL,NULL),(6115,644633941001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','zurlandskij','paronsuren@yahoo.com','Suren Manvelyan','16 block, house 42, app.44','Yerevan','Capital','ARMENIA','0048','+37491011613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 22:13:16',0,NULL,3,1,2,1,NULL,NULL),(6116,684795957002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','oddjohan2004','odd.lundberg@odont.uib.no','Odd Johan Lundberg','Erdalsveien 41','Erdal','','NORWAY','5306','+4790192671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 21:42:13',0,NULL,3,1,2,1,NULL,NULL),(6117,644634418001,110568758656,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',199,'hermeshine','leahubogdan','leahubogdan1@yahoo.com','leahu BOGDAN','cuza voda nr 31 ap 7','oradea','bihor','ROMANIA','410097','0040758069663','NoPaymentFailure','CheckoutComplete','AU_OtherInternational','2011-03-10 22:12:26',0,NULL,3,1,5,1,NULL,'这个人还有一个大套，我没有列在这里\r用他的id 查一下吧，包在一起\r\r放欧标头 \rCP226334868CN\r'),(6118,684822011002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',4,'AO0014',31.6,'hermeshine','radioguy911','findyszh@aol.com','Harry Findysz','10032 E Eric Alan Pl','Tucson','AZ','UNITED STATES','85748','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-10 22:49:03',0,NULL,3,1,1,1,NULL,NULL),(6119,750564864015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','al_carphone','ar4z4@hotmail.com','Ali Raza','9 twinegate','Rochdale','Lancashire','UNITED KINGDOM','OL126dw','01706861325','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-10 23:06:56',0,NULL,3,1,3,1,NULL,'RR843873413CN\r'),(6120,735566964016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','eur0tic','ebay@haargel.nl','Wesley Evers','v.d. klugt wittemansingel 31','Poeldijk','','NETHERLANDS','2685 RV','+31624596996','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-10 23:32:12',0,NULL,8,1,17,0,NULL,NULL),(6121,735567571016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','ctracey2006','chrismxtracey@yahoo.co.uk','christopher tracey','Concept Engineering Ltd<br>33 Wiltshire Road,Dairycoats industrial Estate','Hull','East yorkshire','UNITED KINGDOM','HU4 6PA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-10 23:33:33',0,NULL,3,1,2,1,NULL,NULL),(6122,750576196015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','eur0tic','ebay@haargel.nl','Wesley Evers','v.d. klugt wittemansingel 31','Poeldijk','','NETHERLANDS','2685 RV','+31624596996','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-10 23:38:30',0,NULL,3,1,4,1,NULL,'斜臂   1\r反光板支架    1 \rlight stand  $20\rYW864871040CN'),(6123,684838189002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','dgator002','gator002@tampabay.rr.com','David Bennett','13559 Andova Dr','Largo','FL','UNITED STATES','33774-4634','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 23:44:06',0,NULL,3,1,1,1,NULL,NULL),(6124,644664090001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','jerryjerko2010','arnyc26@hotmail.com','Jerko Jalsovec','Augusta Senoe 29 Senkovec','Cakovec','Cakovec','CROATIA','40000','00385-91-721-5298','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 23:51:50',0,NULL,3,1,5,1,NULL,'申报  gift   $20 \rCP226334854CN\r'),(6125,684868415002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','serch48antonio','sergio1234x@hotmail.com','antonio talamantes','solidaridad 66<br>av.zapata 142','yautepec','morelos','MEXICO','62730','7351606104','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 02:02:38',0,NULL,3,1,3,1,NULL,'RR843873475CN\r'),(6126,684877311002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','juangarg','juancruzgaligniana@yahoo.com.br','juan cruz galigniana','rua vitorio sbalqueiro<br>nº 60, casa 03. Bairro Vista Alegre','curitiba','Paraná - Curitiba','BRAZIL','82100-060','55-41-33592241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 02:09:42',0,NULL,3,1,2,1,NULL,NULL),(6127,644701953001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','tataferchis','ivetestradas@hotmail.com','Ivet Estrada','Morelos Sur 1019 Colonia Constituyentes','Tehuacán','Puebla','MEXICO','75710','1246677','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 02:20:16',0,NULL,3,0,3,1,NULL,'XXL \rRR843873594CN\r'),(6128,644704379001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','christianbernier','info@drakkar.com','Christian Bernier','7628, rue Saint-Dominique','Montréal','QC','CANADA','H2R 1X5','(514) 272-4132','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 02:32:26',0,NULL,3,1,3,1,NULL,'RA022490972CN\r '),(6129,644714862001,110583278510,'TianYa 72mm ND8 filter New 72 Neutral Density Grey NIB',1,'AA2313',7.9,'hermeshine','idansr1981','idansr@gmail.com','Idan Tzror','Vaizman Haim 49','Holon','','ISRAEL','58380','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 03:10:21',0,NULL,5,0,18,0,NULL,''),(6130,644766055001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','iamlado','vorobyevvladimir@mail.ru','Vladimir Vorobyev','Mira 34/1 kv.11<br>tel +7 (701) 747-69-20','Astana','Aqmola obl','KAZAKHSTAN','010000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 08:55:23',0,NULL,3,1,3,1,NULL,' RA022490120CN\r'),(6131,684962252002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','alahomoca','zeljko.jurcic@inet.hr','Zeljko Jurcic','Cernik 18','Cavle','','CROATIA','HR - 51219','00385915142655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 09:10:58',0,NULL,3,1,2,1,NULL,NULL),(6132,750739434015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'AKT023',3.62,'hutongstore','littlemush','john.bardon@virgin.net','John Bardon','36, Mickleton Close<br>Templetown','Consett','Durham','UNITED KINGDOM','DH87UG','01207588168','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-11 09:56:23',0,NULL,3,1,2,1,NULL,NULL),(6133,684989911002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','nekto49','king50@012.net.il','Andrei Vasilenko','Livorno 7/23','Bat Yam','','ISRAEL','59646','0546861300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 11:17:03',0,NULL,3,1,2,1,NULL,NULL),(6134,735779697016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','wojtekturbak','w_turbak@wp.pl','Wojciech Turbak','39 The Orchard Way<br>Greenwood Walk','Ayrefield','Dublin','IRELAND','D13','862494971','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-11 12:57:00',0,NULL,3,1,3,1,NULL,' RA022490116CN\r'),(6135,685015348002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','geoffrey7937','gward@iinet.net.au','geoffrey ward','15 corring way-parmelia','perth','Western Australia','AUSTRALIA','6167','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 13:01:12',0,NULL,3,0,3,1,NULL,'XXXL RA022490323CN\r'),(6136,750550023015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','choang2603','choang263@gmail.com','Duc Hoang','92<br>Waddon Road','Croydon','London','UNITED KINGDOM','CR04JG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-11 15:03:05',0,NULL,3,1,2,1,NULL,NULL),(6137,644864006001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','xkarolinevendraminix','karolinevendramini@hotmail.com','Karoline Vendramini','Avenida Joao Bonicenha Numero 6 Quadra 49','Linhares','Espirito Santo','BRAZIL','29905-110','55 27 99215068','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 15:16:41',0,NULL,3,1,2,1,NULL,'\r '),(6138,644892156001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',2,'AB1203',16,'hermeshine','scx21','pic.noir@free.fr','Caux Sylvie','7 rue Cazotte','Dijon','Bourgogne','FRANCE','21000','0682593568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 16:41:04',0,NULL,3,1,2,1,NULL,NULL),(6139,644905210001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','bird_3075','leprochor@post.cz','Jiri Ptacnik','Sechov 16','Ledec nad Sazavou','','CZECH REPUBLIC','58401','(0420)776156300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 17:14:38',0,NULL,3,1,2,1,NULL,NULL),(6140,750901112015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','starmaroon','lelapskilo@yahoo.com','EMMANOUIL LOURAKIS','1st Welligton street','CHANIA','','GREECE','73131','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-11 17:18:08',0,NULL,3,1,2,1,NULL,NULL),(6141,685114635002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','kriasp0047','morten.aspaas@sbnett.no','Morten Aspaas','Nausthågen','Ulvsvåg','','NORWAY','8276','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 17:51:39',0,NULL,3,1,3,1,NULL,' RA022490195CN\r'),(6142,644921717001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','rimakbud2009','rimakbud@gmail.com','Rimma Akbudak','Chernyshevsky 49-58','Almetyevsk','Tatarstan','RUSSIAN FEDERATION','423465','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 18:04:21',0,NULL,3,1,5,1,NULL,' Valery Nikiforov\rg.Nurlat ul.Karla Marx, 48 kv.1\rTatarstan,423040\rRussia\rCP226334939CN\r王明明\rrimakbud2009'),(6143,681477879002,120601700533,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','bbohnet716','bbohnet18@gmail.com','Brandon Bohnet','4423 109 A Avenue','Edmonton','AB','CANADA','T6A 1S3','(178) 071-6823 ext.: 5','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 18:07:11',0,NULL,7,0,18,0,NULL,NULL),(6144,644770923001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',56.9,'hermeshine','flyfin_ru','flyfin.ru@gmail.com','Ekaterina Karaseva','Solnechnaya Polyana<br>D. 21 KV. 123','Barnaul','Altayskij kraj','RUSSIAN FEDERATION','656060','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 18:07:29',0,NULL,3,1,5,1,NULL,'2m 灯架 2个\rCP226334925CN\r\r刘杰 flyfin_ru'),(6145,644927384001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','rimakbud2009','rimakbud@gmail.com','Rimma Akbudak','Chernyshevsky 49-58','Almetyevsk','Tatarstan','RUSSIAN FEDERATION','423465','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 18:08:25',0,NULL,8,1,17,0,NULL,NULL),(6146,685124054002,120568072824,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','mycbr400','cbr400@skatemalaysia.com','Wan Muhammad Aznan','Unit 45-0-4, Sri Jelatek,<br>Wangsa Maju, Section 10','Kuala Lumpur','Kuala Lumpur','MALAYSIA','53300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 18:14:05',0,NULL,3,1,2,1,NULL,NULL),(6147,641166249001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jweg01','j.gilbert@unb.ca','John Gilbert','2 Conc. 6','Chepstow','ON','CANADA','N0G 1K0','(519) 901-2190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 18:30:15',0,NULL,7,0,18,0,NULL,NULL),(6148,640775018001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','lady_chemicalxx','ladyxxchemical@gmail.com','Vania Stockwell','9 Karanya Street<br>Mount Louisa','Townsville','Queensland','AUSTRALIA','4814','0432872716','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 19:04:16',0,NULL,8,1,17,0,NULL,NULL),(6149,680838111002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',3,'AO0005',54,'hermeshine','lady_chemicalxx','ladyxxchemical@gmail.com','Vania Stockwell','9 Karanya Street<br>Mount Louisa','Townsville','Queensland','AUSTRALIA','4814','0432872716','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 19:04:16',0,NULL,8,0,17,0,NULL,NULL),(6150,680837849002,120605585602,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',76.9,'hermeshine','lady_chemicalxx','ladyxxchemical@gmail.com','Vania Stockwell','9 Karanya Street<br>Mount Louisa','Townsville','Queensland','AUSTRALIA','4814','0432872716','NoPaymentFailure','CheckoutComplete','AU_Other','2011-03-11 19:06:13',0,NULL,3,0,4,1,NULL,'lady_chemicalxx\r3mx6m白色背景布  1\r1.6x3m 背景布  3 白黑灰\r反光板支架  1\r王\rYW864871456CN'),(6151,644969819001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','romang123','rva70024@bigpond.net.au','Roger Van Gramberg','156 Explorers Way','St Clair','New South Wales','AUSTRALIA','2759','0298342085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 19:40:18',0,NULL,8,1,17,0,NULL,NULL),(6152,644969455001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',1,'AB1305',3.79,'hermeshine','romang123','rva70024@bigpond.net.au','Roger Van Gramberg','156 Explorers Way','St Clair','New South Wales','AUSTRALIA','2759','0298342085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 19:40:19',0,NULL,3,1,2,1,NULL,'橡胶遮光罩 58mm  1\r橡胶遮光罩 67mm  1\r '),(6153,685167956002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','batatinharj10','batatinharj@gmail.com','André Cysne','Rua Comandante Cordeiro de Faria 40<br>Maracanã','Rio de Janeiro','Rio de Janeiro','BRAZIL','20271-000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 19:49:19',0,NULL,3,1,3,1,NULL,' RA022490204CN\r'),(6154,749345982015,250599921846,'New 52mm 52 Ring adapter and Holder for Cokin P Series ',1,'AKT018',9.17,'hutongstore','gordonc8193','gordoncooper2@sky.com','GORDON COOPER','24 WHITEBIRK ROAD','BLACKBURN','Lancashire','UNITED KINGDOM','BB13JD','01254601915','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-11 19:57:30',0,NULL,3,0,3,1,NULL,'52mm 接口环  2\r托架  1\r52mm nikon 反接环   1 \rRA022490399CN\r'),(6155,685197255002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','mitokondrium0621','koszegi89@gmail.com','Tamás Kőszegi','Vajda János utca 25','Velence','Fejér megye','HUNGARY','2481','36307180472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 20:53:50',0,NULL,3,1,2,1,NULL,NULL),(6156,685216059002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','jcol2694','jmcolomina@gmail.com','JOSE M COLOMINA','C/ COSTA I LLOBERA 126, 2º','INCA','Baleares','SPAIN','07300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 21:35:20',0,NULL,3,1,2,1,NULL,NULL),(6157,685216654002,120601699795,'New 3 filters & Ring holder set 4 Cokin System P Series',1,'AKT026',22.8,'hermeshine','davivan3011','dvimar@hotmail.es','MotorCartagena S.LConcesionario FIAT','C/ Stª Florentina,nº 1- Media Sala<br>A/A. Damian Vivancos Martinez','Cartagena','Murcia','SPAIN','30310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 21:37:35',0,NULL,3,1,3,1,NULL,' RA022490385CN'),(6158,645044606001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','rdyk4033','dykstra1114@yahoo.com','Ron Dykstra','524 S 94th St','Tacoma','WA','UNITED STATES','98444','(253) 212-1600','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-11 22:42:29',0,NULL,3,1,1,1,NULL,NULL),(6159,685260920002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','rimakbud2009','rimakbud@gmail.com','Rimma Akbudak','Chernyshevsky 49-58','Almetyevsk','Tatarstan','RUSSIAN FEDERATION','423465','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 23:51:47',0,NULL,3,1,3,1,NULL,'爵影5和1       1  \r100 150        1  \rRA022490252CN\r'),(6160,685276452002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','hgarcia470','hgarcia470@hotmail.com','Hilda Garcia','10915 Seguro Dr','Chatsworth','CA','UNITED STATES','91311-1945','(818) 832-9427','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 00:54:52',0,NULL,8,1,17,0,NULL,NULL),(6161,685276201002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','hgarcia470','hgarcia470@hotmail.com','Hilda Garcia','10915 Seguro Dr','Chatsworth','CA','UNITED STATES','91311-1945','(818) 832-9427','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 00:54:52',0,NULL,3,1,1,1,NULL,'CANON 镜头盖  58mm  2 '),(6162,685272155002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','haakonjack','haakon.jack@gmail.com','Ruxandra Balcangiu','La scuola di Pitagora s.r.l.<br>1. Piazza Santa Maria degli Angeli','Napoli','','ITALY','80132','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 01:07:13',0,NULL,3,1,3,1,NULL,' RA022490297CN\r'),(6163,645117296001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','reinym10','reinym@gmail.com','Dame Reiny E. Manalu','Tebet Timur Dalam V No.27<br>Jakarta Selatan','DKI Jakarta','DKI Jakarta','INDONESIA','12820','(62)816-1343179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 03:52:19',0,NULL,3,1,2,1,NULL,NULL),(6164,645118567001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','r0msman','jerivalu@gmail.com','Jeremy Cole','16637 Foothill Blvd<br>Apt 305','Sylmar','CA','UNITED STATES','91342-1484','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 03:58:02',0,NULL,3,1,1,1,NULL,'canon的镜头盖 '),(6165,645121769001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','lowe5954','leroyowens61@gmail.com','Leroy Owens','5672 Dashshund Ct','columbus','OH','UNITED STATES','43232-7506','(614) 833-4508','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 04:29:38',0,NULL,3,1,1,1,NULL,' '),(6166,751175448015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'AC1304',6.1,'hutongstore','chopface1963','topsparks.42@tiscali.co.uk','John Holland','8 Churchside close<br>Biggin Hill','Westerham','Kent','UNITED KINGDOM','TN16 3QF','01959540933','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 04:35:24',0,NULL,3,1,2,1,NULL,NULL),(6167,685350693002,120618815235,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'AA2301',5.7,'hermeshine','sane41k','roldugin.alex@gmail.com','Victoria Zemlyanskaya','Krasnoarmeyskaya str. dom 37- kvartira 85','Sochi','Krasnodarskiy kray','RUSSIAN FEDERATION','354065','79180007571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 07:20:27',0,NULL,8,1,17,0,NULL,NULL),(6168,645150893001,110583278199,'TianYa 58mm CPL filter New 58 Circular Polarizing C-PL',1,'AA2303',5.9,'hermeshine','sane41k','roldugin.alex@gmail.com','Victoria Zemlyanskaya','Krasnoarmeyskaya str. dom 37- kvartira 85','Sochi','Krasnodarskiy kray','RUSSIAN FEDERATION','354065','79180007571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 07:23:14',0,NULL,8,1,17,0,NULL,' '),(6169,685365353002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','fotoz09','zubpho@yahoo.com','zubeyr kureemun','7A, Paul et Virginie Street','Port-Louis','Port-Louis','MAURITIUS','00230','(230) 7683969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 08:37:18',0,NULL,3,1,2,1,NULL,NULL),(6170,751267952015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.28,'hutongstore','efwube','simen@simen.nazwa.pl','HS-TOPP  F H Wojciech Surma','Os. 1000 lecia 1a/9','Stargard Szczecinski','zachodniopomorskie','POLAND','73-110','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-12 10:53:30',0,NULL,3,1,2,1,NULL,NULL),(6171,685402950002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','arnaud6794','arnaud94@gmail.com','Arnaud  CHOQUART','7 rue de Choisy','ALFORTVILLE','Île-de-France','FRANCE','94140','01.43.78.18.77','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 11:10:14',0,NULL,3,1,2,1,NULL,NULL),(6172,685414359002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dmitriy7','contact@bukhonov.com','Dmitriy Bukhonov','59 ap. 51, Novo Uglichskaya str.','Sergiev Posad','Moscow','RUSSIAN FEDERATION','141300','+79261126412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 11:51:38',0,NULL,3,1,2,1,NULL,NULL),(6173,645212390001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','ulldedeu','ulldedeu@yahoo.es','MART GALLEGO GALIANO','POL. INDUSTRIAL CAN BROS<br>CAMI CAN BROS S/N NAVES 4-5','MARTORELL','Barcelona','SPAIN','08760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 11:53:37',0,NULL,8,1,17,0,NULL,NULL),(6174,685413022002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','ulldedeu','ulldedeu@yahoo.es','MART GALLEGO GALIANO','POL. INDUSTRIAL CAN BROS<br>CAMI CAN BROS S/N NAVES 4-5','MARTORELL','Barcelona','SPAIN','08760','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 11:53:38',0,NULL,8,1,17,0,NULL,NULL),(6175,645211710001,110534333419,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','ulldedeu','ulldedeu@yahoo.es','MART GALLEGO GALIANO','POL. INDUSTRIAL CAN BROS<br>CAMI CAN BROS S/N NAVES 4-5','MARTORELL','Barcelona','SPAIN','08760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 11:53:38',0,NULL,8,1,17,0,NULL,NULL),(6176,685413161002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','ulldedeu','ulldedeu@yahoo.es','MART GALLEGO GALIANO','POL. INDUSTRIAL CAN BROS<br>CAMI CAN BROS S/N NAVES 4-5','MARTORELL','Barcelona','SPAIN','08760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 11:53:39',0,NULL,3,1,4,1,NULL,'爵影红外 5 in 1  1\r2m 灯架   1\r单灯头  欧标   1\r反光伞   1 \r柔光伞   2\r115w 5500k 灯泡  220v   1\rphotography acc  $28\rYW864871084CN\rulldedeu\r'),(6177,685438295002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','2011kenhje','kenhje@gmail.com','Kenneth Hjelle','Beregsveien1b','Skodje','møre og romsdal','NORWAY','6260','40032801','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 13:15:07',0,NULL,3,1,3,1,NULL,' RA022497573CN'),(6178,645254411001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','kikepereira','kike.pereira@gmail.com','Luis Pereira','Rua Pedro Franco N251','Cascais','Lisboa','PORTUGAL','2750-262','915385446','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 14:09:17',0,NULL,3,1,2,1,NULL,NULL),(6179,751342158015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','antonis7161','antonis1610@cytanet.com.cy','Antonis Menelaou','2A  Andrea Miaouli St. <br>Meneou','Larnaca','','CYPRUS','7000','0035799585621','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-12 14:19:55',0,NULL,3,0,3,1,NULL,'如果不能控制在2kg以下，通知我 \rRA022490266CN\r'),(6180,645266223001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','bentebakken','smallbangweb@hotmail.com','Bente Bakken','Håkon Magnussons gate 3c','Trondheim','Trondheim','NORWAY','7041','47 91856220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 14:44:44',0,NULL,3,1,2,1,NULL,NULL),(6181,645269950001,110534333294,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',9.69,'hermeshine','chlimallan2009','chlimallan@yahoo.com.sg','Allan lim','Block 163 Toa Payoh Lorong 1<br>#09-1014','default','','SINGAPORE','310163','94576931','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 14:56:24',0,NULL,8,1,17,0,NULL,NULL),(6182,685471389002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','chlimallan2009','chlimallan@yahoo.com.sg','Allan lim','Block 163 Toa Payoh Lorong 1<br>#09-1014','default','','SINGAPORE','310163','94576931','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 14:56:25',0,NULL,3,1,3,1,NULL,'中号内胆包 canon   1 \r方形滤镜接口环 72mm  1\r方形滤镜 镜片卡座  1\rRA022490408CN\r'),(6183,645287253001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','strekov-k','strekovk@gmail.com','Kirill Strekov','Bulvar-Pobedi st. 43-286','Voronezh','Voronezhskaja oblast\'','RUSSIAN FEDERATION','394088','+79616133138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 15:43:11',0,NULL,8,1,17,0,NULL,NULL),(6184,685490386002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','strekov-k','strekovk@gmail.com','Kirill Strekov','Bulvar-Pobedi st. 43-286','Voronezh','Voronezhskaja oblast\'','RUSSIAN FEDERATION','394088','+79616133138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 15:43:11',0,NULL,3,1,2,1,NULL,'橡胶遮光罩 55mm  1 \r爵影红外 sony  1'),(6185,685111715002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','giacomo6013','giasab@infinito.it','Giacomo Sabatini','viale Gabriele D\'Annunzio, 238','Pescara','PE','ITALY','65127','085-65549','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 15:46:05',0,NULL,3,1,2,1,NULL,NULL),(6186,645323070001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',61,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 17:08:18',0,NULL,8,1,17,0,NULL,NULL),(6187,685528503002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',2,'AC3201',79.76,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 17:09:43',0,NULL,8,1,17,0,NULL,NULL),(6188,645324600001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 17:10:57',0,NULL,8,1,17,0,NULL,NULL),(6189,645325261001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:12:20',0,NULL,8,1,17,0,NULL,NULL),(6190,645327146001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',34,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:16:38',0,NULL,8,1,17,0,NULL,NULL),(6191,645327335001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','partyser2009','fabien.dejongdehaas@gmail.com','fabien de jong de haas','jan teulingslaan 58','amstelveen','','NETHERLANDS','1187 sk','06-55852668','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 17:17:00',0,NULL,3,1,4,1,NULL,'背景架 白 黑\rbackground support  $20   \rYW864871073CN\r\r\r刘杰\rpartyser2009'),(6192,736393484016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','bikersir','kroome@yahoo.co.uk','karl roome','12, pollard lane','leeds','West Yorkshire','UNITED KINGDOM','LS131EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:18:48',0,NULL,8,1,17,0,NULL,NULL),(6193,751429111015,250599931689,'New TianYa Star 6 points filters for Cokin P Series',1,'AE2316',7.8,'hutongstore','bikersir','kroome@yahoo.co.uk','karl roome','12, pollard lane','leeds','West Yorkshire','UNITED KINGDOM','LS131EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:18:49',0,NULL,8,1,17,0,NULL,NULL),(6194,751430350015,250692242207,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.68,'hutongstore','bikersir','kroome@yahoo.co.uk','karl roome','12, pollard lane','leeds','West Yorkshire','UNITED KINGDOM','LS131EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:18:49',0,NULL,3,1,3,1,NULL,'方形滤镜接口环 67mm  1\r方形滤镜 镜片卡座  1\r天涯方形滤镜系列  星光镜  star6  1\r橡胶遮光罩 67mm   1\rRA022490371CN\r\r '),(6195,736399523016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','c1bassuk','icornwell@vodafone.net','Ian Cornwell','Unit 15 Silvercourt<br>Intercity Way','Leeds','West Yorkshire','UNITED KINGDOM','LS13 4LY','07525248889','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:26:49',0,NULL,3,1,3,1,NULL,' RA022490354CN\r'),(6196,645327816001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:18:12',0,NULL,3,1,4,1,NULL,'反光板支架  2\r反光板 100*150 40*60 5合1  2\r斜臂   1\r橡胶遮光罩 58mm   1\r柔光箱 50-70cm 单灯头 欧标   1\r115w 5500k 灯泡  220v  1\r庄海f峰\relpoldo\rYW864871062CN\r\r\r\r '),(6197,736408877016,260660051690,'Neoprene Lens Pouch Case 9.5cmx23cm 80-200 70-200mm XL',1,'AC1204',4.38,'hutongstore','christobella','christobella@hotmail.co.uk','Chris Lewis','7 The Terrace<br>Creigiau','Cardiff','S Glam','UNITED KINGDOM','CF15 9NG','07980157239','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:37:16',0,NULL,3,1,2,1,NULL,NULL),(6198,751446109015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','beradi1','radoslaw.bednarczyk@btinternet.com','radek bednarczyk','schepherds court 13','banchory','Aberdeenshire','UNITED KINGDOM','ab31 5tg','01330825926','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:42:20',0,NULL,3,0,2,1,NULL,'1.6x2.1 白色 '),(6199,685546561002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','mco471','phone-city@hotmail.co.uk','Marco Lopez','Lillevångsgatan 12','Simrishamn','Skåne','SWEDEN','27232','0414-16197','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:48:12',0,NULL,3,1,2,1,NULL,NULL),(6200,685546961002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','cuda-k','kaur-@hotmail.com','Kaur Mölder','Elva 10-2','Tartu','','ESTONIA','50404','+37255542044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:48:56',0,NULL,3,1,2,1,NULL,NULL),(6201,645356154001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','matisko2006','mmatisko@pronet.sk','Milan Matisko','Moyzesova 56','Lucenec','','SLOVAK REPUBLIC','98401','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 18:16:02',0,NULL,8,1,17,0,NULL,NULL),(6202,685564347002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariyavoron','vmotom@sibmail.com','Mariya Voronina','pereulok Ovrazhniy, dom 22, kvartira 121<br>pereulok Ovrazhniy, dom 22, kvartira 121','Tomsk','Russian Federation','RUSSIAN FEDERATION','634021','8-913-860-9900','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 18:27:14',0,NULL,8,1,17,0,NULL,NULL),(6203,685568405002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mariyavoron','vmotom@sibmail.com','Mariya Voronina','pereulok Ovrazhniy, dom 22, kvartira 121<br>pereulok Ovrazhniy, dom 22, kvartira 121','Tomsk','Russian Federation','RUSSIAN FEDERATION','634021','8-913-860-9900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 18:37:02',0,NULL,3,1,3,1,NULL,'反光板 100*150 40*60 5合1  1\rlenspen   1 \rRA022490337CN\r'),(6204,645383876001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','guinanet','guinanet88@hotmail.com','Guilherme Camargo','Av. Sapopemba, 8175<br>Jardim Sapopemba','Sao Paulo','São Paulo','BRAZIL','03988-010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 19:10:07',0,NULL,3,1,3,1,NULL,' RA022490345CN\r'),(6205,645388990001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','richardhdez','siomsiom@yahoo.es','Ricardo Hernández Arrondo','Avenida Madrid 226 5-D','Zaragoza','Aragón','SPAIN','50017','652200618','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 19:18:33',0,NULL,3,1,3,1,NULL,'RA022490218CN\r '),(6206,736492741016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','nikal01','inkal00@hotmail.com','Nikos Kalpakidis','(TEL. 6946289780)<br>Leoforos Hatzikyriakou 104','Pireaus','','GREECE','18538','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-12 19:51:13',0,NULL,3,1,2,1,NULL,NULL),(6207,751555365015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.58,'hutongstore','judetheob','bcrowcro@gmail.com','Brian Crowcroft','33 Redhill Heights<br>Glasshoughton','Castleford','Yorkshire','UNITED KINGDOM','WF10 4TJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 20:35:52',0,NULL,3,1,2,1,NULL,NULL),(6208,645435747001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','pdem2309','nagia.d@hotmail.com','Naya Demetriou','36 Chaucer Court New Dover road','Canterbury','Kent','UNITED KINGDOM','CT13AU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 20:55:13',0,NULL,3,1,2,1,NULL,NULL),(6209,645447365001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','tataferchis','ivetestradas@hotmail.com','Ivet Estrada','Morelos Sur 1019 Colonia Constituyentes','Tehuacán','Puebla','MEXICO','75710','1246677','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 21:23:13',0,NULL,3,1,3,1,NULL,' RA022490249CN\r'),(6210,645453340001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','gook90','kristian280@hotmail.com','Kristian Hansen','Langerødødegården','Svinndal','Østfold','NORWAY','1593','92642977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 21:36:30',0,NULL,3,1,2,1,NULL,NULL),(6211,645449582001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','bigbear0072010','ian.cullimore@talktalk.net','Ian Lynton Cullimore','89 Catesby Road<br>Hillmorton','Rugby','Warwickshire','UNITED KINGDOM','CV22 5JL','01788572011','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-03-12 21:40:25',0,NULL,3,1,2,1,NULL,NULL),(6212,645459017001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','oyadgar','oyadgar@gmail.com','Omer Yadgar','Pri Megadim 17<br>apt 2','Maale Adommim','','ISRAEL','98480','972528880662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 21:52:24',0,NULL,8,1,17,0,NULL,NULL),(6213,645458672001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.9,'hermeshine','oyadgar','oyadgar@gmail.com','Omer Yadgar','Pri Megadim 17<br>apt 2','Maale Adommim','','ISRAEL','98480','972528880662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 21:52:25',0,NULL,8,1,17,0,NULL,NULL),(6214,645458888001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.5,'hermeshine','oyadgar','oyadgar@gmail.com','Omer Yadgar','Pri Megadim 17<br>apt 2','Maale Adommim','','ISRAEL','98480','972528880662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 21:52:26',0,NULL,3,1,2,1,NULL,'绿叶 UV  58mm  1 \r绿叶 UV  67mm  1\r绿叶 UV  77mm  1'),(6215,685664301002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',46.99,'hermeshine','sancy77','sancy@datatrans.hu','Sandor Farkas','Csokonai utca 10.','Szekesfehervar','','HUNGARY','8000','+36-20-955-8890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 21:57:03',0,NULL,3,1,3,1,NULL,' RA022490164CN\r'),(6216,645466671001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','roigazit1','roigazit@gmail.com','roi gazit','arlozorov 80','haifa','haifa','ISRAEL','33276','054-673-5209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 22:11:02',0,NULL,3,1,2,1,NULL,NULL),(6217,751613883015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','stanleys8a9f','stanleys@home.se','Stanley Sjogren','Norra Krokslattsgat 12','Goteborg','','SWEDEN','41264','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-12 22:21:10',0,NULL,3,1,3,1,NULL,' RA022490235CN\r'),(6218,685690554002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','glenn650g','leono000@planet.nl','GMA Leonora','Willemstraat 1','Sneek','','NETHERLANDS','8601 GH','0515432778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 22:52:38',0,NULL,3,1,2,1,NULL,NULL),(6219,645478182001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','joaovictorinacio','joao.victor.inacio@gmail.com','João Pereira','Rua Prof Assis Goncalves 1326 Apt 201<br>Água Verde','Curitiba','Paraná','BRAZIL','80620-250','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-12 22:55:26',0,NULL,3,1,2,1,NULL,NULL),(6220,683159313002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','1hectornoel','estudio505@gmail.com','HECTOR RAMOS','VILLA GRANADA<br>ALAMEDA 937','SAN JUAN','PR','UNITED STATES','00924','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,' 649\rRA022490796CN'),(6221,685678303002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','tlqman','jhbray62@ssvecnet.com','James Bray','6275 S Moson Rd','Hereford','AZ','UNITED STATES','85615','(520) 378-5186','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 01:40:23',0,NULL,3,1,1,1,NULL,NULL),(6222,685775188002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','borggu-11','borggu@gmail.com','Timo Spårman','Karvarinaukio  14 A','Oulu','Suomi  Oulu','FINLAND','90650','0408137171','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 04:09:44',0,NULL,3,0,3,1,NULL,'XL RA022490221CN'),(6223,685805262002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 06:55:42',0,NULL,3,1,3,1,NULL,' RA022490306CN\r'),(6224,751764899015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'AA3314',3.82,'hutongstore','sonerics','isakov.spb@gmail.com','Igor Isakov','ul. Zheleznodorozhnaya<br>d.22, kv.63','Otradnoe','Leningradskaya obl','RUSSIAN FEDERATION','187330','+79046174476','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-13 07:08:14',0,NULL,3,1,2,1,NULL,NULL),(6225,685824451002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','zrafal78','rafalzajda@gmail.com','RAFAL ZAJDA','BASEMENT STUDIO FLAT<br>197 BATH ROAD','CHELTENHAM','Gloucestershire','UNITED KINGDOM','GL53 7LZ','07955481556','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 08:25:38',0,NULL,3,1,2,1,NULL,NULL),(6226,645608056001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','gfcodo','gianfrancocod@tiscali.it','Gianfranco    Codognotto','Senofonte 16','Baruccana di Seveso - MB','MI','ITALY','20822','3289646230','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 08:34:19',0,NULL,3,0,3,1,NULL,'XXXL \rRA022495042CN\r'),(6227,685859871002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','raimax20','raimaxas@gmail.com','Raimondas Kazlauskas','Ramuniu g. 9<br>Aukstelke','Siauliai','Siauliai region','LITHUANIA','80180','+37067574850','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 10:12:26',0,NULL,3,1,3,1,NULL,' RA022490283CN\r'),(6228,685892171002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','r1cc4rd0','r.ongaro@libero.it','riccardo ongaro','via quintino alto 38','bergamo','BG','ITALY','24123','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 11:37:15',0,NULL,8,1,17,0,NULL,NULL),(6229,645681656001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','r1cc4rd0','r.ongaro@libero.it','riccardo ongaro','via quintino alto 38','bergamo','BG','ITALY','24123','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 12:09:28',0,NULL,3,1,4,1,NULL,'反光板 100*150 40*60 5合1  1\r反光板支架    1\rreflector $20\r一票两件\r王明明\rr1cc4rd0\rYW864871106CN\r\r'),(6230,645693733001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','xlorian10','jiannis1@mail.com','jiannis chloros','oik. eksikonomou 38','larisa','','GREECE','41223','0030 6948262304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 12:25:59',0,NULL,3,1,2,1,NULL,NULL),(6231,751911595015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','kjiva1','kjellivar.mortensen@gmail.com','Kjell Ivar Mortensen','Tverrmoen 9','default','Nodeland','NORWAY','4645','004792080545','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-13 12:52:01',0,NULL,3,1,3,1,NULL,' RA022490270CN\r'),(6232,685929540002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','652volk','volk652@yandex.ru','Валерий Карпов','Сакко 37б 93','Иваново','Ивановская','RUSSIAN FEDERATION','153012','+79023167509','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 13:14:59',0,NULL,3,0,3,1,NULL,'1.6m x  3m 黑色背景布   1 \rRA022490178CN\r'),(6234,685814136002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',106.9,'hermeshine','spv_x007','spvmail@mail.ru','Pavel Stasenko','Gagarina 3-45','Zelenogorsk','Krasnoyarsky kray','RUSSIAN FEDERATION','663690','+79233724020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 14:42:25',0,NULL,3,1,5,1,NULL,'背景架 2m   1\r1.6mx3m 背景布  3（白 黑 灰） \rCP226334911CN\r\r刘杰 spv_x007'),(6233,685965545002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','popycock','jgundie@cox.net','James Gundersen','1375 Cerritos Dr','Laguna Beach','CA','UNITED STATES','92651-2816','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 14:24:48',0,NULL,3,1,1,1,NULL,NULL),(6235,645150600001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',53.68,'hermeshine','sane41k','roldugin.alex@gmail.com','Victoria Zemlyanskaya','Krasnoarmeyskaya str. dom 37- kvartira 85','Sochi','Krasnodarskiy kray','RUSSIAN FEDERATION','354065','79180007571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 14:46:56',0,NULL,3,0,3,1,NULL,'天涯 cpl 52mm  1\r天涯 cpl 58mm  1\rlenspen   1\r52-58mm  双阳环  1\rcanon-58mm 反接环  1\r50cm 棚  1\r倒影板    1\rRA022490368CN\r\r\r '),(6236,752004293015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.28,'hutongstore','lynx123cats','heavendesigns7th@aol.com','LYN MITCHELL','4 CASTLE WALK','EGREMONT','Cumbria','UNITED KINGDOM','CA22 2BY','01946824747','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 15:42:55',0,NULL,3,1,2,1,NULL,NULL),(6237,686010136002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','cheec_l','rku294@freescale.com','Chee Choy Liew','51, Jalan BU 7/3 Bandar Utama,','Petaling Jaya','Selangor','MALAYSIA','47800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 15:49:38',0,NULL,3,1,2,1,NULL,NULL),(6238,645803615001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','ammaabba','k_mahmood20@yahoo.com','KHALED MAHMOOD','1/20-22 BRANDON AVE','BANKSTOWN','New South Wales','AUSTRALIA','2200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 16:13:26',0,NULL,8,1,17,0,NULL,NULL),(6239,645806263001,110409866856,'77mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1307',3.79,'hermeshine','ammaabba','k_mahmood20@yahoo.com','KHALED MAHMOOD','1/20-22 BRANDON AVE','BANKSTOWN','New South Wales','AUSTRALIA','2200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 16:17:11',0,NULL,3,1,2,1,NULL,NULL),(6240,752107287015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',73,'hutongstore','martar1933','mariatarallo@rocketmail.com','maria fionda','Via Liguria 56<br>Sacile','(Pordenone)','PN','ITALY','33077','0434733131','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-13 17:32:03',0,NULL,3,1,4,1,NULL,'欧标 \rlighting kit  $28\rYW864871110CN\r\r\r刘杰\rmartar1933'),(6241,686079543002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','anthony_william','tonybainbridge1@googlemail.com','anthony bainbridge','Oakend<br>Bridge Close','Byfleet','Surrey','UNITED KINGDOM','KT147DE','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 17:36:16',0,NULL,3,0,3,1,NULL,'XXL \rRA022490155CN\r'),(6242,645881280001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','519stasiu','stan.ela@3web.net','Stanislaw Sokolowski','301 General PL','Kitchener','ON','CANADA','n2k 3v5','(519) 568-7676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 17:58:35',0,NULL,3,1,2,1,NULL,NULL),(6243,645961561001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mdwalters120157','mdwalters.sr@gmail.com','Michael Walters','1710 Viking Dr','Houston','TX','UNITED STATES','77018-1819','','NoPaymentFailure','CheckoutComplete','Other','2011-03-13 19:15:28',0,NULL,3,1,3,1,NULL,' RA022490181CN\r'),(6244,645975527001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','matset1966','mat_set@mail.ru','Sergey Matyuhevich','Vesennaya 3 75<br>Ferma','Sergiev Posad','Moscow region','RUSSIAN FEDERATION','141307','+79031906811','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 19:36:51',0,NULL,3,1,2,1,NULL,NULL),(6245,645972362001,110566020598,'New GGS Digital Camera 3.0\" LCD Screen Protector Glass ',3,'AB2208',16.8,'hermeshine','christianvinces','vinceschristian@gmail.com','christian vinces','CALLE PASTOR SEVILLA 197 CHORRILLOS','LIMA','LIMA','PERU','LIMA 09','511999085143','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 19:39:08',0,NULL,8,1,17,0,NULL,' '),(6246,645973642001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',2,'AB2401',27.98,'hermeshine','christianvinces','vinceschristian@gmail.com','christian vinces','CALLE PASTOR SEVILLA 197 CHORRILLOS','LIMA','LIMA','PERU','LIMA 09','511999085143','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 19:39:07',0,NULL,3,1,3,1,NULL,' GGS  3.0       3     \r90周年镜头筒   2 \rRA022490133CN'),(6247,752267741015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','gulpedalive','paulybear1956-ebay@yahoo.co.uk','Mr P Elvidge','80 Harcourt Drive','Harrogate','North Yorkshire','UNITED KINGDOM','HG1 5AB','01423561777','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 19:41:03',0,NULL,3,1,2,1,NULL,NULL),(6248,686213048002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','matisko2006','mmatisko@pronet.sk','Milan Matisko','Moyzesova 56','Lucenec','','SLOVAK REPUBLIC','98401','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 19:45:23',0,NULL,3,1,5,1,NULL,'欧标  背景布是1.6x2.1白色 \rCP226334908CN\r加一个反光板支架\r\r庄海峰 matisko2006'),(6249,646024161001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','mmalowic','yurple@hotmail.com','Mark Malowicki','7227 Cowell Rd','Brighton','MI','UNITED STATES','48116-5131','(248) 431-9646','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 20:24:33',0,NULL,3,1,1,1,NULL,NULL),(6250,752281509015,250599412421,'Green.L 67mm 67 Neutral Density ND8 Filter ND 8 New',1,'AE2312',4.3,'hutongstore','fotolanders','jansklubal@seznam.cz','Jan Sklubal','6 Home Park','Plymouth','Devon','UNITED KINGDOM','pl2 1bq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 19:52:24',0,NULL,3,1,2,1,NULL,NULL),(6251,646021389001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','rafaelroseiro','rafael_roseiro@hotmail.com','Rafael Roseiro','Rua Amaro Bezerra Cavalcanti, 290','São Paulo','São Paulo','BRAZIL','03513010','11 85052808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 20:27:49',0,NULL,3,1,2,1,NULL,NULL),(6252,752319751015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','leannetill','leanne@liberocounselling.co.uk','Leanne Till','64 Arundel Close<br>Randlay','Telford','Shropshire','UNITED KINGDOM','TF3 2LX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 20:47:16',0,NULL,3,1,2,1,NULL,NULL),(6253,646043467001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.95,'hermeshine','labrujulainquieta','cerol10@gmail.com','Raul Soler','Ronda de poniente 9','Tres Cantos','Madrid','SPAIN','28760','645837155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 20:52:07',0,NULL,3,1,2,1,NULL,NULL),(6254,686280580002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','ellitri62','anfiselec@gmail.com','Angel Figueredo Figueredo','Josep Cuxart 51 5º3ª','Cornella Ll','Barcelona','SPAIN','08940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 21:04:44',0,NULL,3,1,2,1,NULL,NULL),(6255,646080641001,110409866856,'77mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1307',3.79,'hermeshine','donald6687','dcaylor@frontiernet.net','Donald Caylor','962 Mulberry Grove Road','Mulberry Grove','IL','UNITED STATES','62262','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 22:39:49',0,NULL,3,1,1,1,NULL,NULL),(6256,686341289002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',2,'AB1306',7.58,'hermeshine','asifakis','aadubadu@gmail.com','Angela Sifakis','1289 Rippey St','El Cajon','CA','UNITED STATES','92020-1741','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 22:53:32',0,NULL,3,1,1,1,NULL,NULL),(6257,645782369001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:07:11',0,NULL,8,1,17,0,NULL,NULL),(6258,645784766001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',3,'AO0006',32.97,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:07:15',0,NULL,8,0,17,0,NULL,NULL),(6259,645783378001,110499652243,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:07:25',0,NULL,8,1,17,0,NULL,NULL),(6260,645783948001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:07:28',0,NULL,8,1,17,0,NULL,NULL),(6261,686006647002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:07:31',0,NULL,8,1,17,0,NULL,NULL),(6262,645785212001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:08:07',0,NULL,3,1,4,1,NULL,'倒影板   1\r双灯头   1 欧标   \r大力夹球台   1\r柔光伞    1\r背景布 1.6x2.1   3（ 白 黑 灰）\r80cm 5in1    1\rphotography acc  $28\rYW864871121CN\rorellanajacobo\r'),(6263,752433707015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','erisej','for.ri4i@gmail.com','Ricardas Kuprys','17 Creighton Road','London','London','UNITED KINGDOM','N17 8JU','07828127856','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 23:11:03',0,NULL,3,0,2,1,NULL,'1.6x2.1  灰色 '),(6264,686358111002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 23:33:30',0,NULL,8,1,17,0,NULL,NULL),(6265,686341705002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 23:33:31',0,NULL,3,1,3,1,NULL,'背景架2mx2m    2 ( 白) \r改成两票国内挂号重发\r王明明 saud-p\rCP226334899CN\rRA022497499CN\rRA022497508CN\r'),(6266,646131303001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','aidswarrior','managercreative@gmail.com','Stefan Bogdan Terente','str. Pacurari nr.111 bl.603 sc.A et.1 ap.3','Iasi','Iasi','ROMANIA','700523','0754534595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:54:56',0,NULL,3,1,2,1,NULL,NULL),(6267,686367581002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ashturner850','ashrobin87@gmail.com','Ashley Turner','181 Wildflower Ln','Pensacola','FL','UNITED STATES','32514-6665','(850) 866-7468','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 00:00:37',0,NULL,3,1,1,1,NULL,NULL),(6268,686372745002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 00:12:55',0,NULL,8,0,17,0,NULL,'XXXL '),(6269,646138316001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 00:14:43',0,NULL,3,0,3,1,NULL,'摄影背心 Canon  老款 XXXL   1\r摄影背心 绿色薄 canon  XXXL   1\rcanon  肩带     1  \rRA022490456CN\r\r\r看看在不在2kg以下\r '),(6270,686378287002,120462363779,'CTR-301 P Wireless Flash Trigger Kit with PC Port ',1,'AKT013',25.8,'hermeshine','rumasa2','ruterin@hotmail.com','Rubén Maestro Sanz','Urb. Las Nieves, calle guadalajara nº19','Nambroca','Toledo','SPAIN','45191','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 00:27:33',0,NULL,3,1,3,1,NULL,' RA022490310CN'),(6271,752468987015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.5,'hutongstore','hachiko777','dushku5x5@hotmail.it','ilaria medda','via emilia levante 34','bologna','BO','ITALY','40139','3403895818','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 00:31:19',0,NULL,3,1,2,1,NULL,NULL),(6272,646152438001,110408007449,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',7.3,'hermeshine','penster57','rivait@mnsi.net','Erin Gibb','777 Republic Dr','Allen Park','MI','UNITED STATES','48101-3651','(313) 425-2483','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 00:57:05',0,NULL,3,1,1,1,NULL,NULL),(6273,686392384002,120461606047,'New 64\" Pro metal Tripod FT-6662A with Ballhead Bag',1,'AE1601',61,'hermeshine','yuqui','luiscartajena@hotmail.com','Luis cartajena lira','San Luis 1468, El Retiro<br>San Luis 1446, El Retiro','Quilpué','V Region','CHILE','2420678','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 01:09:07',0,NULL,3,1,3,1,NULL,' RA022490147CN\r'),(6274,646157693001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','nllumberco','nllumberco@hotmail.com','Joe Rohrbach','17360 Fontana Path','Farmington','MN','UNITED STATES','55024','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 01:10:26',0,NULL,3,1,1,1,NULL,NULL),(6275,686397201002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ale.sturion','alesturion@gmail.com','Alexandre Graner Sturion','Rua Itamiami, 131<br>Bloco 4 - Apto 104','São Paulo','São Paulo - SP','BRAZIL','04120-100','55 11 6700-0919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 01:17:19',0,NULL,3,1,2,1,NULL,NULL),(6276,646180753001,110451012922,'Adjustable Padded Camera Neck shoulder Strap for Canon',1,'AB1404',8.9,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 02:12:37',0,NULL,8,1,17,0,NULL,NULL),(6277,686425521002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','moklanarpa','moklanarpa@yahoo.es','Miguel Ángel Moclán Arpa','Avenida Carlos I, 9, 9º A','San Sebastián','Guipuzcoa','SPAIN','20011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 02:29:12',0,NULL,3,1,3,1,NULL,' RA022490782CN'),(6278,686460143002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arykinroman','arykin@yandex.ru','Roman Arykin','Lunacharskogo st. 29<br>apartment 12','Shadrinsk','Kurgan region','RUSSIAN FEDERATION','641870','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 04:17:02',0,NULL,3,1,3,1,NULL,'RA022490779CN '),(6279,646220034001,110532007043,'67mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1302',2.6,'hermeshine','apporizon','aporizon@gmail.com','Konstantin Makarov','1204 Avenue U<br># 2012','Brooklyn','NY','UNITED STATES','11229-4107','(347) 587-6084','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 05:01:02',0,NULL,3,1,1,1,NULL,' '),(6280,646019721001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',9.1,'hermeshine','fluffypillow1','pmccaleb@surewest.net','Peggy D. McCaleb','2273 Independence Way','Roseville','CA','UNITED STATES','95747','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 06:18:22',0,NULL,3,1,1,1,NULL,'绿叶 CPL  77mm  1\r77mm canon 镜头盖   1'),(6281,686486367002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','nurdasanto2009','nurdasanto@yahoo.com','Nurdasanto','Wisma Bakrie<br>Jl. HR Rasuna Said Kav.B-1','Jakarta','DKI','INDONESIA','12920','08176617123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 06:49:13',0,NULL,3,1,2,1,NULL,NULL),(6282,737301447016,260660055182,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',15,'hutongstore','gf24708','gfunina@rambler.ru','Galina Funina','Fakultetsky per. 3-54','Moscow','','RUSSIAN FEDERATION','125080','7-903-2562144','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 07:47:04',0,NULL,3,1,2,1,NULL,NULL),(6283,686499544002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','ozbargain.king','bargain.king@yahoo.com','U L Seneviratne','5 Raby Place','Deer Park','Victoria','AUSTRALIA','3023','0433999980','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 08:13:48',0,NULL,3,1,4,1,NULL,'lighting kit  $30 \rozbargain.king\rYW864871316CN\r'),(6284,752624401015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','elfin-embroidery','bigfoot11@btinternet.com','Graham L Harvey','9 Ayr Street<br>Moorlands','Lancaster','Lancashire','UNITED KINGDOM','LA1 3Dt','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 09:21:55',0,NULL,3,1,3,1,NULL,' \rRA022497145CN\r'),(6285,686520639002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ppnbuy','prpn@mail.ru','Pavel Prokopovich','ulitsa Mira 1/1  kvartira 22','Surgut','HMAO','RUSSIAN FEDERATION','628400','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 09:42:42',0,NULL,8,1,17,0,NULL,' '),(6286,646275272001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','ppnbuy','prpn@mail.ru','Pavel Prokopovich','ulitsa Mira 1/1  kvartira 22','Surgut','HMAO','RUSSIAN FEDERATION','628400','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 09:55:12',0,NULL,3,1,3,1,NULL,'ppnbuy\r斜臂   1 \r反光板支架   1\r看看是否2kg以下\r小庄    \rRA022497131CN\r'),(6287,751951572015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','normsbm','lindnorm1@aol.com','NORMAN HARRISON','12 TRINITY CLOSE','DUKINFIELD','CHESHIRE','UNITED KINGDOM','SK16 5JE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 10:06:52',0,NULL,3,1,2,1,NULL,NULL),(6288,646278860001,110529627255,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7º 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 10:08:01',0,NULL,3,1,2,1,NULL,NULL),(6289,646281868001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fboy9685','federico.boy448@gmail.com','federico boy','via garau 29','san sperate','CA','ITALY','09026','0709601716','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 10:22:37',0,NULL,3,1,3,1,NULL,' 小刘  \rfboy9685\rRA022497128CN\r'),(6290,646284987001,110414474017,'Remote Cord Shutter Release for Olympus E420 E410 E510',1,'AA3229',5.18,'hermeshine','marbella756','rafael-sat@hotmail.com','Lorena Romer','GTA<br>C/ Torrente Ballester. Edificio Albatros II, Local 1','Marbella','Andalucía Ceuta y Melilla','SPAIN','29660','609531102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 10:33:43',0,NULL,8,1,17,0,NULL,NULL),(6291,646284616001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','marbella756','rafael-sat@hotmail.com','Lorena Romer','GTA<br>C/ Torrente Ballester. Edificio Albatros II, Local 1','Marbella','Andalucía Ceuta y Melilla','SPAIN','29660','609531102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 10:33:43',0,NULL,8,1,17,0,NULL,' '),(6292,646285481001,110469599833,'New translucent white umbrella soft 85cm / 33.5\"',4,'AD1402',55.96,'hermeshine','curlybren_68','andynbren@bigpond.com','BRENDA PARSONS','7 carlson street<br>bluestone estate','MOUNT BARKER','South Australia','AUSTRALIA','5251','','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-03-14 10:34:56',0,NULL,3,1,3,1,NULL,'RA022497202CN\r '),(6293,752648740015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.95,'hutongstore','bowbelles','bowbelles2011@live.co.uk','Peter King','14 Grasmere Grove, Frindsbury','Rochester','Kent','UNITED KINGDOM','ME24PL','01634723775','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 10:41:29',0,NULL,3,1,2,1,NULL,NULL),(6294,686532575002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','marbella756','rafael-sat@hotmail.com','Lorena Romer','GTA<br>C/ Torrente Ballester. Edificio Albatros II, Local 1','Marbella','Andalucía Ceuta y Melilla','SPAIN','29660','609531102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 10:33:44',0,NULL,3,1,2,1,NULL,'爵影快门线 E2  1 \r爵影快门线C1   1\r爵影快门线C3  1'),(6295,686553577002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','teddy-baku23','ted.baku@mail.ru','bakuteddi jabrayilov','neftyanikov 145 flat 122','baku','baku','AZERBAIJAN','aze1000','009940502208013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 11:51:27',0,NULL,3,1,3,1,NULL,'RA022497180CN\r'),(6296,686554474002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','bigzetek','bigzet@gmail.com','Zbyszek Panek  PHOTO','Gagarina 31','Warszawa','mazowieckie','POLAND','00753','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 11:59:59',0,NULL,8,0,17,0,NULL,''),(6297,646307170001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','bigzetek','bigzet@gmail.com','Zbyszek Panek  PHOTO','Gagarina 31','Warszawa','mazowieckie','POLAND','00753','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 12:03:36',0,NULL,3,1,3,1,NULL,'摄影背心 Canon  老款 XL   1\r气吹+ 布   1 \rRA022497397CN\r'),(6298,646321671001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',133.98,'hermeshine','lerych66','valeriyvn@gmail.com','Valeriy Nazarov','Aralskaya 212-21','Chelyabinsk','','RUSSIAN FEDERATION','454025','+73519096587','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 13:55:06',0,NULL,3,0,5,1,NULL,'2m 灯架  2\r反光板支架   2\r斜臂   2 \r小王    lerych66\rCP226334960CN\r'),(6299,646348849001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','mcsatama','mmatasic@gmail.com','Marko Matasić','Kralji 19, Sesvete','Zagreb','Croatia','CROATIA','10360','00385958024480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 14:29:37',0,NULL,3,1,2,1,NULL,NULL),(6300,686609064002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','jfossb','jhf022@student.uit.no','Jostein Fossbakk','Dramsveien 541','Tromsø','Troms','NORWAY','9014','77613076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 14:51:26',0,NULL,3,1,2,1,NULL,NULL),(6301,646365493001,110566020611,'NEW GGS LCD Screen Protector for Canon EOS 450D 500D',1,'AB2209',7.2,'hermeshine','uciteljica_nina','ninuska18@hotmail.com','Nina Miler','Kralja Tomislava 46','Krk','','CROATIA','51500','0038551221957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:23:27',0,NULL,8,1,17,0,NULL,NULL),(6302,646366052001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','uciteljica_nina','ninuska18@hotmail.com','Nina Miler','Kralja Tomislava 46','Krk','','CROATIA','51500','0038551221957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:25:07',0,NULL,8,1,17,0,NULL,NULL),(6303,686621547002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','selbergswe','robertselberg@hotmail.com','Robert Selberg','Västibäcksvägen 12','Boden','','SWEDEN','96196','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:26:43',0,NULL,3,1,2,1,NULL,NULL),(6304,686621337002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','uciteljica_nina','ninuska18@hotmail.com','Nina Miler','Kralja Tomislava 46','Krk','','CROATIA','51500','0038551221957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:27:46',0,NULL,8,1,17,0,NULL,NULL),(6305,686622236002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','uciteljica_nina','ninuska18@hotmail.com','Nina Miler','Kralja Tomislava 46','Krk','','CROATIA','51500','0038551221957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:29:55',0,NULL,3,1,3,1,NULL,'lenspen   1\r气吹+ 布   1\r麂皮   1\rGGS 450D    1 \rRA022497176CN\r'),(6306,686622783002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','thegrandmatux','matu.posei@fastwebnet.it','Marco Polselli','Via Ergisto Bezzi 34','Roma','RM','ITALY','00153','065813327','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:30:23',0,NULL,3,1,2,1,NULL,NULL),(6307,686625007002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','glazowski81','glaziz@interia.pl','lukasz glazowski','68 Abberley Apt<br>Hight Street','Dublin','Dublin','IRELAND','24','086 0323276','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 15:37:02',0,NULL,3,1,3,1,NULL,' 小庄    glazowski81\rRA022497220CN\r'),(6308,737704073016,260661735101,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',20.8,'hutongstore','kevincho761129','dakeeus@hotmail.com','Kevin (KEE PIL) Cho','Hornsbergs Strand 43<br>1tr','Stockholm','Sweden','SWEDEN','112 16','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 16:22:07',0,NULL,3,1,3,1,NULL,'4镜片，其中+8 换成+4 \rRA022497879CN'),(6309,686643639002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','bourneid','bourneidentity@abv.bg','TEODOR TODOROV','Rue Vandenbroeck 2, app 4, ettage 3','Bruxelles','','BELGIUM','1050','0476057394','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 16:25:11',0,NULL,3,1,2,1,NULL,NULL),(6310,686642262002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','antiqueclockworks','antiqueclockworksgalicia@gmail.com','Iván Blanco Vilar','Av. Vilachán nº11, 1º izquierda','Negreira (A Coruña)','Galicia','SPAIN','15830','667757296','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 16:37:47',0,NULL,3,1,3,1,NULL,'欧标 \r小王  antiqueclockworks\rRA022497233CN\r\r'),(6311,752793589015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1604',16,'hutongstore','crook2205','ian-helen@sky.com','Ian Crook','400 Leyland Road, Lostock Hall','Preston','Lancashire','UNITED KINGDOM','PR55SA','01772316721','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 16:57:36',0,NULL,3,0,3,1,NULL,'wf1003   1\r小庄    crook2205\rRA022497247CN\r'),(6312,646422025001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','r7rocket','davbowman@yahoo.com','David Bowman','10273 Miner Place','Cupertino','CA','UNITED STATES','95014','(650) 438-4815','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 17:51:06',0,NULL,3,1,1,1,NULL,' '),(6313,646435381001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','aperturef2.8','t.dickeson@ntlworld.com','Tim Dickeson','6 Denison Way','St Fagans','Cardiff','UNITED KINGDOM','CF5 4SF','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 18:16:28',0,NULL,3,1,4,1,NULL,'light stand  $20 \r小王   aperturef2.8\rYW864871261CN\r'),(6314,646442719001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','6tuka','andrey.foto.brest@gmail.com','andrei shuka','Suvorova st., 114-19','Brest','','BELARUS','224000','375295739686','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 18:33:53',0,NULL,3,1,3,1,NULL,' 小刘   \r6tuka\rRA022497162CN\r'),(6315,686751219002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','volpone76','karsheimer@gmail.com','Fredrik Jarl','Dalgången 5','Stockholm','','SWEDEN','16841','(+46)0735070869','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 19:57:08',0,NULL,3,1,3,1,NULL,' 小王    \rvolpone76\rRA022497255CN\r'),(6316,646494519001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','ald182','l.david@9online.fr','Laurent david','74 BIS avenue Paul Doumer','Rueil-Malmaison','Île-de-France','FRANCE','92500','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 20:01:44',0,NULL,3,1,4,1,NULL,'tripod $20 \r小庄      ald182\rYW864871272CN\r'),(6317,686764393002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',111.98,'hermeshine','jskinner84t','js84t@yahoo.com','John Skinner','360 CARON<br>Suite #406','WINDSOR','ON','CANADA','N9A5B2','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 20:16:58',0,NULL,3,1,5,1,NULL,'小庄   \rjskinner84t\rCP226334956CN\r'),(6318,646505236001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','pousaul','saul7070@yahoo.com','SAUL POU','# 39 Rafaela Rivera Street Urb. Paseo de los Artesanos  ','LAS PIEDRAS','PR','UNITED STATES','00771','(787) 590-1556','NoPaymentFailure','CheckoutComplete','Other','2011-03-14 20:20:02',0,NULL,3,0,1,1,NULL,'pousaul\r刘'),(6319,751389866015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','lauren_jr1','lauren_jr1@hotmail.co.uk','Marcus Wiltshire','Arrowspeed, 5 Bonville Trading Estate<br>Brislington','Bristol','Bristol','UNITED KINGDOM','bs4 5qu','07983394127','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 21:10:00',0,NULL,3,1,3,1,NULL,' 小刘  \rlauren_jr1\rRA022497264CN\r'),(6320,686794601002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','deimossssss','darslanov@yahoo.com','Denis Arslanov','Vossendijk<br>159','Nijmegen','','NETHERLANDS','6534TN','31616922022','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 21:12:11',0,NULL,3,1,4,1,NULL,'background support   $20 \r背景架2m  白\r小王    deimossssss\rYW864871283CN\r'),(6321,752975390015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','karada_uk','lord.james.of.lochaber@googlemail.com','Jim Findlay','21 Bramble Bank<br>Frimley Green','Camberley','Surrey','UNITED KINGDOM','GU16 6PN','01252836463','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 21:37:52',0,NULL,3,1,3,1,NULL,' 小王   \rkarada_uk\rRA022497352CN\r'),(6322,646565037001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','manutxao6.0','manutxao5.0@gmail.com','Txema Serrano','FAUSTEBEKOA 3A 2C','DURANGO','País Vasco','SPAIN','48200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 22:26:10',0,NULL,3,1,2,1,NULL,' 庄'),(6323,753003159015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','kachok2001','kachok2001@gmail.com','GrigorI Zelenov','PALKKATILANKATU 1 D 80','Helsinki','FIN','FINLAND','00240','358407190206','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 22:34:54',0,NULL,3,1,2,1,NULL,' 庄'),(6324,737925904016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','travelyourlife','travelyourlife@gmail.com','tommaso iadicicco','Google Ireland<br>Barrow St','Dublin','Dublin','IRELAND','D4','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 22:39:46',0,NULL,8,1,17,0,NULL,' 小王   \rtravelyourlife'),(6325,753008829015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','travelyourlife','travelyourlife@gmail.com','tommaso iadicicco','Google Ireland<br>Barrow St','Dublin','Dublin','IRELAND','D4','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 22:44:29',0,NULL,3,1,4,1,NULL,' 小庄    \rtravelyourlife\r斜臂   1\r反光板支架   1\rYW864871294CN\r'),(6326,737931282016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','b_nikolov','bnnikolov@yahoo.com','Boyan Nikolov','dstr.\"Sveta Troica\", bl.366, vh.B ap.44','Sofia','','BULGARIA','1309','(+359889)834140','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 22:52:01',0,NULL,3,1,2,1,NULL,'庄 '),(6327,753038836015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','mk2brian','brianandliz@sky.com','BRIAN HODGKINS','4 THROSTLENEST<br>FARCET','PETERBOROUGH','Cambridgeshire','UNITED KINGDOM','PE73BP','01733240509','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 00:02:15',0,NULL,3,1,3,1,NULL,' 小庄  \rmk2brian\rRA022497216CN\r'),(6328,686869351002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','garyohboy3rv8','garyohboy@aol.com','GARY J FERREIRA','192 Hayden Ave','TIVERTON','RI','UNITED STATES','02878-2122','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 00:23:42',0,NULL,3,1,1,1,NULL,'庄 '),(6329,686891328002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','edji_kiz','linedji@hotmail.fr','Jean-pierre Gilly','10 chemin pierre stajano','La penne sur huveaune','Provence-Alpes-Côte d\'Azur','FRANCE','13821','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 01:28:52',0,NULL,3,1,3,1,NULL,'小刘    \redji_kiz\rRA022497278CN\r'),(6330,686925322002,120451406324,'New EyeCup for Nikon D80 D90 D200',1,'AA1203',4,'hermeshine','hips2220','hipcoral@hotmail.com','Hipolito Corral','1988 Goya','Laval','QC','CANADA','H7S 1T1','(514) 994-4843','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 03:20:53',0,NULL,3,1,2,1,NULL,'hips2220 '),(6331,686926395002,120564178812,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','akarae','genchildren@hotmail.com','Teo   Hong Joo',' Block 426 Serangoon Avenue 1 #11-203','Singapore','Singapore','SINGAPORE','550426','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 03:26:13',0,NULL,3,1,11,1,NULL,'\rakarae\r接口环是77mm的 \r小王'),(6332,646652606001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','leofotografias','leo.fotografias@hotmail.com','Leonardo Pimentel Magalhães','Rua: Manoel Samora, nº 108<br>Bairro: Bromélias','Timóteo','Minas Gerais','BRAZIL','35180-510','(31) 8625-5202','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 03:39:58',0,NULL,3,1,3,1,NULL,'leofotografias \rRA022497383CN\r庄'),(6333,646209985001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',16.56,'hermeshine','santimuya','vamoloredondos@hotmail.com','Santiago D\'Addezio','Darregueyra 2438   3ero A','Capital Federal','Buenos Aires','ARGENTINA','C1425FLR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 04:03:49',0,NULL,3,1,3,1,NULL,'santimuya\r申报 ：  light reflector $10\rRA022497321CN\r庄\r'),(6334,646210333001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',22.6,'hermeshine','santimuya','vamoloredondos@hotmail.com','Santiago D\'Addezio','Darregueyra 2438   3ero A','Capital Federal','Buenos Aires','ARGENTINA','C1425FLR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 04:06:54',0,NULL,3,1,3,1,NULL,'santimuya \r单灯头  欧标   2\rRS-C1    1\r申报： lamp holder accesory  $10\rRA022497318CN\r庄\r'),(6335,646209709001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',30.96,'hermeshine','santimuya','vamoloredondos@hotmail.com','Santiago D\'Addezio','Darregueyra 2438   3ero A','Capital Federal','Buenos Aires','ARGENTINA','C1425FLR','541147733629','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 04:09:06',0,NULL,3,1,3,1,NULL,'santimuya\r申报：bulb holder accesory   $12\rRA022497406CN\r\r\r'),(6336,646657224001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','a.schoenberg','adrian_schoenberg@gmx.net','Adrian Schönberg','Burgwall 27','Vehlefanz','','GERMANY','16727','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 04:09:16',0,NULL,3,1,3,1,NULL,' RA022497335CN\r庄\r'),(6338,686954787002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','royrak','royrak@gmail.com','Rogelio Hernandez','3789 Diamond ct','Simi Valley','CA','UNITED STATES','93063','(805) 304-2594','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 05:56:12',0,NULL,3,1,1,1,NULL,'royrak\r刘'),(6339,646666143001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','santimuya','vamoloredondos@hotmail.com','Santiago D\'Addezio','Darregueyra 2438   3ero A','Capital Federal','Buenos Aires','ARGENTINA','C1425FLR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 06:07:18',0,NULL,8,1,17,0,NULL,'santimuya'),(6340,686960756002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','tricksecret','sathitporn@gmail.com','Sathitporn Jittramontri','32/337 Moo1 Jangwatthana RD.<br>Pakkret','Nonthaburi','','THAILAND','11120','(668)145-63049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 06:36:50',0,NULL,3,1,3,1,NULL,'tricksecret\rRA022497587CN'),(6341,686961764002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','hoonbk','bijolotte@naver.com','Kyoung-Hoon Bae','669-12 3F, Pungdeokcheon 1-dong<br>Suji-gu','Yongin-si','Gyeonggi-do, Korea','KOREA,REPUBLIC OF','448-552','82-10-8706-6853','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 06:46:40',0,NULL,3,1,3,1,NULL,'hoonbk\rRA022497595CN'),(6342,749288574015,250600521662,'Remote Control Cord Shutter Nikon D300/D200/D700​ MC-30',1,'AA3207',2.98,'hutongstore','crag67','michaelcraig67@hotmail.com','M Craig','141 Ribbleton Avenue','Preston','Lancashire','UNITED KINGDOM','PR26YS','07876790728','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 08:19:26',0,NULL,7,0,18,0,NULL,'crag67'),(6343,753235578015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','ziguitow','ziguitow2@gmail.com','Cauã Csik Lima','Estrada Sorima 222 Barra da Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22611030','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-15 12:24:43',0,NULL,3,1,3,1,NULL,'ziguitow\rRA022497794CN\r庄\r'),(6344,752963108015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0005',15.98,'hutongstore','exercise2006','jm2heffernan@eircom.net','j heffernan','24 Forgehill Crescent<br>Stamullen','Co. Meath','Meath','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 12:25:25',0,NULL,3,0,3,1,NULL,'exercise2006庄\rRA022497825CN\r黑色 灰色 1.6x2.1\r'),(6345,753239609015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','ziguitow','ziguitow2@gmail.com','Cauã Csik Lima','Estrada Sorima 222 Barra da Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22611030','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-15 12:37:12',0,NULL,3,1,3,1,NULL,'ziguitow\rRA022497689CN\r'),(6346,646758489001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','harleysc91','bill-pope@sbcglobal.net','Billie  G  Pope','804 Spring Lake Cir','Enon','OH','UNITED STATES','45323','(937) 864-5418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 12:47:21',0,NULL,3,1,1,1,NULL,'harleysc91\r庄'),(6347,738176251016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','jpintom7204','zeamandio@gmail.com','José Mesquita','Avenida D. Dinis, 36-38','Vila Real','','PORTUGAL','5000-600','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 13:51:21',0,NULL,3,1,2,1,NULL,'jpintom7204'),(6348,646779518001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',3,'AC3301',43.68,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:04:20',0,NULL,3,1,3,1,NULL,'nixette_nixette\r庄RA022497692CN\r'),(6349,646789479001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.9,'hermeshine','vitorf2011','vmaf@netcabo.pt','Vitor Fernandes','Pta. Almeida Garrett, nº5, 3ºesq<br>Quinta do Rouxinol','Corroios','Corroios','PORTUGAL','2855-213','+351917220027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:37:44',0,NULL,8,1,17,0,NULL,'vitorf2011'),(6350,738194652016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',5.9,'hutongstore','zbynek.hromek','hromek@zzsoft.cz','Zbynek Hromek','Jaroslava Jezka 786','Trutnov','','CZECH REPUBLIC','54101','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-15 14:41:14',0,NULL,8,1,17,0,NULL,'zbynek.hromek'),(6351,753284484015,250599424460,'72mm Snap-on Front Cap for Nikon 72mm Filters Lens New',2,'AA1308',3.76,'hutongstore','zbynek.hromek','hromek@zzsoft.cz','Zbynek Hromek','Jaroslava Jezka 786','Trutnov','','CZECH REPUBLIC','54101','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 14:41:15',0,NULL,3,1,2,1,NULL,'zbynek.hromek\r大力夹   1\rNIKON 镜头盖 72mm   2\r'),(6352,646790567001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',4,'hermeshine','vitorf2011','vmaf@netcabo.pt','Vitor Fernandes','Pta. Almeida Garrett, nº5, 3ºesq<br>Quinta do Rouxinol','Corroios','Corroios','PORTUGAL','2855-213','+351917220027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:41:32',0,NULL,8,1,17,0,NULL,'vitorf2011'),(6353,646775228001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','dkrm','randy@rwmyers.com','Randy Myers','Forensics Service, 150 East Main St.<br>Police Dept.','Lexington','KY','UNITED STATES','40507','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 14:50:34',0,NULL,3,1,1,1,NULL,'dkrm'),(6354,646793894001,110419742832,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',8.2,'hermeshine','vitorf2011','vmaf@netcabo.pt','Vitor Fernandes','Pta. Almeida Garrett, nº5, 3ºesq<br>Quinta do Rouxinol','Corroios','Corroios','PORTUGAL','2855-213','+351917220027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:52:38',0,NULL,3,1,2,1,NULL,'vitorf2011\r眼罩 450D/500D   1\r绿叶 ND8  77mm  1\r绿叶 UV  67mm   1'),(6355,753292770015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.28,'hutongstore','joseluis.295','jlrsmartin@gmail.com','José Luís Martín (ServeisWeb)','C. Ponent, 13 -15 Pol. Ind. Mas Llado II','Fornells de la Selva','Cataluña','SPAIN','17458','644320882','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 15:04:21',0,NULL,3,1,2,1,NULL,'joseluis.295'),(6356,687097232002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','reverendo_ferryz','ferriz_manson@hotmail.com','Christian Ferriz Santos','c/ flor de nit 5-7 5 B','cornella','Cataluña','SPAIN','08940','933764548','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 15:46:28',0,NULL,3,1,3,1,NULL,'reverendo_ferryz\r刘\rRA022497644CN\r'),(6357,646815747001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','kanfar1','l2939@aceweb.com','Nelson Smith','98645 Camellia Dr','Brookings','OR','UNITED STATES','97415','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 16:03:02',0,NULL,3,1,1,1,NULL,'kanfar1'),(6358,687115389002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','calico.cat!','milo@grika.com','Milo Grika','5642 100th Ln N','Brooklyn Park','MN','UNITED STATES','55443-5700','(612) 730-6456','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 16:37:57',0,NULL,3,1,1,1,NULL,'calico.cat!'),(6359,753346593015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',4,'AA3314',15.28,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163<br>Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 17:08:40',0,NULL,8,1,17,0,NULL,'sparky01278'),(6360,753347332015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',4,'AA3314',15.28,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163<br>Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 17:10:13',0,NULL,8,1,17,0,NULL,'sparky01278'),(6361,753348287015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',4,'AA3314',15.28,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163<br>Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 17:12:06',0,NULL,3,1,3,1,NULL,'sparky01278\r绿叶 CPL  77mm    12\rRA022496122CN\r'),(6362,646849992001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','grisoxxl1','grisoxxl@zoznam.sk','Peter Greňo','L. Svobodu 14','Lučenec','','SLOVAK REPUBLIC','98401','+421907657527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:35:18',0,NULL,8,1,17,0,NULL,'grisoxxl1\r庄'),(6363,687142307002,120568072824,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','grisoxxl1','grisoxxl@zoznam.sk','Peter Greňo','L. Svobodu 14','Lučenec','','SLOVAK REPUBLIC','98401','+421907657527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:43:13',0,NULL,3,1,2,1,NULL,'grisoxxl1\r52-58mm 双阳环  1\r52-52mm 双阳环  1\r庄'),(6364,687151383002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dmitry-e-bay','dmwq@bk.ru','Dmitriy Golubev','Malaya Buharestskaya street dom 6 korp 1 kv 367','St. Petersburg','RU','RUSSIAN FEDERATION','192288','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 18:06:14',0,NULL,3,1,2,1,NULL,'dmitry-e-bay'),(6365,687153946002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','thomasjavier','thomasjcastillo@gmail.com','Thomas Castillo','445 S 5th Ave','Tucson','AZ','UNITED STATES','85701-2446','(520) 403-1467','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 18:10:52',0,NULL,3,1,1,1,NULL,'thomasjavier\r庄'),(6366,687162673002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gal-gal','galm69@walla.com','gal mizrahi','haim laskov 7/5','jerusalem','israel','ISRAEL','1363','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 18:30:21',0,NULL,3,1,3,1,NULL,'gal-gal\rRA022497613CN\r'),(6367,687187667002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','riso_lubi_kavu','richardslovakia@hotmail.com','Richard Medzihradsky','ATT Slovakia, Karadzicova 8/A,','Bratislava','','SLOVAK REPUBLIC','82108','421903814164','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 19:17:17',0,NULL,3,1,2,1,NULL,'riso_lubi_kavu'),(6368,753405556015,250746713895,'67mm Graduated Neutral Density Filter Gradual Grey 67',2,'AA3312',10.4,'hutongstore','luke.morgan.bmx.2009','luke.morgan.bmx@googlemail.com','luke morgan','38 the crescent<br>sea mills','bristol','Bristol','UNITED KINGDOM','bs9 2js','07785592930','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 18:59:36',0,NULL,3,1,2,1,NULL,'luke.morgan.bmx.2009\r庄\r'),(6369,646939385001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','hakanberg1','ebay@hocke.se','Håkan Berg','Albogatan 16','Lund','Skane','SWEDEN','22241','+46709280709','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 20:35:57',0,NULL,3,1,3,1,NULL,'hakanberg1\r庄\rRA022497658CN\r\r'),(6370,687230818002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','woopz86','woopz@hot.ee','Eduard Jashin','Sopruse 250-8','Tallinn','Estonia / Harjumaa','ESTONIA','13412','(+372)55604952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 20:37:27',0,NULL,3,1,2,1,NULL,'woopz86\r刘\r\r'),(6371,646941465001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','igoreksimbiker','ligasurskoe@rambler.ru','Makarov Aleksei','street Samarskaya d.17 kv.91','Ulyanovsk','','RUSSIAN FEDERATION','432073','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 20:38:09',0,NULL,3,1,2,1,NULL,'igoreksimbiker'),(6372,738391697016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','kimh139','kimhughes_uk@yahoo.co.uk','kim Hughes','1, Oaklands Drive','Bridgend','Bridgend','UNITED KINGDOM','CF31 4SH','07887931743','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 21:00:50',0,NULL,3,1,2,1,NULL,'kimh139\r庄\r'),(6373,682327235002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','correa*wellington','wttf_nunes@hotmail.com','Wellington Correa Nunes','Rua Bulcão Viana, n.198','Florianópolis','Santa Catarina','BRAZIL','88020-010','(48) 9635-5842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 22:12:21',0,NULL,3,1,2,1,NULL,'woopz86\r刘'),(6374,646989673001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','pedrofelipe-pedrolas','pedrolas25@hotmail.com','Pedro Felipe Iglesias Sánchez','Av. Portugal nº 195 -Bajo.(peluquería)','Salamanca','Castilla y León','SPAIN','37006','636577533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 22:27:15',0,NULL,3,1,2,1,NULL,'pedrofelipe-pedrolas\r欧标\r庄\r'),(6375,753541554015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','rtkzn','sm-video@inbox.ru','Радик Гаялиев','Ноксинский Спуск, 16, 42','Казань','Республика Татарстан','RUSSIAN FEDERATION','420140','89046666270','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-15 22:47:53',0,NULL,3,1,5,1,NULL,'rtkzn刘\r+一件摄影背心 冬夏 XL\rCP226630619CN'),(6376,753544322015,250662485736,'New Pro Photo Vest for all DSLR fans Size: XL',1,'AA1104',21.5,'hutongstore','rtkzn','sm-video@inbox.ru','Радик Гаялиев','Ноксинский Спуск, 16, 42','Казань','Республика Татарстан','RUSSIAN FEDERATION','420140','89046666270','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 22:53:42',0,NULL,8,1,17,0,NULL,'rtkzn'),(6377,647021496001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','staversky','lgreenm@gmail.com','Dmitry Staversky','Architectors St., 24, kv.53','Kharkov','','UKRAINE','61174','(050)3255120','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 00:08:48',0,NULL,3,0,3,1,NULL,'staversky\rXXXL\rRA022497560CN\r庄  \r'),(6378,647030299001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','plorenzo29','plorenzog@gmail.com','Paul Lorenzo','Jr. Tiahuanaco 889<br>urb. Zarate','Lima','Lima','PERU','Lima 36','511995570853','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 00:44:53',0,NULL,3,1,2,1,NULL,'plorenzo29庄\r'),(6379,647061352001,110534333294,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',9.69,'hermeshine','zeb86','theguy_911@hotmail.com','Miranda Bruckner','3/50 Pakington Street','Kew','Victoria','AUSTRALIA','3101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 02:42:12',0,NULL,3,1,2,1,NULL,'zeb86庄\r'),(6380,647062457001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','ardens','junkorama@comcast.net','Ms. Arden Shelton','1524 N Terry St','Portland','OR','UNITED STATES','97217','(503) 709-7252','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 03:04:55',0,NULL,3,1,1,1,NULL,'ardens\r刘'),(6381,753647934015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','mr_geoff2','ihaveteeth@hotmail.com','Geoff Wols','35/147 Talavera Road','Marsfield','New South Wales','AUSTRALIA','2122','0298691285','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-16 04:20:47',0,NULL,3,1,2,1,NULL,'mr_geoff2\r庄'),(6382,687394513002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','beata_muszynski','wm@usprocom.com','Beata Muszynski','646 N Northwest Hwy<br>Apt B','Park Ridge','IL','UNITED STATES','60068','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 05:10:46',0,NULL,3,1,1,1,NULL,'bern047\r庄'),(6383,647096817001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','martinez1800','martinez1800@comcast.net','Miguel Martinez','1502 Peony Dr','Tracy','CA','UNITED STATES','95377-8815','(209) 832-5079','NoPaymentFailure','CheckoutComplete','Other','2011-03-16 05:50:44',0,NULL,3,0,1,1,NULL,'martinez1800\rxxxl\r刘'),(6384,647096851001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','yudi1103','maspaidy@yahoo.co.id','Yudi ardiyanto','PT TERUMO INDONESIA<br>Wisma Kyoei Prince 5th Floor Jl. Jenderal Sudirman Kav. 3','Jakarta','JK','INDONESIA','10220','62215724071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 05:51:16',0,NULL,3,1,2,1,NULL,'yudi1103\r庄'),(6385,642433815001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',5.4,'hermeshine','nio-999','sergei-r@yandex.ru','Sergei Rozhdestvenskiy','Tarkhanskaya street, 3/1<br>119','Moscow','','RUSSIAN FEDERATION','109156','(926) 886-31-99','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 05:51:42',0,NULL,3,1,2,1,NULL,'nio-999\r庄'),(6386,687409637002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dimgordeev','dim555@bk.ru','Dmitry Gordeev','Vostochniy poselok, 20-14','Cheboksary','Chuvashiya','RUSSIAN FEDERATION','428011','(905)345-57-10','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 07:25:49',0,NULL,3,1,2,1,NULL,'dimgordeev\r庄'),(6387,753709365015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','unusualigor','unusuallll@gmail.com','Igor Karpov','ylitsa 70 let Oktjabrja 5-220','Togliatti','Samarskaja','RUSSIAN FEDERATION','445030','79626127152','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-16 09:15:12',0,NULL,3,1,2,1,NULL,'unusualigor\r庄'),(6388,753709784015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','igoris.g','garvida@takas.lt','Igoris Gargazinas','Zygio 93-44','Vilnius','Zirmunai','LITHUANIA','08234','37069955218','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-16 09:16:16',0,NULL,3,1,2,1,NULL,'igoris.g\r庄'),(6389,647137565001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','mazeke777','mazeke@rambler.ru','Almas Kozygulov','K.Satpaev str. 4-65','Ust-Kamenogorsk','East Kazakhstan','KAZAKHSTAN','070020','87055000022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 09:43:17',0,NULL,8,1,17,0,NULL,'mazeke777'),(6390,687442788002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','mazeke777','mazeke@rambler.ru','Almas Kozygulov','K.Satpaev str. 4-65','Ust-Kamenogorsk','East Kazakhstan','KAZAKHSTAN','070020','87055000022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 09:43:18',0,NULL,3,1,2,1,NULL,'mazeke777\r绿叶 UV  58mm   1\rCANON 镜头盖  58mm  1\r庄'),(6391,687451989002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','phoenix4027','mail@artfacade.com.au','Andrew Baird','21 Burton Street','Dromana','Victoria','AUSTRALIA','3936','0414263555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 10:23:23',0,NULL,3,1,2,1,NULL,'phoenix4027\r刘'),(6392,647158537001,110566020598,'New GGS Digital Camera 3.0\" LCD Screen Protector Glass ',1,'AB2208',5.6,'hermeshine','vvvova','vvvrost@mail.ru','VLADIMIR VAKULENKO','Chicherinsky 1A','Rostov-on-Don','Rostovskaya obl','RUSSIAN FEDERATION','344034','+79081816800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 11:15:27',0,NULL,5,0,18,0,NULL,'vvvova'),(6393,647170923001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','xandhao','asc1407@ig.com.br','Alexandre da Silva Cruz','R. Piracicaba, 480 - Apt.131','Santo André','São Paulo','BRAZIL','09060-180','55-11-44256377','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 12:02:42',0,NULL,3,1,3,1,NULL,'xandhao\r庄\rRA022496025CN\r'),(6394,647174883001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','harcangel','morehh@hotmail.es','Antonio Francisco Morenilla Díaz','Campanilleros, 26 K<br>Benjamin Lopez, 13 bajo A','San Fernando','Andalucía Ceuta y Melilla','SPAIN','11100','647864915','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 12:17:29',0,NULL,3,1,3,1,NULL,'harcangel\r刘\rRA022496048CN\r'),(6395,753776925015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',1,'AA3308',3.38,'hutongstore','jokubas.lioge','joqbas@gmail.com','Jokubas Lioge','Bitininku 1a-10','Vilnius','','LITHUANIA','LT-08414','+37060383067','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-16 12:46:23',0,NULL,3,1,2,1,NULL,'jokubas.lioge\r庄'),(6396,687498490002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','lviana1968','luisviana_89@hotmail.com','Luis Viana','rua tomé de sousa n14 r/chão direito','Póvoa de Varzim','porto','PORTUGAL','4490-681','252100521','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 13:17:06',0,NULL,3,1,3,1,NULL,'lviana1968\rRA022496082CN\r'),(6397,753791642015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',125,'hutongstore','xscrolls','triciro@hotmail.com','patricia whelan','2 cappagh green, finglas west','dublin','ireland','IRELAND','11','018645005','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-16 13:27:49',0,NULL,3,1,4,1,NULL,'xscrolls\r白色布\rlighting kit  $30\rYW864871246CN\r'),(6398,687510666002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','6topal','shestopal@gmail.com','Konstantin Shestopal','Gorodnya str., 13, app. 42','Kiev','','UKRAINE','03141','+38 068 9054985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 13:55:26',0,NULL,3,1,2,1,NULL,'6topal\r刘'),(6399,753830453015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',4.3,'hutongstore','dt090772','ght1942@googlemail.com','Graham Taylor','18 Normanhurst Close<br>Three Bridges','Crawley','West Sussex','UNITED KINGDOM','RH10 1YL','01293534513','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 15:08:20',0,NULL,3,1,2,1,NULL,'dt090772\r王'),(6400,687540725002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','carploos','roquetascity@gmail.com','carlos','c/Seneca Nº8 , Puebla de Vícar','ALMERIA','Andalucia','SPAIN','04738','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 15:27:12',0,NULL,3,1,4,1,NULL,'carploos\r庄\rYW864871235CN\r'),(6401,647245769001,110606921919,'New Portable 50cm 20\"x20\" Soft Box Softbox for Flash ',1,'AB3328',50.99,'hermeshine','wilfred951','skunker925@yahoo.com','Wilfred Briones','3600 Cashmere Cir','Perris','CA','UNITED STATES','92571','(951) 312-2165','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 16:03:10',0,NULL,3,1,3,1,NULL,'wilfred951\r刘\rRA022496119CN\r'),(6402,687552247002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','loufield_roadwin','loufield_@hotmail.com','Ivan Antunez','Urb brisas del aljarafe 40','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41907','696012201','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 16:07:08',0,NULL,3,1,4,1,NULL,'loufield_roadwin\r庄\rYW864871224CN\r'),(6403,687572546002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 16:57:39',0,NULL,3,1,3,1,NULL,'arnorolf10\rRA022496034CN\r'),(6404,687582254002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','ph4rm3r_3d','ed.piebiak@gmail.com','Ed Piebiak','Box 97','Eaglesham','AB','CANADA','T0H 1H0','(780) 359-2448','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 17:13:24',0,NULL,3,1,3,1,NULL,'    ph4rm3r_3d\rRA022496051CN\r'),(6405,687512073002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','stacey.reardon2010','gracesjack@yahoo.com','Stacey Reardon','445 Litchfield Rd','New Milford','CT','UNITED STATES','06776-2005','(860) 350-2087','NoPaymentFailure','CheckoutComplete','Other','2011-03-16 17:43:45',0,NULL,3,1,4,1,NULL,'stacey.reardon2010\rlighting kit  $30\r灯泡 是110v 的\r庄\rYW864871202CN\r'),(6406,687595754002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','eldaral','aliyev.eldar@gmail.com','Ali Aliyev','Comfort Suites(TXA73)<br>631 I-45 South','Huntsville','TX','UNITED STATES','77340','','NoPaymentFailure','CheckoutComplete','Other','2011-03-16 17:50:27',0,NULL,3,1,3,1,NULL,'eldaral\rRA022496105CN\r'),(6407,687602446002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','baggedmitsu','illdragonyou@aol.com','Ernesto Macias','13895 Pheasant Knoll Ln','Moreno Valley','CA','UNITED STATES','92553','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 17:59:35',0,NULL,3,1,1,1,NULL,'baggedmitsu'),(6408,738827854016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'AA2204',2.75,'hutongstore','jtnewman2011','johnthomas.newman@btinternet.com','John Thomas Newman','5 Bindloss Cottages','Milnthorpe','Cumbria','UNITED KINGDOM','LA7 7QD','0153964843','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 18:44:34',0,NULL,3,1,2,1,NULL,'jtnewman2011庄'),(6409,687621596002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','robertmarino31','bmar223@aol.com','Robert Marino','2399 Lakeshore Dr','Mandeville','LA','UNITED STATES','70448-5736','(985) 674-7634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 18:51:11',0,NULL,3,1,1,1,NULL,'robertmarino31\r庄'),(6410,647320464001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','rexregum','honkietong@hotmail.com','Cheng Shian Wen','Hougang Ave 2 BLK 705<br>#10-249','default','','SINGAPORE','530705','+6597110935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 18:57:06',0,NULL,3,1,11,1,NULL,'rexregum\r庄'),(6411,647364880001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.55,'hermeshine','kew78','kewang78@hotmail.com','Eric Wang','860 Centennial Ave<br>Genscript USA Inc','Piscataway','NJ','UNITED STATES','08854-3918','(812) 340-3923','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 20:17:09',0,NULL,3,1,1,1,NULL,'kew78\r庄'),(6412,687682272002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','airfxca','cmw9001@hotmail.com','ying chuan lin','2989 E 26AVE','Vancouver','BC','CANADA','V5R1L4','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 20:33:05',0,NULL,3,1,3,1,NULL,'airfxca刘\rRA022496096CN\r'),(6413,738959574016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','zimoutlaw','ryanclivelaw@gmail.com','Ryan Law','38 Cliveden Road<br>Wimbledon','Wimbledon','London','UNITED KINGDOM','SW19 3RB','02085436535','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 22:20:31',0,NULL,3,1,3,1,NULL,'zimoutlaw\r王\rRA022496017CN\r'),(6414,683159313002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','1hectornoel','estudio505@gmail.com','HECTOR RAMOS','VILLA GRANADA<br>ALAMEDA 937','SAN JUAN','PR','UNITED STATES','00924','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 22:29:41',0,NULL,5,0,18,0,NULL,'1hectornoel\r庄'),(6415,687744005002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','c0starx','costarx@gmail.com','Joaquin costa subias','parroco eusebio cuenca 36 6A','Madrid','Madrid','SPAIN','28045','651199699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 22:44:01',0,NULL,3,1,4,1,NULL,'c0starx\r庄\rtripod  $15\rYW864871213CN\r\r'),(6416,687745038002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','georgecanitgy','graby0@hotmail.com','gabriel mestre sole','calle montserrat, 7, 1-1<br>calle sant pere, 12','calafell','Tarragona','SPAIN','43820','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 22:47:15',0,NULL,8,1,17,0,NULL,'georgecanitgy\r'),(6417,738977098016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','lcor1768','lino.coria@gmail.com','Lino Coria','125 - 2875 Osoyoos Crescent','Vancouver','BC','CANADA','V6T 2G3','(604) 221-5929','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-16 23:00:34',0,NULL,3,1,5,1,NULL,'lcor1768\r灯泡是110v  的\r王\rCP226630622CN\r'),(6418,754094835015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',7.8,'hutongstore','allanb24','allan.brisbane@hotmail.co.uk','Allan Brisbane','1 Hawkwood<br>Whitehills','East Kilbride','South Lanarkshire','UNITED KINGDOM','G75 0SP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 23:07:18',0,NULL,8,1,17,0,NULL,'allanb24'),(6419,754094258015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','allanb24','allan.brisbane@hotmail.co.uk','Allan Brisbane','1 Hawkwood<br>Whitehills','East Kilbride','South Lanarkshire','UNITED KINGDOM','G75 0SP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 23:07:19',0,NULL,8,1,17,0,NULL,'allanb24'),(6420,738978773016,260660053536,'New Pro Photo Vest for all DSLR fans Size: L',1,'AA1103',20.5,'hutongstore','allanb24','allan.brisbane@hotmail.co.uk','Allan Brisbane','1 Hawkwood<br>Whitehills','East Kilbride','South Lanarkshire','UNITED KINGDOM','G75 0SP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 23:07:19',0,NULL,3,1,4,1,NULL,'allanb24\r反光伞  1\r摄影背心 冬夏  L    1\r灯架  2m   1\r闪光灯B座    1\r柔光伞    1\r2.056\r刘\rYW864871191CN  \r'),(6421,641126481001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','aaz38','saletorrent@gmail.com','Alexey Zyuzyun','Pervomayskiy d.8a kv.23','Irkutsk','','RUSSIAN FEDERATION','664058','3952613620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 00:54:43',0,NULL,3,1,2,1,NULL,'aaz38\r庄'),(6422,687789450002,120581555897,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','aimeedesigns','studioaimee@msn.com','Aimee Cooper','957 E Chelsea Dr','Queen Creek','AZ','UNITED STATES','85240','(480) 357-4239','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 01:13:23',0,NULL,8,1,17,0,NULL,'aimeedesigns'),(6423,647470057001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','aimeedesigns','studioaimee@msn.com','Aimee Cooper','957 E Chelsea Dr','Queen Creek','AZ','UNITED STATES','85240','(480) 357-4239','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-03-17 01:13:23',0,NULL,8,1,17,0,NULL,'aimeedesigns'),(6424,647470164001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','aimeedesigns','studioaimee@msn.com','Aimee Cooper','957 E Chelsea Dr','Queen Creek','AZ','UNITED STATES','85240','(480) 357-4239','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 01:13:24',0,NULL,3,1,1,1,NULL,'aimeedesigns\r10片装套装 + 72mm 环架  1\r77mm 接口环  1\r82mm 接口环   1\r徐'),(6425,647475350001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','ljubisa-jagodina','ljubisa.jovanovic@hotmail.com','Ljubisa Jovanovic','Kneza Lazara B1 167/10','Jagodina','Serbia','SERBIA','35000','(381)600626466','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 01:32:32',0,NULL,3,1,2,1,NULL,'ljubisa-jagodina\r新地址： \r Ljubisa Jovanovic \rKneza Lazara 173/3/10 35000 Jagodina Serbia +381600626466\r庄'),(6426,687803918002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','buyerul','manuel_agotici@hotmail.com','Manuel Agotici','134, Marl Meadow Dr.','Kitchener','ON','CANADA','N2R1L3','(519) 589-2336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 02:00:25',0,NULL,3,1,2,1,NULL,'buyerul\r庄'),(6427,647494357001,110523102293,'72mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1308',2.6,'hermeshine','tyman1975','ty_miles@yahoo.com','Tyler Miles','694 Buoy Dr','Pensacola','FL','UNITED STATES','32507-8696','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 02:42:59',0,NULL,3,1,1,1,NULL,'tyman1975\r庄'),(6428,687931408002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','jdoc6368','info@policlinicaareilza.com','Jorge Zamacona','Dr. Areilza 21 ','Bilbao','País Vasco','SPAIN','48011','652734131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 12:12:45',0,NULL,8,1,17,0,NULL,'jdoc6368'),(6429,687932386002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','jdoc6368','info@policlinicaareilza.com','Jorge Zamacona','Dr. Areilza 21 ','Bilbao','País Vasco','SPAIN','48011','652734131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 12:15:59',0,NULL,8,1,17,0,NULL,'jdoc6368'),(6430,647619470001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','trubicboris','trubic.boris@gmail.com','Boris Trubic','Preradoviceva 7','Krizevci','','CROATIA','48260','385-98-9332-301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 13:10:00',0,NULL,3,1,2,1,NULL,'trubicboris\r欧标'),(6431,687927513002,120498233006,'New Camera Tripod Fancier 6662A for Dslr with Bag',1,'AE1601',59,'hermeshine','mrkenosuke','kkarta@graduate.uwa.edu.au','Kenneth Karta','2 Eden Close','perth','Western Australia','AUSTRALIA','6150','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-03-17 12:00:02',0,NULL,3,1,4,1,NULL,'mrkenosuke\rtripod   $16\rYW864871180CN\r'),(6432,647623138001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','anusov-2007','anusovbay@hotmail.com','Anusorn Vanasant','69 Soi Lardpround 110 Yak 3,  Lardpround Rd.<br>Wongthonglang','Bangkok','Bangkok','THAILAND','10310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 13:24:24',0,NULL,3,1,2,1,NULL,'anusov-2007'),(6433,647624910001,110566020611,'NEW GGS LCD Screen Protector for Canon EOS 450D 500D',1,'AB2209',7.2,'hermeshine','pi****','dpmzgz@gmail.com','Daniel  Pérez Mendoza','c/ Segundo de Chomon<br>nº12   6ºA','zaragoza','Aragón','SPAIN','50018','677313160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 13:29:49',0,NULL,5,1,18,0,NULL,'pi****'),(6434,684358304002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.2,'hermeshine','richardenbridge','edith.richard@enbridge.com','Edith Richard','289 Scout Street','Ottawa','ON','CANADA','K2C 4E7','(613) 792-4123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 13:49:55',0,NULL,5,0,18,0,NULL,'richardenbridge'),(6435,0,110662306866,'New 72mm Rubber 3in1 Collapsible Lens Hood',1,'AB1306',2.99,'hermeshine','hollym666','hollym666@aol.com','Holly Mergogey','83 Tower Rd','Cream Ridge','NJ','UNITED STATES','08514-2428','(732) 226-3320','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 14:13:04',0,NULL,3,1,1,1,NULL,'arthurlumen\r庄'),(6436,647636460001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:01',0,NULL,8,1,17,0,NULL,'alexsrf'),(6437,647636988001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:03',0,NULL,8,1,17,0,NULL,'alexsrf'),(6438,647636861001,110544744106,'Neoprene Protector Camera Cover for Canon 450D 550D M',1,'',6.24,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:02',0,NULL,8,1,17,0,NULL,'alexsrf'),(6439,687965971002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:02',0,NULL,8,1,17,0,NULL,'alexsrf'),(6440,647636768001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',6.9,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:03',0,NULL,8,1,17,0,NULL,'alexsrf'),(6441,647636585001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:04',0,NULL,3,1,3,1,NULL,'52-58mm 双阳环  1\r52-52mm 双阳环  1\r万用遮光罩  1\r肥皂盒 柔光罩   580EX  1\r中号内胆包 canon  1\r热靴保护盖  普通  1'),(6442,647613538001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',5,'AC2302',31.05,'hermeshine','alexandreuehara','uehara73@terra.com.br','Ana Maria Armelin Uehara','Rua Gema 141 Bloco 6 Apart 23<br>Jd São Judas','Diadema','Sao Paulo','BRAZIL','09930290','40913711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 12:50:41',0,NULL,3,1,3,1,NULL,'alexandreuehara\rRA022496428CN'),(6443,647645817001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11,'hermeshine','rustyreliks','randb@san.rr.com','Betty Gehm','5023 Hilda Rd','San Diego','CA','UNITED STATES','92110','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 14:40:47',0,NULL,3,1,1,1,NULL,'rustyreliks'),(6444,647651857001,110583278181,'TianYa 55mm CPL filter New 55 Circular Polarizing C-PL',1,'AA2302',5.7,'hermeshine','esiskandar','esiskandar@yahoo.com.sg','Is\'al Ismail','Blk 787B, Woodlands Crescent,<br>#04-78','default','','SINGAPORE','732787','96971456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:59:34',0,NULL,8,1,17,0,NULL,'esiskandar'),(6445,647595381001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','kalina11111111','kalina._@rambler.ru','Elena Gaykova','per. Severnyi 9-19','Kaliningrad','Russia','RUSSIAN FEDERATION','236029','+79527938458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 11:40:43',0,NULL,3,1,2,1,NULL,'kalina11111111'),(6446,687923392002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','jdoc6368','info@policlinicaareilza.com','Jorge Zamacona','Dr. Areilza 21 ','Bilbao','País Vasco','SPAIN','48011','652734131','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 12:00:30',0,NULL,8,1,17,0,NULL,'jdoc6368'),(6447,687949123002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','felipefurtado','felipesfurtado@gmail.com','Felipe Furtado','SQN 308 Bloco J Apto 106<br>Asa Norte','Brasília','Distrito Federal','BRAZIL','70747100','556184577637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 13:16:42',0,NULL,3,1,3,1,NULL,'felipefurtado\rRA022496167CN'),(6448,647602136001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','jdoc6368','info@policlinicaareilza.com','Jorge Zamacona','Dr. Areilza 21 ','Bilbao','País Vasco','SPAIN','48011','652734131','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 12:05:26',0,NULL,3,1,4,1,NULL,'jdoc6368\r反光板支架   1\r2m 灯架   1\rb座   2\r柔伞   1\r无字肩带   1\rlighting kit $25\r庄\rYW864871176CN\r\r\r'),(6449,754376688015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',51.9,'hutongstore','stewebster','stewebster@hotmail.com','Stephen Alan Webster','32 lovett drive','prescot','Merseyside','UNITED KINGDOM','l35 5hj','07891258294','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-17 15:33:12',0,NULL,8,1,17,0,NULL,'stewebster'),(6450,754383445015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24.99,'hutongstore','stewebster','stewebster@hotmail.com','Stephen Alan Webster','32 lovett drive','prescot','Merseyside','UNITED KINGDOM','l35 5hj','07891258294','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-17 15:49:07',0,NULL,8,1,17,0,NULL,'stewebster\r徐'),(6451,753287089015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',8.99,'hutongstore','sarahjones522','sarahjones522@hotmail.com','sarah jones','152 kimberley road<br>Roath','Cardiff','Cardiff','UNITED KINGDOM','CF23 5AF','07828928535','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-17 16:53:24',0,NULL,3,1,2,1,NULL,'sarahjones522'),(6452,647696507001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','candyfloss0215','candyfloss@cutey.com','Candace Henson','2239 Cromwell Cir<br>Apt 207','Austin','TX','UNITED STATES','78741-6058','(832) 444-5351','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 17:12:53',0,NULL,3,1,1,1,NULL,'candyfloss0215'),(6453,647709479001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','vincentrozenberg','vincent@voordebuis.com','Vincent Rozenberg','Hoofdlaan 18','ROTTERDAM','','NETHERLANDS','3051XG','0103400440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 17:45:19',0,NULL,8,1,17,0,NULL,'vincentrozenberg\r庄'),(6454,647682291001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','grotex','dmytropanchyshyn@yahoo.com','Western Bid company','3410 Winnetka Ave N<br>Ste 105','New Hope','MN','UNITED STATES','55427-2091','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 18:26:11',0,NULL,3,1,1,1,NULL,'grotex'),(6455,739398109016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',2,'AA1315',4.4,'hutongstore','peterm1906','mccullow@msn.com','peter mccullow','21 austin avenue<br>hartburn','Stockton On Tees','Cleveland','UNITED KINGDOM','ts18 3qn','01642647550','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-17 20:17:36',0,NULL,3,1,2,1,NULL,'peterm1906'),(6456,687743548002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','shaulialek','alek11@walla.com','Shauli Alek','15','Moshav Sde Ya\'akov','ID','ISRAEL','36586','050-5667720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:44:36',0,NULL,3,1,3,1,NULL,'shaulialek\rRA022496269CN'),(6457,687979016002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','arthurlumen','arthurlumengevorgyan@gmail.com','Arthur Gevorgyan','4 Nar-Dos, apt. 44','Yerevan','Yerevan','ARMENIA','0018','0037491471989','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 14:56:12',0,NULL,3,1,3,1,NULL,'arthurlumen\rRA022496198CN\r'),(6458,647698710001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','vincentrozenberg','vincent@voordebuis.com','Vincent Rozenberg','Hoofdlaan 18','ROTTERDAM','','NETHERLANDS','3051XG','0103400440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 17:17:43',0,NULL,3,1,3,1,NULL,'vincentrozenberg\r单灯头   欧标 1\r一转四 灯头   1\r刘\rRA022496343CN\r'),(6459,647799227001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','nilantha722','nilantha_daya@yahoo.com','Nilantha Dahanak','230<br>Ilam road','Chirstchurch','','NEW ZEALAND','8011','02102390080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 20:53:36',0,NULL,3,1,2,1,NULL,'nilantha722'),(6460,647662774001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','dalmatinoid','gasparjurica@gmail.com','Jurica Gašpar','Put Nina 17','Zadar','Dalmatia','CROATIA','23000','+385 98 582 264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 15:36:53',0,NULL,3,1,2,1,NULL,'hollym666\r庄'),(6461,684784692002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','albertgerrard','alberto2_sa@hotmail.com','Alberto Sanz Alegre','Lopez de Hoyos 133 7º 4','Madrid','Madrid','SPAIN','28002','914169314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 21:29:49',0,NULL,3,1,2,1,NULL,'albertgerrard\r刘'),(6462,647682445001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',3,'AKT007',56.97,'hermeshine','skarp92','erikskarp@hotmail.com','Erik Skarp','Ramshult Norrgård','Mjölby','','SWEDEN','59591','0707499450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:38:10',0,NULL,3,1,3,1,NULL,'nilantha722\r刘\rRA022496286CN'),(6463,647677287001,110658456901,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',9,'hermeshine','zuhalbizz','zuhalbiz@hotmail.com','Awang  Zuhal','No. 33, Taman Rakyat Mergong','Alor Setar','Kedah','MALAYSIA','43000','04-7337244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:44:23',0,NULL,3,1,2,1,NULL,'peterm1906\r刘\r新地址:\rMOHD LUTFI LOKMAN BAH. TEKNOLOGI MAKLUMAT, KEM. PERTANIAN & INDS. ASAS TANI, ARAS 3 PODIUM, LOT 4G1, WISMA TANI, NO.28 PRESINT 4, 62624 PUTRAJAYA,\r MALAYSIA '),(6464,647688025001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','stefdima-2007','stefdima@yandex.ru','Dima Stefanov','6 Demokraticheskaya street, apartment 56','Samara','Samara','RUSSIAN FEDERATION','443031','+79297000281','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:52:38',0,NULL,3,1,3,1,NULL,'felipefurtado\r庄\rRA022496391CN\r'),(6465,687859651002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','bogopolsky1','bog.vadim@gmail.com','vad bogopolsky','motzkin 21 ap 10','netanya','israel','ISRAEL','42460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 17:26:47',0,NULL,3,1,3,1,NULL,'richardenbridge\r徐\rRA022496175CN'),(6466,647799193001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','htnwassenaar','hermanwassenaar@gmail.com','Herman Wassenaar','Torenlaan 72','Blaricum','','NETHERLANDS','1261','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 20:52:33',0,NULL,3,1,3,1,NULL,'htnwassenaar\r刘\rRA022496357CN'),(6467,688194333002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','roquerosolitario','monticolasolitarius@gmail.com','Isidoro Hidalgo Aguilera','C/ Cerrillo, 20','ALMEDINILLA','Andalucía Ceuta y Melilla','SPAIN','14812','609856643','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 23:20:20',0,NULL,3,0,3,1,NULL,'rustyreliks\r庄\r3片装 滤镜袋   1\r50cm 棚   1\r摄影背心绿色 薄款 nikon XL  1\rRA022496431CN\r930\r'),(6468,688199604002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ivanrobe','ivancorreio@yahoo.com.br','Ivan Correa','Rua Rio Espera, 368<br>Carlos Prates','Belo Horizonte','Minas Gerais','BRAZIL','30710-260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 23:36:25',0,NULL,3,1,2,1,NULL,'sarahjones522\r刘'),(6469,688111893002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',111.98,'hermeshine','themike38','themike38@shaw.ca','mike hughes','1408<br>17327 69 ave','edmonton','AB','CANADA','t5t3s9','(780) 721-4710','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 22:51:49',0,NULL,3,1,5,1,NULL,'shaulialek\r王\r2m 灯架   2\r斜臂  2\r反光板支架    1\rCP226334973CN\r'),(6471,647507679001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','guit_in_mos','alvogadro2000@gmail.com','Aleksandr Volkov','Kashirskoe shosse, 84-1-379','Moscow','','RUSSIAN FEDERATION','115569','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 04:01:44',0,NULL,8,1,17,0,NULL,'shenker123\r庄'),(6472,647549006001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','chudostepan','her_husband@inbox.lv','Sergejs Nescereckis','Darzu 60-31','Rezekne','Latvia','LATVIA','LV4601','26704742','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 08:13:10',0,NULL,3,1,2,1,NULL,'skarp92\r刘'),(6473,647528638001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','guit_in_mos','alvogadro2000@gmail.com','Aleksandr Volkov','Kashirskoe shosse, 84-1-379','Moscow','','RUSSIAN FEDERATION','115569','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 08:04:15',0,NULL,3,1,5,1,NULL,'guit_in_mos\r2m 灯架    2\r柔光箱 50-70cm 单灯头  欧标  2\r包   1\r一转四 灯头  2\r王\rCP226334987CN\r\r'),(6474,687876767002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','shenker123','shenkerbay@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 08:16:31',0,NULL,3,1,3,1,NULL,'stefdima-2007\rRA022496312CN\r'),(6475,687886945002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','tuah_reno_design','ben_@singapore.com','Tuah .','650C JURONG WEST ST 61<br>#03-244','default','','SINGAPORE','643650','65 91594849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 09:17:24',0,NULL,3,1,11,1,NULL,'tuah_reno_design\r刘'),(6476,647568089001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','dominiquej999','cbrdoom@free.fr','Dominique julian','4, place des lilas','Montpellier','Languedoc-Rousillon','FRANCE','34070','06 62 62 96 22','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 09:42:39',0,NULL,3,1,3,1,NULL,'dominiquej999\rRA022496374CN'),(6477,644376224001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','nikakvasi','nika.kosir@gmail.com','Nika Ko.ir','Bernekerjeva 22','ljubljana','ljubljana','SLOVENIA','1000','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-17 09:45:43',0,NULL,3,1,2,1,NULL,'nikakvasi\r庄'),(6478,647433946001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','georgecanitgy','graby0@hotmail.com','gabriel mestre sole','calle montserrat, 7, 1-1<br>calle sant pere, 12','calafell','Tarragona','SPAIN','43820','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 10:23:45',0,NULL,3,1,3,1,NULL,'trubicboris\r镜头筒 中号  1\r反光板 100*150 40*60 5合1  1\rRA022496445CN\r庄\r'),(6479,647562670001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fotoivideo','vlado.ludas@gmail.com','Vladimir Luda.','Argentinska <br>2','Zagreb','','CROATIA','10000','00385989601830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 09:18:04',0,NULL,3,1,3,1,NULL,'fotoivideo\r刘\rRA022496207CN\r'),(6480,647577741001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','0045zetteangel','dj719@hotmail.com','Duzette Johannessen','Algade 72, 1','Vordingborg','','DENMARK','4760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 10:46:56',0,NULL,3,1,2,1,NULL,'alexandreuehara\r庄\r'),(6481,687907843002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','hun_jz','jugoslavijezeleznice@gmail.com','Balint G.tz','41. Acsadi Strasse','Monor','','HUNGARY','H-2200','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 10:41:29',0,NULL,3,1,2,1,NULL,'albertgerrard\r庄'),(6482,647583577001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Christina Popova','Rokossovskogo avenue, 115-3','Minsk','','BELARUS','220085','+3757007155','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 10:51:43',0,NULL,3,1,3,1,NULL,'kajzik\r庄\rRA022496330CN'),(6483,647866283001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','999jaby','jaby999@gmail.com','Javier Borja Molina','Tomas Breton 53','Madrid','Madrid','SPAIN','28045','651121336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 00:04:36',0,NULL,3,0,2,1,NULL,'999jaby\r徐'),(6484,739110926016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','sprollieandcollie','nikkicharlton@btinternet.com','nikki charlton','cae poeth<br>abergeirw','dolgellau','Gwynedd','UNITED KINGDOM','ll40 2pf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-17 08:00:44',0,NULL,3,1,2,1,NULL,'sprollieandcollie\r庄'),(6485,688230000002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','dsincere1','david.l.redick@gmail.com','David Redick','464 jordan stuart circle<br>apt 234','Apopka','FL','UNITED STATES','32703','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 01:23:31',0,NULL,3,1,1,1,NULL,'dsincere1'),(6486,647650851001,110566018220,'55mm 55 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT019',34.84,'hermeshine','esiskandar','esiskandar@yahoo.com.sg','Is\'al Ismail','Blk 787B, Woodlands Crescent,<br>#04-78','default','','SINGAPORE','732787','96971456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 01:33:56',0,NULL,3,0,3,1,NULL,'esiskandar\r55mm 接口环  1\r托架  1\r小号内胆包   1\rlenspen   1\r3pcs 滤镜袋   1\rsony 红外遥控   1\r索尼热靴盖   1\r55mm 天涯cpl    1\rRS-S1   1\r\r刘\rRA022496290CN\r\r\r\r'),(6487,739249516016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','stewebster','stewebster@hotmail.com','Stephen Alan Webster','32 lovett drive','prescot','Merseyside','UNITED KINGDOM','l35 5hj','07891258294','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-17 15:29:20',0,NULL,3,1,4,1,NULL,'stewebster\r绿布  \r英标\rlighting kit  $30\r再加上\r115w220v   2\r2m 灯架  1\r斜臂   1\r50-70 棚 英标  1\r王\rYW864871154CN\r\r'),(6488,688251765002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','tdun824259','tdunagan@grandislandchiro.net','Timothy L. Dunagan','620 N Custer Ave','Grand Island','NE','UNITED STATES','68803-4375','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 02:43:03',0,NULL,3,1,1,1,NULL,'tdun824259\r庄'),(6489,647844441001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','icutu','icutu@aol.com','Drew Schnitt','1001 Avocado Isle','Fort Lauderdale','FL','UNITED STATES','33315-1337','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 22:47:18',0,NULL,3,1,1,1,NULL,'icutu\r庄\r中号内胆包  canon    1'),(6490,647772822001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','themike38','themike38@shaw.ca','mike hughes','1408<br>17327 69 ave','edmonton','AB','CANADA','t5t3s9','(780) 721-4710','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 22:51:50',0,NULL,8,0,17,0,NULL,'themike38'),(6491,688189195002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','roquerosolitario','monticolasolitarius@gmail.com','Isidoro Hidalgo Aguilera','C/ Cerrillo, 20','ALMEDINILLA','Andalucía Ceuta y Melilla','SPAIN','14812','609856643','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 23:20:21',0,NULL,8,1,17,0,NULL,'roquerosolitario'),(6492,647848182001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','roquerosolitario','monticolasolitarius@gmail.com','Isidoro Hidalgo Aguilera','C/ Cerrillo, 20','ALMEDINILLA','Andalucía Ceuta y Melilla','SPAIN','14812','609856643','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 23:20:20',0,NULL,8,1,17,0,NULL,'alexandreuehara\rRA022496388CN'),(6493,688270165002,120538959115,'NEW Flash Diffuser for Canon 580EX II',3,'AB3332',7.8,'hermeshine','donnajean0619','treasuredevents@carolina.rr.com','Donna jean Deshaies','710 Bellows Ln','Charlotte','NC','UNITED STATES','28270','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 04:03:02',0,NULL,3,1,1,1,NULL,'donnajean0619\r徐'),(6494,688303803002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:40:13',0,NULL,8,1,17,0,NULL,'osmanshawkat'),(6495,647953370001,110566021477,'TianYa ND8 Filter for Cokin P Series Neutral Density',1,'AA2325',7.2,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:44:43',0,NULL,8,1,17,0,NULL,'osmanshawkat'),(6496,647953765001,110566021441,'TianYa ND4 Filter for Cokin P Series Neutral Density',1,'AA2324',7.2,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:48:44',0,NULL,8,1,17,0,NULL,'osmanshawkat'),(6497,647953980001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:48:43',0,NULL,3,1,3,1,NULL,'osmanshawkat\r天涯方形滤镜  渐变蓝  1\r天涯方形滤镜  ND8  1\r天涯方形滤镜  ND4  1\r天涯方形滤镜  渐变橙   1\r大号内胆包canon   1\r庄\rRA022496961CN'),(6498,688310138002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:14:17',0,NULL,8,1,17,1,NULL,'osmanshawkat'),(6499,647962586001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',4.95,'hermeshine','e_gedaminas','evaldas_ged@inbox.lt','Evaldas Gedaminas','H. Manto 5-3','Klaipėda','','LITHUANIA','92128','+37068165225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:35:38',0,NULL,3,1,2,1,NULL,'e_gedaminas\r庄'),(6500,645514132018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'',80,'photographyacc','pantis80','jensjohansen@gmail.com','Jens Anton Johansen','Ørneveien 38, 101','Tromsø','Troms','NORWAY','9015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:40:17',0,NULL,3,0,4,1,NULL,'pantis80\rbackground  support $25\r2m 背景架  （ 白  黑）  1\rYW864871132CN\r'),(6501,688308108002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','klysner200551','steen@faklysner.dk','steen klysner','laeskovvej 117','Bjaeverskov','sjaeland','DENMARK','4632','45+22687661','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 08:05:48',0,NULL,3,0,3,1,NULL,'klysner200551\rRA022496975CN'),(6502,647450707001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','evanswindaching','stevenzilla151@sbcglobal.net','Steven Ching','6220 Calvine Rd','Sacramento','CA','UNITED STATES','95823-5794','(916) 422-0635','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 09:08:24',0,NULL,3,0,1,1,NULL,'evanswindaching\r美国客户帮忙发了，tracking number 是：\r03103200000021098645\r'),(6503,647984734001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','bluesmansur','ramrif@hotmail.com','Ramón Rivera Freire','San Antonio,6 1º C','ALGECIRAS','Cadiz','SPAIN','11201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 10:23:17',0,NULL,8,1,17,0,NULL,'bluesmansur'),(6504,647788912001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','toggasantiques','toggasbyggatervinning@hotmail.com','Torgny Samuelsson','Lummelundsväg 49','Visby','Visby','SWEDEN','62141','070-1750033','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 10:55:19',0,NULL,3,1,4,1,NULL,'toggasantiques\rbackground support  $20\r2m 背景架   （ 白  黑）   1\rYW864871390CN'),(6505,688349081002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','perteco','quvo@quvo.es','Alejandro Jesus Nieto Fernandez','Calle Ladera de los almendros, 18A, 2ºd','Madrid','Madrid','SPAIN','28032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 11:10:39',0,NULL,3,1,2,1,NULL,'perteco'),(6506,754803367015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',25,'hutongstore','kyodai_studio','krasz76@hotmail.com','Dave Kraszewski','St. Johns College Computer Department<br>St. Johns Street','Cambridge','Cambridgeshire','UNITED KINGDOM','CB21TP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-18 11:31:29',0,NULL,3,1,3,1,NULL,'kyodai_studio\r英标\rRA022495144CN'),(6507,648013363001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','kojak-with-a-kodak','danny_bowes@hotmail.com','danny bowes, room 523','riverside condo, 324/11 chiang mai lampun road<br>t.nonghoi, a.muang.','chiang mai','thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 12:29:15',0,NULL,3,1,2,1,NULL,'kojak-with-a-kodak\r接口环是67mm的'),(6508,754823738015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','andraz25','andraz_muljavec@t-2.net','Andraž Muljavec','Lojzeta Hrovata 9','Kranj','Slovenia','SLOVENIA','4000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-18 12:33:51',0,NULL,3,1,3,1,NULL,'andraz25\rRA022496958CN\r'),(6509,688337973002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','bluesmansur','ramrif@hotmail.com','Ramón Rivera Freire','San Antonio,6 1º C','ALGECIRAS','Cadiz','SPAIN','11201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 10:25:27',0,NULL,3,1,4,1,NULL,'bluesmansur\r2m 灯架   1\rb座   1\r柔光伞    1\r反光板支架   1\rlighting kit    $20\rYW864871386CN'),(6510,688396118002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','charles1713','chasespotshot@aol.com','charles wilkinson','393 Main St','paterson','NJ','UNITED STATES','07501','(201) 406-0589','NoPaymentFailure','CheckoutIncomplete','Other','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'charles1713'),(6511,648043055001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','metlili','metlilimout@yahoo.fr','Raphael Caputo','16 Luis Vives','Fuenlabrada','Madrid','SPAIN','28946','695167369','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 13:59:05',0,NULL,3,1,2,1,NULL,'metlili'),(6512,648029622001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','xrobertojosuex','xxrunkenxx@gmail.com','roberto josue naranjo rosario','BB72 CALLE 26<br>LAS VEGAS','catano','PR','UNITED STATES','00962-6428','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 13:15:04',0,NULL,3,1,1,1,NULL,'xrobertojosuex'),(6513,688414466002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','boon_song_2502','boon_song_2502@hotmail.com','boonsong jiamjitvanicha','166/1 soi.Phachachun20 Phachachun Road, Bangsue,Bangsue','Bangkok','Bangkok','THAILAND','10800','02-5731687','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 14:55:09',0,NULL,3,1,2,1,NULL,'boon_song_2502'),(6514,648071475001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','halatchev1','halatchev@yahoo.com','peter halatchev','42 Victoria street','Box Hill','Victoria','AUSTRALIA','3128','0412032147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 15:27:54',0,NULL,3,1,2,1,NULL,'halatchev1'),(6515,739765990016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','omuliss','ugis.naglins@gmail.com','Ugis Naglins','Silverlawn 17','Navan','Meath','IRELAND','','0851204884','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-18 15:57:47',0,NULL,3,1,3,1,NULL,'omuliss\rRA022495175CN\r'),(6516,648081300001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','nomarsavir','ramon.rivas.bcn@gmail.com','Ramon Rivas Lloret','Calle Sant Ramon, 63 - 1º<br>08301 Mataró (Barcelona)','Mataró','Cataluña','SPAIN','08301','680884215','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 16:00:11',0,NULL,3,1,4,1,NULL,'nomarsavir\r\rtripod   $20\rYW864871331CN'),(6517,688400598002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','sergei_martin','kulverstuukas@gmail.com','Lasuy Sergei','8 Maslova st., арр.52','Monino','','RUSSIAN FEDERATION','141170','(926)2673303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 14:47:41',0,NULL,3,1,2,1,NULL,'sergei_martin'),(6518,688468088002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','karandaev.ea','karandaev@gmail.com','Evgeny Karandaev','Democratic st., 4-21','Samara','Samara obl','RUSSIAN FEDERATION','443031','+79272040151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 17:21:53',0,NULL,3,1,2,1,NULL,'karandaev.ea'),(6519,688487688002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','nikp89','niklauspavlov@gmail.com','Nik Pavlov','8573 Southwestern Blvd<br>Apt 2236','Dallas','TX','UNITED STATES','75206-2350','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 18:11:34',0,NULL,3,1,1,1,NULL,'nikp89'),(6520,688428385002,120626873273,'New wide angle holder for Cokin P series filter',2,'AA2216',7.98,'hermeshine','franksdirect','fschifano@gmail.com','Frank J. Schifano','112 E Euclid St','Valley Stream','NY','UNITED STATES','11580-4145','(516) 456-6219','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 15:37:20',0,NULL,3,1,1,1,NULL,'franksdirect'),(6521,648153889001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','hugoestevespereira','hugoesteves@gmail.com','HUGO ESTEVES','Av. Prof. Manoel de Abreu<br>n.851 apto.402','Rio de Janeiro','Rio de Janeiro','BRAZIL','20550170','5521 9386-3119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 19:03:46',0,NULL,3,1,2,1,NULL,'hugoestevespereira'),(6522,648084436001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','s4271504','s42715@gmail.com','WAI LAI YIP','FLT2010,BLOCK A,SHEK TO HSE,<br>SHEK WAI KOK EST,TSUEN WAN,NT','default','','HONG KONG','default','(852)63336753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 16:07:02',0,NULL,3,1,2,1,NULL,'s4271504'),(6523,0,130498063928,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',6.49,'hermeshine','rsr1080','rsteven66@gmail.com','Ronald Steven Ran','1080 Carpenters Trace','Villa Hills','KY','UNITED STATES','41017-4414','(859) 331-4837','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 19:24:17',0,NULL,3,1,1,1,NULL,'rsr1080'),(6524,648173312001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',2,'AB3321',39.98,'hermeshine','woodsroad','danz1745@comcast.net','Dan Johnson','1745 Walnut Ln','Quakertown','PA','UNITED STATES','18951-2046','(215) 529-4671','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 19:44:34',0,NULL,3,1,1,1,NULL,'woodsroad'),(6525,645741852018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','71204k','tru2kbee@sbcglobal.net','James Alexander','2267 E Kirkwood St','Springfield','MO','UNITED STATES','65804-2604','','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-03-18 19:56:27',0,NULL,3,1,4,1,NULL,'灯泡是110v的\rYW864871342CN'),(6526,648207233001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','kourepatos','orionas7@hotmail.com','aris kourepis','alexandroupoleos 17','patras','achaia','GREECE','26443','6997189222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 21:17:00',0,NULL,8,1,17,0,NULL,'kourepatos'),(6527,648215566001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','kourepatos','orionas7@hotmail.com','aris kourepis','alexandroupoleos 17','patras','achaia','GREECE','26443','6997189222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 21:23:12',0,NULL,3,1,2,1,NULL,'52-52mm 双阳环  1\r58-58mm 双阳环   1\r'),(6528,739965569016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','262.5','gregbevf@comcast.net','Gregory Foreman','6283 Dimitri Ct','Magalia','CA','UNITED STATES','95954','(530) 873-8155','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-18 22:40:57',0,NULL,3,1,1,1,NULL,'262.5'),(6529,688614042002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','deloner','kai.pihl.vatland@lyse.net','Kai Vatland','Utslaatten 27','Sandnes','','NORWAY','4332','99610397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 23:04:05',0,NULL,3,1,3,1,NULL,'deloner\rRA022495011CN\r'),(6530,754982878015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','petebest1','pete@fastjapcars.com','Peter Best','65 Ramsbury Avenue','Swindon','Wiltshire','UNITED KINGDOM','SN25NY','07979535123','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-18 18:40:52',0,NULL,3,1,2,1,NULL,'petebest1'),(6531,648269790001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',1,'AB1305',3.79,'hermeshine','lthurmon','lthurmon@gmail.com','Lauren Thurmon','202 Appleby Rd','Port Wentworth','GA','UNITED STATES','31407-1108','(912) 966-1584','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 00:23:02',0,NULL,3,1,1,1,NULL,'lthurmon'),(6532,688481880002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sirbion','polustudio@yandex.ru','Alexander Pyatiletov','Moscow avenue, 94, 72','Voronezh','Voronezh','RUSSIAN FEDERATION','394068','74732755225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 17:55:32',0,NULL,3,1,3,1,NULL,'sirbion\rRA022495025CN\r'),(6533,648217675001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','lucseguin','luc.seguin@videotron.ca','Luc Séguin','388 des Erables','Brownsburg-Chatham','QC','CANADA','J8G 2Y3','(450) 533-5830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 21:26:38',0,NULL,3,1,3,1,NULL,'lucseguin\rRA022496935CN\r'),(6534,688588808002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','har20','wh11630@att.net','William T Harwell','11630 White Cross','San Antonio','TX','UNITED STATES','78253-6019','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-18 21:53:10',0,NULL,3,1,3,1,NULL,'har20\rRA022495039CN\r'),(6535,648309237001,110409866856,'77mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1307',3.79,'hermeshine','jeff_mar','jeff30_ha@yahoo.com','Jefferson Edouasie','8381 Hurlbut St','San Diego','CA','UNITED STATES','92123-2011','(843) 441-2430','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 03:26:19',0,NULL,3,1,1,1,NULL,'jeff_mar'),(6536,688510373002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','le_juki','jukkatallinen@gmail.com','Jukka Tallinen','Toppilansaarentie 3 B 19','Oulu','-','FINLAND','90510','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 19:00:52',0,NULL,3,1,3,1,NULL,'le_juki\rRA022497009CN\r'),(6537,648184827001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','9999196868','giorgos220@gmail.com','GIORGOS PANOYRGIAS','SAXTOYRI 37','ASPROPYRGOS','GREECE','GREECE','19300','6975959524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 20:09:59',0,NULL,3,1,2,1,NULL,'9999196868'),(6538,688669992002,120654651653,'Pro Photo Vest Blue for Nikon D90 D300s D7000 D80  user',1,'AA2117',32,'hermeshine','bousympatico','rogerio@videotron.ca','Rogerio Barbosa','4740 Lacombe','Montreal','QC','CANADA','h3w 1r3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 02:39:06',0,NULL,3,1,3,1,NULL,'bousympatico\rRA022495100CN\rxxxl  '),(6539,688587127002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','sincejan5163','sincejan63@gmail.com','Joe  Williams','62 Harnworth Drive','Toronto','ON','CANADA','M2h 3C2','(416) 318-1545','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 21:56:44',0,NULL,3,1,3,1,NULL,'sincejan5163\r王\rRA022494991CN'),(6540,688761517002,120601699344,'JueYing Lambency Flash Diffuser for 430EX F36AM P2',1,'AB3308',22,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7º 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 10:39:01',0,NULL,3,1,3,1,NULL,'javivi001\rRA022495158CN'),(6541,688761858002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','david.fms','david.fms.67@gmail.com','David Martinez Suarez','ROSALIA DE CASTRO 49 - 5A','SANTIAGO DE COMPOSTELA','Galicia','SPAIN','15706','619737362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 10:40:07',0,NULL,3,1,2,1,NULL,'david.fms'),(6542,648336816001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','shenker123','shenkerbay@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 06:34:53',0,NULL,3,1,3,1,NULL,'shenker123\r RA022495135CN'),(6543,740181199016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'AA2204',2.75,'hutongstore','pedroramon2007','mancini6@hotmail.com','pedro  r mancini','avda catalunya  41/43 bajos 1 derecha','badalona','Cataluña','SPAIN','08917','935333089','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 12:47:28',0,NULL,3,1,2,1,NULL,'pedroramon2007'),(6544,648430367001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','alik321','g.ales@seznam.cz','Ales Brenek','Veverkova 11','Ostrava','Hrabuvka','CZECH REPUBLIC','70030','+420737363232','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 13:17:28',0,NULL,8,0,17,0,NULL,'alik321\r'),(6545,648431547001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','alik321','g.ales@seznam.cz','Ales Brenek','Veverkova 11','Ostrava','Hrabuvka','CZECH REPUBLIC','70030','+420737363232','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 13:21:29',0,NULL,3,0,3,1,NULL,'52mm cpl  x  2\r52mm nd8  x  2\r52mm 渐变镜  x  2\r52mm +2 近摄镜  x2\r4片装 滤镜袋   x  2\ralik321\rRA022491071CN'),(6546,648442280001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','ana_pma','ddlua@uol.com.br','Ana Paula Martins de Araújo','Rua Aleixo Jorge, 172/116<br>Perdizes','Sao Paulo','SP','BRAZIL','01259050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 14:04:47',0,NULL,3,1,2,1,NULL,'ana_pma'),(6547,688830602002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','pastrayer85022','pastrayer@gmail.com','Patrick Strayer','401 E Paradise Ln','Phoenix','AZ','UNITED STATES','85022-2520','(602) 326-9400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 14:29:56',0,NULL,8,1,17,0,NULL,'pastrayer85022'),(6548,688830440002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','pastrayer85022','pastrayer@gmail.com','Patrick Strayer','401 E Paradise Ln','Phoenix','AZ','UNITED STATES','85022-2520','(602) 326-9400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 14:29:59',0,NULL,8,1,17,0,NULL,'pastrayer85022'),(6549,648451955001,110566018419,'72mm 3-Stage Rubber Lens Hood for 80-200mm 24-105mm',1,'AB1306',3.79,'hermeshine','pastrayer85022','pastrayer@gmail.com','Patrick Strayer','401 E Paradise Ln','Phoenix','AZ','UNITED STATES','85022-2520','(602) 326-9400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 14:30:03',0,NULL,8,1,17,0,NULL,'pastrayer85022'),(6550,648452258001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','pastrayer85022','pastrayer@gmail.com','Patrick Strayer','401 E Paradise Ln','Phoenix','AZ','UNITED STATES','85022-2520','(602) 326-9400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 14:30:05',0,NULL,8,1,17,0,NULL,'pastrayer85022'),(6551,688828806002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','pastrayer85022','pastrayer@gmail.com','Patrick Strayer','401 E Paradise Ln','Phoenix','AZ','UNITED STATES','85022-2520','(602) 326-9400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 14:30:04',0,NULL,3,0,1,1,NULL,'pastrayer85022\r58mm 橡胶罩   1\r橡胶遮光罩 52mm  1\r橡胶遮光罩 72mm  1\r橡胶遮光罩 67mm   1\r橡胶遮光罩 77mm   1\r'),(6552,688856545002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','tremontrods','jschatz@columbus.rr.com','Michael Schatz','3344 Mansion Way','columbus','OH','UNITED STATES','43221-1573','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 15:39:20',0,NULL,3,1,1,1,NULL,'tremontrods'),(6553,648285709001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','mikelatimer74','mlatimer74@yahoo.com','Mike Latimer','3737 Loretto Rd<br>Apt 208','jacksonville','FL','UNITED STATES','32223','','NoPaymentFailure','CheckoutComplete','Other','2011-03-19 01:31:51',0,NULL,3,1,3,1,NULL,'\rmikelatimer74\r RA022495127CN'),(6554,648523941001,110583709836,'NEW 62mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT045',28,'hermeshine','tmelda','mmichalx@seznam.cz','Michal Macák','miličova 267/4','Vysoké Mýto','CZ','CZECH REPUBLIC','56601','+420608346569','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 17:33:10',0,NULL,3,1,3,1,NULL,'tmelda\r62mm CPL 1\r62mm   ND8   1\r62mm   Macro+8    1\r62mm  渐变灰    1\r4片装滤镜袋     1  滤镜不要盒子了\rRA022496913CN'),(6555,688909525002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',19.9,'hermeshine','marius.krivicius','mkrivicius@gmail.com','Solveiga Kriviciene','Mikalojaus 7-22','Vilnius','','LITHUANIA','01133','+37061519868','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 17:45:13',0,NULL,3,1,2,1,NULL,'marius.krivicius'),(6556,688926076002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bank_4nb','bank_4nb@hotmail.com','Charath Petthongchai','23/190 Lumpini Condo Phahol-Sutthisarn<br>Intramara 2 Samsanenai','Phyathai','Bangkok','THAILAND','10400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 18:19:42',0,NULL,3,1,2,1,NULL,'bank_4nb'),(6557,688697701002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','kimballcorson','kimcorson@netzero.com','Kimball Corson','General Delivery','Pago Pago','AS','UNITED STATES','96799-9999','(684) 258-0590','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 05:01:14',0,NULL,3,1,1,1,NULL,'kimballcorson'),(6558,689039661002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',6.24,'hermeshine','sdaepsa','ivanazp@gmail.com','ivan ong','6 colonial cir','east norriton','PA','UNITED STATES','19401','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 22:20:45',0,NULL,3,1,1,1,NULL,'sdaepsa'),(6559,740475667016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','dark_alucard230782','dave_hamilton66@hotmail.com','David Hamilton','2 Railway Bridge<br>Brackhill','Castlemaine','County Kerry','IRELAND','0','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 22:37:45',0,NULL,3,0,2,1,NULL,'dark_alucard230782\r1.6x2.1 背景布 白色的'),(6560,740476895016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',43.8,'hutongstore','aard.fi','bernd.wachter@gmail.com','Bernd Wachter','Kivääritehtaankatu 1 A 16','Jyväskylä','','FINLAND','40100','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 22:40:39',0,NULL,8,1,17,0,NULL,'aard.fi'),(6561,755635722015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','aard.fi','bernd.wachter@gmail.com','Bernd Wachter','Kivääritehtaankatu 1 A 16','Jyväskylä','','FINLAND','40100','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 22:44:29',0,NULL,3,1,4,1,NULL,'2m 灯架   1\r反光板支架   1\r斜臂   1\rlight stand  $25\rYW864871351CN'),(6562,740529503016,260660050674,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',16.99,'hutongstore','ashmills','imagework@btinternet.com','Ash Mills','Dean Cottage, Mulberry Court<br>Sixpenny Handley','Salisbury','Dorset','UNITED KINGDOM','SP5 5AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-20 01:12:19',0,NULL,3,1,3,1,NULL,'ashmills\rRA022495113CN'),(6563,689055407002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','guanwei6971','guanwei6971@gmail.com','wei guan','81 Empringham Cres.','Markham','ON','CANADA','L3R3E9','(905) 470-0947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 23:03:51',0,NULL,3,1,2,1,NULL,'guanwei6971'),(6564,689130445002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','eberles','mellisaeb@gmail.com','Mellisa Eberle','2315 Green Valley Ln','Moody','AL','UNITED STATES','35004-3214','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-20 03:36:37',0,NULL,3,1,1,1,NULL,'eberles'),(6565,689170633002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','gottikkus','rkoblev@gmail.com','Roman Koblev','Turmalinovskaya 85/12, flat 17','Rostov-on-Don','Rostovskaya oblast','RUSSIAN FEDERATION','344038','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 07:29:24',0,NULL,3,1,2,1,NULL,'gottikkus'),(6566,689179559002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 08:10:10',0,NULL,3,1,2,1,NULL,'tomis.ales'),(6567,689184418002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','mafrin','martin.frolin@gmail.com','Martin Frolin','Malmögatan 23','Helsingborg','','SWEDEN','25252','+46736760050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 08:35:59',0,NULL,3,1,2,1,NULL,'mafrin'),(6568,648794598001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','888ronc','ronbc@ozemail.com.au','Ron Coker','9/2Fern st','Randwick','New South Wales','AUSTRALIA','2031','0296658863','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 08:53:54',0,NULL,3,1,2,1,NULL,'888ronc'),(6569,689198771002,120601700875,'TianYa New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','drewspoon72','wopper@me.com','Drew Wotherspoon','280 Keira St','Wollongong','New South Wales','AUSTRALIA','2500','0467061939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 09:19:14',0,NULL,3,1,2,1,NULL,'drewspoon72'),(6570,648826319001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',4.95,'hermeshine','happy-j','bragin72@gmail.com','Alexey Bragin','Krasnobogatyrskaya 11 - apt 195','Moscow','Moscow region','RUSSIAN FEDERATION','107564','(909)6299244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 10:25:37',0,NULL,3,1,2,1,NULL,'happy-j'),(6571,648818910001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',75,'hermeshine','jarker28','jarker@hotmail.com','Jack Hu','37 Telfer Road','Castle Hill','New South Wales','AUSTRALIA','2154','61431695139','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2011-03-20 10:07:05',0,NULL,3,1,4,1,NULL,'jarker28\rreflector holder   $20\rYW864871364CN'),(6572,648857518001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','stuzzystyle','stuessir@gmail.com','Raphael Stüssi','Tannerstrasse 58','Aarau','','SWITZERLAND','5000','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 11:45:25',0,NULL,3,1,2,1,NULL,'stuzzystyle'),(6573,648851232001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','suzana1','suzanahorvat@gmail.com','Suzana Ludaš','Šumska 14, Brdovec','Zaprešić, Prigorje brdovečko','Croatia','CROATIA','10291','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-20 11:29:24',0,NULL,3,1,3,1,NULL,'suzana1\rRA022496944CN\r'),(6574,648869644001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','d_man1990','ganelind@mail.tau.ac.il','Daniel Ganelin','8 HaRav Levi Street, Apartment 42','Bat-Yam','','ISRAEL','59647','97235514008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 12:17:59',0,NULL,3,1,2,1,NULL,'d_man1990'),(6575,648877126001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ronald14669','rjcoulombe@comcast.net','Ronald Coulombe','4 E Sheppard Ln','Chelmsford','MA','UNITED STATES','01824-2215','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-20 12:36:17',0,NULL,3,1,1,1,NULL,'ronald14669'),(6576,689240628002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','suhadajayamanne','djsuhada@gmail.com','suhada jayamanne','no 197/35A,Padri PioMavatha,Taladuwa ,Negombo,','Negombo','western','SRI LANKA','11500','+94 77 3 611 554','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-20 11:25:44',0,NULL,3,1,3,1,NULL,'suhadajayamanne\rRA022495056CN\r'),(6577,689279575002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','vincent3483471','vincent.laniel@videotron.ca','Vincent Laniel','222 rue Sainte-Marie','Sainte-Marthe-sur-le-Lac','QC','CANADA','J0N 1P0','(450) 735-4317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 12:49:54',0,NULL,3,1,2,1,NULL,'vincent3483471'),(6578,648885826001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','pbrav','tmptie-dcomp@yahoo.es','Alfonso Alfaro Pelayo','C/Montearagon, 3 pral.dcha.','Zaragoza','Aragón','SPAIN','50013','976591640','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-20 12:57:51',0,NULL,3,1,3,1,NULL,'pbrav\rRA022495095CN'),(6579,689336271002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','spyros_tav','tavspyros@hotmail.com','Spyros Tavladorakis','Daidalou 10 Ammoudara','Heraklion','Crete/Greece','GREECE','71414','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 14:58:49',0,NULL,3,1,2,1,NULL,'maciek173\r庄'),(6580,689307449002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','vetec_666','vetold@gmail.com','Witold Dondalski','ul. Konopna 34','Torun','kujawsko-pomorskie','POLAND','87-100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-20 13:56:02',0,NULL,3,1,4,1,NULL,'vetec_666\rtripod  $30\r先发脚架给他，\rYW864871423CN\r随后补袋子（+把手）给他：\rRA117713079CN'),(6581,648884019001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','mushkaboom','wishlist@rock.com','Ania Markowska','3339 Carillion Ave','Mississauga','ON','CANADA','L5C 2A9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 15:04:00',0,NULL,3,1,2,1,NULL,'mushkaboom'),(6582,688393008002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','padua12','coutinho.padua@gmail.com','antonio de padua lima  coutinho','rua thome 120<br>bairro mury','nova friburgo','rio de janeiro','BRAZIL','28615240','55212225421852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 15:51:10',0,NULL,3,1,2,1,NULL,'padua12'),(6583,755983533015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.5,'hutongstore','krisi-b','k.boneva1@gmail.com','Kristina Boneva','1 Brazil House<br>2 Brazil Street','Manchester','Greater Manchester','UNITED KINGDOM','M1 3PW','07871658619','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-20 15:11:14',0,NULL,3,1,2,1,NULL,''),(6584,756000043015,250599918807,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.39,'hutongstore','joesoap100','theblackburns4@btinternet.com','John Blackburn','10 Atholl,<br>Ouston,','Chester-le-Street,','Durham','UNITED KINGDOM','DH2 1RS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-20 15:35:43',0,NULL,3,1,2,1,NULL,'joesoap100'),(6585,646717446018,280541368434,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','gubat_hill','gubat_hill@yahoo.com','Virgil Rovensky','247 greenfield Cres.','Saskatoon','SK','CANADA','S7R0B6','(306) 717-3217','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-20 18:58:01',0,NULL,3,1,5,1,NULL,'gubat_hill\r8个45w的灯泡换成 4个115w 110v的\rCP226379440CN'),(6586,741041036016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','samgy1','sami.laine@hotmail.com','Sami Laine','orapihlajanpolku 1 b 32','vantaa','Finland','FINLAND','01360','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-20 19:28:11',0,NULL,3,1,2,1,NULL,'samgy1'),(6587,649164138001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','embassylimosine','utokhvre@yahoo.com','Urmas Tokhvre','723 A St NE<br># B','Auburn','WA','UNITED STATES','98002-4026','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-20 19:51:55',0,NULL,3,1,1,1,NULL,'sincejan5163'),(6588,646832770018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','817zoealexis','klbeaub1@sbcglobal.net','Nicholas Novak','3065 33rd St NE','Paris','TX','UNITED STATES','75462-3312','(903) 249-9342','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-03-20 21:12:24',0,NULL,3,1,4,1,NULL,'灯泡是110v的\rYW864871375CN'),(6589,741302520016,260660053303,'New Neoprene Reversible Cover for Stand-DSLR Camera M',2,'AC1301',11,'hutongstore','ffotografo','rui-gaio@hotmail.com','Rui Gaio','Rua de Cabo Verde Lt. 54, 3º esq.','Portimão','Portugal','PORTUGAL','8500','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-21 01:52:35',0,NULL,3,1,2,1,NULL,'ffotografo'),(6590,0,120700660095,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',1.99,'hermeshine','98642john','johnkimball1020@msn.com','J Kimball','1819 NE 209th St','Ridgefield','WA','UNITED STATES','98642-8212','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 03:55:58',0,NULL,3,1,1,1,NULL,'98642john\rLK032882647CN'),(6591,756297969015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','multimati76','multimati@interia.pl','Maciej Janiczek','9 Warrenstown Lawn<br>Blanchardstown','Dublin','Dublin','IRELAND','15','0879707768','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-20 20:33:26',0,NULL,3,1,3,1,NULL,'multimati76\rRA022496927CN'),(6592,689615274002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','elidoskalovich','weedick@walla.co.il','Eli Doskalovich','Hatavor st 23/2','Gan Yavne','','ISRAEL','70800','+972 52 8948493','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-20 20:53:59',0,NULL,3,1,3,1,NULL,'elidoskalovich\rRA022496887CN'),(6593,689445580002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','compradorveloz','apodo360@aol.com','Matias Curtidor','7231 Boulder Ave<br># 269','highland','CA','UNITED STATES','92346-3313','(909) 831-6440','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 17:50:57',0,NULL,3,1,1,1,NULL,'compradorveloz'),(6594,649196077001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','schneidermato','martin.schneider@zoznam.sk','Martin Schneider','Muskatova 2','Pezinok','Slovakia','SLOVAK REPUBLIC','90201','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 20:44:42',0,NULL,3,1,2,1,NULL,'schneidermato\r庄'),(6595,649368667001,110417009860,'58mm 58 mm Macro +4 Close-Up Close Up Filter',1,'AE3217',5.9,'hermeshine','hammar12','alaiyed@gmail.com','saleh alaiyed','11104 Cavalier Ct','fairfax','VA','UNITED STATES','22030-4914','(571) 335-6742','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 03:27:52',0,NULL,3,1,1,1,NULL,'hammar12\rLK032879890CN'),(6596,649413682001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','majormfrf','shtuchkaz@yandex.ru','Andrey Shtuchka','Yangelya st., 6/74','Baykonur','KZ','KAZAKHSTAN','468320','73362270348','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 08:04:18',0,NULL,3,1,2,1,NULL,'majormfrf\r庄'),(6597,756362496015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','gioelegio1','giovannettifabio@tin.it','Fabio Giovannetti','via firenze 22','pavona st.','RM','ITALY','00040','348-4075074','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-20 21:52:23',0,NULL,3,0,3,1,NULL,'gioelegio1\r庄\rRA022495918CN\r'),(6598,689841211002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','nncnfrmst','syntaxfree+signup@gmail.com','Michelle Quah','16 Amber Gardens<br>#11-02','default','','SINGAPORE','439961','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 08:42:24',0,NULL,3,1,11,1,NULL,'nncnfrmst\r庄'),(6599,689841966002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','kojak-with-a-kodak','danny_bowes@hotmail.com','danny bowes, room 523','riverside condo, 324/11 chiang mai lampun road<br>t.nonghoi, a.muang.','chiang mai','thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 08:49:08',0,NULL,3,1,2,1,NULL,'庄'),(6600,689844594002,120571007466,'New Umbrella in Silver 85cm / 33.5\" Photo Studio Light',1,'AD1401',9.9,'hermeshine','danilbokeh','element3200@hotmail.com','Daniil Golubtsov','Kivila 13-79','Tallinn','Harjumaa','ESTONIA','13917','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 08:59:51',0,NULL,3,1,2,1,NULL,'刘'),(6601,689853839002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','uramechii','uramechi@hotmail.com','piyawat chitjaiman','27/147 Rama2 soi 39 BangMod Jomthong','Bangkok','Bangkok','THAILAND','10150','+6694851668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 09:41:42',0,NULL,3,1,2,1,NULL,'uramechii\r庄'),(6602,649041493001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','logova','logova@teleline.es','LORENZO GONZALEZ VAZQUEZ','C/OCCITANIA, 7.','SANT QUIRZE DEL VALLES','Cataluña','SPAIN','08192','650395592','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-20 17:44:45',0,NULL,3,0,3,1,NULL,'logova\rL\r'),(6603,741464595016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','whoray1960','r.gibson874@btinternet.com','Ray Gibson','15 West Carr Road','Retford','Nottinghamshire','UNITED KINGDOM','DN22 7NN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-21 12:21:51',0,NULL,3,1,2,1,NULL,'whoray1960\r庄'),(6604,649473343001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','mrtim63129','timrichards1@juno.com','Tim Richards','2707 Blackforest Dr','Saint Louis','MO','UNITED STATES','63129-4005','(314) 221-7146','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 12:23:01',0,NULL,3,1,1,1,NULL,'mrtim63129\r再加上 77mm 接口环  1\r72mm 接口环   1\r刘'),(6605,689903101002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','origrupo','origrupo@ono.com','Jose Fenoll Perez','Plaza Nueva, 8','orihuela','Comunidad Valenciana','SPAIN','03300','609674147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 12:49:20',0,NULL,3,1,2,1,NULL,'origrupo\r刘'),(6606,689898648002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','greenzeen','lessz0rs@gmail.com','Zeen Dsouza','12/32 Meron Street','Southport','Queensland','AUSTRALIA','4215','0432677798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 12:54:26',0,NULL,8,1,17,0,NULL,'greenzeen'),(6607,649479186001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','greenzeen','lessz0rs@gmail.com','Zeen Dsouza','12/32 Meron Street','Southport','Queensland','AUSTRALIA','4215','0432677798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 12:54:30',0,NULL,8,1,17,0,NULL,'greenzeen'),(6608,649478928001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','greenzeen','lessz0rs@gmail.com','Zeen Dsouza','12/32 Meron Street','Southport','Queensland','AUSTRALIA','4215','0432677798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 12:54:31',0,NULL,8,1,17,0,NULL,'ricardo-del-rio\r庄'),(6609,689728344002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','ricardo-del-rio','rdr-foto@hotmail.com','Ricardo Garcia Granados','José María Vigil 101-C2<br>Col. Escandón','México','Distrito Federal','MEXICO','11800','5515092737','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 00:48:39',0,NULL,3,0,3,1,NULL,'ricardo-del-rio\rRA022495745CN'),(6610,649530760001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3302',5.9,'hermeshine','glenbren','glenbren@gmail.com','E. Brennan','PO Box 46','Fort Covington','NY','UNITED STATES','12937','(450) 371-4891','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 15:46:26',0,NULL,8,1,17,0,NULL,'origrupo\r庄'),(6611,689956104002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.49,'hermeshine','glenbren','glenbren@gmail.com','E. Brennan','PO Box 46','Fort Covington','NY','UNITED STATES','12937','(450) 371-4891','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 15:46:25',0,NULL,3,1,1,1,NULL,'northandos\r刘'),(6612,0,120700927157,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.06,'hermeshine','brockman-woodworks','brock.kokopelli@gmail.com','Brock  Stokes','298 Spencer Way','Farmington','UT','UNITED STATES','84025','(801) 451-7882','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 16:11:14',0,NULL,8,1,17,0,NULL,'brockman-woodworks'),(6613,0,110664158425,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.06,'hermeshine','brockman-woodworks','brock.kokopelli@gmail.com','Brock  Stokes','298 Spencer Way','Farmington','UT','UNITED STATES','84025','(801) 451-7882','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 16:11:15',0,NULL,8,1,17,0,NULL,''),(6614,0,120700926039,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.55,'hermeshine','brockman-woodworks','brock.kokopelli@gmail.com','Brock  Stokes','298 Spencer Way','Farmington','UT','UNITED STATES','84025','(801) 451-7882','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 16:11:15',0,NULL,3,1,1,1,NULL,'brockman-woodworks\rLenspen   3\r庄'),(6615,0,110664162846,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','docwifford','docwifford@msn.com','Wayne Ford','2464 Kingfisher Lane','Lincoln','CA','UNITED STATES','95648','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 16:21:23',0,NULL,3,1,1,1,NULL,'docwifford\r庄'),(6616,0,130499736491,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',1.25,'hermeshine','gracious78','happyone78@msn.com','Pansy k Lim','815 E Lucille Ave','West Covina','CA','UNITED STATES','91790-5220','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 17:11:58',0,NULL,3,1,1,1,NULL,'tiborita\r肩架   1\r双灯头 欧标   1\r申报：Pad support  $15\r庄'),(6617,649570036001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','vasiliy9','vasiliy76@inbox.ru','Василий Нечаев','Алексея Томского 6/2, кв.1','Тверь','Россия','RUSSIAN FEDERATION','170019','+7-905-607-25-68','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 17:18:23',0,NULL,3,1,3,1,NULL,'vasiliy9\r刘\rRA022495590CN'),(6618,0,130499737443,'Genuine Lenspen lens cleaning CANON NIKON just ship USA',1,'AA1310',1.25,'hermeshine','bmooney33','brendan@emooney.com','Brendan Mooney','36 Pequot Ln','East Islip','NY','UNITED STATES','11730-2713','(860) 796-4679','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 17:34:03',0,NULL,3,1,1,1,NULL,'ke4clu\r刘'),(6619,0,130499738431,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.5,'hermeshine','junbug0024','junbug0024@aol.com','Demosthenes Lao','13930 Valley View Ln','Chino Hills','CA','UNITED STATES','91709','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 17:39:33',0,NULL,8,1,17,0,NULL,'junbug0024'),(6620,0,110664155441,'Genuine Lenspen lens cleaning CANON NIKON just ship USA',1,'AA1310',0.55,'hermeshine','junbug0024','junbug0024@aol.com','Demosthenes Lao','13930 Valley View Ln','Chino Hills','CA','UNITED STATES','91709','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 17:40:21',0,NULL,3,1,1,1,NULL,'刘\r'),(6621,649096837001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','maliena_175','maliena_1757@hotmail.com','Nurul Amalina Ahmad Tajudin','NO: 596 Spg 592 Kampong Kasat<br>Negara Brunei Darussalam','Bandar Seri Begawan','Negara Brunei Darussalam','BRUNEI DARUSSALAM','BJ1724','6738804995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 17:55:28',0,NULL,3,1,2,1,NULL,'maliena_175'),(6622,690020608002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','ke4clu','gander@nc.rr.com','Richard Anderson','811 Bain St<br>Wayne County Schools','Goldsboro','NC','UNITED STATES','27530-2816','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 18:11:19',0,NULL,3,1,1,1,NULL,'jaynoda\r庄'),(6623,0,110664158071,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.06,'hermeshine','jaynoda','jaynoda@msn.com','Joaquin  G Noda','7803 sw 88st<br>apt# F106','MIAMI','FL','UNITED STATES','33156','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 19:27:30',0,NULL,3,1,1,1,NULL,'jaynoda\r刘'),(6624,0,130499740752,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.01,'hermeshine','northandos','darrinmascarin@gmail.com','Norhtandos Evolution','9302 Cty Rd #1 RR #1','Palgrave','ON','CANADA','L0N 1P0','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-21 20:14:15',0,NULL,3,1,2,1,NULL,'northandos\r庄'),(6625,0,110664164931,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 20:17:25',0,NULL,8,1,17,0,NULL,'danbbbb'),(6626,0,110664164620,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 20:17:25',0,NULL,8,1,17,0,NULL,'hammar12\r刘'),(6627,0,130499747626,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 20:17:26',0,NULL,8,1,17,0,NULL,'danbbbb'),(6628,0,130499746353,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','hellovending','hellovending2002@yahoo.com','Phillip Gillis','827 S. Griffith Ave.','Aurora','MO','UNITED STATES','65605','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 19:47:32',0,NULL,8,1,17,0,NULL,'hellovending'),(6629,649592457001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','frankedisson','heyaaaa@inbox.lv','Aleksandrs Puzijs','Balta 24-70','Riga','','LATVIA','LV 1055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:30:22',0,NULL,3,1,2,1,NULL,'frankedisson\r欧标\r庄'),(6630,0,120700931159,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 20:17:24',0,NULL,8,1,17,0,NULL,'danbbbb\r'),(6631,0,130499748376,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 20:17:23',0,NULL,3,1,1,1,NULL,'danbbbb\rCANON 镜头盖  58mm    5\r庄'),(6632,649684156001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ambaaaaa','amber.hopkins@gmail.com','Amber Hopkins','C/- Harrex Group<br>24 Main Street','Gore','New Zealand','NEW ZEALAND','9710','+64 21 032 2623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:57:12',0,NULL,3,1,2,1,NULL,'ambaaaaa'),(6633,649695647001,110566018399,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','anderurkiza','hadpersonal@gmail.com','Eugenio Alonso Garcia','Avda. Antigua, 5, 4º C','Zumarraga','País Vasco','SPAIN','20700','655700046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 21:23:30',0,NULL,8,1,17,0,NULL,'docwifford\r刘'),(6634,649692155001,110566018220,'55mm 55 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT019',4.87,'hermeshine','anderurkiza','hadpersonal@gmail.com','Eugenio Alonso Garcia','Avda. Antigua, 5, 4º C','Zumarraga','País Vasco','SPAIN','20700','655700046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 21:23:31',0,NULL,8,1,17,0,NULL,'danilbokeh\r67mm 环架   1\r55mm 环架   1\r庄'),(6635,0,130499738735,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.06,'hermeshine','hellovending','hellovending2002@yahoo.com','Phillip Gillis','827 S. Griffith Ave.','Aurora','MO','UNITED STATES','65605','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 19:47:11',0,NULL,3,1,1,1,NULL,'hellovending\rCANON 镜头盖  58mm   1\rlenspen    1\r刘'),(6636,649749857001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','shoxpro','shoxpro@mailcity.com','reynald barredo','13890 Sayre st<br>Apt. 218','Sylmar','CA','UNITED STATES','91342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 23:47:55',0,NULL,3,1,1,1,NULL,'shoxpro\r渐变灰   1\r72mm 环架   1'),(6637,649735714001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','tiborita','tiborita@gmail.com','Igor Gottardi','Via Piani d\'Isarco, 12','Bolzano','BZ','ITALY','39100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 00:02:11',0,NULL,8,1,17,0,NULL,'tiborita'),(6638,690169246002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','tiborita','tiborita@gmail.com','Igor Gottardi','Via Piani d\'Isarco, 12','Bolzano','BZ','ITALY','39100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 00:02:16',0,NULL,3,1,3,1,NULL,'tiborita\r肩架   1\r双灯头 欧标   1\r申报：Pad support  $15\r庄\rRA022495833CN'),(6639,741824074016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','little.rabbit90','stephanee.huizhen@gmail.com','Stephanie Stephanie','2/18 Courtney Street','North Melbourne','Victoria','AUSTRALIA','3051','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-22 00:38:38',0,NULL,3,1,2,1,NULL,'little.rabbit90\r刘'),(6640,0,120701185557,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.51,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:39:59',0,NULL,8,1,17,0,NULL,'toyoza'),(6641,0,130499966565,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.66,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:01',0,NULL,8,1,17,0,NULL,'toyoza'),(6642,0,110664413594,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.41,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:07',0,NULL,8,1,17,0,NULL,'toyoza'),(6643,0,120701184785,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.31,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:09',0,NULL,8,1,17,0,NULL,'bmooney33\r刘'),(6644,0,120701183675,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.4,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:10',0,NULL,8,1,17,0,NULL,'toyoza'),(6645,0,110664417373,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',1.25,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:10',0,NULL,8,1,17,0,NULL,'toyoza'),(6646,0,110664414547,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.31,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:16',0,NULL,8,1,17,0,NULL,'toyoza\rttt'),(6647,0,130499965914,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.66,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:16',0,NULL,8,1,17,0,NULL,'ambaaaaa\r庄'),(6648,0,120701186747,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.81,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:16',0,NULL,8,1,17,0,NULL,'toyoza'),(6649,0,110664414937,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.56,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:41:49',0,NULL,3,1,1,1,NULL,'98642john\r徐'),(6650,757021031015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','bern047','bernard.mannas@gmail.com','Bernard Mannas','244 Broadway','Yaxley','Cambs','UNITED KINGDOM','PE7 3NR','01733761722','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-22 00:57:08',0,NULL,3,1,2,1,NULL,'bern047\r庄'),(6651,0,110664163695,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 01:20:24',0,NULL,3,1,1,1,NULL,'gubat_hill\r8个45w的灯泡换成 4个115w 110v的\r刘'),(6654,649792100001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ericporto1977','swrswr2x10@hotmail.com','Eric Portelance','1375 des rouges gorges','Saint Jérome','QC','CANADA','J7Z6Z4','(450) 512-4398','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 02:20:54',0,NULL,3,1,2,1,NULL,'toyoza\rLenspen  10\r徐'),(6652,689882483002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','peterkremzar','peter.kremzar@gmail.com','Peter Kremzar','Krekova 9','Komenda','','SLOVENIA','1218','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 11:43:28',0,NULL,3,1,3,1,NULL,'0peterkremzar\r庄\rRA022495643CN'),(6653,649464820001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','tampromise2010','tampromise@gmail.com','Kalygin Dmitriy','Kalygin Dmitriy<br>Karbysheva 20-30','Berezovskiy, Kemerovskaya oblast','','RUSSIAN FEDERATION','652427','+79626267076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 11:46:38',0,NULL,3,1,2,1,NULL,'tampromise2010\r庄'),(6655,649474987001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','greenzeen','lessz0rs@gmail.com','Zeen Dsouza','12/32 Meron Street','Southport','Queensland','AUSTRALIA','4215','0432677798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 12:54:30',0,NULL,3,1,3,1,NULL,'greenzeen\r机身盖/镜头后盖  Canon\r气吹 + 布\rNIKON 镜头盖 52mm\r小号内胆包 Nikon\r王\rRA022495802CN'),(6656,689906011002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','toxawww','anton.gvozdikov@gmail.com','Anton Gvozdikov','Leninskij prospekt 77-2-242','Moscow','Moscow','RUSSIAN FEDERATION','119261','+79262072089','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:00:06',0,NULL,3,1,2,1,NULL,'tiborita\r肩架   1\r双灯头 欧标   1\r刘'),(6657,649802115001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','padisolodiver','solo.diver@sbcglobal.net','Jason Wessler','16947 Shea ave','Hazel Crest','IL','UNITED STATES','60429-1348','(708) 422-7300','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 03:06:26',0,NULL,3,1,1,1,NULL,'wienerdude26\r'),(6658,649806915001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','deelist','dilysss@gmail.com','Dilys Woo','Blk 726 Woodlands Circle #07-138','default','','SINGAPORE','730726','91373202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 03:23:24',0,NULL,3,1,11,1,NULL,'deelist'),(6659,689916243002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','saponac17','matpor75@aol.com','Matthew Porter','1 Martingale Rd','Amherst','NH','UNITED STATES','03031-2625','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 13:32:05',0,NULL,3,1,1,1,NULL,'saponac17'),(6660,689939513002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','ziguitow','ziguitow2@gmail.com','Cauã Csik Lima','Estrada Sorima 222 Barra da Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22611030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 14:45:14',0,NULL,3,1,3,1,NULL,'ziguitow\rRA022495820CN'),(6661,741520049016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','lukas.hlavacka','lukas.hlavacka@gmail.com','Lukas Hlavacka','Osuskeho<br>3','Bratislava','Slovensko','SLOVAK REPUBLIC','85103','00421908574077','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-21 14:50:52',0,NULL,3,1,2,1,NULL,'lukas.hlavacka'),(6662,649823415001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','vshtern','vladimirshtern@walla.com','Vladimir Shtern','Hazionut 57/27','Ashdod','Non-US','ISRAEL','77456','972546327822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 05:05:05',0,NULL,3,1,2,1,NULL,'vshtern\r徐'),(6663,689864820002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','chad030708','richardpureza08@yahoo.com','Richard Robles Pureza','National Lead Smelting Co. Ltd<br>2nd Industrial Area, Sanaiya','P.O. Box 43169','Riyadh','SAUDI ARABIA','11561','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 10:27:36',0,NULL,3,1,3,1,NULL,'chad030708\rRA022495793CN\rRA022495847CN'),(6664,741552263016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','wondervlad','kovalev.vladimir1990@gmail.com','Vladimir Kovalev','194<br>King\'s College','Cambridge','Cambridgeshire','UNITED KINGDOM','CB2 1ST','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-21 16:11:14',0,NULL,3,1,2,1,NULL,'wondervlad'),(6665,740851831016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','fabriferratingtong','f.ferazzini@alice.it','fabrizio ferazzini','via leonardo da vinci 4/6','carobbio degli angeli','BG','ITALY','24060','+393334296872','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-21 10:58:57',0,NULL,3,1,4,1,NULL,'fabriferratingtong\r欧标\rlighting kit  $30\rYW864871434CN'),(6666,689876225002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT055',126,'hermeshine','kepkeretezo','wasser01@freemail.hu','Vass Gergely','Bolgárkertész utca 13/F; III/12','Budapest','Budapest','HUNGARY','1148','+36304124582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 11:12:57',0,NULL,3,1,5,1,NULL,'kepkeretezo\rCP226379422CN'),(6667,690305511002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','alfarif','alfarif@alfarif.com','Warren Stallworth','3791 Mac Nicholas Ave','Cincinnati','OH','UNITED STATES','45236','(513) 375-2919','NoPaymentFailure','CheckoutComplete','Other','2011-03-22 08:59:26',0,NULL,3,1,3,1,NULL,'alfarif\rRA022494020CN'),(6668,649506961001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','richardrandik','rrandik@gmail.com','Richard Randik','Bohunova 32','Bratislava','','SLOVAK REPUBLIC','81104','+421 944 431 680','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 14:15:43',0,NULL,3,1,2,1,NULL,'richardrandik'),(6669,649641906001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','dedamarijan','marijan.forgac1@zg.t-com.hr','Marijan Forgac','D.Domjanica 13','Dugo Selo','','CROATIA','10370','+38512759159','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 19:40:28',0,NULL,3,1,3,1,NULL,'dedamarijan\rRA022495688CN'),(6670,690328614002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gasparitos','fanakov@mail.ru','Artem Fanakov','Sedova str. 55-25','Tyumen','RU','RUSSIAN FEDERATION','625048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 10:45:14',0,NULL,3,1,2,1,NULL,'stevetanner\r刘'),(6671,649897060001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','dekanyz','dekaaa71@gmail.com','Zoltan Dekany','Hitel str. 5','Kecskemet','','HUNGARY','6000','+36209849183','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 11:45:29',0,NULL,3,1,2,1,NULL,'dekanyz'),(6672,649909338001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',6,'AB1302',20.04,'hermeshine','bearmanolith','aloolmez@gmail.com','Alaattin Olmez','Hasan Ali Yucel sok. Senil apt. No:34/36 D.15','Ciftehavuzlar / Kadikoy / Istanbul','Yoksam kapiciya birakin','TURKEY','34728','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:34:23',0,NULL,3,1,3,1,NULL,'bearmanolith\r庄\rRA022494957CN\r'),(6673,690355536002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','kap_t','kapatost@in.gr','Anastasios Kapatos','Agion Anargyron<br>P.O. Box 4310','Epanomi','Thessaloniki','GREECE','57500','0302392041331','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:35:27',0,NULL,3,1,2,1,NULL,'snoz2\r刘'),(6674,756902829015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','snoz2','snoz_2@hotmail.co.uk','Sophie Day','2 mill farm ave','sunbury on thames','London','UNITED KINGDOM','tw167dg','07507130847','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-21 20:42:01',0,NULL,3,0,3,1,NULL,'aliaksei_kaniuka\r徐\rRA022495855CN'),(6675,690109411002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 20:49:29',0,NULL,3,0,3,1,NULL,'arnorolf10\rRA022495816CN'),(6676,649913901001,110566018317,'62mm 3-Stage Rubber Lens Hood for D80 D90 450D 500D',1,'AB1304',3.79,'hermeshine','scomaroo1','aubin.ma@videotron.ca','MARC AUBIN','342 DU CANTONNIER','ST-AUGUSTIN','QC','CANADA','G3A1N4','(418) 878-4905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:51:33',0,NULL,3,1,2,1,NULL,'ronbj1\r刘'),(6677,757215306015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',2,'AB1204',25.98,'hutongstore','deuce460','deuce460@aol.com','dave turley','30 keswick road','bexleyheath','kent','UNITED KINGDOM','da7 5du','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-22 13:26:45',0,NULL,3,1,3,1,NULL,'arnorolf10\r刘\rRA022494869CN'),(6678,690370367002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','elosodelamariola','monteverdi1643@gmail.com','Luis Calvente-Romero','avd/ Blasco Ibanez 27-3','Mislata','Comunidad Valenciana','SPAIN','46920','600697155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 13:28:42',0,NULL,3,1,2,1,NULL,'elosodelamariola'),(6679,649585249001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','aliaksei_kaniuka','bloodypooh@mail.ru','Shevcov S. V.','Djukovskogo str., 6-1-169','Minsk','','BELARUS','220007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 13:29:53',0,NULL,3,1,2,1,NULL,'aliaksei_kaniuka'),(6680,690381376002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','fdel3335','monteventas@hotmail.com','Felix de la Calle Pastor','C/monasterio Sanmillan Cogolla, 18, AticoB<br>Valladolid','Valladolid','Castilla y León','SPAIN','47015','606042783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 14:05:44',0,NULL,3,1,2,1,NULL,'fdel3335\r庄'),(6681,647588588018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','exousia247','moovman@sbcglobal.net','Armand Buford','1218 Roxton Dr','Saint Louis','MO','UNITED STATES','63137-2139','','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-03-22 14:32:52',0,NULL,3,1,4,1,NULL,'灯泡是110v的\rYW864871493CN\rexousia247   '),(6682,0,110664683101,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','stevetanner','stanner@pinpointgroup.com','Steve Tanner','424 Kendall Rd','Churchville','NY','UNITED STATES','14428-9326','(585) 293-2320','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 14:47:48',0,NULL,3,1,1,1,NULL,'elosodelamariola\r徐'),(6683,0,110664682430,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.37,'hermeshine','ken71951','mtnmankrs@yahoo.com','Ken Smith','PO Box 2051<br>2650 Washington Blvd.','Crescent City','CA','UNITED STATES','95531-6051','(707) 218-0719','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 15:01:52',0,NULL,3,1,1,1,NULL,'ken71951\r58mm 佳能镜头盖   3'),(6684,0,110664688066,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','allgooddeals4u','leonvaf@yahoo.com','Leontios Vafeiadis','3920 Mystic Valley Pkwy','Medford','MA','UNITED STATES','02155-6912','(857) 919-4601','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 15:07:51',0,NULL,3,1,1,1,NULL,'allgooddeals4u'),(6685,0,120701517236,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.26,'hermeshine','fotojohnyoc','foto_johnyoc@yahoo.com','John O\'Connor','2416 Sheelah Ct','Kettering','OH','UNITED STATES','45420-1127','(937) 479-6700','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 15:12:11',0,NULL,3,1,1,1,NULL,'fotojohnyoc\r徐'),(6686,690405129002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.49,'hermeshine','akyros360','ikodolemos@yahoo.com','IOANNIS47 KONTOLAIMOS','RAGAVI 25    N FALIRO','ATHENS','eu','GREECE','185 47','2104813053','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 15:24:13',0,NULL,3,1,2,1,NULL,'akyros360'),(6687,0,130500249185,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.06,'hermeshine','udnllc','signsvdc@aol.com','John Temple','2253 E Fairfield St','Mesa','AZ','UNITED STATES','85213-5210','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 15:31:56',0,NULL,8,1,17,0,NULL,'udnllc'),(6688,0,130500248982,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.06,'hermeshine','udnllc','signsvdc@aol.com','John Temple','2253 E Fairfield St','Mesa','AZ','UNITED STATES','85213-5210','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 15:31:57',0,NULL,3,1,1,1,NULL,'udnllc\r橡胶遮光罩 58mm  2'),(6689,0,130500248156,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','ronbj1','ronbj99@yahoo.com','Ronald Johnstone','251 Rodonovan Dr','Santa Clara','CA','UNITED STATES','95051-6605','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 16:20:52',0,NULL,3,1,1,1,NULL,'ronbj1'),(6690,0,120701510787,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','ekkotrading','ebayshop@trading.ekkosolutions.com','Carson Porter','662 W 150 N','Hurricane','UT','UNITED STATES','84737-3408','(435) 229-9331','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 17:08:30',0,NULL,3,1,1,1,NULL,'ekkotrading'),(6691,690179074002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',4,'AKT055',250,'hermeshine','polamsky','vlad.barreto@gmail.com','Vlad da Cunha','Locked Bag 15','Rozelle','New South Wales','AUSTRALIA','2039','0293511051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 23:27:10',0,NULL,3,1,4,1,NULL,'polamsky\rYW864871445CN\r'),(6692,649612105001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','joachimottow','joachim.ottow@gmail.com','Joachim Ottow','Cromhoffsbleekweg 82','Enschede','','NETHERLANDS','7513EW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 19:00:17',0,NULL,3,0,2,1,NULL,'joachimottow'),(6693,690472714002,120568072824,'Male to Male 52mm-52mm Macro Reverse Ring reversing',2,'AA1211',6.8,'hermeshine','cleg6298','clegnion@yahoo.com','cacy legnion','1701 old omen rd','tyler','TX','UNITED STATES','75701-5130','(903) 330-9350','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 18:21:34',0,NULL,3,1,1,1,NULL,'cleg6298'),(6694,0,120701515745,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.16,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','T Le','po box 953','getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 18:33:48',0,NULL,3,0,1,1,NULL,'usa_global_trader'),(6695,650050675001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','alexrubiom','alejandrorubiom@terra.es','Alejandro Rubio Martinez','Narvaez, 60','Madrid','Madrid','SPAIN','28009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 19:21:37',0,NULL,3,1,3,1,NULL,'alexrubiom\r庄\rRA022494815CN\r'),(6696,756848269015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','zanemangale','zonkis@gmail.com','ZANE MANGALE','LĪDUMA 8-109','RĪGA','','LATVIA','LV-1079','+37129822898','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-21 19:46:50',0,NULL,3,0,5,1,NULL,'zanemangale\r背景架 2m 白  黑  1\rCP226335007CN'),(6697,650063820001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','andrey_rayskiy','andrey.rayskiy@gmail.com','Andrii Raiskyi','vyl. Kudryashova, dom 7-b, kv. 133','Kyiv','','UKRAINE','03035','+380992799787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 19:51:55',0,NULL,3,1,2,1,NULL,'andrey_rayskiy'),(6698,742227530016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',4,'AA1310',15.12,'hutongstore','ralphm64','ralph.mills@vodamail.co.za','Ralph Mills','PO Box 53657<br>Wierda Park','Centurion','','SOUTH AFRICA','0149','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-22 20:41:48',0,NULL,3,1,2,1,NULL,'joachimottow\r庄'),(6699,0,120701511545,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','basara1013','eeriepa@gmail.com','Joel Rickenbach','1558 Tanglewood Dr','West Chester','PA','UNITED STATES','19380-5855','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 21:08:12',0,NULL,8,1,17,0,NULL,'basara1013\r徐'),(6700,0,110664683503,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','basara1013','eeriepa@gmail.com','Joel Rickenbach','1558 Tanglewood Dr','West Chester','PA','UNITED STATES','19380-5855','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 21:08:13',0,NULL,8,1,17,0,NULL,'basara1013\r徐'),(6701,0,130500245633,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','basara1013','eeriepa@gmail.com','Joel Rickenbach','1558 Tanglewood Dr','West Chester','PA','UNITED STATES','19380-5855','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 21:08:13',0,NULL,8,1,17,0,NULL,'basara1013\r庄'),(6702,0,110664683727,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','basara1013','eeriepa@gmail.com','Joel Rickenbach','1558 Tanglewood Dr','West Chester','PA','UNITED STATES','19380-5855','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 21:08:44',0,NULL,8,1,17,0,NULL,'basara1013'),(6703,690130550002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','anderurkiza','hadpersonal@gmail.com','Eugenio Alonso Garcia','Avda. Antigua, 5, 4º C','Zumarraga','País Vasco','SPAIN','20700','655700046','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 21:25:37',0,NULL,3,1,4,1,NULL,'anderurkiza\rYW864871412CN\r6662a   1\r67mm 环架   1\r55mm 环架   1\r\r'),(6704,690568435002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','mikeysmom45','bballgirlmikey@aol.com','Micahlyn Allen','SUNDEF<br>UCO','Angers','Pays de la Loire','FRANCE','49100','(336) 482-1028 ext.: 7','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 21:32:04',0,NULL,3,1,2,1,NULL,'mikeysmom45'),(6705,0,130500245972,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','basara1013','eeriepa@gmail.com','Joel Rickenbach','1558 Tanglewood Dr','West Chester','PA','UNITED STATES','19380-5855','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 23:33:11',0,NULL,3,1,1,1,NULL,'basara1013\rCANON 镜头盖  58mm   5'),(6706,0,130500250879,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.16,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','Thu thi Le','PO Box 953','Getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:10:24',0,NULL,3,0,1,1,NULL,'usa_global_trader'),(6707,690628276002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','remiaus','akestanolatienes@gmail.com','Jon Ribera Medina','betolaza num.7bis bajo dcha','Bilbo','País Vasco','SPAIN','48002','689708226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 00:13:20',0,NULL,8,1,17,0,NULL,'remiaus'),(6708,650168176001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','remiaus','akestanolatienes@gmail.com','Jon Ribera Medina','betolaza num.7bis bajo dcha','Bilbo','País Vasco','SPAIN','48002','689708226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 00:13:22',0,NULL,8,1,17,0,NULL,'remiaus'),(6709,649812453001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',60.3,'hermeshine','remiaus','akestanolatienes@gmail.com','Jon Ribera Medina','betolaza num.7bis bajo dcha','Bilbo','País Vasco','SPAIN','48002','689708226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 00:13:21',0,NULL,3,1,3,1,NULL,'remiaus\r气吹 + 布    1\r麂皮   2\r115w 220v   1\r反光板支架   1\r单灯头 欧标    1\r庄\rRA022494988CN'),(6710,0,120701513489,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:12',0,NULL,8,1,17,0,NULL,'wienerdude26\r庄'),(6711,0,110664685948,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:12',0,NULL,8,1,17,0,NULL,'wienerdude26\r刘'),(6712,0,110664687204,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:13',0,NULL,8,1,17,0,NULL,'wienerdude26\r庄'),(6713,0,130500249295,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:13',0,NULL,8,1,17,0,NULL,'wienerdude26\r庄'),(6714,0,110664686965,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:13',0,NULL,8,1,17,0,NULL,'wienerdude26\r庄'),(6715,0,130500248313,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:14',0,NULL,3,1,1,1,NULL,'wienerdude26\r58rubber   7   \r\\'),(6716,0,110664685214,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:53:15',0,NULL,8,1,17,0,NULL,'wienerdude26\r庄\r'),(6717,757110095015,250607841646,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',20,'hutongstore','ricardofrajuca','ricardo2509@hotmail.co.uk','Ricardo Silva','27 A Brett Road','LONDON','London','UNITED KINGDOM','E81JP','07706926691','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-22 07:23:36',0,NULL,3,1,3,1,NULL,'ricardofrajuca\rRA022495317CN'),(6718,649858957001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','alfarif','alfarif@alfarif.com','Warren Stallworth','3791 Mac Nicholas Ave','Cincinnati','OH','UNITED STATES','45236','(513) 375-2919','NoPaymentFailure','CheckoutComplete','Other','2011-03-22 08:52:16',0,NULL,3,1,3,1,NULL,'alfarif\rRA022494033CN'),(6719,690277432002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','niteskie','jweedop@gmail.com','Jade Weedop','756 E 60 S','American Fork','UT','UNITED STATES','84003-2247','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 06:13:52',0,NULL,3,1,1,1,NULL,'niteskie\rLK032928295CN'),(6720,649962290001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',9.58,'hermeshine','dollyredshoes','strangekatts@hotmail.com','Audrey Leong','Blk 100, Commonwealth Crescent<br>#07-78','Singapore','','SINGAPORE','140100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 03:09:01',0,NULL,3,1,11,1,NULL,'dollyredshoes\r52mm 橡胶罩   1\r中号内胆包  无字   1\r庄\r'),(6721,649888687001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','tony_c77','tony_c@mail.ru','Cheremukhin Anton','Moravsky side str.  3-1-395','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','192289','+79216446366','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 11:16:41',0,NULL,3,1,3,1,NULL,'tony_c77\r刘\rRA022494965CN'),(6722,647600468018,280522563067,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',98,'photographyacc','woojiebear','info@sarahbeebe.com','Sarah Beebe','101B 1477 Glenmore Rd.','Kelowna','BC','CANADA','V1V 2H6','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-23 03:43:29',0,NULL,3,1,5,1,NULL,'woojiebear\r2m 背景架  （白　黑　灰　蓝）　　１\r１.６ｘ２.１ｍ   \rCP226379467CN'),(6723,757188784015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',2,'AO0001',236,'hutongstore','pastortunde2011','pastortunde@kingdomarena.org.uk','Pastor Tunde Ogedengbe','39 Sunderland Place<br>Shortstown','Bedford','Bedfordshire','UNITED KINGDOM','MK42 0FE','01582405757','PayPalPaymentInProcess','CheckoutComplete','UK_StandardShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'colossus2011\r庄'),(6724,649843122001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','photoblacktony','antonio99159@hotmail.com','ANTONIO A. RODRIGUEZ MARTINEZ','Rbla. Anselmo Clavé, 49, entlo. 3ª','CORNELLÁ DE LLOBREGAT, BARCELONA','Cataluña','SPAIN','08940','933774268','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 07:33:47',0,NULL,3,0,3,1,NULL,'photoblacktony\rRA022495586CN'),(6725,649902621001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','im.simply.me','naturallymorbid@gmail.com','Matan Eshel','Antot 12A','Tel Aviv','','ISRAEL','69080','0545806362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:28:25',0,NULL,3,0,2,1,NULL,'im.simply.me'),(6726,690701572002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','ike_emi','emhakim@gmail.com','Emil Yagudin','74 Main St','Framingham','MA','UNITED STATES','01702-2952','(508) 270-8844','NoPaymentFailure','CheckoutComplete','Other','2011-03-23 05:02:24',0,NULL,3,1,3,1,NULL,'zaferdefnezafer\r庄\rRA022494492CN'),(6727,690317514002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','sturamironova1','sturamironova@yandex.ru','Yalovegin Andrey','Stalingradskaya,11-120','Volzhsky','Volgograd region','RUSSIAN FEDERATION','404111','+79876484629','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 09:55:18',0,NULL,3,0,3,1,NULL,'sturamironova1\rRA022494930CN'),(6728,690335578002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','garseklis','garseklis@gmail.com','Andrius Paulavicius','Suduviu 50, Gineitiskiu km','Vilniaus raj, Buivydiskiu pst','','LITHUANIA','14166','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 11:14:46',0,NULL,3,0,3,1,NULL,'imanolguirado\r徐   \rRA022494886CN\r'),(6729,690410817002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE3104',29.04,'hermeshine','shenker123','shenkerbay@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 15:43:20',0,NULL,3,0,3,1,NULL,'shenker123\rRA022494872CN'),(6730,647307652001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','miriamomland','miriam_sk@hotmail.com','Miriam Skår Omland','Opplandsveien 187b','Grimstad','','NORWAY','4885','+47 97176674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:34:20',0,NULL,3,0,2,1,NULL,'miriamomland'),(6731,649886392001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','chilla1142','kahuna@bigpond.net.au','P PEACOCK','42 LAKE BREEZE DRIVE','WINDAROO','Queensland','AUSTRALIA','4207','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 11:00:23',0,NULL,3,0,2,1,NULL,'chilla1142'),(6734,690456013002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','theonewearingbluesocks','tomy_gyeresy@yahoo.com','Tamas Gyeresi','Suseni/130','Sintana de Mures','Mures','ROMANIA','547565','+40740847652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 17:42:04',0,NULL,3,1,2,1,NULL,'theonewearingbluesocks'),(6732,757224275015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',1.88,'hutongstore','david_garvey_1987','davidgarvey1987@googlemail.com','David Garvey','TRaC, Unit E, South Orbital Trading Park<br>Hedon Rd','Hull','East Riding of Yorkshire','UNITED KINGDOM','HU91NJ','07875236580','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-22 13:52:11',0,NULL,3,0,2,1,NULL,'david_garvey_1987\r刘'),(6733,690718053002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','imanolguirado','imanolguirado@hotmail.com','Imanol Guirado Perez','Avda. Isabel II Nº4, esc. Izq, 1-D','Donostia - San Sebastian','País Vasco','SPAIN','20011','605725709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 06:55:57',0,NULL,3,1,2,1,NULL,'waynehe51\r徐'),(6735,757240502015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',127,'hutongstore','4myclothesuk','myclothesuk@live.com','David Lingard','71 Canada Road','Deal','Kent','UNITED KINGDOM','CT14 7EJ','01304362303','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-22 14:35:46',0,NULL,3,0,4,1,NULL,'4myclothesuk\r燕文   lighting kit  $30\rYW864871482CN'),(6736,757669187015,250692240567,'TianYa Gradual color Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','micky2009b','m_pbarrett@yahoo.co.uk','Michael Barrett','Turlough','Castlebar','Mayo','IRELAND','000','0877604479','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-23 09:42:57',0,NULL,3,1,2,1,NULL,'micky2009b\r58mm 接口环  1\r托架   1\r渐变灰   1'),(6737,649451409001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','sokolc','sokol_cekrezi@hotmail.com','sokol cekrezi','Lagja. 4 Rruga  \"skenderbe\"<br>Pallati i Papajve, cel - 0692152285','DURRES','DURRES','ALBANIA','2001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 10:38:56',0,NULL,3,1,2,1,NULL,'欧标'),(6738,650290471001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','7481858','studia5@yahoo.com','Vladimir Kuleshov','Andrianova str. 12-70','Orel','','RUSSIAN FEDERATION','302040','+7-910-748-1858','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-23 10:55:57',0,NULL,3,1,3,1,NULL,'7481858\rzhuang\rRA022494475CN\r'),(6739,650300004001,110566020814,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',67,'hermeshine','explorer200hiking','shillsborough@aol.com','James Smith','6001 Guess Rd','Durham','NC','UNITED STATES','27712-9279','(919) 471-1198','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 11:16:21',0,NULL,3,1,3,1,NULL,'explorer200hiking\rzhuang\rRA022494461CN'),(6740,647943144018,280522563067,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',90,'photographyacc','justformichelle2008','justformichelle@ymail.com','Thi Bich Tram Pham','8 Belfort Street<br>St Albans','Melbourne','Victoria','AUSTRALIA','3021','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-23 11:22:50',0,NULL,3,1,4,1,NULL,'justformichelle2008\r背景架 2m （ 白 黑 灰  ）   1\r1.6mx2.1m布\r庄\rYW864871471CN\r'),(6741,0,120701919087,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 13:43:34',0,NULL,8,1,17,0,NULL,'i3izkit311'),(6742,0,120701918812,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 13:55:01',0,NULL,8,1,17,0,NULL,'i3izkit311'),(6743,0,120701919233,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 13:56:45',0,NULL,8,1,17,0,NULL,'i3izkit311'),(6744,0,120701919503,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 13:57:52',0,NULL,8,0,17,0,NULL,'i3izkit311\r'),(6745,0,110665060923,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 13:59:15',0,NULL,8,1,17,0,NULL,'i3izkit311'),(6746,0,130500586320,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:00:43',0,NULL,8,1,17,0,NULL,'i3izkit311'),(6747,0,110665060659,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:02:49',0,NULL,8,1,17,0,NULL,'i3izkit311\r'),(6748,0,110665054116,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:04:05',0,NULL,8,1,17,0,NULL,'i3izkit311'),(6749,0,130500598261,'New 62mm Rubber 3in1 Collapsible Lens Hood',1,'AB1304',1.04,'hermeshine','dcalbrecht','dave@dcdadvancedtech.com','Dave Albrecht','14 Hudson Dr','New Windsor','NY','UNITED STATES','12553-7427','(914) 455-4243','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:31:14',0,NULL,3,1,1,1,NULL,'dcalbrecht'),(6750,0,130500598718,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',0.16,'hermeshine','hayhay1968','colleenball@att.net','Haley Ball','5805 Spring Hollow Dr','Toledo','OH','UNITED STATES','43615-7905','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:37:40',0,NULL,3,1,1,1,NULL,'\r庄'),(6751,0,110665075004,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',0.57,'hermeshine','bonniec9090','bonnie@buildingsolution.net','Bonnie Carroll','1111 Butterworth Ct','Stevensville','MD','UNITED STATES','21666-2580','(443) 223-4696','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:38:56',0,NULL,3,1,1,1,NULL,''),(6752,0,120701930419,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','g_enterprises','bgentle@centurytel.net','Bruce G. Gentle','6909 Buck Jackson Rd','Vernon','AL','UNITED STATES','35592-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:44:57',0,NULL,3,1,1,1,NULL,'g_enterprises'),(6753,742560223016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','sav0801','saravanan.anandathiyagar@googlemail.com','Mr Saravanan Anandathiyagar','180 Arrowsmith Road','Chigwell','Essex','UNITED KINGDOM','IG7 4NZ','07525990204','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-23 14:58:00',0,NULL,3,1,3,1,NULL,'sav0801\r庄\rRA022494444CN'),(6754,0,130500597884,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',0.16,'hermeshine','schee','sdchee@yahoo.com','Sonny D Chee','12629 Centurion Ln','Fairfax','VA','UNITED STATES','22033-1708','(571) 643-9975','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 15:02:03',0,NULL,3,1,1,1,NULL,'oceoke\r刘'),(6755,0,110665076467,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',0.06,'hermeshine','jshen.1','jshen.1@netzero.net','Jun Shen','1017 Thistle Ct','Sunnyvale','CA','UNITED STATES','94086-9079','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 15:08:41',0,NULL,3,1,1,1,NULL,'jshen.1'),(6756,690841486002,120568891550,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',2.6,'hermeshine','speedmadness','richard.l.jongsma@jci.com','Richard Jongsma','7310 Indigo Ridge Dr SW','Byron Center','MI','UNITED STATES','49315-8453','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 15:17:29',0,NULL,8,1,17,0,NULL,'speedmadness'),(6757,0,130500599988,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',3.94,'hermeshine','speedmadness','richard.l.jongsma@jci.com','Richard Jongsma','7310 Indigo Ridge Dr SW','Byron Center','MI','UNITED STATES','49315-8453','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 15:17:30',0,NULL,3,1,1,1,NULL,'speedmadness\rNIKON 镜头盖 77mm   1\r绿叶 UV  77mm   1\rZHN'),(6758,650161988001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','maciek173','mskireco@3web.net','maciek sierminski','33 Fulton Cres.','Whitby','ON','CANADA','L1R2C9','(905) 665-7263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 23:50:16',0,NULL,3,1,2,1,NULL,'maciek173'),(6759,0,110664688516,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.07,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','Thu thi Le','PO Box 953','Getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 15:42:34',0,NULL,3,0,1,1,NULL,'usa_global_trader'),(6760,650025693001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','jammieshopper','ccbonessa@sbcglobal.net','Lisa Newenhouse','122 W Glengate Ave','Chicago Heights','IL','UNITED STATES','60411-1730','(219) 923-1846','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 18:31:04',0,NULL,3,1,1,1,NULL,'jammieshopper'),(6761,650379020001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 15:56:36',0,NULL,3,1,2,1,NULL,'jamesikf\r徐'),(6762,0,110665505012,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',3.69,'hermeshine','mwunsch1031','mihawunsch@hotmail.com','MiHa Wunsch','10 Bostin Ln','McCleary','WA','UNITED STATES','98557-9433','(360) 878-3001','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 16:05:32',0,NULL,8,1,17,0,NULL,'mwunsch1031\r\r'),(6763,0,110665076546,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',2.26,'hermeshine','mwunsch1031','mihawunsch@hotmail.com','MiHa Wunsch','10 Bostin Ln','McCleary','WA','UNITED STATES','98557-9433','(360) 878-3001','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 16:05:33',0,NULL,3,1,1,1,NULL,'gorrionsudaca\r绿叶 UV  77mm    1\r绿叶 UV  72mm    1\rZHN'),(6764,0,120701911230,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.12,'hermeshine','nmphoto22','nmariet@gmail.com','Nicole T','8513 Red Wing Ln','Lanham','MD','UNITED STATES','20706-3858','(240) 678-5545','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 16:17:30',0,NULL,3,1,1,1,NULL,'nmphoto22'),(6765,690543498002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','mon_jark','mistamoocow@hotmail.com','Jon-Mark Wiltshire','#303-331 Burnside Road East','Victoria','BC','CANADA','V9A1A6','(250) 858-5930','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 20:36:58',0,NULL,3,1,3,1,NULL,'mon_jark\r庄\rRA022494909CN'),(6766,757811955015,250692241086,'YongNuo SF-18 Flash Battery Pack 8*AA for Nikon SB900',1,'AB3311',32.99,'hutongstore','reapapke25','reapapke@web.de','Rea Papke','Mühlenbrook 9','Kiel','','GERMANY','24106','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-23 16:34:36',0,NULL,3,1,3,1,NULL,'reapapke25\rRA022494458CN'),(6767,690885711002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','photolady2011','nggphotography@gmail.com','nadeene  gholston','5802 Northwoods Dr','hixson','TN','UNITED STATES','37343-3627','(423) 870-2117','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 17:13:28',0,NULL,3,1,1,1,NULL,'photolady2011'),(6768,0,110665074671,'New 52mm Rubber 3in1 Collapsible Lens Hood',1,'AB1301',0.16,'hermeshine','2009bikeman','legoskibike@gmail.com','Matthew Richey','19830 SE 328th PL','Auburn','WA','UNITED STATES','98092','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 17:20:03',0,NULL,3,1,1,1,NULL,'2009bikeman'),(6769,690501330002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','colossus2011','colossus86@gmail.com','dima spivak','Haoren st.  , P.O. box: 5039.<br>Apartment: 7 , building: 11 .','Akko','','ISRAEL','24406','972545303373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 19:19:45',0,NULL,3,1,2,1,NULL,'colossus2011'),(6770,0,120701930739,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',0.84,'hermeshine','waynehe51','heyang51@gmail.com','Yang He','365 S Atlantic Blvd<br>Apt A','Monterey Park','CA','UNITED STATES','91754-3248','(626) 688-2518','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 17:28:05',0,NULL,3,1,1,1,NULL,'waynehe51'),(6771,650121503001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','sageata_de_aur','sageata_de_aur@yahoo.com','ionel stanciu','via de gasperi nr 9','ponte di piave','TV','ITALY','31047','0422759544','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 21:46:01',0,NULL,3,1,3,1,NULL,'sageata_de_aur\rRA022494912CN\r申报：  support pad  camera\r $15'),(6772,690525064002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',4,'AC2303',24.84,'hermeshine','gorrionsudaca','juanotesone@gmail.com','Juan Tesone','Av. Libertador 886<br>Piso 8 Dpto E','Vicente Lopez','Buenos Aires','ARGENTINA','1638','+5411 4718 3175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 20:05:02',0,NULL,3,1,2,1,NULL,'gorrionsudaca'),(6773,0,130500597993,'Canon 58mm Reverse Adapter Combined shipping discounts',1,'AA1208',1.5,'hermeshine','phoenixsoaring','phoenixsoaring2008@gmail.com','Glen Chin','8778 24th Ave','Brooklyn','NY','UNITED STATES','11214','(646) 807-8182','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 18:52:30',0,NULL,3,1,1,1,NULL,'phoenixsoaring'),(6774,0,110665074742,'New 55mm Rubber 3in1 Collapsible Lens Hood',1,'AB1302',0.06,'hermeshine','xxxgmoney','theeternal_1@yahoo.com','Daniel Garman','423 Sanford St<br>Apt D','Radford','VA','UNITED STATES','24141-3140','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 19:22:43',0,NULL,3,1,1,1,NULL,'xxxgmoney'),(6775,690953390002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','gulbrandtang','gulbrand.tangen@c2i.net','Gulbrand Tangen','Brennivegen 45','Algarheim','','NORWAY','2056','+4763976867','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-23 19:37:08',0,NULL,3,1,3,1,NULL,'gulbrandtang\r庄\rRA022494501CN'),(6776,650139915001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','black_hack_magik','archangel23@gmail.com','Robert Coffey','6770 Scott St','Allendale','MI','UNITED STATES','49401','(616) 895-4118','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 22:35:55',0,NULL,3,1,1,1,NULL,'i3izkit311'),(6777,690962640002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','nibor626','robinehs@gmail.com','Ilse Taylor','50 Victoria road<br>Bakoven','Cape Town','Western Cape','SOUTH AFRICA','8001','(021)438-8941','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-23 19:55:46',0,NULL,3,0,3,1,NULL,'nibor626\r欧标\r3个包:\r灯架+棚RA022494210CN\r灯架+棚RA022494237CN\r灯泡+包RA022494223CN\r'),(6778,650208132001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','paulopqdt','prtfoto@yahoo.com.br','Paulo Rosa Teixeira','BRAS DE PINA 617 APT 202<br>VILA DA PENHA','RIO DE JANEIRO','rio de janeiro','BRAZIL','21210673','021 25735432','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-23 02:45:15',0,NULL,3,1,3,1,NULL,'paulopqdt\r-liu-\rRA022494489CN'),(6779,0,120701931759,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.17,'hermeshine','marinehacker','djtkatchjr@yahoo.com','duane tkatch jr','PO Box 352','fontana','CA','UNITED STATES','92334-0352','(909) 331-5144','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 20:08:57',0,NULL,3,1,1,1,NULL,'marinehacker'),(6780,690993046002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','jamesikf','jamesipkf@yahoo.com.hk','Ka Fai Ip','Flat A 20/F Fu Bon Court Fortress Garden<br>32 Fortress Hill Road North Point','default','','HONG KONG','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:50:11',0,NULL,3,1,2,1,NULL,'jamesikf'),(6781,690615987002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jotamadrid','jose.tachu@gmail.com','Jose Elías Rodríguez','Calle Plomo, 3A, 1º C','Madrid','Madrid','SPAIN','28045','606696053','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 23:33:20',0,NULL,3,1,4,1,NULL,'jotamadrid\r燕文   tripod  $15\rYW864871504CN   '),(6782,690566298002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','vmoreno_es','vtemz03@gmail.com','Vicente Moreno Zafra','C/ Churruca, 4 atico izda.','ALICANTE','Alicante','SPAIN','03003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 21:26:12',0,NULL,8,0,17,0,NULL,'vmoreno_es\r庄（包含另外一票80cm 5in1）'),(6783,650111773001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','vmoreno_es','vtemz03@gmail.com','Vicente Moreno Zafra','C/ Churruca, 4 atico izda.','ALICANTE','Alicante','SPAIN','03003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 21:26:13',0,NULL,3,1,2,1,NULL,'vmoreno_es\r80 5in1  1  \r广角托架   1'),(6784,0,120701930813,'Nikon 52mm Reverse Adapter',1,'AA1210',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:23:14',0,NULL,8,1,17,0,NULL,'i3izkit311'),(6785,0,110665075226,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:23:51',0,NULL,8,1,17,0,NULL,'i3izkit311\r'),(6786,0,110665075091,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:24:49',0,NULL,8,1,17,0,NULL,'i3izkit311'),(6787,0,110665075157,'New 77mm Rubber 3in1 Collapsible Lens Hood',1,'AB1307',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:25:19',0,NULL,8,1,17,0,NULL,''),(6788,0,110665075037,'New 72mm Rubber 3in1 Collapsible Lens Hood',1,'AB1306',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:25:57',0,NULL,8,1,17,0,NULL,'i3izkit311\r'),(6789,0,110665074961,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:26:48',0,NULL,8,1,17,0,NULL,'i3izkit311'),(6790,0,130500580318,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.12,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:27:44',0,NULL,8,1,17,0,NULL,'trikerexcalibur\rXXL\r'),(6791,0,120701930359,'New 58mm Rubber 3in1 Collapsible Lens Hood',1,'AB1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:27:44',0,NULL,8,1,17,0,NULL,'i3izkit311\r'),(6792,0,110665053639,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:28:28',0,NULL,8,1,17,0,NULL,'4myclothesuk\r刘+庄+王'),(6793,0,110665074932,'New 67mm Rubber 3in1 Collapsible Lens Hood',1,'AB1305',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:30:15',0,NULL,8,1,17,0,NULL,'i3izkit311\r'),(6794,0,130500579768,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.11,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:30:21',0,NULL,8,1,17,0,NULL,'xxxgmoney\r庄'),(6795,0,110665053899,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.12,'hermeshine','amishelvis1','amishelvis1@aol.com','Will Shilts','4055 Flatley Rd','Richmond','IN','UNITED STATES','47374-9204','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 22:27:52',0,NULL,3,0,1,1,NULL,'nibor626\r刘'),(6796,691045054002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','proshkin','proxorov@gmail.com','Katerina Adyseva','pr. Shevchenko 33-B, app. 203','Odessa','','UKRAINE','65058','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 22:49:00',0,NULL,3,1,2,1,NULL,'proshkin'),(6797,650557596001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',3,'AA1210',10.74,'hermeshine','zaferdefnezafer','zaferdefne@hotmail.com','ahmet zafer tunc','569 sk. no. 14. k.1 d.2 osmangazi mah.<br>bayrakli','izmir','','TURKEY','35030','5079464074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 22:50:42',0,NULL,3,1,2,1,NULL,'zaferdefnezafer'),(6798,645213229001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','alati61252','alati61@hotmail.com','ioannis kokologiannis','45 ipsilantou','loutraki','korinthos','GREECE','20300','+302744023333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 00:11:21',0,NULL,3,1,2,1,NULL,'alati61252'),(6799,0,120701930074,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',1,'AB1405',0.11,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 00:42:48',0,NULL,8,1,17,0,NULL,'danbbbb'),(6800,0,120701912632,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.06,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 00:42:49',0,NULL,3,1,1,1,NULL,'\r'),(6801,690973161002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','oceoke','oceoke01@gmail.com','Miguel Angel Ruiz Santaella','Avda. del Mediterraneo nº 7 2º I<br>Salobreña (Granada)','Salobreña   (Granada)','Andalucía Ceuta y Melilla','SPAIN','18680','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:13:44',0,NULL,3,1,2,1,NULL,'oceoke'),(6802,690341645002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','erinjohn','erinjohnreho@yahoo.com','john reho','11 grand port rd','Ocean Pines','MD','UNITED STATES','21811-1520','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 01:27:54',0,NULL,3,1,1,1,NULL,'erinjohn\rLIU'),(6808,0,130500597958,'Canon 52mm Reverse Adapter Combined shipping discounts',1,'AA1207',0.11,'hermeshine','sunniey924','edwardsunnie@gmail.com','Edward Yang','450 S Los Robles Ave<br>Apt 1','Pasadena','CA','UNITED STATES','91101-3256','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:05:02',0,NULL,3,1,1,1,NULL,'sunniey924\r庄\r肩带 pentax 1\r橡胶遮光罩 58mm 1'),(6803,0,120702387044,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 01:47:44',0,NULL,8,1,17,0,NULL,'i3izkit311'),(6804,0,120702387175,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.12,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 01:48:06',0,NULL,8,1,17,0,NULL,'i3izkit311'),(6805,0,120701930688,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 01:50:00',0,NULL,3,1,1,1,NULL,'i3izkit311\rCANON 镜头盖  58mm  4\rCANON 镜头盖  67mm  1\rCANON 镜头盖  72mm   5\rNIKON 镜头盖 72mm 1\rNIKON 镜头盖 77mm   1\rNikon  52mm 反接环  1\r橡胶遮光罩 58mm   1\r橡胶遮光罩 67mm   1\r72mm 橡胶罩    4\r橡胶遮光罩 77mm   1\r绿叶 UV  67mm   1\r绿叶 UV  58mm   1\r王'),(6806,742719575016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','rellydasal1976','rellydasal@yahoo.com','Vanessa Buendia','Ceann-Lios, The Twenties','Drogheda','Louth','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-23 20:12:12',0,NULL,3,1,2,1,NULL,'rellydasal1976\r庄'),(6807,650502011001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','hp67210','henripascal@hotmail.fr','Henri PASCAL','3c rue poincaré','OBERNAI','Alsace','FRANCE','67210','0685129515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:36:55',0,NULL,3,1,2,1,NULL,'hp67210\r庄'),(6809,0,110665058376,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:16',0,NULL,5,0,18,0,NULL,'segalu'),(6810,0,120701912299,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:17',0,NULL,5,0,18,0,NULL,'segalu'),(6811,0,110665054291,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:17',0,NULL,5,0,18,0,NULL,'segalu'),(6812,0,120701915368,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:18',0,NULL,5,0,18,0,NULL,'segalu'),(6813,0,120701915892,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:18',0,NULL,3,0,1,1,NULL,'segalu\r发个镜头布给他就行了'),(6814,0,110665054739,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:19',0,NULL,5,0,18,0,NULL,'segaluttsfsfs'),(6815,0,130500582332,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:19',0,NULL,5,0,18,0,NULL,'fdfsdsegalusssss'),(6816,0,130500581991,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:20',0,NULL,5,0,18,0,NULL,'sdfsegalu'),(6817,0,110665055914,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:20',0,NULL,5,0,18,0,NULL,'segalu'),(6818,0,110665074705,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.93,'hermeshine','richardctchang','richardctchang@yahoo.com','Richard Chang','93 Monterey Road','South Pasadena','CA','UNITED STATES','91030','(626) 285-8578','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 03:22:49',0,NULL,3,1,1,1,NULL,'richardctchang'),(6819,0,130500251284,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.07,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','Thu thi Le','PO Box 953','Getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 04:57:31',0,NULL,3,1,1,1,NULL,'usa_global_trader'),(6820,650645592001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','hpsiu1','bensiu_87@hotmail.com','Hou Pan Siu','30 Campden Place','Markham','ON','CANADA','L6C2J8','(905) 887-5351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 05:13:21',0,NULL,3,1,2,1,NULL,'hpsiu1'),(6821,650535801001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','prtycrys26','prtycrystal26@att.net','Crystal Lopez','2188 Coastland Ave<br># 3','San Jose','CA','UNITED STATES','95125-2609','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:50:31',0,NULL,3,1,1,1,NULL,'prtycrys26'),(6822,758029884015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.28,'hutongstore','newparts11','newpartsebay@gmail.com','auguste banyte','31 hartingdon street','manchester','Lancashire','UNITED KINGDOM','M14 4RW','07963124666','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-23 22:58:26',0,NULL,3,1,2,1,NULL,'newparts11'),(6823,650673235001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','msocin','m.socin@virgilio.it','MASSIMO SOCIN','via Premuda, 19','Mestre','VE','ITALY','30171','328/4185377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 08:14:30',0,NULL,3,1,2,1,NULL,'msocin\r\\'),(6824,691176921002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','flaviopetrini','info@flaviopetrini.it','PETRINI, FLAVIO','VIA ZUCCARI 24','ANCONA','AN','ITALY','60129','331-4540741','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 08:44:06',0,NULL,3,1,2,1,NULL,'flaviopetrini'),(6825,650688044001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',3.55,'hermeshine','pazzo_66','plamen66@gmail.com','Plamen Petrov','Luln, bl.427, ap.78','Sofia','Sofia','BULGARIA','1359','359899261269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:29:11',0,NULL,3,0,2,1,NULL,'pazzo_66\r方形滤镜接口环 52mm  1\r方形滤镜接口环 49mm   1\r广角托架   1'),(6826,650594079001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','bobb77777','bobb77777@hotmail.com','paul camp','23 hillview dr','Drayton','ON','CANADA','n0g1p0','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-24 01:04:43',0,NULL,3,0,3,1,NULL,'bobb77777\rRA022494183CN'),(6827,650650529001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','volka78','v0lka@list.ru','Vladimir Popov','Bebelya<br>110-55','Ekaterinburg','','RUSSIAN FEDERATION','620034','9022534273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 10:45:38',0,NULL,3,1,2,1,NULL,'volka78\r\\'),(6828,0,110665060430,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.59,'hermeshine','highbidderlady02','stephanie@powertranstechinc.com','Stephanie Sedlacek','PO Box 573<br>170236 Co Rd 37','Bayard','NE','UNITED STATES','69334-0573','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 13:14:27',0,NULL,3,1,1,1,NULL,'highbidderlady02\r52mm uv   1\r55mm  uv   1\r67mm uv    1\r52-52 双阳环  1\r52-58 双阳环   1\r58-58 双阳环   1\r佳能肩带   1\r72mm 镜头盖  canon   1\r72mm 橡胶罩   1\r\\\r'),(6829,0,130500251466,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','Thu thi Le','PO Box 953','Getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 13:55:09',0,NULL,3,0,1,1,NULL,'usa_global_trader'),(6830,0,120702380413,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.06,'hermeshine','norabla','norabla@aol.com','Alan Baron','78 Cherry Ln','Syosset','NY','UNITED STATES','11791','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:25:33',0,NULL,8,1,17,0,NULL,'norabla'),(6831,0,130500953499,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.11,'hermeshine','norabla','norabla@aol.com','Alan Baron','78 Cherry Ln','Syosset','NY','UNITED STATES','11791','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:25:34',0,NULL,8,1,17,0,NULL,'volka78\rLIU'),(6832,0,110665495356,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',1.25,'hermeshine','norabla','norabla@aol.com','Alan Baron','78 Cherry Ln','Syosset','NY','UNITED STATES','11791','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:25:34',0,NULL,8,1,17,0,NULL,'norabla'),(6833,0,130500953300,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',1.26,'hermeshine','norabla','norabla@aol.com','Alan Baron','78 Cherry Ln','Syosset','NY','UNITED STATES','11791','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:25:35',0,NULL,3,1,1,1,NULL,'norabla\rNIKON 镜头盖 52mm  4\r'),(6834,0,130500953920,'New 55mm Rubber 3in1 Collapsible Lens Hood',1,'AB1302',0.01,'hermeshine','2009bikeman','legoskibike@gmail.com','Matthew Richey','19830 SE 328th PL','Auburn','WA','UNITED STATES','98092','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:40:00',0,NULL,3,1,1,1,NULL,'2009bikeman\r\r'),(6835,0,120702383009,'New 62mm Rubber 3in1 Collapsible Lens Hood',1,'AB1304',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:48:12',0,NULL,8,1,17,0,NULL,'danbbbb'),(6836,0,120702381381,'New 55mm Rubber 3in1 Collapsible Lens Hood',1,'AB1302',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:48:12',0,NULL,8,1,17,0,NULL,'danbbbb'),(6837,0,120702382885,'New 62mm Rubber 3in1 Collapsible Lens Hood',1,'AB1304',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:48:13',0,NULL,3,1,1,1,NULL,'danbbbb\r62mm 橡胶罩   2\r55mm 橡胶罩   1\r\\\r\r'),(6838,743067466016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','leepfp','lee4pfp@btinternet.com','Mr L Howell','Lake Cottage, Church Lane<br>Saul','Gloucester','Glos','UNITED KINGDOM','GL2 7JY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 14:51:41',0,NULL,8,1,17,0,NULL,'leepfp\r'),(6839,743066963016,260660051651,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D S',1,'AC2305',5.5,'hutongstore','leepfp','lee4pfp@btinternet.com','Mr L Howell','Lake Cottage, Church Lane<br>Saul','Gloucester','Glos','UNITED KINGDOM','GL2 7JY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 14:51:41',0,NULL,3,1,2,1,NULL,'leepfp\rlenspen   1\r中号内胆包 canon    1\r\\'),(6840,650775994001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','skotsomitis','spikots@hotmail.com','kotsomitis spiros','ISIODOU 7','KOROPI','GREECE','GREECE','19400','+306936968226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 15:17:49',0,NULL,3,0,3,1,NULL,'skotsomitis\rRA022494387CN'),(6841,758109058015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','moet16','rnewbery@optusnet.com.au','Robyn Newbery','9 Boyce Street','Ryde','New South Wales','AUSTRALIA','2112','0298781103','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-24 03:01:06',0,NULL,3,1,2,1,NULL,'moet16\rLIU'),(6842,0,120700932244,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.02,'hermeshine','maliysem','vdsem@aol.com','vadim  semenov','3409 northrop ave','sacramento','CA','UNITED STATES','95864-5026','(916) 320-2790','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 16:22:09',0,NULL,3,0,1,1,NULL,'maliysem\rCANON 镜头盖  58mm  2'),(6843,0,120701910155,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','goodstoyou','kenofsimi@yahoo.com','Kenneth DeNunez','2373 Morley St','Simi Valley','CA','UNITED STATES','93065-3630','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 16:53:16',0,NULL,3,1,1,1,NULL,'goodstoyou'),(6844,650803096001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','electro5555','ilkka.rutanen@kymp.net','Ilkka Rutanen','Juustenintie 3 H 96','Helsinki','Pirkanmaa','FINLAND','00410','3583730773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 16:35:29',0,NULL,3,1,2,1,NULL,'electro5555\r\\'),(6845,691317848002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-24 17:17:13',0,NULL,3,1,3,1,NULL,'arnorolf10\rRA022495997CN'),(6846,0,130500953029,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',1.2,'hermeshine','molle444','molle4444@gmail.com','Anders Moldén','528 Hale Hall','Storrs','CT','UNITED STATES','06269','617 416 5952','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 19:29:01',0,NULL,3,1,1,1,NULL,'2009bikeman\rZHUANG'),(6847,650885406001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','synthesis','propq@hotmail.com','Quintin Erasmus','35 River Drive Mews,<br>The Circus ave, Three Rivers','Vereeniging','Gauteng','SOUTH AFRICA','1935','+27839557246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 19:47:04',0,NULL,3,1,2,1,NULL,'synthesis\r\\'),(6848,650842510001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','andreatoth22','andrea.toth@st.t-com.hr','Andrea Toth','Kroz Smrdečac 11','Split','AZ','CROATIA','21000','+385993000309','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-24 18:19:17',0,NULL,3,1,3,1,NULL,'andreatoth22\rRA022496003CN'),(6849,650937662001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',2,'AC1204',15.8,'hermeshine','travelindaze','islands_11@earthlink.net','Lata Lightsey','1606 Phelps Rd','Courtland','MS','UNITED STATES','38620','(662) 934-0765','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:22:32',0,NULL,3,1,1,1,NULL,'travelindaze\r\\'),(6850,0,110665503034,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:36',0,NULL,8,1,17,0,NULL,'ragginghoe'),(6851,0,130500956771,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:37',0,NULL,8,1,17,0,NULL,''),(6852,0,110665498129,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:38',0,NULL,8,1,17,0,NULL,'ragginghoe'),(6853,0,130500956952,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:38',0,NULL,8,1,17,0,NULL,'ragginghoe'),(6854,0,130500957195,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:39',0,NULL,8,1,17,0,NULL,'ragginghoe'),(6855,0,110665498884,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:40',0,NULL,8,1,17,0,NULL,'ragginghoe'),(6856,0,130500955020,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:40',0,NULL,8,1,17,0,NULL,'ragginghoe'),(6857,0,130500957362,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:41',0,NULL,8,1,17,0,NULL,'ragginghoe'),(6858,0,120702381909,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:41',0,NULL,3,1,1,1,NULL,'ragginghoe\rCANON 镜头盖  58mm  4\r绿叶 UV  58mm   5\r\\'),(6859,691386255002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','magugwana','gugulakhe@hotmail.com','Gugulethu Sibiya','P O Box 30540','Richards Bay','KwaZulu Natal','SOUTH AFRICA','3900','0839810238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 19:46:58',0,NULL,3,1,3,1,NULL,'magugwana\r潘\rRA022492386CN\r\\'),(6860,650964630001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','onlineshop*2009','ivantocao@live.com.ph','ivan tocao','unionbank of the philippines<br>quibod complex, rizal street','davao city','davao del sur','PHILIPPINES','8000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 22:47:39',0,NULL,8,1,17,0,NULL,''),(6861,648670230018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','dmalhaz','rn3qc@mail.ru','Sergey Chernykh','Vokzalnaya 53','Voronezh','','RUSSIAN FEDERATION','394024','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-24 22:48:27',0,NULL,3,1,5,1,NULL,'dmalhaz\rCP226379475CN\r'),(6862,650974731001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','onlineshop*2009','ivantocao@live.com.ph','ivan tocao','unionbank of the philippines<br>quibod complex, rizal street','davao city','davao del sur','PHILIPPINES','8000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 23:20:56',0,NULL,3,1,2,1,NULL,'onlineshop*2009\r52-52mm 双阳环  1\rnikon 反接环  52mm   1\r\\'),(6863,691396679002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','trikerexcalibur','guenther@chello.at','Günther Moro','Hillerstrasse 6/7','Wien','','AUSTRIA','A-1020','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-24 20:06:02',0,NULL,3,0,3,1,NULL,'trikerexcalibur\rXXL\rRA022494373CN'),(6864,0,130500955593,'New 62mm Rubber 3in1 Collapsible Lens Hood',1,'AB1304',0.3,'hermeshine','fsgor','fainasamg@gmail.com','Semen Gorelov','6627 N Mozart St','Chicago','IL','UNITED STATES','60645-4307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 00:28:13',0,NULL,3,1,1,1,NULL,'fsgor'),(6865,0,120702380945,'New 55mm Rubber 3in1 Collapsible Lens Hood',1,'AB1302',0.01,'hermeshine','arrielle78','homeyertx@yahoo.com','Arrielle Homeyer','532 17th st','niagara falls','NY','UNITED STATES','14301-2216','(716) 345-0814','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 00:42:44',0,NULL,3,1,1,1,NULL,'arrielle78'),(6866,650895096001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','aok_antti','antti.kansala@gmail.com','Antti Känsälä','Louhentie 13 a 3','Espoo','Espoo','FINLAND','02130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 20:05:18',0,NULL,3,1,3,1,NULL,'aok_antti\rRA022491916CN\r'),(6867,0,130500956587,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.3,'hermeshine','myhustle09','vietcrimeboss@yahoo.com','James Vu','1556 Spruce st','Placentia','CA','UNITED STATES','92870','(626) 533-6391','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 01:11:13',0,NULL,3,1,1,1,NULL,'myhustle09'),(6875,691439867002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,8,1,17,0,NULL,'datoow78'),(6868,758499071015,250621659362,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','farhangroosta','farhang_roosta@yahoo.com','farhang roosta','Friskväderstorget 4 läg 421','Göteborg','Göteborg','SWEDEN','41838','0046-31-3307327','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-24 21:24:05',0,NULL,3,1,2,1,NULL,'farhangroosta\r\\'),(6869,0,110665497444,'New 55mm Rubber 3in1 Collapsible Lens Hood',1,'AB1302',0.01,'hermeshine','arx808','weondaair808@aol.com','Lorelie Arcalas','94-693 Kupuna Loop','Waipahu','HI','UNITED STATES','96797-1120','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 01:31:16',0,NULL,3,1,1,1,NULL,'arx808\r\\'),(6874,650762587001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',2,'AA1202',56.03,'hermeshine','nightdesigner1981','nightdesigners@gmail.com','Liubou Kazakova','Денисовская, 41-2-5','Минск','','BELARUS','220006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 02:06:51',0,NULL,3,1,3,1,' ','nightdesigner1981\rRA022494395CN\r\\\r'),(6870,650935282001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','PayPalPaymentInProcess','CheckoutComplete','AU_SmallParcels','0000-00-00 00:00:00',0,NULL,3,1,4,1,NULL,'datoow78\r大力夹   1\r80cm 2in1 反光板   1\r反光板支架   1\r斜臂    1\rboom arm $25\rYW864871526CN\r\r'),(6871,0,120700660253,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',1.99,'hermeshine','tapdure','mondzeu_v@yahoo.com','Francis Seftel','87 Fairway Drive','Daly City','CA','UNITED STATES','94015','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 01:44:27',0,NULL,3,1,1,1,NULL,'tapdure\r\\'),(6872,650937525001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,8,1,17,0,NULL,'datoow78'),(6873,691439996002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,8,1,17,0,NULL,'datoow78'),(6876,0,130500958384,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',0.01,'hermeshine','jayceew','jcwumail@gmail.com','Jinchong Wu','123 Golden Meadow Ln','Franklin','TN','UNITED STATES','37067','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 04:17:25',0,NULL,3,1,1,1,NULL,'jayceew'),(6877,691477665002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','denybarboza','denyzinho@gmail.com','Paulo Cesar Neves Barboza','Rua Ver. Severo Ribeiro, 912<br>Três Vendas','Pelotas','Rio Grande do Sul','BRAZIL','96020-620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 23:15:51',0,NULL,3,1,3,1,NULL,'denybarboza\r\\\rRA022492134CN\r'),(6878,0,130500251599,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','T Le','107 Springville Ave','Buffalo','NY','UNITED STATES','14226-3117','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 04:39:34',0,NULL,3,0,1,1,NULL,'usa_global_trader'),(6879,650966613001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','gfcodo','gianfrancocod@tiscali.it','Gianfranco Codognotto - PROTEAM Srl','Via 25 Aprile, n° 51','BARLASSINA','MI','ITALY','20825','3289646230','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-24 22:56:37',0,NULL,3,1,3,1,NULL,'gfcodo\rreflector holder  $15\rRA022492103CN\r\\'),(6880,650992852001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','phan2om','sudden@gmail.com','Stephan Witane','106 Lindvest Crescent','Maple','ON','CANADA','L6A 4N2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 00:29:58',0,NULL,3,1,2,1,NULL,'phan2om\r\\'),(6881,758581583015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','bob9038','b_alam9038@msn.com','bobby alam','44 gooseley lane','east ham','London','UNITED KINGDOM','e66ap','02085489038','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 00:42:20',0,NULL,3,1,4,1,NULL,'bob9038\r柔光箱 60-60cm  四灯头  2\rlight  $22\rYW864871515CN\r'),(6882,758396232015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.39,'hutongstore','rafal6767','kkkwiatuszek@poczta.fm','Rafal Kwiatkowski','36 Burlington Road','Coventry','West Midlands','UNITED KINGDOM','CV2 4QH','07727249258','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 05:57:50',0,NULL,3,1,2,1,NULL,'rafal6767\r\\'),(6883,758519159015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','james670_0','jamescombe@supanet.com','James Combe','7 Spey Road Craigellachie  Aberlour','Elgin','Moray','UNITED KINGDOM','ab389ta','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 23:47:49',0,NULL,3,1,2,1,NULL,'james670_0\r\\'),(6884,758563088015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','bob9038','b_alam9038@msn.com','bobby alam','44 gooseley lane','east ham','London','UNITED KINGDOM','e66ap','02085489038','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 23:48:19',0,NULL,8,1,17,0,NULL,'bob9038'),(6885,651067838001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','vlinder301','sgsub@earthlink.net','Suzanne Gedance','232 Wakeman Ave','Wheaton','IL','UNITED STATES','60187-3664','(630) 588-8533','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 07:15:01',0,NULL,3,1,1,1,NULL,'vlinder301'),(6886,651072247001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','markobaric','marko_baric@yahoo.com','Marko Baric','Hektoroviceva 11B','Solin','Splitsko-dalmatinska','CROATIA','21210','021-244-346','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 07:40:58',0,NULL,3,1,3,1,NULL,'markobaric\r\\\rRA022491981CN\r'),(6887,743449611016,260660055167,'18% Gray card set 8x6\" 6x4\" for White balance exposure',3,'AA2217',20.85,'hutongstore','futureshop.fi','smartbuy.fi@gmail.com','Vladimir Novikov','Karstulantie 10 A 5','Helsinki','Uusimaa','FINLAND','00550','0451224100','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-25 08:09:22',0,NULL,3,1,3,1,NULL,'futureshop.fi\rRA022492001CN\r\\'),(6889,651050591001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','migggo','m.junttila@ovi.com','Mikko junttila','Kurkihirrentie 3C22','Oulu','','FINLAND','90540','358451271086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 05:10:04',0,NULL,3,1,2,1,NULL,'migggo'),(6888,651087801001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','godzila-zk','godzilazk@seznam.cz','Zdeněk Krňanský','Tloskovská 248','Neveklov','','CZECH REPUBLIC','25756','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 08:58:53',0,NULL,3,0,3,1,NULL,'godzila-zk\r发 52mm CPL+ND8+Macro+2 +Gradual grey+filter case \r潘\r刘\rRA022492284CN\r'),(6890,691604433002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','mamaneos','majikm@azet.sk','Ing. Marian Majik','3 Allee des Charmes','Luxembourg','','LUXEMBOURG','L-1372','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 09:15:54',0,NULL,3,1,2,1,NULL,'mamaneos\r、'),(6891,651054801001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','shenker123','shenkerbay@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 05:43:49',0,NULL,3,1,3,1,NULL,'shenker123\rRA022492094CN'),(6892,691609318002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','2011*annak','farciara84@wp.pl','anna kramek','40 woodview','castlebridge','Wexford','IRELAND','1','0871466066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 09:29:31',0,NULL,3,1,2,1,NULL,'2011*annak\r、'),(6893,651059113001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',18.99,'hermeshine','nabelrock','marcusbabao@yahoo.com','Marcus Babao','Blk 627 Yishun Street 61, #09-79, Singapore','default','','SINGAPORE','560627','(65)92311107','NoPaymentFailure','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,0,3,1,NULL,'nabelrock\rRA022492085CN\r、加到这行了'),(6894,651060041001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','susu361','suhairie@gmail.com','suhairi suhadah','Hong Leong Investment Bank Berhad<br>Level 8, Menara HLA, No. 3 Jalan Kia Peng','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','50450','0123992524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 06:22:38',0,NULL,3,1,2,1,NULL,'susu361'),(6895,651097640001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','arteemusica','mirbus@libero.it','Mirko Buschiazzo','C.so Sebastopoli 240','Torino','TO','ITALY','10100','3476826031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 09:46:07',0,NULL,3,1,2,1,NULL,'arteemusica\r、'),(6896,651113689001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',2,'AD1401',19.8,'hermeshine','gulbrandtang','gulbrand.tangen@c2i.net','Gulbrand Tangen','Brennivegen 45','Algarheim','','NORWAY','2056','+4763976867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 10:55:38',0,NULL,3,1,11,1,NULL,'gulbrandtang'),(6897,691263151002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','lenagon','lena.goncharov@gmail.com','Elena Goncharov','Ben Zvi Izhak12/41','K.Mozkin','','ISRAEL','26230','972544475325','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 04:59:51',0,NULL,3,1,3,1,NULL,'\rRA022492117CN\rlenagon'),(6898,648847294018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','xavifrias','xfriasahs@yahoo.es','Xavier Frias Garrido','Iris 15<br>Martí Julià 11-17','BADALONA','Cataluña','SPAIN','08911','934642711','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-25 12:24:12',0,NULL,3,1,4,1,NULL,'xavifrias\r2m 背景架   1\r1.6x2.1  背景布 （ 白 黑）\rYW864488384CN\r'),(6899,691651268002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','raqmaci2010','raqmaci@hotmail.com','Raquel Macías Cabrera','Tirso de Molina, 18, 2ºD','Valladolid','Castilla y León','SPAIN','47010','983258813','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 12:35:03',0,NULL,3,1,2,1,NULL,'raqmaci2010'),(6900,758795212015,250692242296,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'AA3314',4.68,'hutongstore','iwanoff81','iwanfokin@yahoo.com','Iwan Fokin','van alkemadelaan 359','Den Haag','','NETHERLANDS','2597BA','0619552505','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-25 14:04:37',0,NULL,3,1,2,1,NULL,'iwanoff81'),(6901,691671753002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','a.buragohain','aburagohain@gmail.com','Apratim Buragohain','Samsung India Software Operations, JP Techno Park, 3/1 Miller\'s Road','Bangalore','Karnataka','INDIA','560052','9008127000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 13:51:07',0,NULL,3,1,3,1,NULL,'a.buragohain\rRA022491690CN、'),(6902,651159960001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','a.buragohain','aburagohain@gmail.com','Apratim Buragohain','Samsung India Software Operations, JP Techno Park, 3/1 Miller\'s Road','Bangalore','Karnataka','INDIA','560052','9008127000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 13:51:06',0,NULL,3,1,3,1,NULL,'a.buragohain\rRA022491743CN、'),(6903,651161778001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','glenviewpark','panola.carter@gmail.com','Panola Carter III','2462 Zanone Ave','Memphis','TN','UNITED STATES','38114-2463','','NoPaymentFailure','CheckoutComplete','Other','2011-03-25 13:55:14',0,NULL,3,1,3,1,NULL,'glenviewpark\rRA022491726CN、'),(6904,651170994001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','regon7','jotafoto@yahoo.es','Francisco Javier Replinger Gonzalez','C/ Opera Carmen 65- 3ºB<br>Eurohogar II','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41007','687790888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 14:25:49',0,NULL,3,1,2,1,NULL,'regon7'),(6905,691661726002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','diavoletto1985','diavoletto85@yahoo.it','Stefano Messerville','Viale Madrid cond. ITALCO 4C','Frosinone','FR','ITALY','03100','3807972732','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 13:20:41',0,NULL,3,1,3,1,NULL,'diavoletto1985\rRA022491788CN、'),(6906,0,120702823957,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.01,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:41:15',0,NULL,8,1,17,0,NULL,'elmster1st'),(6907,0,110665938748,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.01,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:41:19',0,NULL,8,1,17,0,NULL,'elmster1st'),(6908,0,130501322310,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.16,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:41:22',0,NULL,8,1,17,0,NULL,'elmster1st'),(6909,0,110665932682,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.06,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 14:41:22',0,NULL,8,1,17,0,NULL,'elmster1st'),(6910,0,130501318196,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.06,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 14:41:26',0,NULL,8,1,17,0,NULL,'elmster1st'),(6911,0,120702819181,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.06,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 14:41:26',0,NULL,8,1,17,0,NULL,'elmster1st'),(6912,0,110665933257,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.06,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 14:41:30',0,NULL,8,1,17,0,NULL,'elmster1st'),(6913,0,120702823792,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.01,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:41:31',0,NULL,3,1,1,1,NULL,'elmster1st\rNIKON 镜头盖 52mm   4\rNIKON 镜头盖 62mm   4'),(6914,691690666002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','sousamlis','sousamli@hol.gr','Petros Sousamlis','Mirogianni 2A','Mitilini','','GREECE','81100','302251023728','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 14:36:36',0,NULL,3,1,4,1,NULL,'sousamlis\r欧标\rYW864488373CN\r'),(6915,758712509015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','neilukd','neildharris@sky.com','Neil Harris','23 Jardine Close','Stourbridge','West Midlands','UNITED KINGDOM','DY8 4AT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 09:55:52',0,NULL,3,0,3,1,NULL,'neilukd\rRA022491933CN'),(6916,691698314002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','antoshka8877','a.n.t.o.s.h.k.a@mail.ru','Антон Джавадян','ул. Набережная, д.59','Пятигорск','Ставропольский край','RUSSIAN FEDERATION','357500','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 15:01:15',0,NULL,3,1,3,1,NULL,'antoshka8877\rRA022491448CN、'),(6917,651209540001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','gil540','gillesdemenois@wanadoo.fr','GILLES   DEMENOIS','540 RUE DE DONNERY','MARDIE','Centre','FRANCE','45430','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 16:22:32',0,NULL,3,1,3,1,NULL,'gil540\r、\rRA022491902CN'),(6918,648928361018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','erminbeg1','erminbeg@gmail.com','Begovic Ermin','Porodice Foht 82','Sarajevo','Sarajevo','BOSNIA AND HERZEGOVINA','71000','+38762105157','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-25 16:23:04',0,NULL,3,1,5,1,NULL,'erminbeg1\r1.6m 背景架  1\r白 黑  1.6x2.1\r申报 gift  $10\rCP226379484CN\r'),(6919,0,130500954588,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','mrscat70','kats1964@yahoo.com','Kimberly Hazzard','155 E Monroe St','Auburn','IL','UNITED STATES','62615-1523','(217) 960-3517','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 17:00:23',0,NULL,3,1,1,1,NULL,'mrscat70'),(6920,0,120702820986,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.11,'hermeshine','carlosvincenzo','carlosdv@microsoft.com','Carlos De Vincenzo','9012 229th PL NE','Redmond','WA','UNITED STATES','98053-2067','(425) 836-9309','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 17:03:12',0,NULL,3,1,1,1,NULL,'carlosvincenzo'),(6921,691803124002,120566694530,'Neoprene Protector Camera Cover  for Nikon Size: Large ',1,'AC1303',7.5,'hermeshine','bglytle','blytle@ups.com','Brooke Lytle','15 Ogden Ter','Butler','NJ','UNITED STATES','07405','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 19:25:34',0,NULL,3,1,1,1,NULL,'bglytle'),(6922,651011602001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',68.3,'hermeshine','konischev','paraidey@yandex.ru','Maxim Konischev','N. Ostrovskogo St.<br>162/1, 104','Astrakhan','','RUSSIAN FEDERATION','414022','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 15:25:35',0,NULL,3,1,3,1,NULL,'konischev\r反光板支架  1   \r肩架   1 \r发两个小包给他\rRA022491880CN\rRA022492205CN'),(6923,651309327001,110618902967,'Pro Photo Vest Blue for Canon 500D 550D 7D 60D  user',1,'AA2116',32,'hermeshine','btf5a','bradfoster@comcast.net','Bradley Foster','501 Enola Rd.','Pikesville','MD','UNITED STATES','21208','','NoPaymentFailure','CheckoutComplete','Other','2011-03-25 20:17:01',0,NULL,3,1,1,1,NULL,'btf5a\rxxl'),(6924,758988437015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','optiker72','waznyadres@gmail.com','Peter Kanka, Bush Opticians Laboratory','337 Holderness Road','Hull','North Yorkshire','UNITED KINGDOM','HU8 8RD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 20:34:05',0,NULL,3,1,3,1,NULL,'optiker72\rRA022491862CN\r、'),(6925,651231864001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',10,'AA3301',27.5,'hermeshine','elpeladoedu','enocetti@adinet.com.uy','EDUARDO NOCETTI','AVDA  RONDEAU  1470','MONTEVIDEO','','URUGUAY','11100','59829029106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 20:35:37',0,NULL,3,1,3,1,NULL,'elpeladoedu\rRA022491261CN、'),(6926,651337295001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','ishkabibble','john_stephenson@bellsouth.net','John W. Stephenson','340 Swan Dr','Brandon','MS','UNITED STATES','39047-6729','','NoPaymentFailure','CheckoutComplete','Other','2011-03-25 21:24:04',0,NULL,3,0,1,1,NULL,'ishkabibble\rXXXL'),(6927,691822340002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','donkafkas','akin@balcab.ch','Enrico Akin','Postfach','Basel','','SWITZERLAND','4005','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 21:26:55',0,NULL,3,1,2,1,NULL,'donkafkas'),(6928,650831301001,110664971677,'GGS Glass LCD Screen Protector for Canon 50D 5DII',2,'AB2211',100.2,'hermeshine','expertsourcing','cvaleriu@gmail.com','Valeriu Crangus','P.O.Box 41-6<br>Sector 1','Bucharest','Bucharest','ROMANIA','011252','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 19:21:19',0,NULL,3,1,4,1,NULL,'expertsourcing\r2m 灯架  2\r双灯头   欧标  2\r反光伞   2\r包   1\rggs 50d   保护屏   2\rYW864488362CN\r'),(6929,0,130501320084,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','arx808','weondaair808@aol.com','Jared Arcalas','94-693 Kupuna Loop','Waipahu','HI','UNITED STATES','96797-1120','(808) 383-8412','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 00:56:09',0,NULL,8,1,17,0,NULL,'arx808'),(6930,0,110665936369,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','arx808','weondaair808@aol.com','Jared Arcalas','94-693 Kupuna Loop','Waipahu','HI','UNITED STATES','96797-1120','(808) 383-8412','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 00:56:09',0,NULL,3,1,1,1,NULL,'arx808\r绿叶 UV  58mm   2'),(6931,759000693015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.56,'hutongstore','satin-silk','mygarnette@netscape.net','Michael Garnette','490 Watford Way<br>Mill Hill','London','London','UNITED KINGDOM','NW7 2PX','07956375805','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 20:56:42',0,NULL,3,1,2,1,NULL,'satin-silk'),(6932,691900407002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','jimhanseng','jim@hansenlan.com','James Hansen','3 Sardania CT','Sacramento','CA','UNITED STATES','95831','','NoPaymentFailure','CheckoutComplete','Other','2011-03-25 23:26:06',0,NULL,3,1,3,1,NULL,'jimhanseng\rRA022491791CN、'),(6933,0,120701916002,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 03:33:03',0,NULL,5,0,18,0,NULL,'segalu'),(6934,0,110665054987,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 03:33:04',0,NULL,5,0,18,0,NULL,'segalu'),(6935,0,120701913339,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 03:33:04',0,NULL,5,0,18,0,NULL,'segalu'),(6936,651435723001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 03:40:59',0,NULL,3,1,1,1,NULL,'robert5525'),(6937,0,110664689678,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','Thu thi Le','PO Box 953','Getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 03:56:24',0,NULL,3,0,1,1,NULL,'usa_global_trader\r发ggs的麂皮'),(6938,0,130501317800,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.55,'hermeshine','linda4490','linda4490@hotmail.com','Linda Ordonio-Dixon','572 Rose Dr','Benicia','CA','UNITED STATES','94510','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 04:30:41',0,NULL,3,1,1,1,NULL,'linda4490'),(6939,691971331002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','carlos4970','carlitus@three.com.au','Carlos Velasco','P.O. Box 7719<br>Bondi Beach','Sydney','New South Wales','AUSTRALIA','2026','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 04:34:15',0,NULL,3,1,3,1,NULL,'carlos4970\rRA022491522CN、'),(6940,0,120702819816,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','highbiddergent','richard@powertranstechinc.com','Stephanie Sedlacek','PO Box 573<br>170236 Co Rd 37','Bayard','NE','UNITED STATES','69334-0573','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 06:01:12',0,NULL,3,1,1,1,NULL,'highbiddergent'),(6941,651459198001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',2,'AKT059',70,'hermeshine','dlikane','dlikane@tpg.com.au','Dmitry Likane C/O Anatoli Likane','8a Yendon Rd','CARNEGIE','Victoria','AUSTRALIA','3163','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 06:27:48',0,NULL,3,1,3,1,NULL,'dlikane\r注意一共10个220v的（XU:220V？）\rRA022491814CN、'),(6942,651467201001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','spikingsdj','djspikings@gmail.com','David Spikings','14376 Pinnacle Ct.','Canyon Country','CA','UNITED STATES','91387','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 07:18:58',0,NULL,3,1,1,1,NULL,'spikingsdj'),(6943,743744679016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','pultik','marat@ru66.ru','Marat Saitov','Sinyaeva st - 8/103','Yekaterinburg','RU','RUSSIAN FEDERATION','620028','+7 905 801 38 71','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 07:25:49',0,NULL,3,1,2,1,NULL,'pultik'),(6944,651476404001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','greensokol','anpoch@mail.ru','Anna Mambetova','pr. Slavy 52-1 1392','St. Petersburg','St Petersburg','RUSSIAN FEDERATION','192241','+7-911-245-70-29','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 08:18:42',0,NULL,3,1,2,1,NULL,'greensokol'),(6945,0,110665936162,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','naturalseagifts','daydreamingthatsme@yahoo.com','keri dapron','2896 Biscaya Dr','Laughlin','NV','UNITED STATES','89029','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 08:52:16',0,NULL,3,1,1,1,NULL,'naturalseagifts'),(6946,759230299015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','menimm','marcin@mackowiak.name','Marcin Mackowiak','6 Wild Green South','Langley, Slough','Berkshire','UNITED KINGDOM','SL38NT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 10:16:10',0,NULL,3,1,2,1,NULL,'menimm'),(6947,692045814002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','iceman183','steve.c.reid@gmail.com','Stephen Reid','Unit 7<br>96 Edgecumbe Street','Como','Western Australia','AUSTRALIA','6152','0468957498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 10:46:57',0,NULL,3,1,4,1,NULL,'iceman183\rlight set   $22\rYW864488351CN\r'),(6948,759264501015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','grubydzordz','krzysztof-dobrzynski@wp.pl','Krzysztof Dobrzynski','2 West Farm Cottage<br>Bincombe','Weymouth','Dorset','UNITED KINGDOM','DT35PS','07955020734','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 11:55:14',0,NULL,3,0,2,1,NULL,'grubydzordz\r黑色'),(6949,744036046016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','dandins04','evija_2@inbox.lv','Ingus Stepans','31 adnitt road','Northampton','Northamptonshire','UNITED KINGDOM','nn14ll','07556126436','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 12:47:26',0,NULL,3,1,2,1,NULL,'dandins04'),(6950,692087949002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','soontornta4918','soontornta@gmail.com','Mr. Soontorn Tachasakulnapaporn','64/11 M.2  Vibhawadee rd.,<br>Thungsonghong, Laksi','Bangkok','Thai','THAILAND','10210','(66)089-7628989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 13:05:54',0,NULL,3,1,2,1,NULL,'soontornta4918'),(6951,691584174002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','hrenokop','hrenocop@gmail.com','Pavel Tsarev','2 Viktora Gakuna, Appartment 19','Kaliningrad','','RUSSIAN FEDERATION','236000','7-905-249-07-68','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 15:48:48',0,NULL,3,1,2,1,NULL,'hrenokop'),(6952,692158023002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'viong'),(6953,692069602002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','cichlasoma79','faceyourfear@web.de','Schneider Christian','kohlerstr. 17','Ravensburg','','GERMANY','88214','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 16:22:08',0,NULL,3,1,4,1,NULL,'cichlasoma79\r1.6m的背景架 + 1.6x2.1 白色\rYW864488340CN\r'),(6954,692174173002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','lacalafoto','nornoreste@msn.com','  ventalles balfegó','C/. garbí  nº 9, barcelona','Canet de Mar - Barcelona','Cataluña','SPAIN','08360','937941552','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 16:41:56',0,NULL,3,1,3,1,NULL,'lacalafoto\rRA022491607CN、'),(6955,651653183001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','lacie64','normagetsmail@mchsi.com','Norma Williams','211 Mossie Rd','Wewahitchka','FL','UNITED STATES','32465-7329','(850) 532-4626','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 17:09:36',0,NULL,3,1,1,1,NULL,'lacie64\r黄色logo的'),(6956,651661182001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','coldlocoman','anderson_harlen@yahoo.com.br','Fernanda Mota','rua dos cravos,426<br>inacio barbosa','Aracaju','Sergipe','BRAZIL','49040-140','055 21 79 8139 7614','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 17:33:07',0,NULL,3,1,3,1,NULL,'coldlocoman\rRA022491598CN、'),(6957,651672297001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','sergey_gorkiy_city','zykov.sergey87@gmail.com','Sergey Zykov','Lenina st.  45/161','Nizhniy Novgorod','RU','RUSSIAN FEDERATION','603135','+7-930-701-70-01','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 17:50:50',0,NULL,3,1,2,1,NULL,'sergey_gorkiy_city'),(6958,649415820018,280556434923,'Background Support & 10x20ft Green Screen LightKit 3x6m',1,'AKT065',124,'photographyacc','sunandheir','elliechenderson@googlemail.com','Heloise Henderson','210 Peckham Rye','East Dulwich','London','UNITED KINGDOM','SE22 0LU','02086930511','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-26 18:22:40',0,NULL,3,1,4,1,NULL,'sunandheir\r英标\rYW864488336CN\r'),(6959,759520933015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.5,'hutongstore','omplantning','aatonder@gmail.com','Alexander Tønder','Vorrevej 19','Skødstrup','Østjylland','DENMARK','8541','25154416','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 19:49:57',0,NULL,3,1,2,1,NULL,'omplantning'),(6960,759538546015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','lauriha56','han2lau@gmail.com','Hannu Rytky','Mieluskylantie 182','Haapavesi','','FINLAND','86600','+358503516049','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 20:15:58',0,NULL,3,1,3,1,NULL,'lauriha56\rRA022491805CN\r、'),(6961,651769793001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',3,'AKT007',56.97,'hermeshine','dm-pal','dmpal@yandex.ru','Dmitriy Palyanov','Zavodskaya, 24a-55','Kondopoga','Karelia','RUSSIAN FEDERATION','186220','+79214501223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 20:53:12',0,NULL,3,1,3,1,NULL,'dm-pal\r注意是6个灯泡\rRA022491482CN、'),(6962,651769725001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','stermix22','makrigar@hotmail.com','Maurizio  K. Gargiulo','Rua Alice nr 278 / ap 301<br>Laranjeiras','Rio de Janeiro','Rio de Janeiro','BRAZIL','22241-020','(21) 2556-7547','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 20:55:05',0,NULL,3,1,5,1,NULL,'stermix22\rCP226379498CN\r'),(6963,692309899002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','jagacek','zbyszek@bieleniewicz.com','Zbigniew Bieleniewicz','ul. Gdanska 5a/5','Elk','warmińsko-mazurskie','POLAND','19-300','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 21:03:40',0,NULL,3,1,5,1,NULL,'jagacek\rCP226379515CN\r'),(6964,692309171002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','tamkam','tamkamvideo@gmail.com','Tamara McQuade','12007 Old Salem Church Rd','Locust Grove','VA','UNITED STATES','22407','(540) 419-8228','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 21:07:06',0,NULL,3,1,1,1,NULL,'tamkam'),(6965,651788540001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','jonathanlewald','jonathanlewald@hotmail.com','Jonathan Lewald','Hallebergsvägen 11 (3tr)','Bromma','Stockholm','SWEDEN','SE-16737','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 21:34:48',0,NULL,3,1,3,1,NULL,'jonathanlewald\r橡胶遮光罩 58mm   1\r肩架    1\rRA022491615CN、'),(6966,651791193001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','jonathanlewald','jonathanlewald@hotmail.com','Jonathan Lewald','Hallebergsvägen 11 (3tr)','Bromma','Stockholm','SWEDEN','SE-16737','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 21:40:53',0,NULL,8,1,17,0,NULL,'jonathanlewald'),(6967,744336019016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',120,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 21:52:26',0,NULL,3,1,4,1,NULL,'leifs123\r欧标 lighting kit $30\rYW864488421CN\r'),(6968,692194697002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',61.99,'hermeshine','kalapachito','monte.cuco@hotmail.com','JOSE ANTONIO RODRIGO ESPADA','C/SAN ANTON 11, BLQ.1-BAJO','PLASENCIA','Extremadura','SPAIN','10600','676959917','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 22:16:00',0,NULL,3,1,4,1,NULL,'kalapachito\rtripod  $16\rYW864488410CN\r'),(6969,744354391016,260660055182,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',15,'hutongstore','bmscdk','bcll@dbmail.dk','Brian Christensen','Frederikssundsvej 410,2tv','Brønshøj','Denmark','DENMARK','2700','(045)60116735','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 22:30:29',0,NULL,3,1,2,1,NULL,'bmscdk'),(6970,759625740015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.55,'hutongstore','beserker0','timmaidens@bulldoghome.com','Timothy Maidens','11 Sherwood Place','Hemel Hempstead','Hertfordshire','UNITED KINGDOM','HP26PS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 22:59:19',0,NULL,3,1,2,1,NULL,'beserker0'),(6971,651787693001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','olga_j','t_janicki@live.co.uk','tomasz janicki','30 poppy close','london','London','UNITED KINGDOM','ub55tp','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 23:01:42',0,NULL,3,1,3,1,NULL,'olga_j\rRA022491709CN、'),(6972,692371232002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','bearw00d','eddyrademaker@gmail.com','Edward M Rademaker','9 Cocus Crescent','Palm Cove','Queensland','AUSTRALIA','4879','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-03-26 23:41:16',0,NULL,3,0,3,1,NULL,'bearw00d\r1.6x2.1  背景布  2 （ 白 黑）\rRA022491425CN、'),(6973,0,130500252054,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','T Le','po box 953','getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 23:54:03',0,NULL,3,0,1,1,NULL,'usa_global_trader\r发ggs的麂皮'),(6974,651853623001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',3.79,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:12',0,NULL,8,1,17,0,NULL,'sze_ling'),(6975,692392557002,120568891550,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',2.6,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:12',0,NULL,8,1,17,0,NULL,'sze_ling'),(6976,692393005002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:13',0,NULL,8,1,17,0,NULL,'sze_ling'),(6977,692396497002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:13',0,NULL,8,1,17,0,NULL,'sze_ling'),(6978,651856236001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:14',0,NULL,8,1,17,0,NULL,'sze_ling\r'),(6979,651852965001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:15',0,NULL,3,1,3,1,NULL,'sze_ling\r橡胶遮光罩 52mm   1\r橡胶遮光罩 62mm  1\rNIKON 镜头盖 52mm   1\rNIKON 镜头盖 77mm  1\r中号内胆包 nikon   1\r大号内胆包 nikon   1\rRA022491893CN、'),(6980,651890204001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',5,'AKT007',94.95,'hermeshine','gj95600','gj_95600@hotmail.com','Guillaume Depestèle','14 rue Suzanne','Eaubonne','Île-de-France','FRANCE','95600','01.39.59.95.27','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'gj95600\r注意是10个\rRA022491774CN、'),(6981,692472207002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',40,'AA1310',219.6,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 07:29:43',0,NULL,3,1,3,1,NULL,'blinker-182\rRA022491434CN、'),(6982,651953301001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','marcusfluvius','kadoelen141@hotmail.com','Marc van Beek','Roostenlaan 150','Eindhoven','','NETHERLANDS','5644GJ','31402437291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 09:03:36',0,NULL,3,1,2,1,NULL,'marcusfluvius'),(6983,759804318015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','sundberglarsson','thomas.sundberg@hotmail.com','Thomas Sundberg','Tjärn 120','Arnäsvall','Västernorrland','SWEDEN','89195','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-27 09:26:57',0,NULL,3,0,4,1,NULL,'sundberglarsson\r背景架 （ 白 黑 绿)   1\r2m的没有了，就发1.6m的给他\r庄+王\rYW864488465CN\r\r'),(6984,744543701016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','sundberglarsson','thomas.sundberg@hotmail.com','Thomas Sundberg','Tjärn 120','Arnäsvall','Västernorrland','SWEDEN','89195','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-27 09:41:01',0,NULL,8,0,17,0,NULL,'sundberglarsson'),(6985,759820029015,250692237477,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',15.5,'hutongstore','tomek2009rafal','nowy84nrlondyn@interia.pl','rafal nowotnik','2 dundonald close','beckton','London','UNITED KINGDOM','e6 5ru','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 09:54:12',0,NULL,3,1,2,1,NULL,'tomek2009rafal\r英标'),(6986,744574178016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','magica_hada','h_metal16@hotmail.com','Claudia Hurtado Hurtado','Avd. Sants De La Pedra 22','Sagunto','Comunidad Valenciana','SPAIN','46500','607241479','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-27 10:58:50',0,NULL,3,1,4,1,NULL,'magica_hada\rYW864488406CN\r'),(6987,652002558001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','loboau_au','flovibagar@yahoo.es','Florian Vicente Bazataqui Garcia','virgen de lourdes nº 7 bajo derecha','puerto sagunto','Comunidad Valenciana','SPAIN','46520','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 11:16:00',0,NULL,3,1,2,1,NULL,'loboau_au\r\\'),(6988,652015443001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','edu139','eduardo.arranz@hotmail.com','eduardo arranz','cl las monjas, 10 3ºC','palencia','Castilla y León','SPAIN','34005','626363403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 11:54:09',0,NULL,8,1,17,0,NULL,'edu139'),(6989,692562785002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','edu139','eduardo.arranz@hotmail.com','eduardo arranz','cl las monjas, 10 3ºC','palencia','Castilla y León','SPAIN','34005','626363403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 11:54:10',0,NULL,3,1,11,1,NULL,'edu139\r反光伞    1\r柔光伞    1'),(6990,652075840001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','buchhauser','buchhauser1@freenet.de','Christian Buchhauser','Schönstraße 22a','Hallbergmoos','','GERMANY','85399','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 14:09:13',0,NULL,3,1,2,1,NULL,'buchhauser'),(6991,652030442001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','trava-if','trava_if@ukr.net','Taras Travinskyy','Volunska 34','Ivano-Frankivsk','','UKRAINE','76010','00380503731120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 14:15:58',0,NULL,3,1,2,1,NULL,'trava-if'),(6992,692627223002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',2,'AO0034',18,'hermeshine','rdvru','r-dimka@mail.ru','Dima Rebrov','Simonovskiy val 7-1-86','Moscow','Russia','RUSSIAN FEDERATION','109044','+79266298181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 14:16:51',0,NULL,3,1,2,1,NULL,'rdvru'),(6993,0,120702819656,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.24,'hermeshine','blond-n-blue','grethelindemann@aol.com','Grethe Lindemann','1021 W 6th St','Erie','PA','UNITED STATES','16507','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 14:26:10',0,NULL,3,0,1,1,NULL,'blond-n-blue\rCANON 镜头盖  58mm   3'),(6994,652084842001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 14:27:27',0,NULL,3,1,2,1,NULL,'viong'),(6995,651321295001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',23.6,'hermeshine','nikolayxxx','platovnikolay@gmail.com','Nikolay Platov','Zagorodniy per. 21/28','Vyazma','Smolenskaya obl','RUSSIAN FEDERATION','215110','+79057605564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 15:06:52',0,NULL,3,1,3,1,NULL,'nikolayxxx\r欧标\rRA022491417CN、'),(6996,652107208001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','sziga6','szi_ga@vipmail.hu','Gábor Szijártó','Rohonci 48','Szombathely','Vas','HUNGARY','9700','(36)305430541','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 15:14:07',0,NULL,3,1,3,1,NULL,'sziga6\rRA022491496CN、'),(6997,692672159002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','uuchip','uuchip@aliceposta.it','Daniele Simone','Via Manfredi, nr. 83/a','Monte Sant\'Angelo','Foggia','ITALY','71037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 15:41:39',0,NULL,3,1,2,1,NULL,'uuchip'),(6998,760042130015,250599989246,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200mm',1,'AC1204',4.38,'hutongstore','86948','johnward35a@hotmail.co.uk','john ward','35a aranmore avenue','londonderry','Londonderry','UNITED KINGDOM','BT489TS','02871288940','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 16:15:46',0,NULL,3,1,2,1,NULL,'86948'),(6999,652152023001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','gmiethig','gerhard.m@sympatico.ca','Gerhard Miethig','50 Lombard St<br>Suite 2102','Toronto','ON','CANADA','M5C2X4','(416) 363-9086','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 16:23:35',0,NULL,3,1,2,1,NULL,'gmiethig'),(7000,760070478015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','esty2002','jana_parker1@yahoo.co.uk','Jana Parker','Urb Jardin Botanico Fase 3<br>Bloque 5, apt 5B','Cala de Mijas','Andalucía Ceuta y Melilla','SPAIN','29649','608658197','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-27 16:47:55',0,NULL,3,1,4,1,NULL,'esty2002\r欧标\rlighting kit  $30\rYW864488395CN\r'),(7001,692723234002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','shaharstroh','shaharstroh@gmail.com','Shahar Stroh','4546 Winnetka Cir','Woodland Hills','CA','UNITED STATES','91364-4614','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 16:57:07',0,NULL,3,1,1,1,NULL,'shaharstroh'),(7002,692741253002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',22.9,'hermeshine','ag_presentz','barathaanushka@yahoo.com','Anushka Gunasinghe','21-6 New Hospital Rd, Pamunuwa<br>Maharagama','Colombo','Western','SRI LANKA','0094','+94-719331387','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 17:19:30',0,NULL,8,1,17,0,NULL,'ag_presentz'),(7003,652200078001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','ag_presentz','barathaanushka@yahoo.com','Anushka Gunasinghe','21-6 New Hospital Rd, Pamunuwa<br>Maharagama','Colombo','Western','SRI LANKA','0094','+94-719331387','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 17:27:34',0,NULL,3,0,3,1,NULL,'ag_presentz\r摄影背心 绿色薄 nikon XXL  1\r摄影背心 夏  XL   1\rRA022491730CN、'),(7004,744835441016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.39,'hutongstore','timksophie','timispractising@googlemail.com','tim kitchen','6 glebelands road','tiverton','devon','UNITED KINGDOM','ex16 4eb','07890626014','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 17:33:27',0,NULL,3,1,2,1,NULL,'timksophie'),(7005,692819254002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','draghestar2006','dragonzord61@tiscali.it','Gabriele Sopranzi','Via filottrano N.7','Ancona','AN','ITALY','60126','3771581267','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 18:42:07',0,NULL,3,1,2,1,NULL,'draghestar2006'),(7006,652263748001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','fatimah.abdullah','fatimah.dollah@gmail.com','Fatimah Abdullah','Hankyu Hanshin Express Sdn Bhd, Lot D-8, Block D,<br>MAS Cargo Complex, KLIA Cargo Complex','KLIA','Selangor','MALAYSIA','64000','0163113265','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 18:44:07',0,NULL,3,1,2,1,NULL,'fatimah.abdullah'),(7007,652277850001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','jannehapponen','janne.happonen@gmail.com','Janne Happonen','Döbelninkatu 1 A 20','Helsinki','Uusimaa','FINLAND','00260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 18:47:16',0,NULL,3,1,2,1,NULL,'jannehapponen'),(7008,692912492002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','don604','don.middleton@dccnet.com','Don Middleton','889 Bayview Drive','Delta','BC','CANADA','V4M2R5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 20:10:40',0,NULL,3,1,2,1,NULL,'don604'),(7009,760338838015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','littlelambfound','jtpornstar@yahoo.com','Krajcsi Pal','Zrinyi ut 80/B','Batonyterenye','Nograd','HUNGARY','H-3078','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-27 20:30:45',0,NULL,3,1,3,1,NULL,'littlelambfound\rRA022491519CN、'),(7010,745061092016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',2,'AO0005',24,'hutongstore','purpleserpentgirl','purplesnakegirl@yahoo.com','Anne Duffy','14 Phoenix Pl Giralang','Canberra','Australian Capital Territory','AUSTRALIA','2617','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-27 20:33:24',0,NULL,3,0,3,1,NULL,'purpleserpentgirl\r1.6m x 3m 背景布   红色 + 粉色\rRA022491505CN、'),(7011,760348701015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',16,'hutongstore','schiller_dk','ms@definitivt.dk','Mark Schiller','Vosborgvej 30','Kastrup','','DENMARK','2770','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-27 20:44:56',0,NULL,3,1,3,1,NULL,'schiller_dk\r、RA022491712CN'),(7012,692963104002,120448640631,'62mm 62 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT021',4.87,'hermeshine','kim_hoerning','kim@benn.dk','Kim Benn','Brunhøj 37','Hørning','Jylland','DENMARK','8362','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 21:16:51',0,NULL,3,1,2,1,NULL,'kim_hoerning'),(7013,693008563002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','boriska_gr','boriska_gn@yahoo.com','Boris Gorshtein','Avraam Shtern str. 42/12','Jerusalem','','ISRAEL','96750','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 22:38:04',0,NULL,3,1,2,1,NULL,'boriska_gr'),(7014,693011990002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','*stockweb*','taini.alberto@gmail.com','alberto taini','via del giglio n°60b','cattolica','RN','ITALY','47841','3335811023','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 22:49:48',0,NULL,3,1,2,1,NULL,'*stockweb*'),(7015,650624562001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',290,'hermeshine','fellygish','j.zheng@kneelerdesign.com.au','Jina Zheng','135 Campbell St','Collingwood','Victoria','AUSTRALIA','3066','0433124982','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 22:54:08',0,NULL,3,1,4,1,NULL,'fellygish\rnikon 老款 摄影背心  M   1\r双灯头   澳标   1\r反光伞   1\r反光板支架   1\r2mx3m 背景架   1\r2m灯架   2\r50-70 单灯头棚  澳标   2\r115w 220v   2\r包    1\rYW864488432CN\r\r\r\r\r'),(7016,652481401001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','francisco_bs','franciscobs@gmail.com','Francisco Batalla Sánchez','C/ Villardondiego 23, 2º-B','Madrid','Madrid','SPAIN','28032','687993669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 00:01:09',0,NULL,3,1,2,1,NULL,'francisco_bs'),(7017,652502436001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','bbaker8282','blb8282@gmail.com','brandon baker','24 w pine st','fremont','MI','UNITED STATES','49412','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 01:01:04',0,NULL,3,1,1,1,NULL,'bbaker8282'),(7018,652520561001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','thebadplayer','deekaysk@gmail.com','Daniel Krnac','Devinska 7','Nove Zamky','','SLOVAK REPUBLIC','94063','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 01:50:42',0,NULL,3,1,3,1,NULL,'thebadplayer\rRA022491876CN、'),(7019,693096578002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','livan-2006','licantenino@gmail.com','ivan muñoz','A. Rojas 28','Licanten','Septima Region','CHILE','3410000','75400711','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 02:34:09',0,NULL,3,0,5,1,NULL,'livan-2006\r发1.6m的背景架给他吧\rCP226379507CN\r'),(7020,0,130500585835,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.16,'hermeshine','noblewood57','noblewood57@yahoo.com','E.J. McCollum','3928 Haleys Way','Round Rock','TX','UNITED STATES','78665-1166','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 03:56:40',0,NULL,3,1,1,1,NULL,'noblewood57'),(7021,652556132001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','shenker123','shenkerbay@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 04:01:57',0,NULL,3,0,3,1,NULL,'shenker123\rxxl\r申报 vest  $12\rRA022491828CN、'),(7022,693123048002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','5_star_shop','boangoc@optusnet.com.au','lee xuan loi','24 skipton street','st albans','Victoria','AUSTRALIA','3020','03968974110411467893','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 04:12:52',0,NULL,3,0,4,1,NULL,'5_star_shop\rball head $15\rYW864488443CN\r'),(7023,693129009002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','mycowcow','bagel99@rogers.com','William Ng','1345 Willowvale Gardens','Mississauga','ON','CANADA','L5V 1V1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 04:45:39',0,NULL,3,1,3,1,NULL,'mycowcow\rRA022491765CN、'),(7024,760612267015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','francisco_pico','franciscopico@hotmail.com','Francisco Pico','1 H Springwell avenue','London','London','UNITED KINGDOM','nw10 4hn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 08:12:14',0,NULL,3,1,2,1,NULL,'francisco_pico\r刘\r\\'),(7025,652598995001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',87,'hermeshine','ramboroven','stenssons@telia.com','Tomas Stensson','Pl 467','Svenstavik','none','SWEDEN','84040','0687-10585','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 08:14:11',0,NULL,3,1,4,1,NULL,'ramboroven\rYW864488454CN\r\r'),(7026,652603839001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','sergio.raf','sergio.paolo@alice.it','Paolo Sergio','C.so Garibaldi n.201','Canosa di Puglia','BA','ITALY','70053','0883-664109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 08:37:40',0,NULL,3,1,2,1,NULL,'sergio.raf\r徐\r、'),(7027,760625342015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','autoosta','dedpixto@hotmail.com','Vitalijs Labors','6.linija 58B','Jelgava','','LATVIA','LV-3003','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-28 08:59:43',0,NULL,3,0,2,1,NULL,'autoosta\r1.6x2.1 黑色   1\r徐\r、'),(7028,652610071001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',62,'hermeshine','adelisle14','adelisle14@hotmail.com','VERDE-DELISLE ANTOINE','6 rue RAFFET','Paris','other','FRANCE','75016','0146477173','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 09:06:22',0,NULL,3,1,4,1,NULL,'adelisle14\rreflector holder  $20\r王\rYW864488476CN\r'),(7029,652611473001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',3,'AA2205',10.5,'hermeshine','thanasis117','thanasisxask@yahoo.gr','thanasis xaskos','BK50 arithmos 15','PATRA','N AXAIAS','GREECE','26333','6983503026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 09:13:01',0,NULL,3,1,2,1,NULL,'thanasis117\r\\'),(7030,693192818002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','taz_ufrj','kiwi2free@yahoo.com','JULIO CORAL','9228 Lamont Ave<br>Fl 3','ELMHURST','NY','UNITED STATES','11373-2866','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 10:08:34',0,NULL,3,1,1,1,NULL,'taz_ufrj\r庄'),(7031,652634846001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','militaryjudge','koshild@gmail.com','DMITRIY KOSHIL','LENINA ST. 169 KV. 36','ANAPA','','RUSSIAN FEDERATION','353454','+78613360523','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 10:48:25',0,NULL,3,1,2,1,NULL,'militaryjudge\r庄\r\\'),(7032,693205176002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','rama1981','burnxout@libero.it','Andrea Raimondi','Corso del popolo,15','San Michele al Tagliamento','VE','ITALY','30028','+393401709428','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 10:59:17',0,NULL,3,1,2,1,NULL,'rama1981\r徐\r\\'),(7033,693208466002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','dangfilms210','dangfilms@yahoo.com','freddy dang','5126 Village Crst','san antonio','TX','UNITED STATES','78218','(210) 843-3537','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 11:09:41',0,NULL,3,1,1,1,NULL,'dangfilms210\r注意是5个\r庄'),(7034,652648382001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','jpf_106684','johnpatrick84@btinternet.com','John Patrick Fletcher','22 Ash Grove<br>Yiewsley','London','Middlesex','UNITED KINGDOM','UB7 8BL','01895430530','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 11:40:33',0,NULL,3,0,3,1,NULL,'jpf_106684\rXXL\r王\rRA022492412CN\r\\'),(7035,693222216002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','andyc134','andyt.cobb@gmail.com','Andy Cobb','4426 Greenbriar Rd','Louisville','KY','UNITED STATES','40207-2304','(502) 386-6797','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 12:01:41',0,NULL,3,1,1,1,NULL,'andyc134\r徐'),(7036,651204059001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fotodjuls','djuls@gmx.net','Julien Bataillet C/o ADD','Eppendorfer weg 95a','Hamburg','','GERMANY','20259','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 13:01:08',0,NULL,3,1,3,1,NULL,'fotodjuls\r王\r\\\rRA022492307CN\r'),(7037,693140049002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 15:03:25',0,NULL,3,0,3,1,NULL,'saud-p\r发两个小包挂号\rRA117710245CN\rRA117710231CN\r\\'),(7038,760769217015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.99,'hutongstore','g.loxton','g.loxton@virgin.net','Giles Loxton','14 minerva road','kingston','Surrey','UNITED KINGDOM','kt1 2qa','02082871411','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 15:40:09',0,NULL,3,1,2,1,NULL,'g.loxton\r徐\r\\'),(7039,652725304001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','manuj28','fueratarget@hotmail.com','MANUEL JIMENEZ','C/ LUCENA DEL PUERTO 20 - 4ºA','HUELVA','Andalucía Ceuta y Melilla','SPAIN','21002','627022006','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 15:47:17',0,NULL,3,0,4,1,NULL,'manuj28\r发1.6的背景架  （ 白  黑）   1\r115w 220v  1\rbackground support  \r$20\r王\rYW864488480CN\r'),(7040,652729016001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','jamboleo2010','jamboleo@list.ru','Bogdanov Mikhail','Tolstikova 49-7','Kalininigrad','','RUSSIAN FEDERATION','236011','+79114524743','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 15:59:21',0,NULL,3,1,2,1,NULL,'jamboleo2010\r徐'),(7041,693299878002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','woopz86','woopz@hot.ee','Eduard Jashin','Sopruse 250-8','Tallinn','Estonia / Harjumaa','ESTONIA','13412','(+372)55604952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 15:59:35',0,NULL,3,1,5,1,NULL,'woopz86\r注意是2套\r庄\rCP226379524CN\r'),(7042,652752469001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','manuj28','fueratarget@hotmail.com','MANUEL JIMENEZ','C/ LUCENA DEL PUERTO 20 - 4ºA','HUELVA','Andalucía Ceuta y Melilla','SPAIN','21002','627022006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 16:56:23',0,NULL,8,1,17,0,NULL,'manuj28'),(7043,693326964002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','magmasowulo','gustavolugao@gmail.com','Gustavo Lugão','Rua Vicente Satriani 308- 06<br>Vila Suconasa','Araraquara','São Paulo','BRAZIL','14807-070','+55 16 88129917','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 17:04:03',0,NULL,3,1,2,1,NULL,'magmasowulo\r徐'),(7044,652765325001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','dragonic99','kay_dragonic99@yahoo.com','Michael Ian Lee Tin Wah','6D, Robinson St','Rose Hill','','MAURITIUS','0000','(230) 492 0505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 17:27:12',0,NULL,3,1,2,1,NULL,'dragonic99\r徐\r\\'),(7045,693339539002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','denybarboza','denyzinho@gmail.com','Jordana Brizolara','Rua Ver. Severo Ribeiro, 912<br>Três Vendas','Pelotas','Rio Grande do Sul','BRAZIL','96020-620','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 17:32:07',0,NULL,3,1,3,1,NULL,'denybarboza\r王\rRA022492298CN\r\\'),(7046,652776456001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','bluesmansur','ramrif@hotmail.com','Ramón Rivera Freire','San Antonio,6 1º C','ALGECIRAS','Cadiz','SPAIN','11201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 17:49:56',0,NULL,3,1,3,1,NULL,'bluesmansur\r王\rRA022492236CN\r\\'),(7047,760841628015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',3,'AA1314',6.6,'hutongstore','cdelabbeer','cdelabbeer@aol.com','Charles de la Bertauche','\"Westleigh\"<br>Fore Street,','Beer','Devon','UNITED KINGDOM','EX12 3EQ','0129721016','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 17:57:03',0,NULL,3,1,2,1,NULL,'cdelabbeer\r徐'),(7048,652782760001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','armenak*84','armenak84@mail.ru','Armenak Baghdasaryan','David Beki str. 90','Yerevan','Erebuni','ARMENIA','0008','(374)91010024','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 18:02:13',0,NULL,3,1,3,1,NULL,'armenak*84\r王\rRA022492219CN\r\\'),(7049,652796373001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','andrea_bo57','fabio010790@hotmail.it','Andrea Ferrari','via 2 agosto 1980 n° 19','Monte San Pietro','BO','ITALY','40050','+390516761781','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 18:28:23',0,NULL,3,1,2,1,NULL,'andrea_bo57\r徐'),(7050,745565756016,260660053578,'New Pro Photo Vest for all DSLR fans Size: XL',1,'AA1104',19.5,'hutongstore','peterw4963','peterw579@aol.com','Peter White','4 Cuppleditch Way','Louth','Lincolnshire','UNITED KINGDOM','LN11 0UF','01507606579','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 18:28:30',0,NULL,3,1,3,1,NULL,'peterw4963\r王\rRA022492240CN\r\\'),(7051,652814771001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',2,'AO0015',15.8,'hermeshine','jyrgenro','ykomar@yandex.ru','Iurii Ruzhytskyi','Pryrichna 17V <br>app. 47','Kyiv','','UKRAINE','04213','067-112-15-14','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 19:00:30',0,NULL,3,1,2,1,NULL,'jyrgenro\r刘'),(7052,693346833002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','bboykorrus','expl0@yandex.ru','POLOZOV EVGENIY','ULITSA LENINA DOM 31 KVARTIRA 6','KIROV','KALUZHSKAYA OBLAST\'','RUSSIAN FEDERATION','249440','+79208888626','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 19:31:39',0,NULL,3,1,3,1,NULL,'bboykorrus\r王\rRA022492222CN\r\\'),(7053,650641830018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','timc3986','proexc1@yahoo.com','tim carr','4320 Wilcor Dr','Akron','OH','UNITED STATES','44319-2644','(330) 618-5251','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 19:48:09',0,NULL,3,1,4,1,NULL,'timc3986\r刘（灯换成110V)\rYW864488491CN\r\r'),(7054,760968201015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','lynfm1948','lyn@netconnect.com.au','Lyn MacKenzie','7 Newton St','Stawell','Victoria','AUSTRALIA','3380','0353581878','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-28 20:55:06',0,NULL,3,1,2,1,NULL,'lynfm1948\r徐'),(7055,760982059015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.5,'hutongstore','heljay','jason.pallett@sky.com','JASON P PALLETT','18 JOHN STREET','SWADLINCOTE','DERBYSHIRE','UNITED KINGDOM','DE11 0AZ','01283221426','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 21:28:12',0,NULL,3,1,2,1,NULL,'heljay\r徐\r\\'),(7056,693476187002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','c_r_croker','rccroker@netscape.net','Clayton R Croker','75 Wentworth Avenue','Sydney','New South Wales','AUSTRALIA','2000','0292121005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 21:48:46',0,NULL,3,0,3,1,NULL,'c_r_croker\rRA117710055CN\r\\'),(7057,693486672002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','9228jay','liquid10@telus.net','JAY FERNANDEZ','502 - 5189 GASTON STREET','VANCOUVER','BC','CANADA','V5R6C7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 22:08:25',0,NULL,3,1,2,1,NULL,'9228jay\r庄'),(7058,652938827001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','chongzhili','terry_lee2003@hotmail.com','chongzhi li','325 S Chapel Ave<br>Apt B','alhambra','CA','UNITED STATES','91801-4296','(626) 935-9493','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 23:47:07',0,NULL,3,1,1,1,NULL,'chongzhili\r庄\r\\'),(7059,693519300002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','anar4k3l','anasoares13@gmail.com','Paulo Jorge Gonçalves Lacerda','Rua 25 de Abril Edificio Viana 6 4.º esq<br>3850 - Albegaria-a-Velha','Albergaria-a-Velha','Portugal','PORTUGAL','3850-004','+351935237838','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 23:59:45',0,NULL,3,1,4,1,NULL,'anar4k3l\r庄\r欧标\rYW864488502CN\r'),(7060,652949540001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','brocky05rip','tenille.muscat@sa.gov.au','Tenille Muscat','Level 10, Roma Mitchell House<br>136 North Terrace','ADELAIDE','South Australia','AUSTRALIA','5000','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-03-29 00:29:22',0,NULL,3,0,4,1,NULL,'brocky05rip\r发1.6m 背景架  （ 白 黑）   1\r庄\rYW864488513CN\r'),(7061,652952320001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','gran748','granote@gmail.com','Eran Granot','1 Israel Ishayahoo<br>p.o.box 2704','Petach TIqva','','ISRAEL','49127','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 00:40:31',0,NULL,3,1,2,1,NULL,'gran748\r庄\r\\'),(7062,652983063001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'AO0015',7.9,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 02:35:55',0,NULL,3,1,2,1,NULL,'dvdguychatter2\r徐\r\\'),(7063,652995440001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','yakou-moua','yakoumoua@hotmail.com','Yakou Moua','1400 Monks Ave<br>Apt 480','Mankato','MN','UNITED STATES','56001-5113','(651) 354-1092','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 03:39:23',0,NULL,3,1,1,1,NULL,'yakou-moua\r\\'),(7064,653006804001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','thepraetorianone','sergey@smolyaninov.ru','Sergey Smolyaninov','Krasnomoskovskaya 25-55','Krasnoyarsk','','RUSSIAN FEDERATION','660018','8(983)2690489','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 04:37:28',0,NULL,3,1,5,1,NULL,'thepraetorianone\rCP226379538CN\r'),(7065,653011242001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','crawdog00','rick_crawford@hotmail.com','Richard J Crawford','5901 Pinewood Rd','Oakland','CA','UNITED STATES','94611-1859','(510) 338-0332','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 05:04:28',0,NULL,3,1,1,1,NULL,'crawdog00'),(7066,653012710001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','joakim.k','joakim_k@yahoo.com','Joakim Karlsson','Nobelvagen 11a','Malmo','','SWEDEN','214 29','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 05:14:26',0,NULL,3,1,3,1,NULL,'joakim.k\rRA022492275CN\r\\'),(7067,650849188018,280522560367,'Tripod Fancier FT-6662A with 6160H Ball head 550D D90',1,'AE1503',69.9,'photographyacc','fouadandfatema','fowady2000@gmail.com','Fouad Bou-Khamsin','PO Box: 11791<br>Dhahran','Dhahran','Eastren Province','SAUDI ARABIA','31311','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-29 07:40:08',0,NULL,3,1,3,1,NULL,'fouadandfatema\r王\rRA117710355CN\r'),(7068,693625213002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','plumeriaheaven','judokix@yahoo.com','J Soeda','PO Box 4999','Kaneohe','HI','UNITED STATES','96744-8999','(808) 463-1331','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 07:51:59',0,NULL,3,1,1,1,NULL,'plumeriaheaven\r\\'),(7069,745867952016,260660053068,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',23.9,'hutongstore','probadge999','jc@probadge.com','Jeff Crisp','3 The Walk','Winslow','Buckinghamshire','UNITED KINGDOM','MK18 3AJ','01296715746','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 08:04:04',0,NULL,3,1,3,1,NULL,'probadge999\r刘\rRA117710191CN'),(7070,691755931002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','december196930','i-shubina@mail.ru','Irina Shubina','Krotevicha St., 47','Lipetsk','Russia','RUSSIAN FEDERATION','398020','74742 230165','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 08:19:08',0,NULL,3,0,3,1,NULL,'december196930\r徐\rRA117710452CN\r'),(7071,757188784015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',2,'AO0001',236,'hutongstore','pastortunde2011','pastortunde@kingdomarena.org.uk','Pastor Tunde Ogedengbe','39 Sunderland Place<br>Shortstown','Bedford','Bedfordshire','UNITED KINGDOM','MK42 0FE','01582405757','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-29 08:27:55',0,NULL,3,1,4,1,NULL,'pastortunde2011\r王\rYW864488535CN\r'),(7072,693638277002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',1,'AA1206',5.99,'hermeshine','sypige','sylvain.geyer@arcelormittal.com','Geyer Sylvain','avenue d\'Oberkorn, 118','Differdange','','LUXEMBOURG','L-4640','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 08:56:55',0,NULL,8,1,17,0,NULL,'sypige'),(7073,693638119002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','sypige','sylvain.geyer@arcelormittal.com','Geyer Sylvain','avenue d\'Oberkorn, 118','Differdange','','LUXEMBOURG','L-4640','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 08:56:56',0,NULL,3,1,2,1,NULL,'sypige\r580ex  肥皂盒  1\r带水平仪 热靴保护盖   1\r刘\r\\'),(7074,653058169001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fotoivideo','vlado.ludas@gmail.com','Vladimir Ludaš','Argentinska <br>2','Zagreb','','CROATIA','10000','00385989601830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 09:21:42',0,NULL,3,1,3,1,NULL,'fotoivideo\r王\rRA117710205CN'),(7075,652587184001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','shomaman','exprezident@yandex.ru','Shamil Suleimanov','Nejinskaya 1<br>16','Ufa','Bashkiria','RUSSIAN FEDERATION','450064','8-347-2644325','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 09:48:23',0,NULL,3,1,3,1,NULL,'shomaman\r王\rRA117710435CN\r'),(7076,693680055002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','hinrich19','hinrichbehrens@neofit.de','Magix Print - Hinrich Behrens','Dingstätte 7','Pinneberg','','GERMANY','25421','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 11:52:15',0,NULL,3,1,2,1,NULL,'hinrich19\r徐\r\\'),(7077,653137662001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',5,'AC3301',72.8,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 14:22:51',0,NULL,3,1,5,1,NULL,'nixette_nixette\r反光板  80cm 5合1     5\r圆形柔光棚 40cm       1\r庄\rRA117710112CN\r换号了： CP226342759CN\r'),(7078,653138999001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 14:28:04',0,NULL,8,1,17,0,NULL,'nixette_nixette\r'),(7079,653156828001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','timon_ru','timon.chel@gmail.com','Alimov Dmitry','apt. 39<br>214-A Aralskaya street','Chelyabinsk','Chelyabinskaya obl','RUSSIAN FEDERATION','454025','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 15:24:14',0,NULL,3,1,5,1,NULL,'timon_ru\r王\rCP226344794CN\r'),(7080,761333937015,250709193068,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',4,'AKT056',155.96,'hutongstore','hpan2010','shabir@hpan.org.uk','H-PAN H-PAN','`117 Fairfield Street<br>Manchester','Manchester','Lancashire','UNITED KINGDOM','M12 6EL','01612252307','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-29 15:44:25',0,NULL,3,1,4,1,NULL,'hpan2010\r刘\rYW864488546CN\r'),(7081,693778906002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','rdvru','r-dimka@mail.ru','Dima Rebrov','Simonovskiy val 7-1-86','Moscow','Russia','RUSSIAN FEDERATION','109044','+79266298181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 16:54:08',0,NULL,3,1,2,1,NULL,'rdvru\r徐\r\\\r'),(7082,693780324002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','lindows-by','joshhhab@gmail.com','Andrey Burkov','boulevard Komsomolskiy 59-2','Kamensk-Uralskiy','Sverdlovskaya oblast','RUSSIAN FEDERATION','623430','+7-915-290-14-59','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 17:08:47',0,NULL,3,1,2,1,NULL,'lindows-by\r庄\r\\'),(7083,693794108002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','michi1312','migum13@gmx.ch','Michael Hägele','Holligenstrasse 101','Bern','','SWITZERLAND','3008','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 17:29:49',0,NULL,3,1,2,1,NULL,'michi1312\r徐\r\\'),(7084,693800400002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','leteatbee_cyril','cyril.g@mail.ru','Kirill Golikov','Gagarina, 83-16','Sovetsky','Khanty-Mansiysky autonomous region','RUSSIAN FEDERATION','628240','+7(34675)38370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 17:47:24',0,NULL,3,1,3,1,NULL,'leteatbee_cyril\r庄\rRA117710126CN\r'),(7085,693803816002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','kazus_arthur','kazus1@yandex.ru','Pavel','Ryzhenkov<br>17-17 Stahanovskaya str.','Minsk','','BELARUS','220009','+375296454836','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 17:56:44',0,NULL,3,1,3,1,NULL,'kazus_arthur\r王\rRA117710041CN'),(7086,693847960002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','primorsk1971','primorsk@012.net.il','Vitaliy Berkovych','shmuel hanatsiv 14/9','netanya','hasharon','ISRAEL','42281','+972526686852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 19:17:20',0,NULL,3,1,2,1,NULL,'primorsk1971\r徐\r\\'),(7087,746174425016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','adam.wol','adam.wolynszczak@gmail.com','Adam Wolynszczak','127 The Crescent<br>Park West Pointe','Dublin','Dublin','IRELAND','D12','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-29 20:09:44',0,NULL,3,1,3,1,NULL,'adam.wol\r庄\rRA117710109CN'),(7088,693908469002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','marcio8493','aishaveras@hotmail.com','marcio veras','101 Norfolk St','Dorchester Center','MA','UNITED STATES','02124-3343','','NoPaymentFailure','CheckoutComplete','Other','2011-03-29 21:07:28',0,NULL,3,1,1,1,NULL,'marcio8493\r徐'),(7089,653324057001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','poonny06','lionel.prados@gmail.com','lionel prados','706 chemin du Suy Blanc','La Gaude','Provence-Alpes-Côte d\'Azur','FRANCE','06610','06.28.26.66.83','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 21:22:34',0,NULL,3,1,4,1,NULL,'poonny06\r庄（欧标）\rYW864488550CN\r'),(7090,761442196015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',30,'hutongstore','worldgems2010','wgworldgems7@gmail.com','rahmatullah asmari','93 Oxford Avenue','southampton','Hampshire','UNITED KINGDOM','SO14 0DP','07544853253','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 21:43:56',0,NULL,3,1,3,1,NULL,'worldgems2010\r王\rRA117710090CN\r'),(7091,746234220016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','roryalderson','roryald@aol.com','Rory Alderson','22 James street','Rochester','Kent','UNITED KINGDOM','ME46JS','07970922726','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 21:54:13',0,NULL,8,1,17,0,NULL,'roryalderson'),(7092,746235812016,260660053738,'New Wireless Flash Sync Trigger Receiver D700 D90 5D II',1,'AB3322',13.19,'hutongstore','roryalderson','roryald@aol.com','Rory Alderson','22 James street','Rochester','Kent','UNITED KINGDOM','ME46JS','07970922726','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 21:55:59',0,NULL,8,1,17,0,NULL,'roryalderson'),(7093,746236771016,260660055197,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','roryalderson','roryald@aol.com','Rory Alderson','22 James street','Rochester','Kent','UNITED KINGDOM','ME46JS','07970922726','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 21:58:13',0,NULL,8,1,17,0,NULL,'roryalderson'),(7094,761560436015,250599928359,'TianYa Gradual color Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','roryalderson','roryald@aol.com','Rory Alderson','22 James street','Rochester','Kent','UNITED KINGDOM','ME46JS','07970922726','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 22:00:07',0,NULL,3,1,3,1,NULL,'roryalderson\r方形滤镜接口环 58mm  1\r方形滤镜 镜片卡座   1\r永诺 YN-04 引闪器一套  1\r反光板 60cm 2合1    1\r天涯方形滤镜  渐变灰   1\r刘\rRA117710157CN\r'),(7095,693932350002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jairoperezv','chaca_24@hotmail.com','Jairo Perez Vecino','Bulevar Juan Carlos I,nº21, 1ºi<br>C/Severo Ochoa nº9,1ºA','Ponferrada','Leon','SPAIN','24400','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 22:06:08',0,NULL,3,1,4,1,NULL,'jairoperezv\rtripod  $16\r刘\rYW864488561CN\r'),(7096,761570637015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',24.95,'hutongstore','redbill80','redbill1980@yahoo.gr','Vasilis Lolos','Chrysaugi','Paramythia','Thesprotia','GREECE','46200','6944961595','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-29 22:24:27',0,NULL,3,1,3,1,NULL,'redbill80\r王\rRA117710072CN'),(7097,761577672015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','agalad','phancock@hotmail.co.uk','Paul Hancock','14 Bloomsbury Lane, Timperley','Altrincham','Cheshire','UNITED KINGDOM','WA156LX','07867824762','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 22:42:25',0,NULL,3,1,3,1,NULL,'agalad\r王\rRA117710086CN\r'),(7098,761579119015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','geraldinetenten','gmcgarrigle@gmail.com','geraldine mc garrigle','31 meadowvale park','omagh','Tyrone','UNITED KINGDOM','bt79 7rb','02882251122','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 22:47:38',0,NULL,3,1,3,1,NULL,'geraldinetenten\r王\rRA117710069CN'),(7099,693953995002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',46.99,'hermeshine','rodolfoperez','rodolfoperez79@gmail.com','Rodolfo Perez','8627 NW 54th St','Doral','FL','UNITED STATES','33166-3347','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 23:13:23',0,NULL,3,1,1,1,NULL,'rodolfoperez\r刘'),(7100,761596147015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','michaelmassaro','mike@mikemike.co.uk','michael massaro','38 Kirton Gardens','London','London','UNITED KINGDOM','E2 7LS','07985943981','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 23:36:39',0,NULL,3,1,3,1,NULL,'michaelmassaro\r刘\rRA117710130CN\r'),(7101,650935282001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-03-29 23:43:38',0,NULL,7,0,18,0,NULL,'datoow78'),(7102,691439996002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 23:43:52',0,NULL,7,0,18,0,NULL,'datoow78'),(7103,650937525001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 23:43:54',0,NULL,7,0,18,0,NULL,'datoow78'),(7104,691439867002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 23:44:22',0,NULL,7,0,18,0,NULL,'datoow78'),(7105,693970763002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','fluidsuper','juancamilovenegas@yahoo.com','Juan Venegas','8481 avenue des belges','Montreal','QC','CANADA','h2p2b3','(514) 241-3273','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 00:12:00',0,NULL,3,1,3,1,NULL,'fluidsuper\r王\rRA117710143CN\r'),(7106,653401868001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','assafmajdy','hazar_k@yahoo.com','majdy assaf','non<br>non','mi\'ilya village','mi\'ilya village po box 128','ISRAEL','25140','972547559297','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 01:50:44',0,NULL,3,1,3,1,NULL,'assafmajdy\r刘\rRA117710038CN\r'),(7107,650623943001,110469599855,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',13.99,'hermeshine','fellygish','j.zheng@kneelerdesign.com.au','Jina Zheng','135 Campbell St','Collingwood','Victoria','AUSTRALIA','3066','0433124982','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-03-30 02:11:40',0,NULL,7,0,18,0,NULL,'fellygish'),(7108,0,120701930117,'Adjustable Neoprene Padded Neck shoulder Strap for Sony',1,'AB1406',0.11,'hermeshine','riya_in_pink','brgrl01@gmail.com','Gillian Lansang','5655 Silver Creek Valley Rd<br># 543','San Jose','CA','UNITED STATES','95138-2473','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 02:29:20',0,NULL,3,1,1,1,NULL,'riya_in_pink\r徐'),(7109,694017143002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','alexander_sanchez','alexanderjsanchez@gmail.com','ALEXANDER SANCHEZ','URB LAS FUENTES CALLE 1 EDIF LOS ANDES PB APTO 2A EL PARAISO','CARACAS','DTTO FEDERAL/CARACAS','VENEZUELA','1020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 02:58:39',0,NULL,3,1,3,1,NULL,'alexander_sanchez\r庄\rRA022491200CN\r\\'),(7110,694020686002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','deebarajpal','vindee@airtelmail.in','Deeba Rajpal','#654, Sector 23<br>Urban Estate','Gurgaon','HR','INDIA','122017','9810208298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 03:13:01',0,NULL,3,1,2,1,NULL,'deebarajpal\r刘\r\\'),(7111,653428664001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','ezipman','yapls2002@yahoo.com.sg','William Yap','Blk 662 Choa Chu Kang Crescent<br>#16-271','default','','SINGAPORE','680662','91808647','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 03:53:47',0,NULL,3,1,11,1,NULL,'ezipman\r庄'),(7112,694031585002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','spetsnazth','birdcomloso@gmail.com','Teerakiat Vuttima','6 moo 7,Tambon Chiang Dao<br>Chotana Road','Chiang Dao','Chiang Mai','THAILAND','50170','+6681937769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 04:05:43',0,NULL,3,1,2,1,NULL,'spetsnazth\r刘\r\\'),(7113,653439661001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','vwchacer','hham@usa.com','Hugo Ham','440/10816 Macleod trail SE<br>Suite 129','Calgary','AB','CANADA','T2J5N8','(403) 404-7960','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 04:57:18',0,NULL,3,1,3,1,NULL,'vwchacer\r\\\rRA022491173CN'),(7114,694044397002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','japa984','japa984@gmail.com','Jagraj Pattar','14969 69th Ave','Surrey','BC','CANADA','V3S0Y8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 05:18:40',0,NULL,3,1,2,1,NULL,'japa984\r\\'),(7115,694049358002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','neobanthamia','catlleya1@bigpond.com','Grace Bryant','59 Gostwyck Street','Uralla','New South Wales','AUSTRALIA','2358','0267784169','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 05:47:45',0,NULL,3,0,3,1,NULL,'neobanthamia\rXL\rRA117710259CN\r\\'),(7116,653425652001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',18.99,'hermeshine','hunternmack','kellykiwi@yahoo.com','Kelly Vary','8 Somerset Street<br>Stanhope Gardens','Sydney','New South Wales','AUSTRALIA','2768','0414846563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 06:48:59',0,NULL,3,0,3,1,NULL,'hunternmack\r1.6x2.1 背景布  2\r黑色 浅蓝\rRA117710262CN'),(7117,653460355001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',45.8,'hermeshine','sergeykobah','kobahs@mail.ru','Sergey Nikolov','yl. Tihonova 12, korp:2, kv:21','Mirny, Respublika Saha(Yakutya)','RU','RUSSIAN FEDERATION','678175','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 06:59:25',0,NULL,3,1,3,1,NULL,'sergeykobah\r欧标\rRA117710280CN\r\\'),(7118,653489676001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','giddygaga','lornac@hotmail.com','Heri Natal','41- 43 Erskine Street','Sydney','New South Wales','AUSTRALIA','2001','0292903680','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 09:19:51',0,NULL,3,1,3,1,NULL,'giddygaga\r庄\rRA117713051CN'),(7119,653510120001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','alentement90','tement.alen@gmail.com','Alen Tement','Videm pri Ptuju 37','Videm pri Ptuju','','SLOVENIA','2284 ','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 10:44:18',0,NULL,3,1,2,1,NULL,'alentement90\r庄'),(7120,653539322001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','emarjac','red.door@bigpond.com','Chris B Harrison','PO BOX 24','Durham Ox','Victoria','AUSTRALIA','3576','0354551251','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:34:59',0,NULL,3,1,2,1,NULL,'emarjac\r庄'),(7121,694144017002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:56:41',0,NULL,8,1,17,0,NULL,'andrewespuni1979'),(7122,694143081002,120454225464,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',1,'AE2308',5.8,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:56:41',0,NULL,8,1,17,0,NULL,'andrewespuni1979'),(7123,694144718002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 12:56:42',0,NULL,3,1,4,1,NULL,'andrewespuni1979\r欧标\r套装 + 下面的产品：\r柔光伞   1\r绿叶 ND8  52mm   1\rlenspen     1\r绿叶 渐变镜 52mm    1\r绿叶 渐变镜 58mm    1\r绿叶 渐变镜 72mm    1\r绿叶 ND4  52mm    1\r绿叶 ND4  58mm   1\r绿叶 ND8  58mm   1\rLighting kit  $30\r王\rYW864488583CN\r'),(7124,694143548002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:56:45',0,NULL,8,1,17,0,NULL,'andrewespuni1979'),(7125,653539355001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:56:51',0,NULL,8,1,17,0,NULL,'andrewespuni1979'),(7126,694143229002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',6.2,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:57:02',0,NULL,8,1,17,0,NULL,'andrewespuni1979'),(7127,694142939002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:57:10',0,NULL,8,1,17,0,NULL,'andrewespuni1979'),(7128,694142976002,120454219152,'Green.L 52mm Neutral Density ND4 Filter ND 4 52',1,'AE2301',5.8,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:57:10',0,NULL,8,1,17,0,NULL,'andrewespuni1979'),(7129,694143047002,120454220127,'Green.L 58mm Neutral Density ND4 Filter ND 4 58',1,'AE2303',6.2,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:57:17',0,NULL,8,1,17,0,NULL,'andrewespuni1979'),(7130,694142881002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:57:58',0,NULL,8,1,17,0,NULL,'andrewespuni1979'),(7131,694159447002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','geekool','geek00l@gmail.com','CS Lee','SL-127 Jalan Besar','Kuala Kurau','Perak','MALAYSIA','34350','016-4159873','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 13:33:32',0,NULL,3,1,2,1,NULL,'geekool\r徐'),(7132,653559099001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','busuioaca792010','busuioaca79@yahoo.com','Busuioc Adrian','Mihai Viteazu Nr.1 Sc. B Ap. 35','Bacau','Bacau','ROMANIA','600055','+40752300215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 13:40:18',0,NULL,3,1,2,1,NULL,'busuioaca792010\r徐'),(7133,653578429001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','pakornkitjaikla','jaikla@gmail.com','Pakornkit Jaikla','585/76 CITY HOME Ratchada-Pinklao Condominium<br>Charansanitwong 95/1 Rd. Bang Ao, Bangplat','Bangkok','','THAILAND','10700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 14:43:52',0,NULL,3,1,17,0,NULL,'pakornkitjaikla\r'),(7134,653583996001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','pakornkitjaikla','jaikla@gmail.com','Pakornkit Jaikla','585/76 CITY HOME Ratchada-Pinklao Condominium<br>Charansanitwong 95/1 Rd. Bang Ao, Bangplat','Bangkok','','THAILAND','10700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 14:59:03',0,NULL,3,1,3,1,NULL,'pakornkitjaikla\r徐\r反光板  80cm 5合1    1\r圆形柔光棚 40cm       1\rRA117713153CN'),(7135,653593625001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','loboau_au','flovibagar@yahoo.es','Florian Vicente Bazataqui Garcia','virgen de lourdes nº 7 bajo derecha','puerto sagunto','Comunidad Valenciana','SPAIN','46520','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 15:26:18',0,NULL,8,1,17,0,NULL,'loboau_au\r王'),(7136,761558274015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.28,'hutongstore','gergo*','gery03@mailbox.hu','Gergő Szotkó','Menyhárt József tér 2 fszt. 1','Debrecen','Hajdú-Bihar','HUNGARY','4032','+36306021014','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-30 15:35:25',0,NULL,3,1,2,1,NULL,'gergo*\r徐'),(7137,653597058001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','loboau_au','flovibagar@yahoo.es','Florian Vicente Bazataqui Garcia','virgen de lourdes nº 7 bajo derecha','puerto sagunto','Comunidad Valenciana','SPAIN','46520','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 15:37:18',0,NULL,8,1,17,0,NULL,'loboau_au\r庄'),(7138,653600001001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','loboau_au','flovibagar@yahoo.es','Florian Vicente Bazataqui Garcia','virgen de lourdes nº 7 bajo derecha','puerto sagunto','Comunidad Valenciana','SPAIN','46520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 15:40:23',0,NULL,3,1,4,1,NULL,'loboau_au\r反光板支架   1\r斜臂   1\r小号灰卡    1\rphotography acc  $20\r庄\rYW864488572CN'),(7139,653609228001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','alwaystubed','bwolfe@pacbell.net','Brad Wolfe','2317 Auto Park Way','Escondido','CA','UNITED STATES','92029','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 16:04:06',0,NULL,3,1,1,1,NULL,'alwaystubed\r庄'),(7140,651450633018,280541368434,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','diixiirkazan','diixiir@gmail.com','Dmitri Kochnev','Yamasheva street, dom (house) 51, kvartira(flat) 169','Kazan','Tatarstan','RUSSIAN FEDERATION','420126','89625603803','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-30 16:08:32',0,NULL,3,1,5,1,NULL,'diixiirkazan\r刘\r欧标\r申报：lighting kit　\r$165\rCP226344750CN\r'),(7141,689646403002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','deamidated1911rush','julien14orbt@yahoo.com','Panama Netbuy','8424 NW 56th St<br>Ste PTY-1779','Doral','FL','UNITED STATES','33166-3327','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 16:54:15',0,NULL,3,1,1,1,NULL,'deamidated1911rush\r徐'),(7142,694229488002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',12,'AB1407',65.88,'hermeshine','masterclnprdllc','masterclnprd@gmail.com','Sal Muscarella','745 Valley St<br>Unit B','Colorado springs','CO','UNITED STATES','80915-3745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 16:48:06',0,NULL,3,1,1,1,NULL,'masterclnprdllc\r、'),(7143,653626394001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','anato01','smart2bay@yandex.ru','Anatoliy Alekseev','86 Golovatogo Str.','Krasnodar','ru','RUSSIAN FEDERATION','350004','+7(903)4538945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 17:11:57',0,NULL,3,1,5,1,NULL,'anato01\r庄\rCP226344777CN'),(7144,693946299002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','scuba.carlos','escuba.carlos@gmail.com','Carlos Otero Navarro','avda. Pintor Felo Monzón<br>nº2, portal 3 - 3º puerta 2','Las Palmas de Gran Canaria','Las Palmas','SPAIN','35019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 17:45:34',0,NULL,3,1,2,1,NULL,'scuba.carlos\r徐'),(7145,653663500001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','srclaudinei','srclaudinei@yahoo.com.br','Claudinei Rodrigues dos Santos','Av:  Souza Lima, 557 - Universitária II','Campo Grande','Mato Grosso do Sul','BRAZIL','79071340','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 18:22:10',0,NULL,3,1,5,1,NULL,'srclaudinei\r申报 backgound  support  $35\r王  \rCP226344715CN'),(7146,694282796002,120598267827,'Camera shoulder bag with raincover for Canon 550D 40D',1,'AO0021',28.99,'hermeshine','capnjack818','laurengposs@hotmail.com','Lauren G. Poss','492 N Lake Dr','Sandersville','GA','UNITED STATES','31082-7504','','NoPaymentFailure','CheckoutComplete','Other','2011-03-30 18:38:04',0,NULL,3,0,3,1,NULL,'capnjack818\r王\rRA117713034CN'),(7147,653683977001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','whitelion_85','emilia_m@netti.fi','Marianna Purhonen','Niinitie 38 B 13','Nastola','','FINLAND','15560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 18:45:38',0,NULL,3,1,2,1,NULL,'whitelion_85\r徐'),(7148,653687331001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','emiber63','eniber_63@yahoo.com','Emil Berman','Mishol shedema 23','Karmiel','','ISRAEL','21981','+972545233990','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 18:52:23',0,NULL,3,1,3,1,NULL,'emiber63\r背景架2m（ 白 黑） 1\r发两个小包\r王+庄\rRA117713082CN\rRA117713065CN'),(7149,694280790002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','ultrasmaga','magapsix@meta.ua','Yuri Maga','Kievskaya naberezhna 20 kv 31','Uzhgorod','Zakarpatskaya obl','UKRAINE','88018','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 19:56:05',0,NULL,3,1,5,1,NULL,'ultrasmaga\r白色背景布  2m架子\r庄\rCP226344732CN'),(7150,653736656001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','bigsandro17465','info@media-sound.it','Sandro Gentile','Via San Sisto,6','Trescore Balneario','Bergamo','ITALY','24069','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 20:17:20',0,NULL,3,1,3,1,NULL,'bigsandro17465\r刘\rRA117710302CN'),(7151,653746124001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','o_maggie','kellyrowe@xplornet.ca','Kelly Fraleigh','P.O.Box 212','Nestleton Station','ON','CANADA','L0B1L0','(905) 259-2552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 20:35:41',0,NULL,3,1,2,1,NULL,'o_maggie\r刘'),(7152,694354992002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',3,'AB1307',11.37,'hermeshine','pa4credit','willpa4credit@gmail.com','Rob Rhodes','203 Harbor Lndg','Braidwood','IL','UNITED STATES','60408-1763','(630) 935-7945','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 20:46:04',0,NULL,3,1,1,1,NULL,'pa4credit\r刘'),(7153,762083662015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','prof._b','timn33@gmail.com','Tim Nightinale','3 Butterfields','Camberley','Surrey','UNITED KINGDOM','GU15 3EU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-30 20:51:56',0,NULL,3,1,2,1,NULL,'prof._b\r徐'),(7154,762106081015,250692242373,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'AA1307',2.4,'hutongstore','mzalmy2','mohd_zalmy@yahoo.com','Mohd Zalmy Zakaria','Stipendiegränd 4A Lgh 1201','Umeå','Vasterbotten','SWEDEN','90735','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-30 21:30:52',0,NULL,3,1,2,1,NULL,'mzalmy2\r徐'),(7155,746783678016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',8.99,'hutongstore','secretwishclothinguk','secretwishuk@googlemail.com','Pawel Cwajna','70 Silbury Avenue','Mitcham','Surrey','UNITED KINGDOM','CR4 3SQ','07756910125','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-30 21:59:34',0,NULL,8,1,17,0,NULL,'secretwishclothinguk'),(7156,746783670016,260660051871,'New 3 pcs filters for Cokin System P Series',1,'AKT062',13.8,'hutongstore','secretwishclothinguk','secretwishuk@googlemail.com','Pawel Cwajna','70 Silbury Avenue','Mitcham','Surrey','UNITED KINGDOM','CR4 3SQ','07756910125','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-30 21:59:35',0,NULL,3,1,3,1,NULL,'secretwishclothinguk\rＮＤ２／４／８　　　１\r渐变灰    1\r77mm  1\r环架    1\r刘\rRA117711890CN\r\\'),(7157,694388132002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 22:03:50',0,NULL,3,1,3,1,NULL,'saud-p\r分成两个小包发\r王\rRA117713096CN\rRA117710214CN'),(7158,694382624002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 22:04:01',0,NULL,3,1,3,1,NULL,'saud-p\r分成2个小包发\r王\rRA117713105CN\rRA117710228CN'),(7159,653791369001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','regon7','jotafoto@yahoo.es','Francisco Javier Replinger Gonzalez','C/ Opera Carmen 65- 3ºB<br>Eurohogar II','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41007','687790888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 22:27:16',0,NULL,3,1,2,1,NULL,'regon7\r徐'),(7160,694413042002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','pablocaugusto','ebay@pabloaugusto.com','Pablo  da Cunha Augusto Pinto','Av Nossa Senhora de Fatima 33 / 705 - Centro','Rio de Janeiro','RJ','BRAZIL','20240-050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 23:31:05',0,NULL,3,1,2,1,NULL,'pablocaugusto\r刘'),(7161,653825193001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','kosowar7','clirim@uskana.com','Clirim Ramadani','Rr. Bill Clinton SU5/8E Nr.41','Pristina','Kosovo','ALBANIA','10090','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 00:38:09',0,NULL,3,1,5,1,NULL,'kosowar7\r套装＋一个单灯头欧标　１\r欧标\r庄\rCP226344729CN'),(7162,694435710002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','kosowar7','clirim@uskana.com','Clirim Ramadani','Rr. Bill Clinton SU5/8E Nr.41','Pristina','Kosovo','ALBANIA','10090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 00:44:28',0,NULL,8,1,17,0,NULL,'kosowar7'),(7163,653831092001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','bubbleforshoping','bubbleforshop@gmail.com','Sirichi Srimahattarchi','21/13 Moo 7 Soi Rattanasakha<br>T.Maehei','A.Muang','Chiangmai','THAILAND','50100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 01:01:37',0,NULL,3,1,11,1,NULL,'bubbleforshoping\r刘'),(7164,653323471001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','pappy7209','geevolution@hotmail.com','ERICK PAVEL GUTIERREZ','ING. F. ESPINOSA G. #85-102<br>COL. ATLANTA','CUAUTITLAN IZCALLI','MEXICO','MEXICO','54740','55 5881 7599','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 01:26:33',0,NULL,3,1,3,1,NULL,'pappy7209\r庄\rRA117713025CN'),(7165,653490179001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','chertany2010','chertany@hotmail.com','Tatyana Chernyak','Krasnochechelevska str. 30,<br>Apt.16','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49009','+380958484133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 04:31:33',0,NULL,3,0,2,1,NULL,'chertany2010\r深蓝色\r刘'),(7166,746423049016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','apr0604','alliekidd@hotmail.co.uk','allison kidd','183 bulkington rd','bedworth','warks','UNITED KINGDOM','cv12 9ee','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-31 05:51:40',0,NULL,3,0,2,1,NULL,'apr0604\r黑色'),(7167,651746663018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',248,'photographyacc','andrijm','andrij_m@inbox.ru','Andriy Matskiv','2 Pokutska str.','Sopiv','Ivano-Frankivsk reg','UKRAINE','78217','380673420266','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-31 06:19:10',0,NULL,3,1,5,1,NULL,'andrijm\r2m 灯架   2\r4灯头 棚  欧标   2\r45w 8\r包    1\r2m 灯架   1\r斜臂   1\r50-70 棚 欧标   1\r115w 220v   1\r刘\rCP226344701CN\r'),(7169,653907642001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','beguin5651','juanperva@ya.com','juan antonio perez d las vacas bueno','plza cartaya 1','madrid','Madrid','SPAIN','28024','915184109','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 07:36:38',0,NULL,3,0,3,1,NULL,'beguin5651\rRA117713122CN\r\\'),(7168,653901091001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','gran748','granote@gmail.com','Eran Granot','1 Israel Ishayahoo<br>p.o.box 2704','Petach TIqva','','ISRAEL','49127','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 07:02:20',0,NULL,3,1,11,1,NULL,'gran748\r\\'),(7170,694527812002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','beguin5651','juanperva@ya.com','juan antonio perez d las vacas bueno','plza cartaya 1','madrid','Madrid','SPAIN','28024','915184109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 08:10:01',0,NULL,8,0,17,0,NULL,'beguin5651'),(7171,762294790015,250621654557,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',20,'hutongstore','xeno85','clintonmagro@gmail.com','Clinton Magro','4B, Stardust<br>Luqa Briffa Street','Naxxar','MT','MALTA','NXR 2460','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 08:37:07',0,NULL,3,1,3,1,NULL,'xeno85\rRA117713241CN\r\\'),(7172,0,110667377938,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','skibby650','staral4@wi.rr.com','Michael Staral','4212 S 57th St','Milwaukee','WI','UNITED STATES','53220-3123','(414) 546-1747','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 08:43:42',0,NULL,3,1,1,1,NULL,'skibby650\r徐'),(7173,0,120704314361,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','jdn4525','jd4525@yahoo.com','Jim Nong','4525 S 17th St','Omaha','NE','UNITED STATES','68107-2154','(402) 932-6664','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 09:13:12',0,NULL,3,1,1,1,NULL,'jdn4525\r庄\r、'),(7174,0,120704307665,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','biigmoe','biigmoe@yahoo.com','Jessica Moeller','830 S Webster Ave<br>Apt 23','Anaheim','CA','UNITED STATES','92804-4156','(949) 235-7078','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 09:14:35',0,NULL,3,1,1,1,NULL,'biigmoe\r徐'),(7175,653929869001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','chanjaime','chanjaime@terra.es','Sebastian Molano Robledo','c/ Isaac Albeniz, 24','Cáceres','Extremadura','SPAIN','10005','609861719','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 09:23:31',0,NULL,3,1,2,1,NULL,'chanjaime\r\\'),(7176,653939962001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','borichka','boris@ceva-dsp.com','Boris Shpitser','CEVA DSP<br>2(D) Maskit St.','Herzelia','','ISRAEL','46120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:13:25',0,NULL,8,1,17,0,NULL,'borichka'),(7177,653940189001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','borichka','boris@ceva-dsp.com','Boris Shpitser','CEVA DSP<br>2(D) Maskit St.','Herzelia','','ISRAEL','46120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:13:26',0,NULL,8,1,17,0,NULL,'borichka'),(7178,694553422002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','borichka','boris@ceva-dsp.com','Boris Shpitser','CEVA DSP<br>2(D) Maskit St.','Herzelia','','ISRAEL','46120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:13:27',0,NULL,3,1,3,1,NULL,'borichka\r77mm 接口环   1（缺货）\r广角托架   1\r渐变灰   1\r渐变橙    1\r渐变蓝   1\rRA117713927CN'),(7179,653978542001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','ffmal','florent.marchal@gmail.com','Florent Marchal','1 bis rue de rocheclos','St Germain sur Ille','Bretagne','FRANCE','35250','06 71 61 66 12','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 12:50:33',0,NULL,3,1,4,1,NULL,'ffmal\r6663a   1\r绿叶 CPL  77mm    1\r绿叶 CPL  67mm   1\rtripod $20\r庄\rYW864488594CN\r'),(7180,653978847001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','ffmal','florent.marchal@gmail.com','Florent Marchal','1 bis rue de rocheclos','St Germain sur Ille','Bretagne','FRANCE','35250','06 71 61 66 12','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 12:50:34',0,NULL,8,1,17,0,NULL,'ffmal'),(7181,694592878002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','ffmal','florent.marchal@gmail.com','Florent Marchal','1 bis rue de rocheclos','St Germain sur Ille','Bretagne','FRANCE','35250','06 71 61 66 12','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 12:50:34',0,NULL,8,1,17,0,NULL,'ffmal'),(7182,653467781001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',3,'AE1401',113.97,'hermeshine','lovercyndi','klmc88@hotmail.com','kenneth lam man chung','90,Jalan Midah Besar, Taman Midah, Cheras','Kuala Lumpur','wilayah persekutuan','MALAYSIA','56000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 12:57:15',0,NULL,3,1,6,1,NULL,'lovercyndi\r王3.43\rEE442466390CN'),(7183,694616080002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','gokugohanyeah83','stanebaynow@yahoo.com','stan moua','45012 Tanglewood ct','shelby township','MI','UNITED STATES','48317','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-31 13:58:31',0,NULL,5,1,18,0,NULL,'gokugohanyeah83\r庄'),(7184,654004388001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','loutocky','tomasloutocky@seznam.cz','Tomas Loutocky','SALTO spol. s r.o.<br>Kastanova 129a','Brno','','CZECH REPUBLIC','62000','+420 603 837 432','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 14:05:13',0,NULL,3,1,3,1,NULL,'loutocky\r王\rRA117713238CN\r\\'),(7185,0,120704307966,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:04',0,NULL,8,1,17,0,NULL,'beadspluss'),(7186,0,110667379386,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:05',0,NULL,8,1,17,0,NULL,'beadspluss'),(7187,0,120704307990,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:06',0,NULL,8,1,17,0,NULL,'beadspluss'),(7188,0,120704307671,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:06',0,NULL,8,1,17,0,NULL,'beadspluss'),(7189,0,110667378970,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:08',0,NULL,8,1,17,0,NULL,'beadspluss'),(7190,0,120704307713,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:08',0,NULL,3,1,1,1,NULL,'beadspluss\r麂皮   11\r徐\r、'),(7191,654011099001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','mozzaldinho','morcm006@students.unisa.edu.au','Christopher Morrison','24 Albert St<br>Prospect','Adelaide','South Australia','AUSTRALIA','5082','0882692440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 14:26:15',0,NULL,3,1,3,1,NULL,'mozzaldinho\r刘\rRA117713224CN\r、'),(7192,654014907001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','pribilinskiy','steven.pribilinskiy@gmail.com','Steven Pribilinskij','Generala Petrova str., 10/56','Mukachevo','Zakarpatye','UKRAINE','89600','380509667377','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 14:45:53',0,NULL,3,1,3,1,NULL,'pribilinskiy\r庄\rRA117713215CN\r\\'),(7193,694635582002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','canadianinternational','canadadoux@yahoo.ca','marwan issa','319 rue emile','laval','QC','CANADA','H7N 4M3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 15:03:41',0,NULL,8,1,17,0,NULL,'canadianinternational'),(7194,654019216001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','canadianinternational','canadadoux@yahoo.ca','marwan issa','319 rue emile','laval','QC','CANADA','H7N 4M3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 15:03:42',0,NULL,3,1,3,1,NULL,'canadianinternational\r肩架    1   \r双灯头   1\r大力夹   2   \rRA117713272CN\r\\\r\r'),(7195,694635001002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','canadianinternational','canadadoux@yahoo.ca','marwan issa','319 rue emile','laval','QC','CANADA','H7N 4M3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 15:03:42',0,NULL,8,1,17,0,NULL,'canadianinternational'),(7196,0,110667377495,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.85,'hermeshine','navimomma','katrinasoper@live.com','Katrina Ayala','10109 186th St E<br>Unit 250','Puyallup','WA','UNITED STATES','98375-1810','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 15:59:51',0,NULL,3,1,1,1,NULL,'navimomma\r麂皮  2\r徐'),(7197,0,110667386036,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','jkjdawg1','kerney_inc@hotmail.com','Michelle Kerney','310 7th Ave W','Kalispell','MT','UNITED STATES','59901-4762','(406) 212-5734','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'jkjdawg1\r庄'),(7198,654051807001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','666demos666','choteau.frederic@free.fr','frederic choteau','101 rue kuhlmann','lomme','Nord-Pas-de-Calais','FRANCE','59160','0320094695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 16:22:11',0,NULL,3,1,2,1,NULL,'666demos666\r刘\r\\'),(7199,0,110667385136,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','russumselectronics','russumelectronics@yahoo.com','Cole Russum','1730 Homestead CT','Fulton','MO','UNITED STATES','65251-3077','(573) 529-2924','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 16:42:27',0,NULL,3,1,1,1,NULL,'russumselectronics\r刘'),(7200,0,120704305916,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','byrdtrucks11','byrdtrucks@gmail.com','Justin Byrd','2090 Corson St','Pasadena','CA','UNITED STATES','91107-3270','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 16:52:40',0,NULL,3,0,1,1,NULL,'byrdtrucks11\r徐\r、'),(7201,694684395002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','teatrodemarionetaslaestrella','iberians@hotmail.com','Alberto Gomez Sanchis','Av./Pais Valenciano nº32  Esc.2ª  1ºA','Villajoyosa','ALICANTE','SPAIN','03570','677072979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 17:09:50',0,NULL,8,1,17,0,NULL,'teatrodemarionetaslaestrella'),(7202,694684309002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','teatrodemarionetaslaestrella','iberians@hotmail.com','Alberto Gomez Sanchis','Av./Pais Valenciano nº32  Esc.2ª  1ºA','Villajoyosa','ALICANTE','SPAIN','03570','677072979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 17:09:51',0,NULL,8,1,17,0,NULL,'teatrodemarionetaslaestrella'),(7203,694684044002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','teatrodemarionetaslaestrella','iberians@hotmail.com','Alberto Gomez Sanchis','Av./Pais Valenciano nº32  Esc.2ª  1ºA','Villajoyosa','ALICANTE','SPAIN','03570','677072979','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 17:09:50',0,NULL,3,1,4,1,NULL,'teatrodemarionetaslaestrella\r2m 灯架   1\r反光板支架   1\r反光板 100*150 40*60 5合1  1\r反光板 80cm 2合1    1\r燕文 一票两件\rreflector holder  $25\r刘\rYW864488605CN\r'),(7204,694698467002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','curagash11','ghiweras@yahoo.com','Vadim Sadykov','1934 E 28th St<br>Bsmt Floor','Brooklyn','NY','UNITED STATES','11229-2533','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 17:38:48',0,NULL,3,1,1,1,NULL,'curagash11\r徐'),(7205,762542034015,250692237909,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',2.39,'hutongstore','casualbuyer_7','morrisseeee_7@yahoo.ie','martin nolan','boherash<br>glanworth','cork','Cork','IRELAND','default','0872042774','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 18:50:23',0,NULL,3,1,2,1,NULL,'casualbuyer_7\r徐\r\\'),(7206,694737949002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','csmfnl89','astrofilo2007@libero.it','Cosimo Fanuli','via Giacomo Leopardi 11','Oria','BR','ITALY','72024','0831849031','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 19:00:23',0,NULL,3,0,3,1,NULL,'csmfnl89\rL\r庄\rRA117713184CN\r、'),(7207,747207660016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','hamburg-chill','ebay@feustel.com','Andreas Feustel','Lindenallee 5d','Reinbek','','GERMANY','21465','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 19:08:54',0,NULL,3,1,3,1,NULL,'hamburg-chill\r庄\rRA117713198CN\r、'),(7208,747208227016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','trampower','ctram01@gmail.com','Cuong Tram','35 Moon Shadow Dr','Milpitas','CA','UNITED STATES','95035-8711','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 19:10:20',0,NULL,3,1,1,1,NULL,'trampower\r庄\r、'),(7209,747209043016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','benmachulk','ben.kelly@tiscali.co.uk','Ben Kelly','80 Daylesford Drive<br>Castle Dene','Newcastle Upon Tyne','Tyne and Wear','UNITED KINGDOM','NE3 1TW','07896827685','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-31 19:11:04',0,NULL,3,1,2,1,NULL,'benmachulk\r庄\r\\'),(7210,653774707001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','guajejorge','guaje53@hotmail.com','JORGE VAZQUEZ MARTINEZ','AV CANARIAS, 20-6ª A<br>LAS PALMAS DE GC','LAS PALMAS DE G.C.','Canarias','SPAIN','35002','928256130','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 19:21:03',0,NULL,3,1,4,1,NULL,'guajejorge\r刘\rtripod $20\r6663a  1\r6663a 的快装板   1\rYW864488616CN'),(7211,0,110667387962,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:17',0,NULL,8,1,17,0,NULL,'alemed277'),(7212,0,110667387859,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:17',0,NULL,8,1,17,0,NULL,'alemed277'),(7213,0,110667386752,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:18',0,NULL,8,1,17,0,NULL,'alemed277'),(7214,0,120704314932,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:19',0,NULL,8,1,17,0,NULL,'alemed277'),(7215,0,120704315250,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:19',0,NULL,8,1,17,0,NULL,'alemed277'),(7216,0,110667387387,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:20',0,NULL,8,1,17,0,NULL,'alemed277'),(7217,0,120704315279,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:20',0,NULL,8,1,17,0,NULL,'alemed277'),(7218,0,120704315269,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:21',0,NULL,8,1,17,0,NULL,'alemed277'),(7219,0,110667387823,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:21',0,NULL,8,1,17,0,NULL,'alemed277'),(7220,0,120704314876,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:28:36',0,NULL,8,1,17,0,NULL,'alemed277'),(7221,0,110667387872,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:28:58',0,NULL,8,1,17,0,NULL,'alemed277'),(7222,0,110667387442,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:00',0,NULL,8,1,17,0,NULL,'alemed277'),(7223,0,120704314938,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:02',0,NULL,8,1,17,0,NULL,'alemed277'),(7224,0,110667387373,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:10',0,NULL,8,1,17,0,NULL,'alemed277'),(7225,0,110667387842,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:11',0,NULL,8,1,17,0,NULL,'alemed277'),(7226,654137243001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','guajejorge','guaje53@hotmail.com','JORGE VAZQUEZ MARTINEZ','AV CANARIAS, 20-6ª A<br>LAS PALMAS DE GC','LAS PALMAS DE G.C.','Canarias','SPAIN','35002','928256130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 19:29:16',0,NULL,8,1,17,0,NULL,'guajejorge'),(7227,0,110667387396,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:20',0,NULL,8,1,17,0,NULL,'alemed277'),(7228,0,120704314928,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:24',0,NULL,8,1,17,0,NULL,'alemed277'),(7229,0,120704315244,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:24',0,NULL,8,1,17,0,NULL,'alemed277'),(7230,0,110667387418,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:30:36',0,NULL,8,1,17,0,NULL,'alemed277'),(7231,0,110667387800,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:30:36',0,NULL,3,1,1,1,NULL,'alemed277\r麂皮  20'),(7232,0,110667385102,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','greybeard48','greybeardsebay@yahoo.com','Austin Bradley','PO Box 1291','Buffalo','MO','UNITED STATES','65622-1291','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:57:34',0,NULL,3,0,1,1,NULL,'greybeard48\r徐'),(7233,654169928001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mpchaney8','newkid521@web.de','Michael P. Chaney','Eppelheimer Str. 69','Heidelberg','','GERMANY','69123','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 20:33:34',0,NULL,3,1,2,1,NULL,'mpchaney8\r刘\r\\'),(7234,654178086001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','ibuyyousell2010','a_d_guzman@shaw.ca','alexander de guzman','2820-66 st ne','calgary','AB','CANADA','t1y4m9','(403) 383-4227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 20:51:16',0,NULL,3,1,3,1,NULL,'ibuyyousell2010\r刘\r1 X 77mm ring adapter（缺）\r1 X filter adapter\r3 X Filters (ND2 + ND4 + ND8)\rRA117713913CN\r'),(7235,762634140015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 21:17:39',0,NULL,8,1,17,0,NULL,'turisam'),(7236,762634237015,250623448641,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 21:17:39',0,NULL,8,1,17,0,NULL,'turisam'),(7237,762633862015,250599911589,'New Air Dust Blower Cleaner Pump and Cloth ',1,'AA1311',3.5,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 21:17:40',0,NULL,8,1,17,0,NULL,'turisam'),(7238,762634054015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.49,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 21:17:40',0,NULL,3,1,3,1,NULL,'turisam\r大号灰卡   1\r气吹 + 布   1\rlenspen   2\r45w 5500k 灯泡   2\r庄\rRA117713286CN\r、\r'),(7239,0,110667378590,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1,'hermeshine','makarachan','makararath@gmail.com','Makara Rath','10057 CYPRESS AVE','RIVERSIDE','CA','UNITED STATES','92503-1657','(951) 688-8636','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 21:19:14',0,NULL,3,0,1,1,NULL,'makarachan\r庄'),(7240,654190557001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','r53115','mrrudyv@yahoo.com','Rudy Villarreal','1335 Racine St','Delavan','WI','UNITED STATES','53115-1462','(262) 949-7917','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 21:20:46',0,NULL,8,1,17,0,NULL,'r53115'),(7241,694810024002,120454225464,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',1,'AE2308',5.8,'hermeshine','r53115','mrrudyv@yahoo.com','Rudy Villarreal','1335 Racine St','Delavan','WI','UNITED STATES','53115-1462','(262) 949-7917','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 21:23:06',0,NULL,3,1,1,1,NULL,'r53115\rcanon 反接环  52mm  1\r绿叶 ND8  52mm   1\r庄');
INSERT INTO `hmsh_ebay_transaction` VALUES (7242,747293616016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','sale9900','u_nek_reality@yahoo.com','sandy alexander','6300 Milgen Rd<br>Apt 1270','Columbus','GA','UNITED STATES','31907','(918) 277-2322','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-31 21:32:12',0,NULL,3,1,4,1,NULL,'sale9900\r美标头+110v灯泡\r王\rYW864488620CN'),(7243,654206444001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','raiminati','fernandezj57@gmail.com','Jose Fernandez','578 Academy St<br>Apt 4B','New York','NY','UNITED STATES','10034-5230','','NoPaymentFailure','CheckoutComplete','Other','2011-03-31 22:04:38',0,NULL,3,1,3,1,NULL,'raiminati\r王\rRA117713167CN\r\\'),(7244,653956201001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','hannahkatehm','hannahamills@yahoo.com.au','Janine Rossi','5 Hodgson Terrace','Richmond','Victoria','AUSTRALIA','3121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 22:21:49',0,NULL,3,1,2,1,NULL,'hannahkatehm\r徐\r\\'),(7245,0,110667377301,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',2.5,'hermeshine','tonymorales2','tony.morales2@comcast.net','Ramon A. Morales','6 Steeplechase Ct','Cherry Hill','NJ','UNITED STATES','08003-5165','(856) 354-8715','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 22:31:13',0,NULL,3,0,1,1,NULL,'tonymorales2\r庄\r麂皮   2\r、'),(7246,0,120704307109,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:39',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7247,0,110667377483,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.52,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:32',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7248,0,110667387294,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:39',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7249,0,120704307155,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.16,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:40',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7250,0,120704308012,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:41',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7251,0,120704304752,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:41',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7252,0,120704312505,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:42',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7253,0,120704308508,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:42',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7254,0,120704306614,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:43',0,NULL,3,0,1,1,NULL,'qiqi77zz\r就发1x（黑粗）麂皮给他就行了'),(7255,654229716001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','coorykoray','korayturkay@gmail.com','Koray Turkay','kurucesme mah. sakarya cad no:46<br>Osmangazi','bursa','','TURKEY','16050','902242236064','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 23:41:31',0,NULL,3,1,2,1,NULL,'coorykoray\r徐\r\\'),(7256,694859686002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','julesoille','julesoille@hotmail.com','Jules Oille','189 Bullock Dr','Markham','ON','CANADA','L3P 1W4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 00:04:51',0,NULL,3,1,3,1,NULL,'julesoille\r王\rRA117713255CN\r\\'),(7257,0,110667377505,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.18,'hermeshine','utahskimom','michelle@milburn.cc','Michelle L Milburn','100 Ottermont Ct','Cary','NC','UNITED STATES','27513','(919) 469-5822','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 00:29:25',0,NULL,3,0,1,1,NULL,'utahskimom\r庄\r麂皮 3'),(7258,654256405001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','jhune9','jhunesalenga@gmail.com','Napoleon Salenga','#29 Vivians Crescent','Brampton','ON','CANADA','L6Y 4V1','(905) 454-6711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 01:21:25',0,NULL,3,1,3,1,NULL,'jhune9\r72mm 接口环  1\r托架  1\rND4, ND8 and 渐变灰   1\r庄\rRA117713175CN\r\\'),(7259,654257971001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','salqa','newvisionmedia@snet.net','Jose Martinez','40 Timothy Ter<br>New Vision Media, Llc','Windsor','CT','UNITED STATES','06095-1652','','PayPalPaymentInProcess','CheckoutComplete','Other','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'salqa\rLK035429603CN'),(7260,0,120704307194,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 01:38:27',0,NULL,3,1,1,1,NULL,'i3izkit311\r庄\r、'),(7261,654279042001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','maryanne8516','manne4@mac.com','Mary Anne lapenna','134 D\'Ostende','vimont, Laval','QC','CANADA','H7K3L1','(514) 802-6284','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 03:04:03',0,NULL,3,1,3,1,NULL,'maryanne8516\r庄\rRA117713357CN\r、'),(7262,0,120704314038,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.12,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 03:40:56',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7263,0,110667386780,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',3.72,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 03:40:59',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7264,694926076002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','mikeythetiregod','t_ateah@yahoo.ca','mike alexander','B 45658 lewis ave','CHILLIWACK','BC','CANADA','V2P3C6','(604) 418-1502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 04:50:52',0,NULL,3,1,3,1,NULL,'mikeythetiregod\rRA117716013CN'),(7265,654302131001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','tomburke7','burke.thomas.s@edumail.vic.gov.au','Tom Burke','7 Farrer Crt','Warranwood','Victoria','AUSTRALIA','3134','0398763047','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 05:09:36',0,NULL,3,1,2,1,NULL,'tomburke7\r徐'),(7266,654306164001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',45.8,'hermeshine','dmitriyla','info@da-group.ru','Dmitriy Lagunov','Uinskaya 1b-26','Perm','Permski krai','RUSSIAN FEDERATION','614051','83422712669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 05:35:04',0,NULL,3,1,3,1,NULL,'dmitriyla\r欧标\rRA117713330CN\r、'),(7267,694940637002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ikarus_65','ebay@solbach.org','Ludger Solbach','440 Clyde Ave<br>Audience Inc.','Mountain View','CA','UNITED STATES','94043-2232','(650) 440-0602','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 06:18:53',0,NULL,3,1,1,1,NULL,'ikarus_65'),(7279,654347988001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','robertogrilloph','phrgrillo@gmail.com','Roberto Grillo','via duca degli abruzzi 16','san giovanni la punta','CT','ITALY','95037','3477471241','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 09:32:13',0,NULL,3,1,3,1,NULL,'robertogrilloph\r刘\rRA117713958CN\r'),(7268,654327382001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',2,'AB1203',16,'hermeshine','88boub','nicolas_grienenberger@hotmail.fr','nicolas grienenberger','25 rue frédéric mistral','matzenheim','Alsace','FRANCE','67150','0620965418','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 07:38:59',0,NULL,3,0,2,1,NULL,'88boub\r、'),(7269,0,120704307690,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:08:38',0,NULL,8,0,17,0,NULL,'beadspluss'),(7270,0,110667379460,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:08:39',0,NULL,8,0,17,0,NULL,'beadspluss'),(7271,0,120704307620,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:08:40',0,NULL,8,0,17,0,NULL,'beadspluss'),(7272,0,110667379746,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:08:41',0,NULL,8,0,17,0,NULL,'beadspluss'),(7273,0,110667379000,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:08:42',0,NULL,8,0,17,0,NULL,'beadspluss'),(7274,654336973001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','mohamed_remember','the_remember_@hotmail.com','Mohamed Ratoun','C/General Prim<br>39 - 3 - 3','Sant Fruitós de Bages','Cataluña','SPAIN','08272','634853283','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 08:27:58',0,NULL,3,0,3,1,NULL,'mohamed_remember\rRA117713391CN\r\\'),(7275,694964137002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','kirian7','kirian3@lycos.com','Gunnar Gercke','Achtern Barg 9a','Barsbüttel','','GERMANY','22885','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 08:28:21',0,NULL,3,0,2,1,NULL,'kirian7\r\\'),(7276,654339585001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fotoivideo','vlado.ludas@gmail.com','Vladimir Ludaš','Argentinska <br>2','Zagreb','','CROATIA','10000','00385989601830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 08:40:31',0,NULL,3,1,3,1,NULL,'fotoivideo\r庄\rRA117713374CN\r\\'),(7277,0,110667379376,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:52:54',0,NULL,3,1,1,1,NULL,'beadspluss\r刘'),(7278,654344212001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','uszkomatonta','don@tricon.hu','Szilard Pasztor','Kaposvár u. 14-18.','Budapest','Hungary','HUNGARY','1117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 09:02:49',0,NULL,3,1,2,1,NULL,'uszkomatonta\\'),(7280,747490196016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','graeme-maria','graemeh@o2.ie','Graeme Haughton','24 Ryecroft<br>Church road','Bray','Wicklow','IRELAND','00','35312763294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-01 09:43:16',0,NULL,3,1,2,1,NULL,'graeme-maria\\'),(7281,654362370001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','kata141kata','katahorvat14@gmail.com','Kata Horvat','Šumska 14<br>Brdovec','Prigorje Brdovečko','','CROATIA','10291','00385989601830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 10:24:51',0,NULL,3,1,3,1,NULL,'kata141kata\r刘\rRA117713428CN\r'),(7282,747502641016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','dedoso','d.batacchi@gmail.com','David Batacchi','via di castello 37','firenze','FI','ITALY','50141','055-4590810','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-01 10:29:36',0,NULL,3,0,4,1,NULL,'dedoso\r欧标\rlighting kit  $30\r庄\rYW864488723CN'),(7283,694996013002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',5,'AC2402',114.95,'hermeshine','dermafrance','domdeb0@yahoo.com.br','Dominique Debusschere Dermafrance','rua São Paulo 409 Centro','Belo Horizonte','MG','BRAZIL','30170130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 11:32:25',0,NULL,3,1,5,1,NULL,'dermafrance\rCP226344692CN\r王'),(7284,654378605001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','fgr91','frederic.grosso@free.fr','GROSSO Frédéric','2 rue Pierre Picard','Massy','91','FRANCE','91300','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 11:34:38',0,NULL,3,1,3,1,NULL,'fgr91\rRA117713873CN\r'),(7285,694084740002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ashisusu11','ashisusu@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','3332205045','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 11:57:56',0,NULL,3,1,3,1,NULL,'ashisusu11\r刘\rRA117713414CN\r'),(7286,747551013016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','mike-elvis','info@elvisonline.dk','Mike Andersen','Slotsgade 12, 3Th.','Hillerød','standard','DENMARK','3400','24243808','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-01 13:10:26',0,NULL,3,1,4,1,NULL,'mike-elvis\r欧标\r刘   \rYW864488712CN'),(7287,654414823001,110417009860,'58mm 58 mm Macro +4 Close-Up Close Up Filter',1,'AE3217',5.9,'hermeshine','igorshljivo','sljivo1981@gmail.com','Igor Sljivancanin','Stari aerodrom, Lamela 4','PODGORICA','MONTENEGRO','MONTENEGRO','81000','+38267816326','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 13:44:29',0,NULL,3,1,2,1,NULL,'igorshljivo\r刘\r\\'),(7288,654427990001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','cosplaycasuals','cosplaycasuals@gmail.com','zet barrett','531 bennett ave','american falls','ID','UNITED STATES','83211','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 14:38:59',0,NULL,3,0,1,1,NULL,'cosplaycasuals\r刘'),(7289,654406335001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',36.92,'hermeshine','leon12blau','wolfgang.gfrerer@arcor.de','Wolfgang Gfrerer','Gewuerzmuehlstr. 3','Muenchen','','GERMANY','80538','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 14:41:45',0,NULL,3,0,3,1,NULL,'leon12blau\r刘\rRA117713445CN\r'),(7290,694690414002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AKT039',26.99,'hermeshine','andreiphotografy','photomaestro@mail.ru','Andrei Aksenov','str. Vologodskaya 25-74','Arhangelsk','Arhangelsk region','RUSSIAN FEDERATION','163001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 15:08:37',0,NULL,3,0,3,1,NULL,'andreiphotografy\r新的那个4灯头 有伞孔的  1\rRA117713887CN\r'),(7291,695078922002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','28666466','vadim.ka@inbox.lv','Vadims Blazevics','Rigas 72-15','Daugavpils','','LATVIA','LV-5401','37129895549','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 15:40:22',0,NULL,3,1,3,1,NULL,'28666466\r徐\rRA117713493CN\r'),(7292,654456565001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',3,'AC1201',14.7,'hermeshine','mauriciomartins','mmartins98@yahoo.com','Mauricio Silva','Rua Espumas 200 / 205<br>Ilha do Governador','Rio de Janeiro','Rio de Janeiro','BRAZIL','21941170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 15:54:52',0,NULL,3,1,2,1,NULL,'mauriciomartins\r刘\r\\'),(7293,654502549001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','erikaryanngtar','erikaryann@hotmail.com','Erika Sedmak','1961 S Josephine St<br>Apt 103','Denver','CO','UNITED STATES','80210-4235','(303) 885-9151','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 17:55:39',0,NULL,3,1,1,1,NULL,'erikaryanngtar\r刘'),(7294,695135558002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','armaram','aramkostanyan@gmail.com','Armen Gharibyan','1 Jivani str. (lane)','Yerevan','','ARMENIA','0032','37410534976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 18:03:18',0,NULL,8,1,17,0,NULL,'armaram'),(7295,654510926001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','armaram','aramkostanyan@gmail.com','Armen Gharibyan','1 Jivani str. (lane)','Yerevan','','ARMENIA','0032','37410534976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 18:15:36',0,NULL,3,1,2,1,NULL,'armaram\r反光板 60cm 2合1   1\r倒影板（白黑）   1\r\\'),(7296,695144880002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','drummer5829','drummer5829@comcast.net','Matt Quock','129 Lathrop St','Madison','WI','UNITED STATES','53726-4079','(630) 485-8152','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 18:35:41',0,NULL,3,1,1,1,NULL,'drummer5829\r刘'),(7297,695179417002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','sweetone4ever','sweet_one_at_heart11683@yahoo.com','Karri  Allen','1514 Colorado St','Midland','MI','UNITED STATES','48642-5726','(989) 600-6358','NoPaymentFailure','CheckoutComplete','Other','2011-04-01 19:41:04',0,NULL,3,1,4,1,NULL,'sweetone4ever\rlighting kit $25\r庄\rYW864488701CN'),(7298,695187988002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','hawkkwah','giperhawk@mail.ru','Aleksey Zagirniy','Delegatskaya str., 10-25','Donetsk','UA','UKRAINE','83036','+380503550412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 19:55:53',0,NULL,3,1,2,1,NULL,'hawkkwah\r徐\r\\'),(7299,695198619002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','kados_de','dornbusch@gmx.de','Sascha Dornbusch','Sinnersdorfer Str. 45','Dormagen','','GERMANY','41540','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 20:19:43',0,NULL,3,1,3,1,NULL,'kados_de\r庄\rRA117713900CN\r'),(7300,654569443001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','matthieuwmc13','matthieu.melquiond@voila.fr','matthieu melquiond','93 rue horace bertin','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13005','06.25.07.33.28','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 20:32:11',0,NULL,3,1,3,1,NULL,'matthieuwmc13\r刘\rRA117713502CN\r'),(7301,747772655016,260660055197,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','markem808','markem@inbox.lv','Marks Maksimovs','Yewfield<br>Hawkshead Hill','Ambleside','Cumbria','UNITED KINGDOM','la22 0pr','07532425149','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-01 21:00:14',0,NULL,3,1,2,1,NULL,'markem808\r王\r\\'),(7302,693638601002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','dezlentin','leneyt@live.no','Lene Tindlund','Randulveien 6c','Sellebakk','Østfold','NORWAY','1654','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 21:13:14',0,NULL,3,1,3,1,NULL,'dezlentin\r庄\rRA117713431CN\r'),(7303,654603405001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','embassylimosine','utokhvre@yahoo.com','Urmas Tokhvre','723 A St NE<br># B','Auburn','WA','UNITED STATES','98002-4026','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 21:57:43',0,NULL,3,1,1,1,NULL,'embassylimosine\r徐'),(7304,654608691001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','17tma','t.avis@sky.com','teresa avis','the basement flat<br>17 the esplanade','seaford','East Sussex','UNITED KINGDOM','bn25 1jl','01323872027','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 22:16:41',0,NULL,3,0,3,1,NULL,'17tma\rXXXL\rRA117714009CN'),(7305,652501330018,280559946878,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',200,'photographyacc','stefangraur2010','stefangraur@yahoo.com','Stefan Graur','str. Olanesti, nr. 6, bl38, sc.2, ap72<br>sector 6','Bucuresti','','ROMANIA','060401','+407 43827523','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-01 22:24:23',0,NULL,3,1,5,1,NULL,'stefangraur2010\r欧标\r王\rCP226344675CN'),(7306,747815144016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','mazhitova*2007','forever_after@mail.ru','Assel Mazhitova','Basement Front Flat<br>37 Great Cumberland Place','London','London','UNITED KINGDOM','W1H7TD','07500444807','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-01 22:51:33',0,NULL,3,1,2,1,NULL,'mazhitova*2007\r庄\r\\'),(7307,695251679002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 23:19:14',0,NULL,8,1,17,0,NULL,'nono-ey'),(7308,695252595002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 23:19:15',0,NULL,8,1,17,0,NULL,'nono-ey'),(7309,654617628001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 23:19:15',0,NULL,8,1,17,0,NULL,'nono-ey'),(7310,695252002002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 23:19:16',0,NULL,3,1,4,1,NULL,'nono-ey\r2m 灯架   2\r双灯头  2 欧标\r反光伞  2\r包    1\r反光板 100*150 40*60 5合1     1\r反光板支架    1\r115w 5500k 灯泡  220v   4\rlighting kit  $30\rYW864488690CN\r庄\r反光板单包， 一票两件\r'),(7311,747832622016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',14.5,'hutongstore','75relax','joyful7979@yahoo.co.uk','David Whitaker','79 France Furlong,<br>Gt.Linford,','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK14 5EJ','01908674932','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-01 23:47:06',0,NULL,3,0,3,1,NULL,'75relax\rRA117713520CN\r\\'),(7312,695268966002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','trapero34','saamba2@hotmail.com','SALVADOR GONZALEZ FERRER','C/PERE MARTEL Nº 40,BAJOS,T.B.C','PALMA DE MALLORCA','Baleares','SPAIN','07003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 23:56:26',0,NULL,3,1,2,1,NULL,'trapero34\r徐\r\\'),(7313,695273879002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','ussn36','brunosicotte@gmail.com','Bruno Sicotte','2680 rue de Beausejour<br>app.4','Longueuil','QC','CANADA','J4M 1M5','(514) 942-2022','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 00:18:00',0,NULL,3,1,3,1,NULL,'ussn36\r庄\rRA117713860CN\r'),(7314,695273792002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','paparina-x','fjvila@ono.com','Fco Javier Vila Fernandez','Muntaner 83-C 3º 1ª','Barcelona','Cataluña','SPAIN','08011','666842198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 00:22:01',0,NULL,8,1,17,0,NULL,'paparina-x'),(7315,654637394001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','paparina-x','fjvila@ono.com','Fco Javier Vila Fernandez','Muntaner 83-C 3º 1ª','Barcelona','Cataluña','SPAIN','08011','666842198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 00:22:01',0,NULL,8,1,17,0,NULL,'paparina-x'),(7316,654636721001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','paparina-x','fjvila@ono.com','Fco Javier Vila Fernandez','Muntaner 83-C 3º 1ª','Barcelona','Cataluña','SPAIN','08011','666842198','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 00:22:02',0,NULL,3,1,3,1,NULL,'paparina-x\r摄影背心 Nikon 老款  L   1\r大号内胆包 nikon    1\r防寒罩     1 （老款那种防寒罩，应该是最后一个）\r徐\rRA117713944CN\r\r\r'),(7317,654645746001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','pocharatka83','magdakoziel83@yahoo.ie','Thomas Kucharczyk','\"PFIZER\" Watermarque Building Ringsend Road<br>Dublin 4','Dublin','Dublin','IRELAND','D4','857320556','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 00:56:54',0,NULL,3,1,2,1,NULL,'pocharatka83\r徐\r\\'),(7318,654671909001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','7302edward','yachtvigia@hotmail.com','Edward Atkinson','115/15 Ploenchan 3, Moo 2,<br>Paklok','Thalang','Phuket','THAILAND','83110','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 03:02:16',0,NULL,3,1,6,1,NULL,'7302edward\r庄\rEE442466430CN'),(7319,695295791002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','dcravendavid','crvndcraven@aol.com','David craven','24 chase ln','Cambridge','NY','UNITED STATES','12816-1726','(917) 376-5790','NoPaymentFailure','CheckoutComplete','Other','2011-04-02 03:25:23',0,NULL,3,1,3,1,NULL,'dcravendavid\r庄\r放转美标头\rRA117713459CN'),(7320,654677784001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','your-sweet-home','sweethome.ebay@gmail.com','Maria Belous A.','P.O. Box 1511','Barnaul','Altayregion','RUSSIAN FEDERATION','656066','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 03:35:09',0,NULL,3,1,2,1,NULL,'your-sweet-home\r庄\r、'),(7321,654697392001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','alejandro.arcardini','alejandro.arcardini@hotmail.com','Alejandro Arcardini','osorio 11-75 apto 004','Montevideo','Montevideo','URUGUAY','11300','099280545','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 05:42:42',0,NULL,3,1,2,1,NULL,'alejandro.arcardini\r欧标\r、'),(7322,654701924001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','photography_4kids','annette123000@yahoo.com','Marilyn Jackson','203 Water Tank Rd<br>Lot 5','Ruston','LA','UNITED STATES','71270-8568','','NoPaymentFailure','CheckoutComplete','Other','2011-04-02 06:13:55',0,NULL,3,1,1,1,NULL,'photography_4kids\rXL'),(7323,654024345001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',10,'AA3302',73.52,'hermeshine','nord975','rid75@ukr.net','Mykhaylo Degtyarenko','p.o.box 701','Sumy','','UKRAINE','40003','+38 066 217-54-62','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 06:57:01',0,NULL,3,1,3,1,NULL,'nord975\r绿叶 UV  52mm   5\r绿叶 UV  55mm   10\r绿叶 UV  67mm   5\r绿叶 UV  72mm   3\rRA117713975CN\r、\r'),(7324,654738297001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','inna22088','ofizer22088@rambler.ru','Ilya Ustinov','Naberegnaya reki Ufy 71-134','Ufa','Bashkortostan','RUSSIAN FEDERATION','450105','+79177621450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 09:15:06',0,NULL,3,0,3,1,NULL,'inna22088\r蓝 色   白色 \r王\rRA117711055CN\r\\'),(7325,747995177016,260660050217,'Aluminium Ultra Lightweight 71\" Camera Monopod 3wayhead',1,'AE1603',21.99,'hutongstore','shep803256','daviddodge04@aol.com','david sheppard','23 the ridgeway','south shields','Tyne and Wear','UNITED KINGDOM','ne34 8bb','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 11:07:22',0,NULL,3,1,3,1,NULL,'shep803256\r刘\rRA117711679CN\r\\'),(7326,763383276015,250692240197,'Remote Control Cord for Nikon D300s/D200/D700​/D3 MC-30',1,'AA2220',2.89,'hutongstore','altea-tdi-sport','andy-wills@hotmail.co.uk','ANDY WILLS','C/O RAWLE GAMMON & BAKER<br>FORDTON','CREDITON','DEVON','UNITED KINGDOM','EX17 3BZ','01363772246','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 11:40:57',0,NULL,3,1,2,1,NULL,'altea-tdi-sport\r徐'),(7327,695436123002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','viktor4i4ek','christopher-grand@ya.ru','Viktor Prymachenko','avenue Obolonskiy, 16-e, ap. 350','Kiev','','UKRAINE','04205','+380662726672','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 13:13:30',0,NULL,3,1,2,1,NULL,'viktor4i4ek\r徐'),(7328,654803914001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','origionalgp','jameson.wheeler@sympatico.ca','jameson wheeler','77 balmoral dr.','brampton','ON','CANADA','l6t1v2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 13:31:06',0,NULL,3,1,3,1,NULL,'origionalgp\r庄\rRA117711815CN\r\\'),(7329,654815495001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','pedritto_kite','pedritto_mo@hotmail.com','pedro morales dominguez','c/prokofiev nº9 1-c','torremolinos (málaga)','Andalucía Ceuta y Melilla','SPAIN','29620','667438651','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 14:12:07',0,NULL,3,1,3,1,NULL,'pedritto_kite\rRA117711872CN\r\\'),(7330,695461141002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','terry.hizon','terry.hizon0608@hotmail.com','Terry Hizon','#249 Lauro st. Villacatalina subd.<br>Dasmarinas, Cavite','Dasmariñas','Cavite','PHILIPPINES','4114','9178800439','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 14:28:33',0,NULL,3,1,3,1,NULL,'terry.hizon\rRA117711943CN\r\\'),(7331,654853459001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','mavesariaxym','mavesari@yahoo.es','manoli rizo san segundo','urb. huerta las pilas c/ thomas edison, 31','algeciras (cadiz)','andalucia cadiz','SPAIN','11204','607190459','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 16:01:14',0,NULL,3,1,2,1,NULL,'mavesariaxym\r徐'),(7332,695500383002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 16:18:16',0,NULL,8,1,17,0,NULL,'robert5525'),(7333,763496965015,250666859818,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',48.9,'hutongstore','the-normad03','normad03@hotmail.com','Dean Brindle','12 Maes Famau','Rhyl','Denbighshire , North Wales','UNITED KINGDOM','LL18 4SJ','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-02 16:27:01',0,NULL,3,1,4,1,NULL,'the-normad03\rlighting kit $25\r庄\rYW864488841CN'),(7334,652771830018,280522563067,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','osetia1','art-osetia@mail.ru','Mihnevsky Vladislav Valerevich','13 Street Vorovskogo<br>Apartment 59','Kazan','','RUSSIAN FEDERATION','420057','+79375228723','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-02 16:46:21',0,NULL,3,1,5,1,NULL,'osetia1\r2m 背景架   （ 白色布）  1\r刘\rCP226344573CN'),(7335,654890337001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','maxwellpenney','maxpenney@hotmail.com','MAXWELL PENNEY','43.BRIGUS ROAD, APT 112<br>P.O. BOX 535','WHITBOURNE','NL','CANADA','A0B3K0','(709) 759-3397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 17:38:54',0,NULL,3,1,2,1,NULL,'maxwellpenney\r徐'),(7336,763588660015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','cellavee','rg@raygilbert.plus.com','Raymond Gilbert','65 Main Street<br>Stoneyburn','Bathgate','West Lothian','UNITED KINGDOM','EH47 8BY','01501762538','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 19:08:50',0,NULL,3,1,3,1,NULL,'cellavee\rRA117711930CN\r\\'),(7337,695597708002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','pietro-82ct','pietro82ct@hotmail.it','Pietro Zappalà','Via. C. Marchesi, 4','Misterbianco','CT','ITALY','95045','3494551005','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 19:51:48',0,NULL,3,1,4,1,NULL,'pietro-82ct\rlight stand $20\r2m 灯架  1\r斜臂  1\r50-70柔光棚 通用塑料卡口  1\r刘\rYW864488830CN\r\r'),(7338,763622890015,250615144668,'YongNuo Flash Battery Pack 8*AA Canon Flash 580EXII 550',1,'AB3307',32.99,'hutongstore','nilmattos31','nilmattos31@yahoo.co.uk','Nilton Mattos','Flat 4,  81 Burnley Road','Dollis Hill','London','UNITED KINGDOM','NW10 1EE','02088305469','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 20:04:26',0,NULL,3,1,3,1,NULL,'nilmattos31\r王\rRA117711033CN\r\\'),(7339,654962832001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 20:08:12',0,NULL,8,1,17,0,NULL,'robert5525'),(7340,695609104002,120448646606,'New ND4 Filter for Cokin P Series Neutral Density ND 4',1,'AA2324',7.2,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:24:53',0,NULL,8,1,17,0,NULL,'lobi2318'),(7341,654967367001,110414378946,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:24:57',0,NULL,8,1,17,0,NULL,'lobi2318'),(7342,654966783001,110414378578,'New ND2 Filter for Cokin P Series Neutral Density ND 2',1,'AA2323',7.2,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:25:01',0,NULL,8,1,17,0,NULL,'lobi2318'),(7343,654964796001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:25:04',0,NULL,8,1,17,0,NULL,'lobi2318'),(7344,695608024002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',3.55,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:25:24',0,NULL,3,1,3,1,NULL,'lobi2318\r72mm 接口环  1\r77mm 接口环  1\r托架   1\r渐变灰  1\rND2      1\rND4      1\rND8      1\r徐\rRA117711047CN\r\\'),(7345,695608452002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:26:02',0,NULL,8,1,17,0,NULL,'lobi2318'),(7346,695633060002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','pietro-82ct','pietro82ct@hotmail.it','Pietro Zappalà','Via. C. Marchesi, 4','Misterbianco','CT','ITALY','95045','3494551005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 21:12:52',0,NULL,8,1,17,0,NULL,'pietro-82ct'),(7347,695649241002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','vicentesagredo','vicentesagredo@gmail.com','fernando sagredo stevens','La Marina 7310 dept 1306','Talcahuano','Bio-Bio','CHILE','4260000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 21:57:13',0,NULL,3,1,3,1,NULL,'vicentesagredo\rRA117711767CN\r\\'),(7348,655030526001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 23:19:08',0,NULL,8,1,17,0,NULL,'robert5525'),(7349,655038223001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','the_fanatic_2','fanatic2@hotmail.com','Jonathan Lauzon','750 Pageau','St-Jerome','QC','CANADA','J7Z6E6','(450) 438-2975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 23:49:05',0,NULL,3,1,2,1,NULL,'the_fanatic_2\r徐'),(7350,655040146001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','jaimeluanco','nico1967@ymail.com','JAIME GONZALEZ FERNANDEZ','LA CRUZ  37 BAJO A','LUANCO','Asturias','SPAIN','33440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 00:02:10',0,NULL,3,1,2,1,NULL,'jaimeluanco\r徐'),(7351,695728952002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','lubrician10','lubrician@gmail.com','Larry Luber','5228 Tresham ct','Charlotte','NC','UNITED STATES','28215-5056','(704) 507-9751','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 03:00:31',0,NULL,3,1,1,1,NULL,'lubrician10\r徐'),(7352,0,110667379443,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','trevormotors11','trevormotors@gmail.com','Trevor Davis','2090 Corson St','Pasadena','CA','UNITED STATES','91107-3270','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 03:35:45',0,NULL,3,1,1,1,NULL,'trevormotors11\r徐'),(7353,695751838002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','huyddd','darrendao@gmail.com','Darren Dao','3476 Marathon Dr','San Diego','CA','UNITED STATES','92123-2622','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 04:51:37',0,NULL,3,1,1,1,NULL,'huyddd\r徐'),(7354,695780192002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','djezz91','dhochart@club-internet.fr','didier hochart','2 clos du village','écharcon','Ile-de-France','FRANCE','91540','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 07:26:37',0,NULL,3,0,3,1,NULL,'djezz91\rXXXL\r王\rRA117711965CN\r\\'),(7355,695786937002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','izhak801izhak','izhak801@hotmail.com','izhak haime','aharoov 212/8','atlit','','ISRAEL','30300','00972506829988','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 07:51:44',0,NULL,3,1,3,1,NULL,'izhak801izhak\rRA117711719CN\r\\'),(7356,655139525001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','wan_*6','baitrahmah@yahoo.com','Wan Saifuldin W Hassan','Fakulti Pengajian Kontemporari Islam<br>Universiti Sultan Zainal Abidin (UNiSZA)','Kuala Terengganu','Terengganu','MALAYSIA','21300','0199200963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 08:06:40',0,NULL,8,1,17,0,NULL,'wan_*6'),(7357,655139028001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','wan_*6','baitrahmah@yahoo.com','Wan Saifuldin W Hassan','Fakulti Pengajian Kontemporari Islam<br>Universiti Sultan Zainal Abidin (UNiSZA)','Kuala Terengganu','Terengganu','MALAYSIA','21300','0199200963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 08:06:43',0,NULL,3,1,2,1,NULL,'wan_*6\r52-58 双阳环   1\rcanon-58mm 反接环   1\r庄'),(7358,654721895001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','varisornd','varisornd@gmail.com','varisorn ditsaranont','54 Soi Taksin 14, Taksin Rd.,<br>Bukkalo','Thonburi','Bangkok','THAILAND','10600','66891105449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 08:14:24',0,NULL,3,1,2,1,NULL,'varisornd\r徐'),(7359,655147064001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','iain8368','iainlamond@dodo.com.au','iain lamond','280 westernport rd','lang lang','Victoria','AUSTRALIA','3984','0359975927','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 08:29:10',0,NULL,3,0,3,1,NULL,'iain8368\rXXXL\r刘\rRA117711020CN\r\\'),(7360,695791154002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','blondiini','virpi.niskanen@bosis.fi','Virpi Niskanen','Reunatie 8','Lempaala','','FINLAND','37550','35833751492','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 09:00:43',0,NULL,3,0,3,1,NULL,'blondiini\r摄影背心 canon 老款 xxl   1\r摄影背心 夏季  xl    1\r庄\rRA117713547CN\r\\'),(7361,695787250002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',22.9,'hermeshine','blondiini','virpi.niskanen@bosis.fi','Virpi Niskanen','Reunatie 8','Lempaala','','FINLAND','37550','35833751492','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 09:00:44',0,NULL,8,0,17,0,NULL,'blondiini'),(7362,763881975015,250627432317,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',16.99,'hutongstore','tony12340','tonykaye2004@orangehome.co.uk','Colin Grellis','96 Crock Lane','Bridport','Dorset','UNITED KINGDOM','DT64DQ','01308427882','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-03 09:31:57',0,NULL,3,1,2,1,NULL,'tony12340\r庄'),(7363,695879947002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','bb6800','bab1985@aussiebroadband.com.au','B Blake','5/30 Gordon Street','Traralgon','Victoria','AUSTRALIA','3844','0351745713','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 12:22:29',0,NULL,3,1,3,1,NULL,'bb6800\rRA117711798CN\r\\'),(7364,655235420001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','jorisfriat','friat.joris@gmail.com','joris friat','rue de la Jaqua 122','Attalens','Fribourg','SWITZERLAND','1616','0793598983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 12:37:31',0,NULL,3,1,2,1,NULL,'jorisfriat\r王'),(7365,748626226016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.39,'hutongstore','andyl.33','andy@rc31.co.uk','Andy Long','33 Chestnut Close<br>Kings Hill','West Malling','Kent','UNITED KINGDOM','ME19 4FP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-03 14:30:04',0,NULL,3,1,2,1,NULL,'andyl.33\r庄'),(7366,695974336002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT052',87.8,'hermeshine','toyz_joe','jaffyjaf99@hotmail.com','Joe Fleury','356, av. Fiset','Donnacona','QC','CANADA','G3M 2P5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 15:50:02',0,NULL,8,1,17,0,NULL,'toyz_joe'),(7367,695974067002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.95,'hermeshine','toyz_joe','jaffyjaf99@hotmail.com','Joe Fleury','356, av. Fiset','Donnacona','QC','CANADA','G3M 2P5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 15:50:04',0,NULL,3,1,5,1,NULL,'toyz_joe\r2m 灯架   2\r云台   2\r柔光伞   2\r301p 1托二    1\r庄\rCP226344587CN'),(7368,696026788002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','kleiberfragoso','kfvideo@gmail.com','Kleiber Sequeira','Rua República do Peru, 193/ 41<br>Copacabana','Rio de Janeiro','Rio de Janeiro','BRAZIL','22021040','55-21- 254858598','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 17:01:42',0,NULL,3,1,5,1,NULL,'kleiberfragoso\r王\r改发1.55m高的，再加一个717的快装板给他\rCP226344595CN'),(7369,696105527002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 18:23:22',0,NULL,8,1,17,0,NULL,'robert5525\r'),(7370,696132630002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','subotai-2009','mcarb2008@gmail.com','Miguel Carmena Bermudez','C/ Santa María de Gracia, 34 - esc. A - 1º izq.','Cordoba','Andalucía Ceuta y Melilla','SPAIN','14002','619613683','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 18:51:46',0,NULL,3,1,4,1,NULL,'subotai-2009\rtripod  $16\r王\rYW864488782CN'),(7371,655504605001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','neronmusico','jmdele@hotmail.com','JOSE MARIANO GIL DELEGIDO','C/ CAMI VELL DE L\'ESTACIO<br>Nº6 3er P.9','ONTINYENT','Comunidad Valenciana','SPAIN','46870','678422245','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 19:22:28',0,NULL,3,1,3,1,NULL,'neronmusico\r王\rRA117711016CN\r\\'),(7372,764333095015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.58,'hutongstore','archivlad','spirov.vladimir@gmail.com','Vladimir Spirov','6 Cleveland Road','Ealing','London','UNITED KINGDOM','W13 8AU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-03 19:42:28',0,NULL,3,1,2,1,NULL,'archivlad\r王'),(7373,655542722001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','mikeis1212','mikesbenjamin@gmail.com','Michael Benjamin','151 South Bernardo Ave<br>Apt 14','Sunnyvale','CA','UNITED STATES','94086-5657','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 20:11:42',0,NULL,3,1,1,1,NULL,'mikeis1212\r徐'),(7374,696203336002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','juro168','juraj168@gmail.com','Juraj Belica','Jeskova ves 168<br>958 45 Velky Kliz','okres Partizanske','','SLOVAK REPUBLIC','958 45','+421 944 115 812','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 20:13:58',0,NULL,3,1,3,1,NULL,'juro168\rRA117711682CN\r\\'),(7375,764391834015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','electronicparts321','ivotsolov@yahoo.com','Ivailo  Tsolov','Kr.Pishurka 1','Vratsa','Vratsa','BULGARIA','3000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 20:49:08',0,NULL,8,1,17,0,NULL,'electronicparts321'),(7376,764030984015,250599405329,'Green.L 58mm 58 Neutral Density ND4 Filter ND 4 New',1,'AE2303',4.1,'hutongstore','electronicparts321','ivotsolov@yahoo.com','Ivailo  Tsolov','Kr.Pishurka 1','Vratsa','Vratsa','BULGARIA','3000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 20:49:08',0,NULL,3,1,2,1,NULL,'electronicparts321\r热靴保护盖  普通   1\r绿叶 ND4  58mm   1\r庄'),(7377,749006607016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','ogg78','oleg.gritsinevich@gmail.com','Oleg Grytsynevych','Webersgade 1, 4 th','Copenhagen','O','DENMARK','2100','4531955419','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 21:40:22',0,NULL,3,1,2,1,NULL,'ogg78\r他买了2只lenspen 但不合并，分开发\r徐'),(7378,749008710016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','ogg78','oleg.gritsinevich@gmail.com','Oleg Grytsynevych','Webersgade 1, 4 th','Copenhagen','O','DENMARK','2100','4531955419','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 21:43:25',0,NULL,3,1,2,1,NULL,'ogg78\r他买了2只lenspen 但不合并，分开发\r庄'),(7379,749013699016,260660055197,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','rynektbg','compac@wp.pl','Damian Rys','2 Napier Road<br>54 Merlin House','London','London','UNITED KINGDOM','EN3 4QJ','02082110616','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-03 21:53:02',0,NULL,3,1,2,1,NULL,'rynektbg\r徐'),(7380,696273802002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 22:33:11',0,NULL,8,1,17,0,NULL,'robert5525'),(7381,696309802002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 00:17:36',0,NULL,3,1,3,1,NULL,'arnorolf10\r王\rRA117711988CN\r\\'),(7382,655649135001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','cockney52','wcpooh26@hotmail.com','bill chandler','po box 359','harrah','OK','UNITED STATES','73045-0359','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 00:26:58',0,NULL,3,1,1,1,NULL,'cockney52\r徐'),(7383,696317799002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',5,'AE3102',39.45,'hermeshine','kluzz','kluzz@radical.org','Jan Fredrik Leversund','Alvsvåg 115','BREMNES','','NORWAY','5430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 00:37:52',0,NULL,3,1,3,1,NULL,'kluzz\r注意是5个\r刘\rRA117711991CN\r\\'),(7384,764537717015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','rallynitros','rally27@poczta.fm','Lukas Rabczynski','106 ard alainn<br>Merlin Park','Galway','Galway','IRELAND','1','091471071','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 02:03:54',0,NULL,3,1,3,1,NULL,'rallynitros\rRA117711912CN\r\\'),(7385,655697214001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1305',5,'hermeshine','taraztiger','barryquiet@yahoo.com','Barry Ackerson','12818 Sunnymeadows Dr','Moreno Valley','CA','UNITED STATES','92553-5961','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 02:50:30',0,NULL,3,1,1,1,NULL,'taraztiger\r徐'),(7386,653427387001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','yenna709','jenna@okito.net','Jenna Jolley','4388 El Camino Real #378','Los Altos','CA','UNITED STATES','94086','(650) 391-4094','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 03:17:28',0,NULL,3,1,1,1,NULL,'yenna709\r徐'),(7387,655713421001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','puntella','juanpuntella@yahoo.com.ar','Juan Sebastián Puntella','Cnel Lynch 1765','Villa Luzuriaga','Buenos Aires','ARGENTINA','B1753BUW','54-11 4461-2907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 04:02:50',0,NULL,3,1,2,1,NULL,'puntella\r庄'),(7388,655728868001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','grif_5','grif_5@yahoo.com','Benjamin C Griffith','209 N Hayes St','Bellefontaine','OH','UNITED STATES','43311-2405','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 05:38:57',0,NULL,3,1,1,1,NULL,'grif_5\r徐'),(7389,696403933002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','iceparrot','signups@iceparrot.com','Josh and Erika Thornes','15579 Walton Heath Row','San Diego','CA','UNITED STATES','92128-4477','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 05:44:25',0,NULL,3,1,1,1,NULL,'iceparrot\r徐'),(7390,696419241002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','blackdesirepg','blackdesire@live.cn','Qi Gu','Unit 32/57-63 Belmore Rd','Randwick','New South Wales','AUSTRALIA','2031','0421960787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 07:10:05',0,NULL,3,1,2,1,NULL,'blackdesirepg\r徐'),(7391,655760827001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','moklanarpa','moklanarpa@yahoo.es','Miguel Ángel Moclán Arpa','Avenida Carlos I, 9, 9º A','San Sebastián','Guipuzcoa','SPAIN','20011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 08:23:25',0,NULL,8,1,17,0,NULL,'moklanarpa'),(7392,696433172002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','moklanarpa','moklanarpa@yahoo.es','Miguel Ángel Moclán Arpa','Avenida Carlos I, 9, 9º A','San Sebastián','Guipuzcoa','SPAIN','20011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 08:23:26',0,NULL,3,1,4,1,NULL,'moklanarpa\r2m 灯架  1\rb座   1\r柔光伞   1\r80cm 5in1 反光板   1\r一票两件  lighting kit  $20\rYW864488771CN'),(7393,655761243001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','jirasak2007_123','jirasak_pollamai@yahoo.com','Mr.Kasipat Phonlamai','138 samorai mokamontree Rd.','Muang Nakornratchsima','Nakornratchsima','THAILAND','30000','0858566099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 08:26:09',0,NULL,3,1,3,1,NULL,'jirasak2007_123\r小号灰卡   1\r45w灯泡   2\r庄\rRA117711974CN\r\\'),(7394,655767137001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','algete2','viciao_ps2@yahoo.es','mayte collado rodriguez','c/ rio tajo nº2 2º pta 4','san sebastian de los reyes','madrid','SPAIN','28701','916510138','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 08:54:35',0,NULL,3,1,4,1,NULL,'algete2\rtripod  $16\rYW864488760CN\r'),(7395,764647132015,250746713895,'67mm Graduated Neutral Density Filter Gradual Grey 67',1,'AA3319',5.2,'hutongstore','2006lapin','misteraliyah@hotmail.fr','GANGAT Salim Ahmed','65, rue des Poissonniers<br>Interphone: 201, Bat: A, 1er étage, Gauche','Paris','Ile-de-France','FRANCE','75018','06.26.77.03.29','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 08:58:58',0,NULL,3,1,2,1,NULL,'2006lapin\r庄'),(7396,696451946002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','hirviana','ssanchezdelgado@gmail.com','Silvia SÁNCHEZ DELGADO','Plaza Virgen del Rosario Nº3','Huelva','Andalucía Ceuta y Melilla','SPAIN','21007','636958575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 09:36:44',0,NULL,3,1,2,1,NULL,'hirviana\r徐\r\\'),(7397,749256917016,260660053846,'Photo Studio Background Support 2m×3m 7 x 10 ft + BAG',1,'AO0011',54.6,'hutongstore','sebasgini','sginardnicolau@gmail.com','sebastia ginard nicolau','ses parres nº63 2d','manacor','Baleares','SPAIN','07500','654789875','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-04 10:45:02',0,NULL,3,1,4,1,NULL,'sebasgini\rbackground support  $25\r王\rYW864488756CN'),(7398,655863571001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','merkur_71','gerhard.bruckner1@chello.at','Gerhard Bruckner','Etrichstr. 19/3/5','Wien','','AUSTRIA','1110','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 14:31:29',0,NULL,3,1,3,1,NULL,'merkur_71\r刘\rRA117711665CN\r\\'),(7399,655866475001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','mariochristou1','mariochristou@bigpond.com','mario christou','64 monash rd','newborough','Victoria','AUSTRALIA','3825','04383291910438329191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 14:40:34',0,NULL,3,1,3,1,NULL,'mariochristou1\r徐\rRA117712008CN\r\\'),(7400,696558717002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','candee19','flysxygsxr@yahoo.com','Crystal Skolnik','131 N Parkside Dr','Bardstown','KY','UNITED STATES','40004-9443','(352) 217-7577','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 15:28:29',0,NULL,3,1,1,1,NULL,'candee19\r徐'),(7401,696520668002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','oneownercar','oneownercar@clara.co.uk','Roy Lawrence','10 Turnberry Drive,Bricket Wood','St.Albans','Hertfordshire','UNITED KINGDOM','AL23UF','01923671573','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 15:38:34',0,NULL,3,1,3,1,NULL,'oneownercar\rRA117711855CN\r\\'),(7402,696562072002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','leondcx','allan_hudson@hotmail.com','Allan Hudson','Av. General Rondon, 3542<br>Vila Leopodina','Duque de Caxias','Rio de Janeiro','BRAZIL','25050-230','552126528640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 15:41:01',0,NULL,3,1,3,1,NULL,'leondcx\r\\\rRA117711926CN\r'),(7403,655895092001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','robin372','tramptnv@mail.ru','Andrey Bannov','11-4-34','Zarafshan','','UZBEKISTAN','210300','+998795729372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 16:03:47',0,NULL,3,1,2,1,NULL,'robin372\r庄'),(7404,695102243002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',107.28,'hermeshine','countrydreams','dianne.humble@yahoo.com','Dianne G. Humble','8135 Rustin Rd','Middleton','ID','UNITED STATES','83644-5330','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 16:09:24',0,NULL,3,1,4,1,NULL,'countrydreams\r2m 灯架  1\rB座   1\r柔光伞   1\r斜臂   1\rlenspen   1\rNikon 老款 黑色 背心  xl   1\r庄\rYW864488745CN\r'),(7405,696577309002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','art_buyer_123','transaction@fsmail.net','H N E Bayley','9 Holly Terrace','York','North Yorkshire','UNITED KINGDOM','YO10 4DS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 16:14:55',0,NULL,3,1,2,1,NULL,'art_buyer_123\r徐'),(7406,696665685002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','bepestar','becseypeter@freemail.hu','peter becsey','28. Petnehazy Str. 7f/7d','budapest','budapest','HUNGARY','1139','+36308202663','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 19:07:31',0,NULL,3,0,3,1,NULL,'bepestar\rXL\r王\rRA117711722CN\r\\'),(7407,764945774015,250601901408,'Wireless Remote Control Cord for Canon 500D/1000D/450D',1,'AA3210',11.47,'hutongstore','geavir','kr@elvis.dk','Kristian Rosengren','Monradsvej 16a','Viby j','','DENMARK','8260','26237779','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 19:30:40',0,NULL,3,1,2,1,NULL,'geavir\r庄'),(7408,656006506001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','junglistic_maxim','ebay_junglistic@mail.ru','Mogildea Maxim','A. Xenopol 11','Chisinau','','MOLDOVA, REPUBLIC OF','MD-2051','079844160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 19:35:33',0,NULL,3,1,2,1,NULL,'junglistic_maxim\r徐'),(7409,656029727001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','vaizdostudija','uab@vaizdostudija.com','Arunas Eimulis','Tulpiu 13-3','Klaipeda','','LITHUANIA','91210','+370 673 92399','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 20:17:30',0,NULL,3,1,2,1,NULL,'vaizdostudija\r'),(7410,653990414018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','andresurma','asurma@yahoo.com','Andre Surma','5814 E Pinyon Pine Dr','Orange','CA','UNITED STATES','92869-6006','(714) 633-4783','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-04-04 20:32:19',0,NULL,3,1,4,1,NULL,'andresurma\r灯泡是110v\r刘\rYW864488734CN'),(7411,765003804015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',1.88,'hutongstore','terciopellojosh','dzordz@poczta.onet.pl','Josh Rostkowski','5 Windsor Close','Leyland','Lancashire','UNITED KINGDOM','PR25 1JU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-04 20:58:01',0,NULL,3,1,2,1,NULL,'terciopellojosh\r刘'),(7412,656049339001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','poovey33','x_sveta_x@hotmail.com','Sveta Poovey','1 Easy St','Winfield','KS','UNITED STATES','67156','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 20:58:37',0,NULL,3,0,1,1,NULL,'poovey33\r1.6X2.1 背景布  黑色   1\r徐'),(7413,656063070001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','femto_e','femtoe@earthlink.net','Lei Zhang','111 Parker St.','Acton','MA','UNITED STATES','01720','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 21:32:31',0,NULL,3,1,1,1,NULL,'femto_e\r徐'),(7414,655405241001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','perova','furtuke@bk.ru','Natalia Furtuke','st. Smorodina house 12, apartment 17','Lipetsk','Russian Federation','RUSSIAN FEDERATION','398046','+79202448833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 22:06:34',0,NULL,3,1,2,1,NULL,'perova\r庄\r\\'),(7415,656119277001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','caduviterbo','caduprado@gmail.com','Carlos Eduardo Viterbo Prado','Rua Soares Couto 201/03','Belo Horizonte','Minas Gerais','BRAZIL','30380760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 00:50:39',0,NULL,8,1,17,0,NULL,'caduviterbo'),(7416,696800803002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','caduviterbo','caduprado@gmail.com','Carlos Eduardo Viterbo Prado','Rua Soares Couto 201/03','Belo Horizonte','Minas Gerais','BRAZIL','30380760','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 00:50:42',0,NULL,3,1,3,1,NULL,'caduviterbo\r圆形柔光棚 60cm   1\r爵影碗罩P1    1\r刘\rRA117711740CN\r\\'),(7417,696811020002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','ryrvikryrvik','medolaonas@hotmail.se','magnus ryrvik kjäll','hjortmossegatan 32','trollhättan','västra götaland','SWEDEN','46151','0520203000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 01:22:01',0,NULL,3,1,4,1,'YW864488653CN ','ryrvikryrvik\rlighting kit  $25\r庄\r'),(7418,696810914002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','fookdeck','fookdeck@pacbell.net','Douglas Lee','870 Regulus St','Foster City','CA','UNITED STATES','94404','(650) 522-8942','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 01:22:26',0,NULL,3,1,1,1,NULL,'fookdeck\r徐'),(7419,696846729002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','jirasak2007_123','jirasak_pollamai@yahoo.com','Mr.Kasipat Phonlamai','138 samorai mokamontree Rd.','Muang Nakornratchsima','Nakornratchsima','THAILAND','30000','0858566099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 03:37:49',0,NULL,8,1,17,0,NULL,'jirasak2007_123'),(7420,653850237001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','srfrancisco69','srfrancisco69@yahoo.com.au','simon Francis','3<br>Findon Avenue','Caufield North','Victoria','AUSTRALIA','3161','0418178884','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 04:19:24',0,NULL,3,1,4,1,NULL,'srfrancisco69\r澳标头 \rlighting kit  $30  \r刘\rYW864488664CN'),(7421,696875635002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','sadak3d','sadak@hqcreative.ae','sadak kalathil','hqcreative, 103,liberty building, garhoodh, dubai,uae','garhodh','dubai','UNITED ARAB EMIRATES','61886','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 06:25:35',0,NULL,3,1,3,1,NULL,'sadak3d\rRA117711838CN\r\\'),(7422,656195326001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','kirill602','kir602@mail.ru','kiriLL Grebenev','st.Unih Lenincev 79 building 6 , apartment 48','Moscow','','RUSSIAN FEDERATION','109443','+79261493021','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 06:55:43',0,NULL,3,1,3,1,NULL,'kirill602\rRA117711824CN\r\\'),(7423,656207089001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','flank3r','flanker@rt.sk','Ondrej Morháč','M. R. Štefánika 14','Zvolen','','SLOVAK REPUBLIC','96001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 07:55:55',0,NULL,3,1,2,1,NULL,'flank3r\r徐'),(7424,749765539016,260661403446,'TianYa 77mm CPL filter New 77 Circular Polarizing C-PL',1,'AA2307',5.3,'hutongstore','symonmark07','mark-brookman@live.com','Mr S M Brookman','20 York road','Littlehampton','West Sussex','UNITED KINGDOM','BN17 6EN','01903715584','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-05 07:58:39',0,NULL,5,0,18,0,NULL,'symonmark07\r'),(7425,656208109001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','digitium','digitium@gmail.com','Darrell Lye','38 Loyang View','default','','SINGAPORE','507232','+6590669612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 08:55:10',0,NULL,3,1,11,1,NULL,'digitium\r徐\r\\'),(7426,749789403016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','astralgr','astralgr@mycosmos.gr','Mparmperoglou Marios','Papanastasiou 66','Heraklion','Crete','GREECE','71306','00306977461733','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-05 09:38:23',0,NULL,3,1,4,1,NULL,'astralgr\rlighting kit  $30\r欧标\r庄\rYW864488675CN'),(7427,656234125001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','adamoscz','red.dog@email.cz','Adam Strojsa','Pruchova 3169','Kladno','','CZECH REPUBLIC','27201','+420721102097','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 10:07:46',0,NULL,3,1,5,1,NULL,'adamoscz\r刘\rCP226344600CN'),(7428,696921701002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','hell122010','hell12@mail.ru','Aleksander Golovin','Gurteva, 5, 13','Orel','','RUSSIAN FEDERATION','302028','+7(903)8810081','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 10:16:39',0,NULL,3,1,5,1,NULL,'hell122010\r三脚架 伟峰 EI-717  135   1\r肩架   1\r庄\rCP226344613CN'),(7429,696930037002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','le_juki','jukkatallinen@gmail.com','Jukka Tallinen','Toppilansaarentie 3 B 19','Oulu','-','FINLAND','90510','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 10:49:39',0,NULL,3,1,3,1,NULL,'le_juki\r庄\rRA117711736CN\r\\'),(7430,656244507001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','hell122010','hell12@mail.ru','Aleksander Golovin','Gurteva, 5, 13','Orel','','RUSSIAN FEDERATION','302028','+7(903)8810081','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 10:51:30',0,NULL,8,1,17,0,NULL,'hell122010'),(7431,656247378001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','fireweed72','yukonbee@gmail.com','Elizabeth Beard','409-130 Jameson Ave','Toronto','ON','CANADA','M6K 2Y2','(416) 912-9691','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 11:02:52',0,NULL,3,1,3,1,NULL,'fireweed72\rRA117711886CN\r\\'),(7432,656254683001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','valnabi','valentinas.nabijevas@gmail.com','Valentinas Nabijevas','Zemaiciu g 88-3','Kaunas','','LITHUANIA','44182','37061420015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 11:34:03',0,NULL,3,1,2,1,NULL,'valnabi\r刘'),(7433,696943851002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','dant_riga','dant.riga@gmail.com','dmitry antipov','Anninmuizas bulvars 64-42','Riga','','LATVIA','LV-1029','+371 29129028','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 12:04:14',0,NULL,3,1,3,1,NULL,'dant_riga\r申报： reflector  $10\r王\rRA117711529CN\r\\'),(7434,765297321015,250600523459,'Shutter Release Remote Cord For Canon 500D 450D RS-60E3',1,'AA3203',2.98,'hutongstore','amanda.2969','amanda.laughton@hotmail.co.uk','amanda laughton','6 ST GILES HOUSE<br>RHOSNESNI LANE','WREXHAM','Wrexham','UNITED KINGDOM','LL12 7NJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-05 13:04:07',0,NULL,3,1,2,1,NULL,'amanda.2969\r庄'),(7435,696969456002,120461614281,'JJC Hand Strap Grip  HS-1 Nikon D40 D60 Canon 450D',1,'AB1408',6.99,'hermeshine','editor9','abc9@hot.ee','altor-san OÜ','Jaama 29','Võru','','ESTONIA','65604','37253451682','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:22:42',0,NULL,5,1,18,0,NULL,'editor9\r刘'),(7436,696971949002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','barbosha_max','barbosha@rambler.ru','Maxim Chuprina','Korchagina str., 4','Nezhin','Chernigov','UKRAINE','16600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:23:27',0,NULL,3,1,2,1,NULL,'barbosha_max\r庄'),(7437,656286263001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','igbkmrf','08vev00@gmail.com','Alexandr Kapaev','Trudovaya St., 66, apt.169.','Irkutsk','Irkutskaya Oblast','RUSSIAN FEDERATION','664047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:30:12',0,NULL,3,1,2,1,NULL,'igbkmrf\r徐'),(7438,696576877002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',10.47,'hermeshine','boonheng84','hin_wsc@hotmail.com','Mak Boon Heng','KAMPONG SUNGAI LIANG, TUNGGU LIAN<br>SIMPANG 1307, NO32','Kuala Belait','','BRUNEI DARUSSALAM','KC2735','6738607072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:48:19',0,NULL,3,1,3,1,NULL,'boonheng84\r刘\rRA117711617CN\r\\'),(7439,697013543002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','cyclophonie','reader422002@yahoo.fr','jean-pierre benaroya','101 bd voltaire','asnieres','Ile-de-France','FRANCE','92600','0147930912','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 15:30:45',0,NULL,3,1,2,1,NULL,'cyclophonie\r庄'),(7440,697023140002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','yazhun','a.somos@gmail.com','András Somos','33 Tarkö Street','Budapest','','HUNGARY','1182','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 15:55:08',0,NULL,3,1,2,1,NULL,'yazhun\r徐'),(7441,0,110667386036,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','jkjdawg1','kerney_inc@hotmail.com','Michelle Kerney','310 7th Ave W','Kalispell','MT','UNITED STATES','59901-4762','(406) 212-5734','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 09:30:41',0,NULL,7,0,18,0,NULL,'jkjdawg1'),(7442,697040467002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sevamobile','komkovv@gmail.com','Valeriy Komkov','Novogireevskaya Str. 14, korpus 2, kv.8. Domofon 88.','Moscow','','RUSSIAN FEDERATION','111401','+7(926)250-0200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 16:43:31',0,NULL,8,1,17,0,NULL,'sevamobile'),(7443,697042411002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sevamobile','komkovv@gmail.com','Valeriy Komkov','Novogireevskaya Str. 14, korpus 2, kv.8. Domofon 88.','Moscow','','RUSSIAN FEDERATION','111401','+7(926)250-0200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 16:44:21',0,NULL,3,1,5,1,NULL,'sevamobile\r2m 灯架   2\rb座     2\r柔光伞   2\r王\rCP226344627CN'),(7444,656358356001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','carlos1980e','carlos.mail@terra.es','Carlos Escanlar','C/ Ternera, 6 1ºC','Madrid','Madrid','SPAIN','28013','678303671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 16:56:31',0,NULL,3,1,2,1,NULL,'carlos1980e\r庄'),(7445,697072048002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','alozoven','lozovenko.anatoliy@gmail.com','Anatoliy Lozovenko','13-y Voennyy Gorodok d.15 kv.16','Almaty','Almaty oblast','KAZAKHSTAN','050030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:51:37',0,NULL,3,1,3,1,NULL,'alozoven\r王\rRA117711841CN\r\\'),(7446,697083456002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',5,'AA3306',19.95,'hermeshine','elpeladoedu','enocetti@adinet.com.uy','EDUARDO NOCETTI','AVDA  RONDEAU  1470','MONTEVIDEO','','URUGUAY','11100','59829029106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 18:13:12',0,NULL,3,1,3,1,NULL,'elpeladoedu\r庄\rRA117711784CN\r\\'),(7447,656411871001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',18.19,'hermeshine','johannesnicolaspalm','johannespalm77@gmail.com','Johannes Palm','Hornsgatan 6g','Höganäs','','SWEDEN','26339','0733858633','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-05 18:48:36',0,NULL,3,1,3,1,NULL,'johannesnicolaspalm\r刘\rRA117711957CN\r\\'),(7448,765494507015,250692240862,'Wireless Remote Shutter Release for Nikon D200/D300​/D3',1,'AA3207',11.47,'hutongstore','alanslotus','alan.paterson5@ntlworld.com','Alan   Paterson','13 Littlefield Close, Ash','Aldershot','Hampshire','UNITED KINGDOM','GU12 6TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-05 19:30:40',0,NULL,3,1,3,1,NULL,'alanslotus\r徐\r第一次发错了，重发 爵影无线 N1  1 庄\rRA117728572CN'),(7449,765521349015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','baifa69','deniz_sergio@yahoo.es','Sergio Déniz Rivero','C/ Sancho Panza, 2, 3ºD','Las Palmas De Gran Canaria','Canarias','SPAIN','35009','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-05 20:13:48',0,NULL,3,1,3,1,NULL,'baifa69\r徐\rRA117711807CN\r\\'),(7450,697165203002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','iz5165','ilanziv@bezeqint.net','49223ilan ziv','14 Moshe Sneh St.','Petach Tikva','','ISRAEL','49223','0545337325','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 20:51:30',0,NULL,3,1,3,1,NULL,'iz5165\rRA117711909CN\r\\'),(7451,656478373001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','thank.you.come.again','akifergin@live.com','ANH TRAN','3200 Race St<br>Rm E513C','PHILADELPHIA','PA','UNITED STATES','19104-2753','(215) 866-6067','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 21:03:17',0,NULL,3,1,1,1,NULL,'thank.you.come.again\r徐'),(7452,656218202001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',178,'hermeshine','biller6969','vasilispliatsikas@hotmail.com','VASILEIOS PLIATSIKAS','TRION IERARXON 6 & ASKLIPIOU<br>HRISOPIGI NEROKOUROU','CHANIA','CHANION','GREECE','73100','00302821302106','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 22:02:19',0,NULL,3,1,4,1,NULL,'biller6969\r王\rYW864488686CN'),(7453,656508104001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','salmon404','apuusti6@welho.com','Aki Puustinen','Kyösti Kallion tie 10 D 34','Helsinki','','FINLAND','00570','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 22:59:31',0,NULL,3,1,3,1,NULL,'salmon404\r庄\rRA117711775CN\r\\'),(7454,697215539002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','jlbs2009','telltojlbs@hotmail.com','jose luis bravo','francesc frontera 1 bajos b','palma de mallorca','Baleares','SPAIN','07007','971911822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 23:20:51',0,NULL,8,1,17,0,NULL,'jlbs2009'),(7455,656523688001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','jlbs2009','telltojlbs@hotmail.com','jose luis bravo','francesc frontera 1 bajos b','palma de mallorca','Baleares','SPAIN','07007','971911822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 23:24:53',0,NULL,3,1,2,1,NULL,'jlbs2009\r单灯头 欧标   1\r小号内胆包  canon   1\r徐'),(7456,697257938002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','abraaojr','abraao.junior@yahoo.com.br','Abraão Gomes Soares Jr','R. Conselheiro Lafaiete, 1977<br>apto: 1202, Sagrada Família','Belo Horizonte','Minas Gerais','BRAZIL','31035-560','+55 31 3327-8275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 01:52:37',0,NULL,3,1,2,1,NULL,'abraaojr\r徐'),(7457,697261838002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 02:03:57',0,NULL,3,1,1,1,NULL,'robert5525\r中号内胆包 nikon  1\rNIKON 镜头盖 67mm   1\r麂皮    1\r绿叶 CPL  67mm   1\r3片装的滤镜袋   1\r橡胶遮光罩 67mm  1'),(7458,697268474002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',145.6,'hermeshine','zenitar16','taimen1@mail.ru','Aleksej Aksenov','Medicinskiy 20-532','Krasnoyarsk','Krasnoyarsk','RUSSIAN FEDERATION','660042','(923)289-2744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 02:29:38',0,NULL,3,1,5,1,NULL,'zenitar16\r王\rCP226344635CN'),(7459,656585290001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','billybob2th','billybob2th@msn.com','diego correal','498 dexter st','central falls','RI','UNITED STATES','02863-2646','(401) 855-3800','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 03:41:26',0,NULL,3,0,1,1,NULL,'billyb\r庄'),(7460,697271728002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','mlkt2308','mariathompson23@gmail.com','Maria Thompson','17 Ormiston Gardens, Clarkson','Perth','Western Australia','AUSTRALIA','6030','0893044609','NoPaymentFailure','CheckoutComplete','AU_Other','2011-04-06 03:52:27',0,NULL,3,0,3,1,NULL,'mlkt2308\r1.6mx2.1m 白  黑  \r庄'),(7461,765700934015,250601900955,'Wireless Remote Control Cord for Canon 50D/40D/30D/20D',1,'AA3210',11.47,'hutongstore','koubikm','jakubmachu@seznam.cz','Jakub Machu','Ceská 4758','Zlín','Czech Republic','CZECH REPUBLIC','76005','00420 777 863 995','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 04:57:01',0,NULL,5,0,18,0,NULL,'koubikm\r庄\r爵影无线 C3   1'),(7462,656599054001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','genodis','dr.steen@gmail.com','Marius H Steen','Nubbebakken 7B','Bergen','-','NORWAY','5018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 04:59:29',0,NULL,3,1,2,1,NULL,'genodis\r庄'),(7463,0,120700925692,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.55,'hermeshine','yaroslav_lviv','yaroslavyatskiv@yahoo.com','Yaroslav Yatskiv','6016 Sunrise Vista Dr<br>Apt C Apt 6','Citrus Heights','CA','UNITED STATES','95610-7060','(916) 420-7678','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 05:17:44',0,NULL,3,1,1,1,NULL,'yaroslav_lviv\r庄\rYaroslav Yatskiv\r2633\rCalifornia Ave\rCarmichael CA 95608\rUnited States\r\r'),(7464,697303141002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',2,'AC2303',12.42,'hermeshine','funku28','mustafasakizci@ttnet.net.tr','MUSTAFA SAKIZCI','KORESEHITLERI CD. KAYA ALDOGAN SOK. NO :16 ZINCIRLIKUYU','ISTANBUL','TURKEY','TURKEY','34394','00905318650028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 05:19:11',0,NULL,3,1,2,1,NULL,'funku28\r庄'),(7465,765739016015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',18.3,'hutongstore','tgon4895','tom.villa@gmail.com','Tomas Gonzalez Villa','Department of Microbiology. Faculty of Pharmacy<br>University of Santiago de Compostela','Santiago de Compostela','Galicia','SPAIN','15706','647344039','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 07:49:02',0,NULL,3,1,3,1,NULL,'tgon4895\rRA117711170CN'),(7466,696479816002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',5,'AA2217',44.95,'hermeshine','pinchukov','v_pinchukov@mail.ru','Vassiliy Pinchukov','Karasai Batyra 209/79','Almaty','','KAZAKHSTAN','050009','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 07:58:01',0,NULL,3,1,3,1,NULL,'pinchukov\rRA117711254CN'),(7467,750286903016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','zoki03','cvijanovic.zoran@gmail.com','Zoran Cvijanovic','Cankarjeva ulica 26','Nova Gorica','','SLOVENIA','5000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 09:05:12',0,NULL,3,1,2,1,NULL,'zoki03\r刘'),(7468,765770928015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','manninej1979','manninej@gmail.com','Jarno Manninen','Arkkitehdinkatu 38 A 12','Tampere','Pirkanmaa','FINLAND','33720','+358447552901','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-06 09:45:51',0,NULL,3,1,4,1,NULL,'manninej1979\r刘\r欧标  \rlighting kit  $28\r4.3\rYW864488815CN'),(7469,696914007002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','scat_ap','scat-ap@yandex.ru','Артем Павлов','Алма-Атинская улица, дом 5, кв. 180','москва','','RUSSIAN FEDERATION','115408','+7(916)3138301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:08:51',0,NULL,3,1,3,1,NULL,'scat_ap\r王\rRA117711095CN\r\\'),(7470,697364737002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','339514884','kamikazi@inbox.ru','Andrey Pirinov','yl. Nekrasova d.11','Voronezh','Voronezh','RUSSIAN FEDERATION','394071','8 4732 774840','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 10:30:23',0,NULL,3,1,3,1,NULL,'339514884\r庄\rRA117713476CN\r\\'),(7471,697366364002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','juha191','jupak@elisanet.fi','Juha Pakanen','Koivuahonkuja 7','Oulu','Finland','FINLAND','90630','+35850467013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:37:31',0,NULL,3,1,2,1,NULL,'juha191\r刘'),(7472,656667601001,110414378578,'New ND2 Filter for Cokin P Series Neutral Density ND 2',1,'AA2323',7.2,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:49:04',0,NULL,8,1,17,0,NULL,'phylax57\r'),(7473,697368342002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:49:03',0,NULL,8,1,17,0,NULL,'phylax57\r'),(7474,697368224002,120448646606,'New ND4 Filter for Cokin P Series Neutral Density ND 4',1,'AA2324',7.2,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:51:59',0,NULL,8,1,17,0,NULL,'phylax57'),(7475,656667484001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 11:11:50',0,NULL,3,1,3,1,NULL,'phylax57\r77mm 接口环  1\r托架   1\rND2   1\rND4   1\r渐变灰   1\rRA117711104CN'),(7476,656675686001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','raitis-v','rvalainis@gmail.com','Raitis Valainis','Krisjana Barona 125-75','Riga','Latvia','LATVIA','LV-1012','+37122006160','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 11:20:11',0,NULL,3,1,3,1,NULL,'raitis-v\r徐\rRA117713604CN\r\\'),(7477,750336062016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','kati_mbj','woref_cts@hotmail.com','Catalina Maria Bibiloni joan','c/menorca nº12','Alcudia','Baleares','SPAIN','07400','697194978','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-06 11:58:01',0,NULL,3,0,4,1,NULL,'kati_mbj\r庄\r套装中的布是黑色的， 欧标\r80cm 2in1   反光板   1\r58mm 橡胶罩      1\r52mm 橡胶罩      1\r天涯 58mm cpl     1\r9.68\r申报： lighting kit  \r$40\rYW864488826CN'),(7478,697422128002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','inxlee','inxlee@hotmail.com','Christopher Euw','Block 371 Hougang Street 31 #02-35<br>Singapore 530371','Singapore','Singapore','SINGAPORE','530371','62823227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 14:04:03',0,NULL,3,1,11,1,NULL,'inxlee\r刘\r\\'),(7479,697424058002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','zonagrib','hrun.los@gmail.com','Natalya Babina','9a Revolucye Str.App.28','Perm','Perm Permskiy kray','RUSSIAN FEDERATION','614007','0079824884191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 14:10:35',0,NULL,3,1,5,1,NULL,'zonagrib\r王\rCP226344542CN'),(7480,656725395001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','norestani','mk@nurestan.com','mushtaba norestani','Birkhøjterrasserne 424 E','Farum','sealand','DENMARK','3520','004522956401','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 14:13:01',0,NULL,3,0,4,1,NULL,'norestani\r刘\r欧标\r申报lighting kit  $40\r9.13\rYW864489165CN'),(7481,750284532016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',2,'AO0005',28,'hutongstore','luci.moldovan','nicolas122@hotmail.com','Moldovan Nicolae Lucian','Primaverii nr.2','Tirgu Mures','Jud Mures','ROMANIA','540174','+40744237490','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 15:14:25',0,NULL,3,0,3,1,NULL,'luci.moldovan\r1.6x4m 背景布  2\r绿色   黑色\rRA117713578CN\r\\'),(7482,0,120705977458,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',0.99,'hermeshine','sabbath999','metropolis1928@mac.com','Ken Mitchell','108 N 5th','Edina','MO','UNITED STATES','63537','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-04-06 15:42:50',0,NULL,3,1,1,1,NULL,'sabbath999\r王'),(7483,0,110669242210,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',0.99,'hermeshine','chulincylycos','rhkpf@live.com','Bryan Chu','3870 Maybelle Ave','Oakland','CA','UNITED STATES','94619-2116','(510) 213-3682','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 15:57:33',0,NULL,3,1,1,1,NULL,'chulincylycos\r庄'),(7484,656767322001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','anispamami','isabeljd@hotmail.com','ANGEL BELLO LEON','C/ COCHERAS 4, PORTAL C, 2º -PTA. 3','MADRID','Madrid','SPAIN','28007','915017627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 16:20:41',0,NULL,3,1,2,1,NULL,'anispamami\r王'),(7485,0,110669239679,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',0.99,'hermeshine','mamasledge','jimorcathy@suddenlink.net','Cathy McCarty','6205 Edgeware Place','Amarillo','TX','UNITED STATES','79109','(806) 354-8689','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 16:35:00',0,NULL,3,1,1,1,NULL,'mamasledge\r刘'),(7486,0,120705977409,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',0.99,'hermeshine','hms1405','hms1405@gmail.com','hussain mohammad alsailm','3225 old 63 s','columbia','MO','UNITED STATES','65201-5369','(573) 529-6382','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 17:28:42',0,NULL,3,1,1,1,NULL,'hms1405\r庄\r、'),(7487,765961307015,250600525175,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'AA3205',2.98,'hutongstore','arkadiush77','arkadiusz.sobol@interia.eu','Arkadiusz Sobol','19 Marlborough Way','Uttoxeter','Staffordshire','UNITED KINGDOM','ST14 7HL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-06 17:49:35',0,NULL,3,1,2,1,NULL,'arkadiush77\r刘'),(7488,656803621001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','bluesmansur','ramrif@hotmail.com','Alvaro López Rivera','Avenida manolete 11- 1  2º 3','CORDOBA','Andalucía Ceuta y Melilla','SPAIN','14005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 17:51:05',0,NULL,8,1,17,0,NULL,'bluesmansur\r'),(7489,656804865001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','bluesmansur','ramrif@hotmail.com','Alvaro López Rivera','Avenida manolete 11- 1  2º 3','CORDOBA','Andalucía Ceuta y Melilla','SPAIN','14005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 17:53:09',0,NULL,3,1,2,1,NULL,'bluesmansur\r刘\r橡胶遮光罩 52mm   1\r橡胶遮光罩 58mm   1'),(7490,0,120705979181,'55mm 55 mm Macro +4 Close-Up Close Up Filter',1,'AE3216',0.99,'hermeshine','kohelet_son_of_david','kullyev@yandex.ru','Andrey Kullyev','2930 N Pine Grove Ave<br>Apt 403','Chicago','IL','UNITED STATES','60657-5742','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 17:57:53',0,NULL,3,1,1,1,NULL,'kohelet_son_of_david\r庄'),(7491,765975123015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',39.99,'hutongstore','alcintas','alcintas@gmail.com','Antonio Luis Cintas García','Tomás Romero de Castilla nº4 1ºA','Badajoz','Badajoz','SPAIN','06011','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-06 18:13:40',0,NULL,3,1,4,1,NULL,'alcintas\r王\rtripod $16\rYW864489154CN'),(7492,697518092002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','spikingsdj','djspikings@gmail.com','David Spikings','14376 Pinnacle Ct.','Canyon Country','CA','UNITED STATES','91387','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 18:14:28',0,NULL,3,1,1,1,NULL,'spikingsdj\r刘'),(7493,656835802001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','milkyway_2011','m1lkyway_2011@yahoo.com','Franco Pogi Infante','3350 Griffith Park Blvd<br>Apt 37','Los Angeles','CA','UNITED STATES','90027-2268','(323) 440-1029','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 18:56:04',0,NULL,3,1,1,1,NULL,'milkyway_2011\r庄'),(7494,656837489001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',46.8,'hermeshine','cdat2003','dtull8@yahoo.com','Denelle Tull','1808 N 34th St','Decatur','IL','UNITED STATES','62526-5620','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 18:59:34',0,NULL,3,1,3,1,NULL,'cdat2003\r王  \r1.1\rRA117712025CN\r、'),(7495,697553459002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','bass20311','bass2031@hotmail.com','Sébastien Corriveau','86 D\'Argenson','Québec','QC','CANADA','g1k1r5','(418) 317-0776','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 19:24:54',0,NULL,3,1,3,1,NULL,'bass20311\r刘\r注意是5个\rRA117713555CN'),(7496,656876639001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','jlbs2009','telltojlbs@hotmail.com','jose luis bravo','francesc frontera 1 bajos b','palma de mallorca','Baleares','SPAIN','07007','971911822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:21:32',0,NULL,8,1,17,0,NULL,'jlbs2009\r庄'),(7497,697580280002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','jlbs2009','telltojlbs@hotmail.com','jose luis bravo','francesc frontera 1 bajos b','palma de mallorca','Baleares','SPAIN','07007','971911822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:21:31',0,NULL,3,1,4,1,NULL,'jlbs2009\r刘\r2m 灯架  1\rb座    1\r柔光伞   1\r50-70 棚  欧标   1\rlight stand $25\r2.1\rYW864489143CN'),(7498,656887584001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','jenspettrus','kklemet@yahoo.no','Knut Klemetsen','Tomtegt 25','Skien','Telemark','NORWAY','3714','(+47) 90913991','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 20:50:06',0,NULL,3,1,3,1,NULL,'jenspettrus\r庄\r注意是红盒的\rRA117713595CN\r\\'),(7499,656901048001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',3,'AA1213',10.2,'hermeshine','zsmadar','mad-r@freemail.hu','Madar Zsolt','11. Leiningen str.','Debrecen','Hajdú-Bihar megye','HUNGARY','H-4030','+36204390542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 21:17:45',0,NULL,8,1,17,0,NULL,'zsmadar\r'),(7500,656900279001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',3,'AA1212',10.2,'hermeshine','zsmadar','mad-r@freemail.hu','Madar Zsolt','11. Leiningen str.','Debrecen','Hajdú-Bihar megye','HUNGARY','H-4030','+36204390542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 21:17:46',0,NULL,3,1,3,1,NULL,'zsmadar\r58-58mm 双阳环   3\r52-58mm 双阳环   3\rRA117713533CN\r\\'),(7501,697607671002,120553897299,'Wireless Flash Sync Trigger Receiver NEW pt-04tm ',1,'AB3322',19.99,'hermeshine','dulepg','bimmerpg@gmail.com','Dusko Tasic','II crnogorskog bataljona 14/2','Podgorica','Podgorica','MONTENEGRO','382','+38267255637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 21:20:52',0,NULL,3,1,2,1,NULL,'dulepg\r刘\r检查一下，是发的那个黄盒的吧\r这个很少发'),(7502,0,110669239111,'100% Genuine Lenspen lens cleaning tools NIB free S&H',1,'AA1310',2.61,'hermeshine','circleheartx','foreverpureart@yahoo.com','rene miramontes','4667 Challen ave','Riverside','CA','UNITED STATES','92503-3034','(951) 823-9293','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 21:48:39',0,NULL,3,1,1,1,NULL,'circleheartx\r庄'),(7503,656913511001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','orba_80','orba1@yandex.ru','DMITRY SHIROKOV','AKADEMIKA KOMAROVA str., 18-A, 53','MOSCOW','','RUSSIAN FEDERATION','127276','+7 916 6702890','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 21:49:21',0,NULL,3,1,3,1,NULL,'orba_80\r刘\r注意是红盒的\rRA117713581CN\r\\'),(7504,656922251001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','kiki6666kiki','kiki6666@gmail.com','Kristijan Katarincek','J.J. Strossmayera 51','Nasice','Osjecko-baranjska','CROATIA','31500','00385989471848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 22:17:56',0,NULL,3,1,2,1,NULL,'kiki6666kiki\r庄'),(7505,697621527002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','vimmern','stianvimme@gmail.com','Stian Vimme','Bjerkåsveien 52B','Vollen','Akershus','NORWAY','1391','91644483','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 22:22:06',0,NULL,3,1,4,1,NULL,'vimmern\r刘\rlight stand  $20\rYW864489132CN'),(7506,766130133015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',15.5,'hutongstore','tehwiidhed','i_own_you_all@hotmail.com','Jack Silve','46 Cleveland road','Worthing','West Sussex','UNITED KINGDOM','BN13 2ES','07938157387','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-06 23:03:00',0,NULL,3,1,3,1,NULL,'tehwiidhed\r庄\r英标\r0.568\rRA117712039CN\r、\r'),(7507,0,110669242398,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',0.99,'hermeshine','efuji','efuji@comcast.net','Edwin S. Fujinaka','8402 N. Yellowstone Ave','Tucson','AZ','UNITED STATES','85704','(520) 297-1271','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 23:21:02',0,NULL,3,1,1,1,NULL,'efuji\r刘'),(7508,654936448018,280541368434,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','voiceoveip','i@ztup.com','AI Trade SARL - Ingmar Putz','Chateau de Bimare<br>1, rue de Bimare','Saint Germain des Essourts','Haute-Normandie','FRANCE','76750','0951381378','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-06 23:23:04',0,NULL,3,1,4,1,NULL,'voiceoveip\r王\r欧标     \r5.63\rlighting kit  $35\rYW864489121CN'),(7509,656938890001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','cascaderon','rrivera@cascorp.com','Ron Rivera','2201 NE 201st Ave','Fairview','OR','UNITED STATES','97024-9799','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 23:23:57',0,NULL,3,1,1,1,NULL,'cascaderon\r庄'),(7510,656296131001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','elizeucine','elizeumol@hotmail.com','elizeu mol','rua 05 de maio, 6 b<br>centro','Timóteo','Minas Gerais','BRAZIL','35180036','3138493361','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 23:38:38',0,NULL,3,1,5,1,NULL,'elizeucine\r刘\rCP226344560CN'),(7511,0,120705977362,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',1.29,'hermeshine','arrielle78','homeyertx@yahoo.com','Arrielle Homeyer','532 17th st','niagara falls','NY','UNITED STATES','14301-2216','(716) 345-0814','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 00:01:30',0,NULL,3,1,1,1,NULL,'arrielle78\r庄'),(7512,656953831001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','lisu9789','li_su@hotmail.com','Li Su','3209 Twinfalls Drive','Plano','TX','UNITED STATES','75093','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 00:29:38',0,NULL,3,1,1,1,NULL,'lisu9789\r庄'),(7513,656954906001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',75.98,'hermeshine','geco1968','videos@gecoproducciones.cl','Gerardo Campos Pelayo','San Eugenio #1085 depto. 11-A','santiago','santiago','CHILE','7750000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 00:32:01',0,NULL,3,1,5,1,NULL,'geco1968\r庄\rCP226344556CN'),(7514,656961786001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','divertimento_88','musique88@hotmail.com','Alison Shipley','9-179 MacNab Street South','Hamilton','ON','CANADA','L8P 3C7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 01:01:10',0,NULL,3,1,2,1,NULL,'divertimen\r庄'),(7515,654257971001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','salqa','newvisionmedia@snet.net','Jose Martinez','40 Timothy Ter<br>New Vision Media, Llc','Windsor','CT','UNITED STATES','06095-1652','','NoPaymentFailure','CheckoutComplete','Other','2011-04-07 01:13:56',0,NULL,7,0,18,0,NULL,'salqa'),(7516,656970382001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','bbaker8282','blb8282@gmail.com','brandon baker','24 w pine st','fremont','MI','UNITED STATES','49412','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-07 01:34:42',0,NULL,8,1,17,0,NULL,'bbaker8282'),(7517,656970130001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','bbaker8282','blb8282@gmail.com','brandon baker','24 w pine st','fremont','MI','UNITED STATES','49412','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-07 01:34:43',0,NULL,3,1,1,1,NULL,'bbaker8282\rcanon 反接环  58mm    1\r方形滤镜接口环 58mm   1\r方形滤镜 镜片卡座   1'),(7518,656973890001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','hathuyminhan','ha.ho@bigpond.com','Ha Ho','2/16 Kwinana Street<br>Glen Waverley','Melbourne','Victoria','AUSTRALIA','3150','0386493002','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 01:48:26',0,NULL,3,1,3,1,NULL,'hathuyminhana\rRA117713480CN\r\\'),(7519,0,110669239527,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',1.3,'hermeshine','curtissp6e','jimaroc@cox.net','Jim Cady','2671 Nye Street','Henderson','NV','UNITED STATES','89074','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 03:28:37',0,NULL,3,0,1,1,NULL,'curtissp6e\r'),(7520,657000631001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','jap_magister','jeffrey_pabroquez@yahoo.com','Jeffrey Pabroquez','Al Ain, Abu Dhabi, UAE','Abu Dhabi','Al Ain','UNITED ARAB EMIRATES','7659','00971508384768','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 03:57:56',0,NULL,3,1,3,1,NULL,'jap_magister\r77mm 接口环\rRA117712042CN\r、'),(7521,697711004002,120704792152,'100% Genuine Lenspen lens cleaning tools NIB free S&H',1,'AA1310',5.49,'hermeshine','squirmishermish','philip@ermish.com','LeTourneau University','2100 S Mobberly Ave<br>Philip Ermish Cpo #868','Longview','TX','UNITED STATES','75602-3564','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-07 04:01:00',0,NULL,3,1,1,1,NULL,'squirmishermish\r徐'),(7522,697733154002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','nikki355','nikkihaskell355@msn.com','Nicole Haskell','21 Bunker Ave','Nanango','Queensland','AUSTRALIA','4615','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 06:12:26',0,NULL,3,0,3,1,NULL,'nikki355\r1.6mx3m 背景布 白色\rRA117713825CN\r\\'),(7523,766254540015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',7.75,'hutongstore','emulsion120','exposure.120@hotmail.co.uk','Colin Rogers','63 Yealmpstone Drive<br>Plympton','Plymouth','Devon','UNITED KINGDOM','PL7 1HE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 07:01:53',0,NULL,3,1,2,1,NULL,'emulsion120\r英标\r\\'),(7524,697044808002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','hayberdkadir','hayberd@hotmail.com','Kadir Altan','Ereğli<br>Konya','Türkey','Rasim Erel CadÖnder Color','TURKEY','42320','3327128185','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 07:58:59',0,NULL,3,1,2,1,NULL,'hayberdkadir\r\\'),(7525,697769030002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','hathuyminhan','ha.ho@bigpond.com','Ha Ho','2/16 Kwinana Street<br>Glen Waverley','Melbourne','Victoria','AUSTRALIA','3150','0386493002','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 09:19:49',0,NULL,3,1,3,1,NULL,'hathuyminhan\r王\r斜臂    1\r大力夹   1\rRA117713723CN\r\\'),(7526,744035431016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','dandins04','evija_2@inbox.lv','Ingus Stepans','31 adnitt road','Northampton','Northamptonshire','UNITED KINGDOM','nn14ll','07556126436','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 09:23:01',0,NULL,3,1,2,1,NULL,'dandins04'),(7527,657063010001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','hathuyminhan','ha.ho@bigpond.com','Ha Ho','2/16 Kwinana Street<br>Glen Waverley','Melbourne','Victoria','AUSTRALIA','3150','0386493002','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-04-07 09:26:07',0,NULL,8,1,17,0,NULL,'hathuyminhan\r徐'),(7528,657068295001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','brynjolfur-dk','martin@fam-jessen.dk','Martin Jessen','Bostedet 23','Vaerloese','','DENMARK','3500','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 09:50:26',0,NULL,3,1,2,1,NULL,'brynjolfur-dk\r庄'),(7529,750800931016,260676062965,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',7.5,'hutongstore','tullesfar','jens.nielsen45@gmail.com','Jens Peter Nielsen','Emdrupvej 137 st. th.','2400 København NV','Denmark','DENMARK','0045','(0045) 50805538','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 09:58:55',0,NULL,3,1,2,1,NULL,'tullesfar\r徐'),(7530,697777560002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','thongthong','teezackwhy@gmail.com','Thong Zhen Yang','45, Jalan Kenanga SD9/8<br>Bandar Sri Damansara','Kuala Lumpur','','MALAYSIA','52200','03-62762149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 10:00:15',0,NULL,3,1,2,1,NULL,'thongthong\r庄'),(7531,655074270018,280522560367,'Tripod Fancier FT-6662A with 6160H Ball head 550D D90',1,'AE1503',69.9,'photographyacc','assimons62','anne-sofie.simonsen@vkbb.no','Anne Sofie Simonsen','Øyjord','Straumsjøen','','NORWAY','8475','+4797002381','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-07 10:06:56',0,NULL,3,1,4,1,NULL,'assimons62\r刘\rtripod  $20\rYW864489051CN'),(7532,697765001002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 10:28:47',0,NULL,8,1,17,0,NULL,'nono-ey'),(7533,697779071002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 10:28:48',0,NULL,8,1,17,0,NULL,'nono-ey'),(7534,657062594001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 10:28:48',0,NULL,8,1,17,0,NULL,'nono-ey'),(7535,697769705002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 10:28:49',0,NULL,8,1,17,0,NULL,'nono-ey'),(7536,766322162015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','sundsdal','csundsdal@gmail.com','Christian Sundsdal','Vestre Kvartergade 7d, st','Hvidovre','Denmark','DENMARK','2650','0045 31198080','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-07 11:17:00',0,NULL,3,1,4,1,NULL,'sundsdal\rYW864489036CN\r'),(7537,697796241002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','almoghalili','gizbart@gmail.com','Almog Halili','Harkabi 19','Tel aviv','Israel','ISRAEL','67329','+972544936353','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 11:19:51',0,NULL,3,1,3,1,NULL,'almoghalili\r庄\rRA117713754CN\r\\'),(7538,766326043015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',12.99,'hutongstore','sundsdal','csundsdal@gmail.com','Christian Sundsdal','Vestre Kvartergade 7d, st','Hvidovre','Denmark','DENMARK','2650','0045 31198080','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 11:25:39',0,NULL,8,1,17,0,NULL,'sundsdal\r徐'),(7539,657096012001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','erwha','yellowbeepbeep@hotmail.com','David Munden','2446 Bank St. Unit 636','Ottawa','ON','CANADA','K1V1A8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 11:51:30',0,NULL,3,1,2,1,NULL,'erwha\r庄'),(7540,750867937016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','robbiestail','brian.campbell4@ntlworld.com','Brian Campbell','2 The Moorings<br>Colwich','Stafford','Staffordshire','UNITED KINGDOM','ST17 0XT','07718601163','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 13:30:42',0,NULL,3,0,3,1,NULL,'robbiestail\r刘\r黑色  3m长\rRA117713839CN\r、'),(7541,657125064001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','zhouweiyi1988','dare_5onic_d3@hotmail.com','kelvin','A1006  / 339 sussex street','sydney','New South Wales','AUSTRALIA','2000','0430065788','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 13:36:26',0,NULL,3,1,3,1,NULL,'zhouweiyi1988\r庄\rRA117713737CN\r\\'),(7542,697834747002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','davidbonet','davidboon@hotmail.com','david garcia','patricio borant n-43','lalcudia','Comunidad Valenciana','SPAIN','46250','606837182','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 13:42:30',0,NULL,3,1,2,1,NULL,'davidbonet\r徐'),(7543,655888690001,110471764872,'E-TTL Flash Unit for Canon 450D 500D XSi XS T1i 40D 50D',1,'AB3303',245.98,'hermeshine','senkler','azaro@home.nl','A.Azaro','G.Flinclstraat 46','Meppel','','NETHERLANDS','7944 HB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 14:02:54',0,NULL,3,0,5,1,NULL,'senkler\rSergei Gazarov\rStr. Lisunova kvartal 1\rH.22 app.18\rHamzinskij rajon\r700204 Tashkent\rUzbekistan\rCP226268829CN\r王\rNew Camera shoulder bag a1 for Nikon D80 D90 D3000 	Nikon a1 单肩包	1\rNew Camera bag topload D3 for Canon 550D 500D\r	Canon 三角包	1\r24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm\r	60cm 2in1  反光板	1\rNEW Flash Diffuser for Canon 580EX II\r	肥皂盒 580ex	2\rNEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap\r	72mm canon 镜头盖	2\r67mm 67 mm Macro +8 Close-Up Close Up Filter\r	67mm +8 近摄镜	1\rNew Diffuser for external flash sb800 sb700 580ex metz\r	万用柔光罩	1\r3ft Universal TTL Off camera Cord Canon/Nikon/Pentax\r	爵影的ttl线	1\r24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box\r	60cm 园棚 	1\rNEW Flash Diffuser for Canon 430EX / 430EXII\r	肥皂盒 430ex	2\ri-TTL Flash for Nikon D60 D90 D5000 D3000 D300s D700 D3\r	Yn465 Nikon	1\rE-TTL Flash Unit for Canon 450D 500D XSi XS T1i 40D 50D\r 	Yn465 canon	1\r\r王\r'),(7544,0,110669239265,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',1.04,'hermeshine','venadoub','hikingwithdog@yahoo.com','Jim Hunter','3231 Old Salisbury Concord Rd','Concord','NC','UNITED STATES','28025-1546','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 14:08:09',0,NULL,3,1,1,1,NULL,'venadoub\r庄'),(7545,655148562018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','leilanistouch','leilanistouch@yahoo.com','Leilani Mitchell','14808 Cartagena Dr','Gainesville','VA','UNITED STATES','20155-1978','(571) 222-7686','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 14:38:29',0,NULL,3,1,4,1,NULL,'leilanistouch\r王\r灯泡110v\rYW864489073CN'),(7546,697851250002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 14:42:53',0,NULL,3,1,4,1,NULL,'nono-ey\r2m 灯架   1\r单灯头  欧标   1\r反光伞   1\r大力夹   2\rc型大力夹   1\r45w    2\r庄  \r2.847\rYW864489040CN\r'),(7547,697850609002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','smala68','videozom@gmail.com','Arunas Zilius','Pavasario 31-6','Mazeikiai','','LITHUANIA','89162','(370) 61293372','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 14:44:21',0,NULL,3,1,5,1,NULL,'smala68\r王  2.19\rCP226344525CN'),(7548,697850443002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',2,'AO0023',547,'hermeshine','boutiquetele','service.client@boutique-tele.fr','Ocelys Sarl, Dembele Benedicte','48 Rue la Cigogne Bat C','Angoulême','Poitou-Charentes','FRANCE','16000','0667700704','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 14:45:41',0,NULL,3,1,4,1,NULL,'boutiquetele\r1.8m 717    2\r肩架   2\rtripod $50\r王\rYW864941902CN'),(7549,657147125001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',75.98,'hermeshine','boutiquetele','service.client@boutique-tele.fr','Ocelys Sarl, Dembele Benedicte','48 Rue la Cigogne Bat C','Angoulême','Poitou-Charentes','FRANCE','16000','0667700704','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 14:49:56',0,NULL,8,1,17,0,NULL,'boutiquetele\r刘'),(7550,750929659016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','v00rtex','david.micallef@gmail.com','David Micallef','34, \'Colin Flats\', No.1<br>Bishop F.S. Caruana Street','Msida','Malta','MALTA','MSD1410','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 16:13:14',0,NULL,8,1,17,0,NULL,'v00rtex\r'),(7551,766435055015,250692237083,'Green.L 77mm 77 Neutral Density ND8 Filter ND 8 New',1,'AE2314',4.8,'hutongstore','v00rtex','david.micallef@gmail.com','David Micallef','34, \'Colin Flats\', No.1<br>Bishop F.S. Caruana Street','Msida','Malta','MALTA','MSD1410','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 16:13:14',0,NULL,3,1,2,1,NULL,'v00rtex\r绿叶 渐变镜 77mm   1\r绿叶 ND8  77mm   1\r徐'),(7552,766443251015,250599980827,'New Neoprene Reversible Bag Cover for Large-DSLR',1,'AC1302',6.1,'hutongstore','zenziv','zouyi@live.com','Y Zou','25 Dartmouth Street','Stafford','Staffordshire','UNITED KINGDOM','ST16 3TU','07894352017','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 16:29:22',0,NULL,3,1,2,1,NULL,'zenziv\r徐'),(7553,697898009002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','zaferbakmaz2010','zaferbakmaz@hotmail.com','ZAFER BAKMAZ','baykan ilçe emniyet amirliği inönü polis merkezi<br>siirt baykan','siirt','siirt','TURKEY','56000','+905055466344','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 16:52:25',0,NULL,3,0,3,1,NULL,'zaferbakmaz2010\r庄\rL\rRA117713785CN\r\\'),(7554,766453628015,250599929225,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',8.99,'hutongstore','keetociber','kdotc@hotmail.co.uk','Charles Mills','59 yardley close<br>oldbury','birmingham','West Midlands','UNITED KINGDOM','b68 9dd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 16:54:08',0,NULL,3,1,2,1,NULL,'keetociber\r徐\r62mm 接口环   1\r渐变灰    1(缺)\r托架    1\r\\'),(7555,657194622001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','twsh35','t4wish@gmail.com','Balint Kiss','58','Stary Hradok','Nitra','SLOVAK REPUBLIC','93556','0918823299','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 17:05:32',0,NULL,3,1,3,1,NULL,'twsh35\r庄\rRA117713842CN\r\\'),(7556,697902877002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','a.buragohain','aburagohain@gmail.com','Apratim Buragohain','Samsung India Software Operations, JP Techno Park, 3/1 Miller\'s Road','Bangalore','Karnataka','INDIA','560052','9008127000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 17:11:39',0,NULL,3,1,3,1,NULL,'a.buragohain\r王\rRA117713771CN\r\\'),(7557,766458552015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','pissdrunkdu69','pissdrunkdu694@msn.com','Jeff Loch','4 rue jean moulin','meyzieu','Rhône-Alpes','FRANCE','69330','0663936579','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-07 17:16:13',0,NULL,3,1,4,1,NULL,'pissdrunkdu69\r刘\r2m 灯架  3\r50-70 棚  欧标  2\r115w 220v   4\r包   1\r80cn 2in1 反光板   1\rlighting kit  $32\rYW864489084CN'),(7558,750952924016,260660055262,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',8,'hutongstore','pissdrunkdu69','pissdrunkdu694@msn.com','Jeff Loch','4 rue jean moulin','meyzieu','Rhône-Alpes','FRANCE','69330','0663936579','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 17:16:13',0,NULL,8,1,17,0,NULL,'pissdrunkdu69\r徐'),(7559,766459094015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',28,'hutongstore','pissdrunkdu69','pissdrunkdu694@msn.com','Jeff Loch','4 rue jean moulin','meyzieu','Rhône-Alpes','FRANCE','69330','0663936579','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 17:16:14',0,NULL,8,1,17,0,NULL,'pissdrunkdu69\r王'),(7560,766459018015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24.99,'hutongstore','pissdrunkdu69','pissdrunkdu694@msn.com','Jeff Loch','4 rue jean moulin','meyzieu','Rhône-Alpes','FRANCE','69330','0663936579','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-07 17:16:14',0,NULL,8,1,17,0,NULL,'pissdrunkdu69\r刘'),(7561,657200366001,110566021477,'TianYa ND8 Filter for Cokin P Series Neutral Density',1,'AA2325',7.2,'hermeshine','wateringer1','g.d.dekleijn@kabelfoon.nl','Guido de Kleijn','van Lottomstraat 25','Kwintsheul','','NETHERLANDS','2295HB','0624502686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 17:19:24',0,NULL,3,1,2,1,NULL,'wateringer1\r徐'),(7562,750974811016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','la**ka','borsos.laci@gmail.com','Laszlo Borsos','35a High Street','Hampton Hill','Middlesex','UNITED KINGDOM','tw12 1nb','07850383806','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-07 17:47:08',0,NULL,3,0,4,1,NULL,'la**ka\r庄\r看一下英标放了吗\rlighting  kit  $40\r放了\rYW864489095CN'),(7563,750989171016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','marsyanya','nickson2000@mail.ru','Vladimir Nikulenko','28 Kalarasha Street, Appartment 29','Tuapse','Krasnodarskiy kray','RUSSIAN FEDERATION','352803','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 18:11:59',0,NULL,3,1,2,1,NULL,'marsyanya\r徐'),(7564,766514379015,250599922417,'New 58mm 58 Ring adapter and Holder for Cokin P Series ',1,'AKT020',3.62,'hutongstore','thik_thi_feed','v.nguyen@lancaster.ac.uk','Nguyen Van Linh','D221 Bowland Ash, Bowland college<br>Lancaster University','Lancaster','Lancashire','UNITED KINGDOM','LA1 4YW','07407254832','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 18:43:26',0,NULL,3,1,2,1,NULL,'thik_thi_feed\r徐'),(7565,0,110669239743,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',1.79,'hermeshine','nob1','nob110@q.com','Norbert R Heimlich','12325 w Larkspur RD','El Mirage','AZ','UNITED STATES','85335-5286','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 18:50:49',0,NULL,3,1,1,1,NULL,'nob1\r庄'),(7566,657243749001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','norilsk6867','vikki6867@yandex.ru','4Victoria Yurchenko','Shumilova 77, 6','Volgograd','','RUSSIAN FEDERATION','400021','79876496867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 18:54:46',0,NULL,3,1,2,1,NULL,'norilsk6867\r徐'),(7567,0,110669239189,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',2.75,'hermeshine','mntmansales','robertkellywv@gmail.com','robert kelly','125 rogers st','oak hill','WV','UNITED STATES','25901-2552','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 19:06:04',0,NULL,3,1,1,1,NULL,'mntmansales\r庄'),(7568,751021344016,260660053762,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.16,'hutongstore','maxkozin77','max_1977@mail.ru','Maksim Kozin','Frunze street, 10A-75','Togliatti','Samara Region','RUSSIAN FEDERATION','445037','+79023737372','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 19:17:34',0,NULL,3,1,2,1,NULL,'maxkozin77\r徐'),(7569,751074579016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','zsoltgyapay','zsolt.gyapay@gmail.com','Zsolt Gyapay','Attila u. 34.','Hévíz','Zala','HUNGARY','8380','0036304007688','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 20:33:49',0,NULL,3,1,2,1,NULL,'zsoltgyapay\r庄'),(7570,698011325002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','lunadrift','lunadrift@gmail.com','Bu Wang','1920 Powell Campus Ctr','Alfred','NY','UNITED STATES','14802','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-07 21:00:59',0,NULL,3,1,1,1,NULL,'lunadrift\r刘'),(7571,761000492015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','andrejsplavins','andrejs.plavins@gmail.com','Andrejs Plavins','2 Castle Park','Buncrana','Donegal','IRELAND','','0879178759','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-07 21:10:30',0,NULL,3,1,3,1,NULL,'andrejsplavins\r庄\rRA117713808CN\r\\'),(7572,766609785015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','dazhop-irl','kathybhopkins@yahoo.ie','Kathy Hopkins','Carrickmoyragh','Newtownforbes','Longford','IRELAND','default','0861629151','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 21:22:33',0,NULL,3,0,3,1,NULL,'dazhop-irl\r庄\r白色  3m 长\rRA117713799CN\r\\'),(7573,698024986002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','pinya70','pinya70@hotmail.com','Javier López Raja','CFilet de Fora nº63<br>3ª planta, puerta A','Elche','Comunidad Valenciana','SPAIN','03203','699870303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 21:34:53',0,NULL,3,1,2,1,NULL,'pinya70\r徐'),(7574,766621276015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','cammy3005','lynncameron@gmail.com','Lynn Cameron','Acorn B&B<br>16 Priestden Road','St.Andrews','Fife','UNITED KINGDOM','KY16 8DJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 21:47:17',0,NULL,3,1,3,1,NULL,'cammy3005\r王\rRA117713745CN\r\\'),(7575,518411999003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','zorton7','besantes@hotmail.com','francisco jose besantes fernandez','josep serra carsi 2-19','catarroja','Comunidad Valenciana','SPAIN','46470','622190322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 21:53:57',0,NULL,3,1,2,1,NULL,'zorton7\r徐'),(7576,698037438002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','jfossb','jhf022@student.uit.no','Jostein Fossbakk','Dramsveien 541','Tromsø','Troms','NORWAY','9014','77613076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 22:13:59',0,NULL,3,1,2,1,NULL,'jfossb\r徐\r'),(7577,657341438001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','jessjason_lives','jessicca.pratt@gmail.com','Jess Pratt','7 Joan Avenue ','Dromana','Victoria','AUSTRALIA','3936','0407830797','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 23:00:32',0,NULL,3,1,4,1,NULL,'jessjason_lives\r刘澳标\rYW864489106CN'),(7578,697987818002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','gio757','gio757@simail.it','Giorgio Calore','v. Risorgimento 34','Selvazzano Dentro','Padova','ITALY','35030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 23:24:52',0,NULL,3,1,3,1,NULL,'gio757\r王\r申报：light stand $15\rRA117713710CN\r\\'),(7579,657373864001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','egun_314','e.gunderson@utoronto.ca','Erik Gunderson','116B Barton Ave','Toronto','ON','CANADA','M6G 1P9','(416) 532-5255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 01:19:37',0,NULL,3,1,2,1,NULL,'egun_314\r徐'),(7580,698113940002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','sngchile','sngfotografia@gmail.com','María Teresa Godoy León','Alonso de Córdova 3773, Vitacura','Santiago','Región Metropolitana','CHILE','7630492','(56) 6-8499240','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 03:15:30',0,NULL,3,1,2,1,NULL,'sngchile\r徐'),(7581,657425437001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','funku28','mustafasakizci@ttnet.net.tr','MUSTAFA SAKIZCI','KORESEHITLERI CD. KAYA ALDOGAN SOK. NO :16 ZINCIRLIKUYU','ISTANBUL','TURKEY','TURKEY','34394','00905318650028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 05:31:30',0,NULL,3,1,2,1,NULL,'funku28\r徐'),(7582,698151228002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','ilgar_i','ilgarilyasov@gmail.com','Ilgar Ilyasov','Rashid Behbudov 71','Baku','Baku','AZERBAIJAN','AZ1022','+994556596004','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 06:47:22',0,NULL,3,1,3,1,NULL,'ilgar_i\r徐\rRA117712073CN\r、'),(7583,698153909002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','sean_foulkes','seanfoulkes@gmail.com','SPC Foulkes, Sean','C Co  TF 1-163<br>COS KALSU','APO','AE','AA','09312','(406) 219-4262','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 07:09:26',0,NULL,3,1,1,1,NULL,'sean_foulkes\r徐'),(7584,657443246001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','ilgar_i','ilgarilyasov@gmail.com','Ilgar Ilyasov','Rashid Behbudov 71','Baku','Baku','AZERBAIJAN','AZ1022','+994556596004','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 07:26:46',0,NULL,3,1,3,1,NULL,'ilgar_i\rRA117712087CN\r、'),(7585,698162657002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kaiwan2010','kaiwan.b.h@hotmail.com','Kaiwan Bahroz','Oscarsgate 35A','0258 Oslo','Oslo','NORWAY','0258','004795002606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 07:45:21',0,NULL,8,1,17,0,NULL,'kaiwan2010'),(7586,698163069002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','kaiwan2010','kaiwan.b.h@hotmail.com','Kaiwan Bahroz','Oscarsgate 35A','0258 Oslo','Oslo','NORWAY','0258','004795002606','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 07:47:17',0,NULL,3,1,3,1,NULL,'kaiwan2010\r100*150  5合1 反光板    1\rlenspen   1\r徐\rRA117716849CN'),(7587,657461865001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','jaikoo','jaikoo@gmail.com','Jonathan Conway','3 Parker Way<br>Little Canfield (Priors Green near Takeley)','Dunmow','Essex','UNITED KINGDOM','CM6 1GT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 08:49:04',0,NULL,3,0,3,1,NULL,'jaikoo\rRA117712379CN\r\\'),(7588,698189947002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','asturcop','asturcop@gmail.com','Pelayo Palacio Arce','Avda Portugal 94    5 b','Gijon','Asturias','SPAIN','33207','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 09:55:22',0,NULL,3,1,4,1,NULL,'asturcop\rtripod $16\rYW864941036CN'),(7589,657479916001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','lev_gromov','lgromov@yandex.ru','Лев Громов','Мичуринский пр-кт <br>11-3- 80','Москва','','RUSSIAN FEDERATION','119191','+7(903)7241849','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 10:07:58',0,NULL,3,1,3,1,NULL,'lev_gromov\rRA117712201CN\r\\'),(7590,698198163002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','yaro-t','yaro-t@ukr.net','Andriy Ivanenko','prospekt Peremogi 89a kv 205','Kiev','','UKRAINE','03115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 10:33:03',0,NULL,3,1,2,1,NULL,'yaro-t\r刘\r\\'),(7591,751320031016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','dsiefa','dsiefa@aol.com','Victoria Andrews','7 Sawkins Close<br>The Poplars, Langenhoe','Colchester','Essex','UNITED KINGDOM','CO5 7LU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 10:57:37',0,NULL,3,1,2,1,NULL,'dsiefa\r庄\r\\'),(7592,657500878001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','suhaimuzi','suhaim@012.net.il','uzi haim hacohen','aerez 34a/4','binyamina','','ISRAEL','30500','+972528890644','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 11:34:23',0,NULL,3,1,2,1,NULL,'suhaimuzi\r王\r\\'),(7593,766851230015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','radioactive50149','steves.jones@ge.com','STEPHEN JONES','282<br>MEADOWCROFT','AYLESBURY','Buckinghamshire','UNITED KINGDOM','HP19 9HZ','01494543787','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 11:48:19',0,NULL,3,1,2,1,NULL,'radioactive50149\r刘\r\\'),(7594,698226143002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','gescon77','alvaro.delallaverodriguez@t-gestiona.com','ALVARO RODRIGUEZ','CONDESA DE VENADITO 7 4ªPLANTA','MADRID','Madrid','SPAIN','28027','918478995','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 12:24:47',0,NULL,3,1,4,1,NULL,'gescon77\rtripod $16\rYW864941040CN'),(7595,657551893001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','monra1962','monchodax@hotmail.com','ramon luis alvarado','juan rodriguez nº 221 Bº san salvador','ushuaia','Tierra del fuego','ARGENTINA','9410','02901-431046','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 14:38:33',0,NULL,3,1,2,1,NULL,'monra1962\r庄\r\\'),(7596,657558907001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','ragota','ragoka@enternet.hu','Agota Reti','Szarazhegy u. 29.','Budapest','','HUNGARY','1171','+36 306 808 305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 14:59:14',0,NULL,3,1,2,1,NULL,'ragota\r刘\r\\'),(7597,698306950002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','d_ranade','d_ranade@hotmail.com','Dilip Ranade','GM (Vigilance) RCF Ltd, Room No 942B,<br>9th Floor, Priyadarshini, Eastern Express Highway, Sion','Mumbai','Maharashtra','INDIA','400022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 16:37:42',0,NULL,3,1,2,1,NULL,'d_ranade\r庄\r\\'),(7598,657598045001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','jmscheller','marilyn.scheller@gmail.com','Marilyn Scheller','c/o RM of Glen Bain<br>Box 39  Main Street','Glen Bain','SK','CANADA','S0N 0X0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 16:49:07',0,NULL,3,1,2,1,NULL,'jmscheller\r刘\r\\'),(7599,766974652015,250606686795,'IR Remote Control 4 Canon RC-5 EOS 500D 350D 400D 450D',1,'AA2202',2.75,'hutongstore','marta0872','martamyebay@gmail.com','marta chelli','via fucini 37','grosseto','GR','ITALY','58100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-08 17:02:54',0,NULL,3,1,2,1,NULL,'marta0872\r庄\r\\'),(7600,657620245001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','lexx016','lexx015@gmail.com','Aleksey Petukhov','Pushkarskaya<br>79-52','Perm\'','Permsky Kray','RUSSIAN FEDERATION','614077','89082652737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 17:56:08',0,NULL,3,1,2,1,NULL,'lexx016\r刘\r\\'),(7601,657601900001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','jmta123','hamcomm@comcast.net','Hamilton Communications','1442 Essex Rd','Westbrook','CT','UNITED STATES','06498-1585','','NoPaymentFailure','CheckoutComplete','Other','2011-04-08 18:02:20',0,NULL,3,1,4,1,NULL,'jmta123\r庄\rYW864941051CN'),(7602,657632627001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','willyodd','willy.kommedal@gmail.com','Willy Odd Kommedal','Tomasbakken 8','Hundvaag','Rogaland','NORWAY','4085','+4790980860','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 18:14:14',0,NULL,3,1,3,1,NULL,'willyodd\rRA117712175CN\r\\'),(7603,655755154018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','rtelly837ronald','xax371@yahoo.com','RONALD HOWARD','177-50 106 AV','JAMAICA','NY','UNITED STATES','11433','','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-04-08 22:14:42',0,NULL,3,1,4,1,NULL,'rtelly837ronald\r灯泡是110v\rlighting kit $28\rYW864941062CN\r王'),(7604,698472441002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','bask2727','alohakid2727@yahoo.com','Toni Sullivan','1129 Bloomdale St','Duarte','CA','UNITED STATES','91010-2442','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 00:12:56',0,NULL,3,1,1,1,NULL,'bask2727\r徐\r、'),(7605,698479394002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','richard218','rgryziak@yahoo.com','Richard Gryziak','1401 Madison St NW','Washington','DC','UNITED STATES','20011','(202) 882-0046','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 00:43:53',0,NULL,3,1,1,1,NULL,'richard218\r庄\r、'),(7606,657764225001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',3,'AC3301',43.68,'hermeshine','paulo_alfonso','paulo.alfonso.n@gmail.com','Paulo Alfonso Nuñez Utreras','Artemio Gutierrez 1635<br>Santiago','Santiago','Metropolitana','CHILE','8360658','5625511639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 00:48:38',0,NULL,3,1,3,1,NULL,'paulo_alfonso\r王\r1.418\rRA117712507CN\r、'),(7607,698484097002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','beguin5651','juanperva@ya.com','juan antonio perez d las vacas bueno','plza cartaya 1','madrid','Madrid','SPAIN','28024','915184109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 01:05:43',0,NULL,3,0,3,1,NULL,'beguin5651\r1.6x3m 黑色背景布   1\rRA117712215CN\r\\'),(7608,698497669002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','beverly35533553','terryandbeverly@yahoo.com','BEVERLY KILLIAN','2525 POINT ST<br>FRONT PORCH','CLAREMONT','NC','UNITED STATES','28610-8622','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 02:07:12',0,NULL,3,1,1,1,NULL,'beverly35533553\r徐\r、'),(7609,655842030018,280559946878,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',200,'photographyacc','kd21h','karynhelton@yahoo.com','Karyn Helton','2890 Carl Stuart St','Conway','AR','UNITED STATES','72034-7527','(501) 328-8555','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 03:44:17',0,NULL,3,1,4,1,NULL,'kd21h\r灯泡是110v  \rlighting kit $35\r庄\rYW864941073CN'),(7610,657820369001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 05:50:11',0,NULL,3,1,3,1,NULL,'osmanshawkat\rRA117712161CN\r\\'),(7611,657824915001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','ruc.catala','oriol.corbella@gmail.com','Oriol Corbella Cervelló','Gran Via de les Corts Catalanes, 490, 7è 2a','Barcelona','Cataluña','SPAIN','08015','934537038','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 06:19:52',0,NULL,3,1,3,1,NULL,'ruc.catala\rRA117729480CN\r\\'),(7612,698547508002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','mcguffincemoli','ddemmaa@hotmail.com','Cemal Samli','INONU CAD. NO:386 K:7 D:28 HAKIMEVLERI','IZMIR','KONAK','TURKEY','35290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 06:41:02',0,NULL,3,1,3,1,NULL,'mcguffincemoli\r刘\rRA117712158CN\r\\'),(7613,698561691002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',74.8,'hermeshine','najort-perm','alexandr.abramenkov@gmail.com','Alexandr Abramenkov','M. Gorkogo str, 64/1-145','Perm','Permskiy Kray','RUSSIAN FEDERATION','614007','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 07:55:03',0,NULL,3,1,5,1,NULL,'najort-perm\rCP226268801CN'),(7614,698568021002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','insaned79','tolstenkoiv@gmail.com','Ilya Tolstenko','Glavpochtampt<br>box 3778','Krasnodar','Krasnodarskiy kray','RUSSIAN FEDERATION','350000','+7-918-376-17-89','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 08:42:47',0,NULL,3,1,3,1,NULL,'insaned79\rRA117712189CN\r\\'),(7615,698170401002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 08:56:20',0,NULL,3,1,3,1,NULL,'saud-p\r2m 背景架  白色背景布\r发两个小包\rRA117712135CN\rRA117729414CN\r\\\r\r王'),(7616,698579138002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','imparcial','lundi@wanadoo.es','José Ríos López','C/Los Devis,5','Alcázar de San Juan','Ciudad Real','SPAIN','13600','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 09:09:54',0,NULL,8,1,17,0,NULL,'imparcial'),(7617,657862238001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',6.9,'hermeshine','imparcial','lundi@wanadoo.es','José Ríos López','C/Los Devis,5','Alcázar de San Juan','Ciudad Real','SPAIN','13600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 09:13:58',0,NULL,8,1,17,0,NULL,'imparcial'),(7618,698580959002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','imparcial','lundi@wanadoo.es','José Ríos López','C/Los Devis,5','Alcázar de San Juan','Ciudad Real','SPAIN','13600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 09:17:19',0,NULL,3,1,3,1,NULL,'imparcial\r爵影碗罩P4   1\r万用遮光罩    1\r肥皂盒 柔光罩   580EX  1\r徐\rRA117712232CN\r、\r'),(7619,767299963015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','123kellock','big_boy_willy@hotmail.com','Will Kellock','O2<br>1a, SIlver Street','Wellignborough','Northamptonshire','UNITED KINGDOM','NN81BQ','01933278902','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-09 09:18:34',0,NULL,3,1,2,1,NULL,'123kellock\r庄\r\\'),(7620,639206861018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','solidagoart','solidagoart2010@hotmail.it','marco scarparo','via pertini,21(ex via torino)','gessate','MI','ITALY','20060','3478109706','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-09 09:21:58',0,NULL,3,1,4,1,NULL,'solidagoart\rlighting kit  $26\r欧标\r王\rYW864941084CN'),(7621,698592161002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','h-smulders-2007','h.smulders@hccnet.nl','Harry Smulders','Henk vd Broeklaan 4','Eindhoven','','NETHERLANDS','5626 HA','0402621675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:07:47',0,NULL,3,1,2,1,NULL,'h-smulders-2007\r徐\r\\'),(7622,698594088002,120618815235,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'AA2301',5.7,'hermeshine','zcetrt','ziga.cetrtic@gmail.com','Ziga Cetrtic','Podgora pri Dolskem 6','Dol pri Ljubljani','Dol pri Ljubljani','SLOVENIA','1262','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:13:30',0,NULL,3,1,2,1,NULL,'zcetrt\r庄'),(7623,698600488002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','allaboutsculpting','dansgarbage@yahoo.com','Daniel Moy','127 Wexford Road','Wellington','Miramar','NEW ZEALAND','6022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:41:26',0,NULL,3,1,11,1,NULL,'allaboutsculpting\r刘\r\\'),(7624,698607051002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','indiana107','kyliev@kanet.com.au','Kylie Valencius','12 The Avenue','GLENMORE PARK','New South Wales','AUSTRALIA','2745','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 11:08:02',0,NULL,3,0,3,1,NULL,'indiana107\rL\r庄\rRA117729051CN\r、'),(7625,657900082001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','altermann7878','altermann78@yandex.ru','Anton Mironov','Vilnyusskaya street, 4-163','Moscow','Moscow','RUSSIAN FEDERATION','117574','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 11:48:40',0,NULL,3,1,5,1,NULL,'altermann7878\r2m 背景架 （ 白  黑）  1\r王\rCP226268815CN'),(7626,657898787001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',5,'AA2217',44.95,'hermeshine','fabiobravin','fpbravin@yahoo.com.br','Fabio Bravin','QSA 17 Casa 25<br>Taguatinga','Brasília','Distrito Federal','BRAZIL','72015-170','55-61-92119138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 12:07:20',0,NULL,3,1,3,1,NULL,'fabiobravin\r庄\rRA117729048CN\r、'),(7627,698635883002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','jenigoci','jenigoci@gmail.com','Jenny Goicochea C/O Clinilabs','423 W 55th St<br>4th Floor','New York','NY','UNITED STATES','10019','','NoPaymentFailure','CheckoutComplete','Other','2011-04-09 12:57:09',0,NULL,3,1,3,1,NULL,'jenigoci\r庄\r1.545\rRA117712498CN\r\\'),(7628,698637075002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','garnik1008kg','gk1008kg@yahoo.com','Garnik Karapetyan','A. Serob 10. 26','Erevan','','ARMENIA','0019','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 13:07:23',0,NULL,3,1,3,1,NULL,'garnik1008kg\r欧标\r分两个小包发\r2个灯架 +伞\r双灯头  2 欧标\rRA117712285CN\rRA117729428CN\r\\\r'),(7629,518876031003,130497954344,'New Fancier Complete Tripod 531BT with Ball head 531BH ',1,'AE1102',75,'hermeshine','mellogabriel','mellogabriel@yahoo.com.br','Gabriel Mello','Rua Leandro Dupret, 364 Ap. 142<br>Vila Clementino','São Paulo','São Paulo','BRAZIL','04025-011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:00:32',0,NULL,3,0,5,1,NULL,'mellogabriel\r申报 tripod  $40\r庄\rCP226268792CN'),(7630,657960747001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','mkostas','bladimhros@yahoo.com','Konstantinos Kargas','Eteokleous 4','Thessaloniki','Greece','GREECE','54250','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:02:50',0,NULL,3,1,2,1,NULL,'mkostas\r徐\r\\'),(7631,657961391001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','d_spider541','arha80@msn.com','Rosemarie Arbur','6342 Katie Ln','Klamath Falls','OR','UNITED STATES','97603-7151','(541) 273-6787','NoPaymentFailure','CheckoutComplete','Other','2011-04-09 15:05:54',0,NULL,3,1,1,1,NULL,'d_spider541\r庄\r、'),(7632,751888974016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','jkegholm','kalle@jkegholm.dk','Kalle Egholm','Bellisallé 14','Horsens','','DENMARK','DK8700','004561304107','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-09 15:14:18',0,NULL,3,1,4,1,NULL,'jkegholm\r欧标   \rlighting kit  $40\r刘\rYW864941095CN'),(7633,656015101018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','jenigoci','jenigoci@gmail.com','Jennifer Goicochea','41-36 51Street<br>Apt. C-2','Woodside','NY','UNITED STATES','11377','(718) 779-8442','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-04-09 15:25:44',0,NULL,3,1,4,1,NULL,'jenigoci\r灯泡 是110v\r庄\rYW864941106CN'),(7634,767485494015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','embeclan','alanh44@hotmail.com','Alan Hewitt','4 Moorgate Park','Retford','Nottinghamshire','UNITED KINGDOM','DN22 6TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-09 17:22:50',0,NULL,3,1,2,1,NULL,'embeclan\r徐\r\\'),(7635,658093215001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','lisemiron','normandmiron@hotmail.com','Lise Miron','7064 Marie G.-Lajoie','Montreal','QC','CANADA','H1J 2R9','(514) 353-8098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 20:04:21',0,NULL,3,1,2,1,NULL,'lisemiron\r庄\r\\'),(7636,767579275015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','raztomesko','raztomesco@yahoo.com','razvan tomescu','Bruria 2/7','Ramat Gan','center','ISRAEL','52526','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-09 20:05:36',0,NULL,3,1,3,1,NULL,'raztomesko\r分三个挂号小包发    欧标    王\rRA117712762CN\rRA117712855CN\rRA117712833CN\r'),(7637,658096126001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','swjeweler','a86music@gmail.com','Milan Kiss','Kereknad 9','Gyor','Gyor Moson Sopron','HUNGARY','9030','+36205308688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 20:11:02',0,NULL,3,1,3,1,NULL,'swjeweler\r刘\rRA117712229CN\r、'),(7638,698819623002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','janosik1209','marcinpawlik@hotmail.com','marcin pawlik','293 1/2 Pavonia Ave','jersey city','NJ','UNITED STATES','07302-1577','(201) 704-6095','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 20:39:36',0,NULL,3,1,1,1,NULL,'janosik1209\r庄\r、'),(7639,658112091001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','massimox76','massimox@gmail.com','Massimo Iacarelli','baveno 58','roma','RM','ITALY','00166','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 20:49:25',0,NULL,3,1,2,1,NULL,'massimox76\r徐\r\\'),(7640,658154869001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','khaled3210','the.kbk@gmail.com','Khaled Khadra','94 Spring Farm Rd','Aurora','ON','CANADA','L4G7W7','(647) 867-3210','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 23:14:26',0,NULL,3,1,3,1,NULL,'khaled3210\rRA117712113CN\r\\'),(7641,752154492016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','alechandro78','alechandro@mail.ru','alexey demenschin','5 city west mews','ballincollig','Cork','IRELAND','319','0861091762','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 01:00:21',0,NULL,3,0,3,1,NULL,'alechandro78\r1.6x3m 白色\r刘\rRA117712303CN\r、'),(7642,658271087001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','studio_store','studio43300@gmail.com','Tomasz Zając','ul. Pięciu Stawów 11/60','Bielsko-Biała','śląskie','POLAND','43300','33 4865299','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 08:05:07',0,NULL,3,0,3,1,NULL,'studio_store\rXXL\r庄\rRA117729476CN\r、'),(7643,767810888015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','jara_1960','giralda_1960@yahoo.com','jose aragones aragones','c/ real, 35','viator','Almeria','SPAIN','04240','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-10 08:33:12',0,NULL,3,1,4,1,NULL,'jara_1960\r庄\rYW864941110CN'),(7644,699003764002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',10,'AA1310',54.9,'hermeshine','palvolgyifoto','palvolgyi@palvolgyi.hu','Palvolgyi-Foto Kft','Baross u 261','Budapest','Budapest','HUNGARY','1162','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 08:53:03',0,NULL,3,1,3,1,NULL,'palvolgyifoto\r徐\rRA117712192CN\r、'),(7645,767907000015,250599922417,'New 58mm 58 Ring adapter and Holder for Cokin P Series ',1,'AKT020',3.62,'hutongstore','9997barry','bgibson@bgibson.karoo.co.uk','BARRY GIBSON','87 EASTFIELD ROAD','HULL','East Riding of Yorkshire','UNITED KINGDOM','HU4 6DS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 12:11:01',0,NULL,3,1,2,1,NULL,'9997barry\r庄\r\\'),(7646,658400188001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','macokaz','martind_maco@hotmail.com','Martin Darnadi','Tupolevova 8','Bratislava','','SLOVAK REPUBLIC','85101','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 13:56:44',0,NULL,3,1,2,1,NULL,'macokaz\r徐\r\\'),(7647,0,120708876423,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',2.25,'hermeshine','malim269','malim8888@yahoo.com','Gifts Crafts & Beyond','11291 Senda Luna Llena','San Diego','CA','UNITED STATES','92130','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 14:54:14',0,NULL,3,1,1,1,NULL,'malim269\r庄\r、'),(7648,768004014015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','jaguar200000','extrados@neuf.fr','PASCAL DARNANVILLE','42 RUE FELIX FAURE','DUNKERQUE','Nord-Pas-de-Calais','FRANCE','59240','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 15:17:54',0,NULL,3,1,3,1,NULL,'jaguar200000\rRA117729065CN\r\\'),(7649,752465265016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','bardelas1','habelyan@ntlworld.com','Jan Habelman','28 Rosedale Waltham','Grimsby','Lincolnshire','UNITED KINGDOM','DN37 0UJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 15:33:37',0,NULL,3,1,2,1,NULL,'bardelas1\r徐\r\\'),(7650,768015238015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','r*g*b','robertgburke@hotmail.com','Robert Burke','46 Ashtofts Mount<br>Guiseley','Leeds','West Yorkshire','UNITED KINGDOM','LS20 9DB','07871882896','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 15:34:37',0,NULL,3,1,2,1,NULL,'r*g*b\r庄\r\\'),(7651,699161616002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','2010bousosheila','bousosheila@gmail.com','Carlos Alberto Bouso','Ecuador 318 1 Piso Departamento A','Capital Federal','Buenos Aires','ARGENTINA','C1214ACD','011 48657042','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 15:44:02',0,NULL,3,1,3,1,NULL,'2010bousosheila\rRA117729025CN\r\\'),(7652,752133119016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',2,'AB3307',65.98,'hutongstore','michaelhele','michael@hele.co.uk','Michael Hele','23 Norbiton Road<br>Kingstanding','Birmingham','West Midlands','UNITED KINGDOM','B44 0EE','01216801366','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 15:45:28',0,NULL,3,1,3,1,NULL,'michaelhele\r王\rRA117729975CN'),(7653,699170239002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','zandermatt','risto.piiroinen@gmail.com','Risto Piiroinen','Norkkokuja 3 A 5','Vantaa','','FINLAND','01360','+358400618504','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 15:50:14',0,NULL,3,1,3,1,NULL,'zandermatt\r加77ND8   1   \r王\rRA117712609CN\r、'),(7654,658458534001,110419742832,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',8.2,'hermeshine','zandermatt','risto.piiroinen@gmail.com','Risto Piiroinen','Norkkokuja 3 A 5','Vantaa','','FINLAND','01360','+358400618504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 15:59:59',0,NULL,8,1,17,0,NULL,'zandermatt\r徐'),(7655,699003069002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','arx808','weondaair808@aol.com','Lorelie Arcalas','94-693 Kupuna Loop','Waipahu','HI','UNITED STATES','96797-1120','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 16:06:22',0,NULL,3,1,1,1,NULL,'arx808\r庄\r、'),(7656,752503787016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','dolon2424','dolon24@hol.gr','Ioannis Athanasiadis','Aristotelous 35<br>Stavroupoli','Thessaloniki','Thessaloniki','GREECE','56431','2310665482','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 16:28:03',0,NULL,3,1,3,1,NULL,'dolon2424\r庄\rRA117729079CN\r、'),(7657,658478885001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','dennis.781','dennwise@gmail.com','Dennis S.  Wise','2 Ponkapoag Way','Canton','MA','UNITED STATES','02021-1117','(781) 608-0548','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 16:28:59',0,NULL,3,1,1,1,NULL,'dennis.781\r要“灰色”背景布。\r刘\r、'),(7658,656557207018,280541368434,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','artanis1986','artanis@artanis.hu','Gergely Cziva','Radnoti 15.','Martonvásár','','HUNGARY','2462','Invalid Request','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-10 16:51:43',0,NULL,3,1,5,1,NULL,'artanis1986\r刘\r欧标   \rCP226268775CN'),(7659,658516695001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','schinder1956','skrunda.lv@gmail.com','Indulis Gutmanis','Jubilejas 7-16','Rudbarzu pagasts','Skrundas novads','LATVIA','LV-3324','26271330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 17:20:51',0,NULL,3,1,3,1,NULL,'schinder1956\r庄\rRA117729493CN\r、'),(7660,658526298001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','karloslk','karloska@mail.ru','Karen Lazaryan','Varshavskoe shosse 37A','Moscow','','RUSSIAN FEDERATION','117105','+79265934053','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 17:31:30',0,NULL,3,1,3,1,NULL,'karloslk\rRA117729082CN\r\\'),(7661,768131160015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',1.88,'hutongstore','sakura54t','lobster876@hotmail.com','Richard Taylor','88 Hamilton Road, Summertown','Oxford','Oxfordshire','UNITED KINGDOM','OX2 7QA','01865559694','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 17:46:19',0,NULL,3,1,2,1,NULL,'sakura54t\r刘\r\\'),(7662,768135708015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','bodyboarder1979','lisajones_1982@hotmail.co.uk','lisa jones','78 priory court','neath','Neath Port Talbot','UNITED KINGDOM','sa10 7rz','01639698561','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 17:49:52',0,NULL,3,1,2,1,NULL,'bodyboarder1979\r庄\r\\'),(7663,658549073001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','fred_star101','fred_star@intnet.mu','Frederic Foo Shin','8 cook street','Port Louis','','MAURITIUS','000000','+230 212 6660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 18:07:12',0,NULL,3,1,2,1,NULL,'fred_star101\r刘\r\\'),(7664,658567478001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',61,'hermeshine','magician20','kaprifolvagen@bredband.net','Thomas Andersson','Kaprifolvägen 46','Hässelby','Stockholm','SWEDEN','S-165 59','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 18:12:15',0,NULL,3,1,3,1,NULL,'magician20\r刘\r注意是2个\r1.7\rRA117712475CN\r\\'),(7665,699299679002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','tomuresa','almagra@telefonica.net','Tomas Ureña Saez','C/ Santo Tomas 22','Mazarron','Murcia','SPAIN','30870','609589176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 18:28:06',0,NULL,3,1,2,1,NULL,'tomuresa\r庄\r\\'),(7666,752629477016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','espirelojuan','espirelott@hotmail.es','david bestard','calle plataner 12 4b','Palma de Mallorca','Baleares','SPAIN','07008','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 18:28:43',0,NULL,3,1,2,1,NULL,'espirelojuan\r刘\r\\'),(7667,699335546002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','tg60','ebay@tg60.de','Thomas Gänsdorfer','Im Winterrot 95','Karlsruhe','','GERMANY','76228','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 19:08:24',0,NULL,3,1,3,1,NULL,'tg60\r庄\rXL\rRA117729034CN\r、'),(7668,699416472002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','pavelsib','tigerx@ngs.ru','Pavel Sibirtsev','ul. Vybornaya 110-11<br>ул. Выборная 110-11','Novosibirsk','Novosibirskaya Oblast','RUSSIAN FEDERATION','630126','7(903)9976336','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 21:10:36',0,NULL,3,1,3,1,NULL,'pavelsib\r刘\rRA117712127CN\r\\'),(7669,658714681001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','walbo007','ej.wallet@telfort.nl','Edith-José Wallet-Boers','Berkelstroom 117','Zoetermeer','','NETHERLANDS','2721 AG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 21:42:01',0,NULL,3,1,2,1,NULL,'walbo007\r徐\r\\'),(7670,658715523001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',15,'AA3309',74.25,'hermeshine','1imagen','imaklos@hotmail.com','Manuel','Avenida Derechos Humanos 28 - Rdcia.Los sauces 10','Laredo','Cantabria','SPAIN','39770','942611010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 21:44:22',0,NULL,5,0,18,0,NULL,'1imagen'),(7671,658712327001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',15,'AA3308',74.25,'hermeshine','1imagen','imaklos@hotmail.com','Manuel','Avenida Derechos Humanos 28 - Rdcia.Los sauces 10','Laredo','Cantabria','SPAIN','39770','942611010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 21:44:22',0,NULL,5,0,18,0,NULL,'1imagen'),(7672,658129784001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',18.99,'hermeshine','manolovian','mvianh@hotmail.com','Manuel Vian Hernando','C/ San juan 11-13 1ºB<br>Medina de Rioseco','Valladolid','Castilla y León','SPAIN','47800','650478444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 21:51:08',0,NULL,3,0,3,1,NULL,'manolovian\r1.6x2.1  背景布  2\r灰色  +  绿色\rRA117712294CN\r、'),(7673,658723586001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','shoxpro','shoxpro@mailcity.com','reynald barredo','13890 Sayre st<br>Apt. 218','Sylmar','CA','UNITED STATES','91342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 22:05:01',0,NULL,3,1,1,1,NULL,'shoxpro\r徐\r、'),(7674,752814664016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','bobhllihp','phillybob67@aol.com','PHIL LOCKHART','6 BIRCH CROFT','DEESIDE','Flintshire','UNITED KINGDOM','CH52BN','01244536485','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 22:32:49',0,NULL,3,1,3,1,NULL,'bobhllihp\r王\rRA117729961CN'),(7675,768373260015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',2,'AA3310',7,'hutongstore','sookonn','indrek.polakes@mail.ee','Indrek Polakes','Kärberi 52-11','Tallinn','Harjumaa','ESTONIA','13919','56453066','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 22:35:59',0,NULL,3,1,2,1,NULL,'sookonn\r徐\r\\'),(7676,656810862018,280522560367,'Tripod Fancier FT-6662A with 6160H Ball head 550D D90',1,'AE1503',69.9,'photographyacc','kulyllo','kulyllo@hotmail.com','ENCARNA MARIA GIMENEZ SANCES','C/PICASSO Nº4<br>BALERMA','ALMERIA','Andalucía Ceuta y Melilla','SPAIN','04712','658974588','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-10 22:52:07',0,NULL,3,1,4,1,NULL,'kulyllo\r庄\rtripod  $20\rYW864941121CN'),(7677,699455332002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','revenk0','rda9@ya.ru','Денис Ревенко','11-я улица дом 56','Ростов-на-Дону','','RUSSIAN FEDERATION','344013','89034620514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 22:55:12',0,NULL,3,1,3,1,NULL,'revenk0\rRA117729017CN\r\\'),(7678,699481373002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','mlmho','mlmho@yahoo.com','Ming Ho','274 Pantego Terr NW','Calgary','AB','CANADA','T3K0k3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 00:00:24',0,NULL,3,1,5,1,NULL,'mlmho\r庄\r2m 背景架    白色\rCP226268761CN'),(7679,768414750015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','mikeparsons1974','mcpuk1@btinternet.com','Mike Parsons - Capture Moments Photography','No 5 Green Lawns<br>14 Bay View Road','Colwyn Bay','Conwy','UNITED KINGDOM','LL298DW','01492531032','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 00:26:51',0,NULL,3,1,3,1,NULL,'mikeparsons1974\rRA117729105CN\r\\'),(7680,768420676015,250599922899,'New 67mm 67 Ring adapter and Holder for Cokin P Series ',1,'AKT022',3.62,'hutongstore','sprinter_90','andy_millen@hotmail.co.uk','Andy Millen','7 Phineas Pett Road','Eltham','London','UNITED KINGDOM','SE9 6RQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 00:41:11',0,NULL,8,1,17,0,NULL,'sprinter_90'),(7681,768420678015,250599423735,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'AA1307',1.88,'hutongstore','sprinter_90','andy_millen@hotmail.co.uk','Andy Millen','7 Phineas Pett Road','Eltham','London','UNITED KINGDOM','SE9 6RQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 00:41:13',0,NULL,3,1,2,1,NULL,'sprinter_90\rNIKON 镜头盖 67mm   1\r接口环 67mm   1\r卡座   1\r徐\r\\'),(7682,752892289016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','matzu855','matzu85@yahoo.com','badea nicolae sebastian','7 The Cottage<br>Lewis Street','st helier','Channel Islands','UNITED KINGDOM','JE2 3PB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 01:55:35',0,NULL,3,1,3,1,NULL,'matzu855\rRA117729502CN\r\\'),(7683,658803415001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','plab6987','labedzki@live.ca','Piotr Labedzki','22 Gloucester CRT','Kitchener','ON','CANADA','N2B3W1','(519) 894-2869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 02:04:22',0,NULL,3,1,2,1,NULL,'plab6987\r\\'),(7684,658819132001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','greencatmerlin','richl@unimelb.edu.au','Linda Richmond','Campus Operations Group<br>215 Grattan Street','The University of Melbourne','Victoria','AUSTRALIA','3010','0383446105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 03:01:43',0,NULL,8,1,17,0,NULL,'greencatmerlin'),(7685,699544436002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','greencatmerlin','richl@unimelb.edu.au','Linda Richmond','Campus Operations Group<br>215 Grattan Street','The University of Melbourne','Victoria','AUSTRALIA','3010','0383446105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 03:01:47',0,NULL,8,1,17,0,NULL,'greencatmerlin'),(7686,658818214001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','greencatmerlin','richl@unimelb.edu.au','Linda Richmond','Campus Operations Group<br>215 Grattan Street','The University of Melbourne','Victoria','AUSTRALIA','3010','0383446105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 03:01:48',0,NULL,8,1,17,0,NULL,'greencatmerlin'),(7687,658818738001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.99,'hermeshine','greencatmerlin','richl@unimelb.edu.au','Linda Richmond','Campus Operations Group<br>215 Grattan Street','The University of Melbourne','Victoria','AUSTRALIA','3010','0383446105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 03:01:48',0,NULL,3,1,3,1,NULL,'greencatmerlin\r麂皮   1\r气吹 + 布    1\r橡胶遮光罩 58mm   1\r眼罩 450D/500D   1\rRA117712246CN\r\\'),(7688,0,120708876461,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.99,'hermeshine','rydabomb','ryan4luck@sbcglobal.net','Ryan Wills','7705 Devon Ct','Atascadero','CA','UNITED STATES','93422','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 03:27:12',0,NULL,3,1,1,1,NULL,'rydabomb\r、'),(7689,656904433018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','4697timothy','lexball68@hotmail.com','Timothy Williams','3145 S Prairie Ave','Chicago','IL','UNITED STATES','60616-3903','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 04:20:13',0,NULL,3,1,4,1,NULL,'4697timothy\r刘  \rYW864941983CN'),(7690,657793944001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',71.88,'hermeshine','heart.beth.ann','bskabar@gmail.com','beth skabar','618 N St<br>Apt 2','anchorage','AK','UNITED STATES','99501-6084','','PayPalPaymentInProcess','CheckoutComplete','Other','0000-00-00 00:00:00',0,NULL,3,0,3,1,NULL,'heart.beth.ann\r反光板支架   1\r100-150 5in1 反光板  1\r发两个小包  王\rRA117712467CN\rRA117712419CN\r、\r'),(7691,658863584001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','graf131313','m.prishep@gmail.com','Pryshep Zinaida','Rokossovskogo 48-4','Bobryisk','Belarys','BELARUS','213811','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 07:03:28',0,NULL,3,0,3,1,NULL,'graf131313\rRA117712555CN\r\\'),(7692,658627325001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',75.07,'hermeshine','michaelkozhin','kozhin@mail.ru','MIKHAIL KOZHIN','GRINA 30 - 65','MOSCOW','Russian Federation','RUSSIAN FEDERATION','117628','+79857634708','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 07:26:08',0,NULL,3,1,3,1,NULL,'michaelkozhin\r肩架   1\rB座   1\r大号内胆包  canon   1\rlenspen   2\rNG128    1\rRA117729431CN\r\\\r\r'),(7693,658874614001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','bryan2105','info@artover.com','Janvier Bryan','EDC<br>Riambel','Surinam','','MAURITIUS','0001','(230) 494-2793','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 07:58:51',0,NULL,3,0,2,1,NULL,'bryan2105\r\\'),(7694,768561188015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','agreis81','agreis@agreis.hu','Bela Forgo','Fóti út 122','Budapest','Budapest','HUNGARY','H-1046','36704584638','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 08:56:02',0,NULL,3,0,3,1,NULL,'agreis81\rRA117729462CN\r\\'),(7695,658122636001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','makkirill','mak2do@ukr.net','Kirill Mysak','Vorovskogo st. 11A, ap.76','KIEV','','UKRAINE','04053','+380443603613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 09:09:16',0,NULL,3,1,2,1,NULL,'makkirill\r、'),(7696,658905410001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','frank8490','frank@roland.sk','Frantisek Nagel','Brezova 5','Nove Zamky','','SLOVAK REPUBLIC','94001','00421905601328','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 10:17:33',0,NULL,3,1,2,1,NULL,'frank8490\r\\王'),(7697,768598276015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','nutboy83','japarsons2@gmail.com','James Parsons-Day','47 Talavera Close<br>Old Market','Bristol','Bristol','UNITED KINGDOM','BS2 0EF','07795553030','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 11:14:20',0,NULL,3,1,2,1,NULL,'nutboy83\r庄\\'),(7698,698552458002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','istokka','admoccia@alice.it','pasquale saviano','via GRAMSCI 55','Frattaminore','NA','ITALY','80020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 11:56:50',0,NULL,3,1,4,1,NULL,'istokka\r4灯头棚   2\r2.1\rphoto light  $22\r王\rYW864941891CN'),(7699,658935181001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',20,'hermeshine','costinha50','augustoradacosta@hotmail.com','augusto ra da costa','73, Raeburn road<br>Roleystone','Perth','Western Australia','AUSTRALIA','6111','0893976725','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-04-11 12:10:50',0,NULL,3,1,2,1,NULL,'costinha50\r王\\'),(7700,699665912002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',4,'AE3102',31.56,'hermeshine','karolusko1980','hogo.fogo@azet.sk','Karol Brull','Popolna 32','Bratislava','','SLOVAK REPUBLIC','83106','+421903211474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 12:19:42',0,NULL,3,1,3,1,NULL,'karolusko1980\r王\rRA117712780CN\r、'),(7701,768638283015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','capekfilip','email@capekfilip.cz','Filip Čapek','U Tesly 7','Havířov','Moravskoslezký kraj','CZECH REPUBLIC','73601','+420736272866','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-11 12:51:37',0,NULL,3,1,5,1,'CP226269170CN ','capekfilip\r庄\r'),(7702,699431351002,120654651653,'Pro Photo Vest Blue for Nikon D90 D300s D7000 D80  user',1,'AA2117',32,'hermeshine','hlwhitson','hlwhitson@charter.net','HAROLD WHITSON','1908 Fairway Dr','JOHNSON CITY','TN','UNITED STATES','37601-2207','(423) 929-2096','NoPaymentFailure','CheckoutComplete','Other','2011-04-11 13:10:21',0,NULL,3,1,1,1,NULL,'hlwhitson\rXL\r庄\r、'),(7703,753100149016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',14.5,'hutongstore','david-brookes','david-brookes@supanet.com','David Brookes','24 Oakfield Close','Bolton','Lancashire','UNITED KINGDOM','BL66JR','01204690262','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 14:04:20',0,NULL,3,1,3,1,NULL,'david-brookes\r庄\rRA117712878CN\r、'),(7704,658967898001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','irenep23','ipidal@teleline.es','Irene Pidal Miranda','Martí Costa, 1, 5ºA','Palma de Mallorca','Baleares','SPAIN','07013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 14:20:25',0,NULL,3,1,2,1,NULL,'irenep23\r庄\r、'),(7705,753114420016,260660054359,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',1.58,'hutongstore','harcab02','harcab02@yahoo.com','Harris Cabatingan','63 Glenhugh Park, Ahoghill','Ballymena','Antrim','UNITED KINGDOM','BT42 1LR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 14:41:45',0,NULL,3,1,2,1,NULL,'harcab02\r庄\\'),(7706,658979889001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','pulleirofernando','tricolordelsur@hotmail.com','Fernando Pulleiro','6718 NW 72nd Ave<br>Miami Fl, 33166 Ste A-6702','Miami','FL','UNITED STATES','33166-3045','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 14:42:25',0,NULL,3,1,1,1,NULL,'pulleirofernando\r庄\r、'),(7707,658981808001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','arrandi001','arrandi@gmail.com','Ander Arriandiaga Laresgoiti','Zunzunegi 6<br>10º ezk.','Bilbo','País Vasco','SPAIN','48013','665723749','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 14:49:06',0,NULL,3,1,4,1,NULL,'arrandi001\rtripod  $16\rYW864941935CN\r王'),(7708,0,110671627185,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',2.25,'hermeshine','sigmadelta','busnau@hotmail.com','Stanley Pau','1630 East University Blvd.<br>University Of Arizona','Tucson','AZ','UNITED STATES','85721-0001','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 15:05:07',0,NULL,3,1,1,1,NULL,'sigmadelta\r庄\r、'),(7709,658989308001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'AO0015',7.9,'hermeshine','alvaro19561','aneira65@yahoo.com','Alvaro Neira','340 NW 19th St<br>Apt 200','boca raton','FL','UNITED STATES','33432','(561) 929-2877','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 15:06:54',0,NULL,3,1,1,1,NULL,'alvaro19561'),(7710,753119148016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','gronqvist9690','gronqvist@nrdc.dk','Mogens Grønqvist','Valmuemarken 18','Fjerritslev','standard','DENMARK','9690','98213585','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 15:14:02',0,NULL,3,1,2,1,NULL,'gronqvist9690\r庄\r、'),(7711,0,110671627085,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',2.8,'hermeshine','aries_dreamer','guardgurl86@yahoo.com','Ellie Alikhani','8108 bright meadows ln','Dunn Loring','VA','UNITED STATES','22027','(703) 217-4739','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 15:20:03',0,NULL,3,1,1,1,NULL,'aries_dreamer\r庄\r、'),(7712,657055112018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',88,'photographyacc','a.vyatkin','avyatkin@mail.ru','Anton Vyatkin','Baikal\'skaya 291/2 - 21','Irkutsk','Irkutskaya obl','RUSSIAN FEDERATION','664050','+79149335500','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-11 15:52:21',0,NULL,3,1,5,1,NULL,'a.vyatkin\r2m背景架    1\r3块背景布  白  黑   灰    \r王\rCP226269197CN'),(7713,659014693001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','kosowar7','clirim@uskana.com','Clirim Ramadani','Rr. Bill Clinton SU5/8E Nr.41','Pristina','Kosovo','ALBANIA','10090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 16:19:06',0,NULL,8,1,17,0,NULL,'kosowar7'),(7714,768725424015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'AKT023',3.62,'hutongstore','mike2005walking','driving@supanet.com','Mike Hesp','1 Buttermere Close<br>Little Lever','Bolton','Lancashire','UNITED KINGDOM','BL3 1UF','01204577077','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 16:21:56',0,NULL,3,1,2,1,NULL,'mike2005walking\r庄、'),(7715,659016322001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','parts-auto','info@autopartsbiz.com','Lima Nuno','Av. Antero de Quental nº 86<br>monaco','Braga','Braga','PORTUGAL','4710-377','939840517','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 16:23:19',0,NULL,3,1,2,1,NULL,'parts-auto\r庄\r、'),(7716,699748683002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','kosowar7','clirim@uskana.com','Clirim Ramadani','Rr. Bill Clinton SU5/8E Nr.41','Pristina','Kosovo','ALBANIA','10090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 16:23:49',0,NULL,3,1,3,1,NULL,'kosowar7\r一转四 灯头   1\r4灯头 灯头 孔     2  欧标\r申报 $40\r庄\r1.77\rRA117729842CN\r、'),(7717,768727143015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','colincooks','colin_cook@talktalk.net','colin cook','16 coltishall close','Plymouth','Devon','UNITED KINGDOM','pl5 2pa','01752362916','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 16:24:59',0,NULL,3,1,2,1,NULL,'colincooks\r刘\r、'),(7718,699757310002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','gundamseed84','ahcang@gmail.com','ang wei cang','Blk 286D Toh Guan Road #13-10','singapore','singapore','SINGAPORE','604286','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 16:44:59',0,NULL,3,1,3,1,NULL,'gundamseed84\r刘\rRA117712895CN\r、'),(7719,699766415002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','rcf_1989','rcf33@hotmail.com','Rebeca Castillo','Ramón Sáez de Adana nº 7 2º izq','Santander','Cantabria','SPAIN','39006','660817133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 17:07:41',0,NULL,3,1,2,1,NULL,'rcf_1989\r庄、'),(7720,659035445001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','marcelinopozo','marcelinopozoruiz@gmail.com','Marcelino Pozo Ruiz','Urb El Rocio 32','Malaga','Andalucía Ceuta y Melilla','SPAIN','29016','607540414','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 17:15:36',0,NULL,8,0,17,0,NULL,'marcelinopozo'),(7721,659033536001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','marcelinopozo','marcelinopozoruiz@gmail.com','Marcelino Pozo Ruiz','Urb El Rocio 32','Malaga','Andalucía Ceuta y Melilla','SPAIN','29016','607540414','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 17:15:37',0,NULL,8,1,17,0,NULL,'marcelinopozo'),(7722,659033977001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','marcelinopozo','marcelinopozoruiz@gmail.com','Marcelino Pozo Ruiz','Urb El Rocio 32','Malaga','Andalucía Ceuta y Melilla','SPAIN','29016','607540414','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 17:15:37',0,NULL,3,0,4,1,NULL,'marcelinopozo\r摄影背心 nikon 原厂  XL\r摄影背心 Nikon 老款   M\r摄影背心 Nikon 老款   XL\r刘\rphoto vest  $25\r2.134\rYW864941946CN'),(7723,659025474001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','isabellaisibal','isabella.allegrini@live.it','Isabella Allegrini','via Cascinetto 9 D','Cureggio','NO','ITALY','28060','348 4032674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 17:16:20',0,NULL,3,1,2,1,NULL,'isabellaisibal\r庄、'),(7724,659048325001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','mangokillers','artem.yumashev@gmail.com','Artem Yumashev','Dimitrova street 12-2-64','St. Petersburg','','RUSSIAN FEDERATION','192239','981-862-68-18','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 17:37:57',0,NULL,8,1,17,0,NULL,'mangokillers'),(7725,699788562002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','mangokillers','artem.yumashev@gmail.com','Artem Yumashev','Dimitrova street 12-2-64','St. Petersburg','','RUSSIAN FEDERATION','192239','981-862-68-18','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 17:58:03',0,NULL,8,1,17,0,NULL,'mangokillers\r'),(7726,699814288002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','orlando_xxx','roland.sax@hispeed.ch','Roland Sax','Sägenstrasse 107','Chur','','SWITZERLAND','7000','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 18:40:53',0,NULL,3,1,2,1,NULL,'orlando_xxx\r庄、'),(7727,659083252001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',4,'AKT007',75.96,'hermeshine','voodoohill','dario.m@tin.it','Dario Mollo','Via Alba, 30','BORDIGHERA','IM','ITALY','18012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 18:43:56',0,NULL,3,1,3,1,NULL,'voodoohill\r刘\r8个灯泡   1.35\rRA117712816CN'),(7728,659101075001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','wooqe','wooqe75@hotmail.com','Qi Wu','399 Bathurst St<br>Toronto Western Hospital, Room 14MP301','Toronto','ON','CANADA','M5T 2S8','(647) 863-6957','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 19:18:45',0,NULL,3,1,3,1,NULL,'wooqe\r庄\rRA117712881CN\r、'),(7729,768839860015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','markarnold74','maa13101974@yahoo.co.uk','mark arnold','27 Randolph Drive<br>Southwood','Farnborough','Hampshire','UNITED KINGDOM','GU14 0QQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 19:24:31',0,NULL,3,1,2,1,NULL,'markarnold74\r庄\\'),(7730,699845191002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','mangokillers','artem.yumashev@gmail.com','Dmitriy Rumiancev','Alpiiskii pereulok 15-1-49','St Petersburg','','RUSSIAN FEDERATION','192239','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 19:38:27',0,NULL,3,1,5,1,NULL,'mangokillers\r庄\r肩架    3\rCP226268832CN'),(7731,659111494001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','marioknor','mario.knor@gmail.com','Mario Knor','Vukovarska 2','Varaždin','Varaždin','CROATIA','42000','0915017137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 19:40:31',0,NULL,3,1,2,1,NULL,'marioknor\r庄\r、'),(7732,768867351015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','zenelb','zenelb@gmail.com','Zenel Batagelj','Tavcarjeva 4','Ljubljana','','SLOVENIA','SI-1000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 20:05:19',0,NULL,3,1,2,1,NULL,'zenelb\r庄、'),(7733,659130167001,110658456901,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',9,'hermeshine','matan-sabag','matansbg@gmail.com','matan sabag','chochit 12','beer sheva','south','ISRAEL','84828','054-6564-572','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 20:12:35',0,NULL,3,1,11,1,NULL,'matan-sabag\r庄\r、'),(7734,0,120708477651,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1308',1.25,'hermeshine','eightball777','eightball777@sbcglobal.net','STACEY LYNN BLEVINS','4445 MCNIEL AVE','WICHITA FALLS','TX','UNITED STATES','76308-3530','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 20:24:06',0,NULL,3,1,1,1,NULL,'eightball777\r庄\r、'),(7735,753307285016,260660056304,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.68,'hutongstore','tallauders','msh@ms-h.demon.co.uk','Audrey Scott-Hopkins','Crows Oak<br>Crow Hill','Ringwood','Hampshire','UNITED KINGDOM','BH24 3DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 20:28:55',0,NULL,3,1,2,1,NULL,'tallauders\r庄\\'),(7736,699876742002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','apoel1977','george1977@gmail.com','George Georgiou','P.O.Box 23588','Nicosia','','CYPRUS','1685','99617323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 20:40:39',0,NULL,3,1,3,1,NULL,'apoel1977\r刘\rRA117712793CN\r、'),(7737,659147335001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','gildmai*210','gildmai@gmail.com','Sergey Guzev','October st. 11-23','Magnitogorsk','Chelyabinsk region','RUSSIAN FEDERATION','455023','+79068727983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 20:49:32',0,NULL,3,1,2,1,NULL,'gildmai*210\r庄\\'),(7738,768912594015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.99,'hutongstore','our-friends-electric','andre.govia@london.com','Mr a govia','50 perrycroft<br>windsor','berkshire','Berkshire','UNITED KINGDOM','sl44he','01753683253','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 21:27:50',0,NULL,3,1,2,1,NULL,'our-friends-electric\r刘\\'),(7739,768929328015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',3.59,'hutongstore','ramonpastormarco','rpastor@iberdrola.es','Ramón Pastor Marco','C/ Jorge Juan, nº 37','San Vicente del Raspeig','Alicante','SPAIN','03690','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 22:08:59',0,NULL,3,1,2,1,NULL,'ramonpastormarco\r庄\r\\'),(7740,659190598001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','jengelsmeier','blackcat1957@netscape.com','Jeanne Engelsmeier','16681 Garnet St NW','Ramsey','MN','UNITED STATES','55303','(763) 258-9093','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 23:02:31',0,NULL,3,1,1,1,NULL,'jengelsmeier\r庄\r、'),(7741,0,120708477477,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',0.99,'hermeshine','lewisville','ebay@texaspowells.org','Jeff Powell','1705 Ash ln','Corinth','Tx','UNITED STATES','76210-3106','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 23:33:17',0,NULL,3,1,1,1,NULL,'lewisville\r庄\r、'),(7742,699948901002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','rainlook','reinlook@hotmail.com','Vladimir Luchianiuc','1816 Woodlands Dr SE','Smyrna','GA','UNITED STATES','30080-8405','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 00:34:13',0,NULL,3,1,1,1,NULL,'rainlook\r刘、'),(7743,659221192001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','jlking52','jking@hhbc.com','Jenny King','500 Pepperdine Ave','Edmond','OK','UNITED STATES','73013-5456','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 01:09:29',0,NULL,3,1,1,1,NULL,'jlking52\r刘\r、'),(7744,659225593001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','receedo69','mmargeson@krrc.ns.ca','Mike Margeson','170 South Street','Berwick','NS','CANADA','B0P1E0','(902) 538-0763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 01:20:42',0,NULL,3,1,2,1,NULL,'receedo69\r刘\r\\'),(7745,659232941001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','gregz2008','gregor.zelle@gmail.com','Gregor Zelle','4 Jobson Avenue','Mount Ousley','New South Wales','AUSTRALIA','2519','0406780709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 01:47:18',0,NULL,3,1,3,1,NULL,'gregz2008\r是金属卡口的在白盒子里\r庄\rRA117712864CN\r、'),(7746,699994825002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT055',126,'hermeshine','noisegenerator23','zns.photography@live.it','marco pugliese','via libero grassi, 9','palermo','PA','ITALY','90135','3881011166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 03:33:53',0,NULL,3,1,4,1,NULL,'noisegenerator23\r王\rYW864941950CN'),(7747,698893993002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','jezreex','jezreex@gmail.com','Jezreel Bago','1826 Carolann St','Pomona','CA','UNITED STATES','91766','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 04:52:58',0,NULL,3,1,1,1,NULL,'jezreex\r庄、'),(7748,700008048002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',3,'AA1103',80.4,'hermeshine','udotaty','udotati@globo.com','tatiana teixeira','av luiz aranha 890 apt 508<br>barra da tijuca cond pedra de itauna','rio de janeiro','rio de janeiro','BRAZIL','22793810','55 21 8113 1499','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 05:08:59',0,NULL,3,1,3,1,NULL,'udotaty\r庄\rRA117712776CN\r、'),(7749,700019952002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','n.c.m.2002','nmaiers@mac.com','Neil Maiers','4927 La Calandria Dr','Los Angeles','CA','UNITED STATES','90032-3329','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 05:54:55',0,NULL,3,1,1,1,NULL,'n.c.m.2002\r、'),(7750,700022987002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','valuter.ru','valuter@gmail.com','Владимир Паршин','Zvodskaya 71','c.Mayma','Respublika Altay','RUSSIAN FEDERATION','649100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 06:11:29',0,NULL,3,1,3,1,NULL,'valuter.ru\r王\rRA117712904CN\r\\'),(7751,659302276001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','barry9019','barryslade@tpg.com.au','Barry Slade','61 Mulyan st, Como','Sydney','New South Wales','AUSTRALIA','2226','0295286617','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 07:44:28',0,NULL,3,1,4,1,NULL,'barry9019\rphoto boom arm $20\r刘\rYW864941961CN'),(7752,700051969002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','elle-ch','auktion@swisselle.ch','Michelle Brügger','Stationsstrasse 57','Embrach','','SWITZERLAND','8424','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 08:42:18',0,NULL,3,1,3,1,NULL,'elle-ch\r庄\rRA117729992CN\r、'),(7753,700050806002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','elle-ch','auktion@swisselle.ch','Michelle Brügger','Stationsstrasse 57','Embrach','','SWITZERLAND','8424','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 08:42:19',0,NULL,3,1,3,1,NULL,'elle-ch\r刘 \rRA117729913CN\r、'),(7754,700051860002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','elle-ch','auktion@swisselle.ch','Michelle Brügger','Stationsstrasse 57','Embrach','','SWITZERLAND','8424','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 08:42:19',0,NULL,3,1,3,1,NULL,'elle-ch\r庄\rRA117729958CN\r、'),(7755,659319805001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','dja-u','dja-u@nm.ru','Ilia Chungurov','60 let Oktyabya d. 5, kv. 59','Simferopol','Crimea','UKRAINE','95044','380676527619','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 09:09:03',0,NULL,3,1,3,1,NULL,'dja-u\r刘\rRA117729935CN\r、'),(7756,659321225001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','v0xff','voxtobox@gmail.com','Vova Antonyuk','Filatova 4','Lutsk','Volyn region','UKRAINE','43018','380631788440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 09:14:41',0,NULL,3,1,2,1,NULL,'v0xff\r庄'),(7757,697244640002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','abraaojr','abraao.junior@yahoo.com.br','Abraão Gomes Soares Jr','R. Conselheiro Lafaiete, 1977<br>apto: 1202, Sagrada Família','Belo Horizonte','Minas Gerais','BRAZIL','31035-560','+55 31 3327-8275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 09:23:55',0,NULL,3,1,2,1,NULL,'abraaojr\r刘'),(7758,769127135015,250599920440,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.39,'hutongstore','kennyipcu','kmclellon@aol.com','Kenneth   McLennan','58 Ness Circle','Ellon','Aberdeenshire','UNITED KINGDOM','AB419BR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-12 10:09:22',0,NULL,3,1,2,1,NULL,'kennyipcu\r庄'),(7759,700094084002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','aleksei5425','aleksei.lang@mail.ee','Aleksei Lang','Oismae tee 109-54','Tallinn','Harjumaa','ESTONIA','13515','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 11:35:50',0,NULL,3,1,3,1,NULL,'aleksei5425\r刘\rRA117729944CN\r、'),(7760,659366396001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','crenatoycar','smelly_texta@hotmail.com','corinna conforti','57 rugby crescent<br>chipping norton','sydney','New South Wales','AUSTRALIA','2170','0297552558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 12:13:01',0,NULL,3,1,2,1,NULL,'crenatoycar\r庄'),(7761,753589900016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','rossii_91','rossii_g@abv.bg','Rossi Gencheva','6 Layosh Koshut str., ap. 5','Shumen','','BULGARIA','9700','+357-896-515-272','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 12:23:10',0,NULL,3,1,2,1,NULL,'rossii_91\r刘'),(7762,700127622002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','woodloretech','leo@woodlore.ca','Leo Fleury','160 Delta Park Blvd.','Brampton','ON','CANADA','L6T 5T6','(905) 791-9555','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 13:30:56',0,NULL,3,1,3,1,NULL,'woodloretech\r庄\rRA117729927CN\r\\'),(7763,659403578001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','pas2par','paskay@bezeqint.net','GIDEON PASKAY','SHMARIAHU LEVIN 23/16','RISHON LE ZION','','ISRAEL','75278','972548110224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 14:14:53',0,NULL,3,1,2,1,NULL,'pas2par\r刘'),(7764,659408194001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','lau009','laurent3@gmail.com','Laurent Nangniot','rue Louis Titeca 42','Woluwe Saint Pierre','','BELGIUM','1150','0477917909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 14:29:48',0,NULL,3,1,2,1,NULL,'lau009\r庄'),(7765,769218076015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',13.64,'hutongstore','thaleinfo','t.aleziardo@gmail.com','THIBAUD ALEZIARDO','22 RUE DU GENERAL BERTRAND','PARIS','Ile-de-France','FRANCE','75007','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 14:35:14',0,NULL,3,1,3,1,NULL,'thaleinfo\r王\r小号镜头筒   1\r优永佳 快门线  RE-A  1\rcanon-58mm 反接环   1\rRA117729839CN\r、\r'),(7766,659411675001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','brainquinn','quinn.b@comcast.net','Brian Quinn','3306 Charles St','Rockford','IL','UNITED STATES','61108-3746','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 14:42:07',0,NULL,3,1,1,1,NULL,'brainquinn\r庄'),(7767,659437039001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','danr1234','danr1234@comcast.net','Daniel Reynolds','1426 Orkney Dr','Leesburg','FL','UNITED STATES','34788-7642','(352) 343-1446','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 15:54:11',0,NULL,3,1,1,1,NULL,'danr1234\r刘'),(7768,700175546002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','youst75','youst@ukr.net','Yuriy Druzhinets','Lenina str., 27A-38','Tokmak','Zaporozhye region','UKRAINE','71700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 16:23:59',0,NULL,3,1,2,1,NULL,'youst75\r注意是2只    庄'),(7769,659461730001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','diablocds1','diablocds1@yahoo.com','christopher sisti','620 Peachtree St NE<br>Apt 1904','Atlanta','GA','UNITED STATES','30308-2381','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 16:58:04',0,NULL,3,1,1,1,NULL,'diablocds1\r刘'),(7770,700252415002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','user-maat-ra-63','felix-arranz-martin@hotmail.com','FÉLIX ARRANZ MARTÍN','CARRETERA DE LA GRANJA, 4<br>CONSEJERÍA DE EDUCACIÓN','COLLADO VILLALBA','Madrid','SPAIN','28400','656560066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 18:49:21',0,NULL,3,1,2,1,NULL,'user-maat-ra-63\r庄'),(7771,659498384001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','dudziakw','wdudziak@wp.pl','Wojciech Dudziak','Telimeny<br>17/32','Kraków','','POLAND','30638','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 19:02:19',0,NULL,8,1,17,0,NULL,'dudziakw'),(7772,700237017002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','dudziakw','wdudziak@wp.pl','Wojciech Dudziak','Telimeny<br>17/32','Kraków','','POLAND','30638','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 19:02:18',0,NULL,3,0,3,1,NULL,'dudziakw\r摄影背心 黑色厚 无字   XXL  1\r伟峰 717 快装板   1\r王   RA117729895CN\r、'),(7773,700271900002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','ryrvikryrvik','medolaonas@hotmail.se','magnus ryrvik kjäll','hjortmossegatan 32','trollhättan','västra götaland','SWEDEN','46151','0520203000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 19:26:36',0,NULL,3,1,4,1,'YW864941876CN\r','ryrvikryrvik\r白色 1.6x2.1\r2m 架子    王\r'),(7774,700273599002,120454225464,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',2,'AE2308',11.6,'hermeshine','fodi64','fojola@digikabel.hu','Fodor Jozsef','Tulipan u. 1. II/8.','Bekescsaba','','HUNGARY','5600','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 19:30:04',0,NULL,3,1,2,1,NULL,'fodi64\r2个    庄'),(7775,700278105002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','manakayak40','manmeryal@telefonica.net','Manuel Navarro Ballester','Calle Huelva nº 36','San Cristobal de La Laguna','Canarias','SPAIN','38205','922641123','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 19:40:33',0,NULL,3,1,3,1,NULL,'manakayak40\r刘\rRA117730001CN\r、'),(7776,700281417002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','s0324','ssykes1@hot.rr.com','Stanley Sykes','2707 Huckleberry Dr','Killeen','TX','UNITED STATES','76549','(254) 634-9468','NoPaymentFailure','CheckoutComplete','Other','2011-04-12 19:45:18',0,NULL,8,1,17,0,NULL,'s0324\r庄'),(7777,0,110671627420,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',3.75,'hermeshine','jayredbraveman','redbraveman27@hotmail.com','Jay Reise','436 Canal Lake Rd','Blairsville','GA','UNITED STATES','30512-0249','(678) 936-7121','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 19:53:07',0,NULL,3,1,1,1,NULL,'jayredbraveman\r刘'),(7778,769402721015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','derekoo','dereko@btinternet.com','Derek Oosthuizen','DST House<br>St Marks Hill','Surbiton','Surrey','UNITED KINGDOM','KT64QD','02083995395','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-12 20:05:00',0,NULL,3,1,2,1,NULL,'derekoo\r庄'),(7779,700289636002,120461006671,'Digital SLR Camera Raincover rain cover for Nikon Canon',1,'AA3101',16.99,'hermeshine','s0324','ssykes1@hot.rr.com','Stanley Sykes','2707 Huckleberry Dr','Killeen','TX','UNITED STATES','76549','(254) 634-9468','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 20:21:12',0,NULL,8,1,17,0,NULL,'s0324\r刘'),(7780,659545039001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','s0324','ssykes1@hot.rr.com','Stanley Sykes','2707 Huckleberry Dr','Killeen','TX','UNITED STATES','76549','(254) 634-9468','NoPaymentFailure','CheckoutComplete','Other','2011-04-12 20:21:12',0,NULL,8,0,17,0,NULL,'s0324\r庄'),(7781,700287708002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','s0324','ssykes1@hot.rr.com','Stanley Sykes','2707 Huckleberry Dr','Killeen','TX','UNITED STATES','76549','(254) 634-9468','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 20:21:13',0,NULL,3,1,4,1,NULL,'s0324\r2m 灯架   1\r云台   1\r柔光伞   1\r防雨罩   1\r80cm 2in1 反光板   1\r摄影背心 Nikon 老款 XXL\r一票两件吧 \r lighting kit  $30    \r     刘\rYW864941865CN'),(7782,700299791002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','loro_swett','lswettn@hotmail.com','Lorenzo Swett','Duble Almeyda 1617 dpto 406-C<br>Nunoa','Santiago','Region Metropolitana, Nunoa','CHILE',' 7750097','56-998026337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 20:31:56',0,NULL,3,1,3,1,NULL,'loro_swett\r庄\rRA117729887CN\r、'),(7783,659572222001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',18.19,'hermeshine','daredeviljohn','daredeviljohn@hotmail.com','John Gauci','10, Triq Censu Busuttil','Iklin','MLT','MALTA','BZN11','(+356) 21435755','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 20:55:37',0,NULL,3,1,3,1,NULL,'daredeviljohn\r刘\rRA117729825CN\r、'),(7784,659573280001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',3,'AA2205',10.5,'hermeshine','vildandy','daaal81@hotmail.com','Andreas Dalevik','Ällingavägen 9B<br>1317','Lund','S','SWEDEN','22734','0730821179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 21:01:17',0,NULL,3,1,2,1,NULL,'vildandy\r庄\r注意是3个'),(7785,659578754001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','yesse87','jesse.juhani@netti.fi','Aku Kainulainen','Myllykyläntie 99','SIUNTIO KK','','FINLAND','02570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 21:11:03',0,NULL,3,1,2,1,NULL,'yesse87\r刘'),(7786,659585097001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','zhalfrin85','alpayaktan@hotmail.com','Alpay Aktan','Atatürk Sitesi,Hilmi Çayıroglu Sokak 4.Blok No:2','Ankara','OranÇankaya','TURKEY','06312','+905395700108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 21:27:06',0,NULL,3,1,3,1,NULL,'zhalfrin85\r庄    RA117729811CN\r、'),(7787,769447079015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',2,'AC2402',24.2,'hutongstore','fidel.cornelis','fidel.cornelis@gmail.com','Fidel Paul Cornelis Gimenez','Calle 1º de Mayo Nº 35 , Puerta 12','Alfara del Patriarca','Comunidad Valenciana','SPAIN','46115','655829242','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 21:29:06',0,NULL,3,1,3,1,NULL,'fidel.cornelis\r刘    注意是两个 \rRA117729900CN\r、'),(7788,700346675002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jctoletum','toletum@gmail.com','Jose Carlos Sanchez','Calle de Aragoneses, 2A<br>SELF BANK','Alcobendas','Madrid','SPAIN','28108','676325593','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 22:26:03',0,NULL,3,1,4,1,NULL,'jctoletum\r王\rtripod  $16\rYW864941854CN'),(7789,700351743002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','miha90','miha.horvat@gmail.com','Miha Horvat','Bevkova ulica 43','Radovljica','','SLOVENIA','4240','0038631506375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 22:43:29',0,NULL,3,1,2,1,NULL,'miha90\r刘'),(7790,659614249001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','alxg3','alxgag3@gmail.com','Alexander Vedeler','Fjellveien<br>123','Bergen','Hordaland','NORWAY','5019','+4797514080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 23:12:10',0,NULL,3,1,2,1,NULL,'alxg3\r庄'),(7791,700390904002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','bobsgrobert','bobsg@videotron.ca','Robert Sgouromitis','5833 Crevier','Montreal','QC','CANADA','H1G 2C9','(514) 326-0949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 01:15:32',0,NULL,3,1,2,1,NULL,'bobsgrobert\r刘'),(7792,700394588002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','wenfasiluy','wenfasiluy@yahoo.com','SILVANA  DOS SANTOS','11 Pillot Pl','WEST ORANGE','NJ','UNITED STATES','07052-5205','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 01:29:47',0,NULL,3,1,1,1,NULL,'wenfasiluy\r庄'),(7793,0,110671627256,'72mm 72 mm Macro +8 Close-Up Close Up Filter',1,'AE3227',0.99,'hermeshine','1marcuss','m1569@hotmail.com','Marcus gantt','5444 Peterson Ln<br>Apt 2013','dallas','TX','UNITED STATES','75240-5129','(214) 306-4970','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 02:45:07',0,NULL,3,1,1,1,NULL,'1marcuss\r庄'),(7794,659675923001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','az626rca','77295654@tigo.com.sv','Arnoldo Zetino','Urb. San Juan Bosco, calle circunvalación, polig. C, # 20, Santa Ana<br>contiguo a piscina de Apanteos.','Santa Ana','El Salvador','EL SALVADOR','00106-8000','(503)7729-5654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 03:28:27',0,NULL,3,1,2,1,NULL,'az626rca\r刘'),(7795,657803512018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','1ronryan2','rbshav@telusplanet.net','Ron Shavchook','4412 29 Street','Edmonton','AB','CANADA','T6T1G9','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-13 03:54:53',0,NULL,3,1,5,1,NULL,'1ronryan2\r灯泡是110v 的\r刘\rCP226269166CN'),(7796,0,120708477611,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',1.98,'hermeshine','huaguosan','shop94556@gmail.com','K C Hua','109 Alta Mesa Court','Moraga','CA','UNITED STATES','94556','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 04:36:42',0,NULL,3,1,1,1,NULL,'huaguosan\r庄'),(7797,659688522001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','green61dog','maggie_07108@yahoo.com','margaret adams','39 mead st','newark','NJ','UNITED STATES','07106','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 04:41:01',0,NULL,3,1,1,1,NULL,'green61dog\r庄\r、'),(7798,0,110671627393,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',2.75,'hermeshine','camexico','partscameras@hotmail.com','juan carlos velazquez','105 E San Antonio Ave','El paso','TX','UNITED STATES','79901-1111','(915) 542-4553','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 05:02:34',0,NULL,3,1,1,1,NULL,'camexic\r庄'),(7799,769126954015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','deadline2030','kameraverleih@gmail.com','Peter A. Egger','Schuetzengasse 1','Wien','','AUSTRIA','1030','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-13 07:11:56',0,NULL,3,1,2,1,NULL,'deadline2030\r庄\r、'),(7800,700476495002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','pheter01','lp25@freemail.hu','Peter Lindi','Halle 7/E 2/5','Veszprem','Veszprem','HUNGARY','8200','3670-3133416','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 08:13:27',0,NULL,3,1,2,1,NULL,'pheter01\r庄'),(7801,659732726001,110566021477,'TianYa ND8 Filter for Cokin P Series Neutral Density',1,'AA2325',7.2,'hermeshine','sprestoy','prestoy@yahoo.no','Ståle Prestøy','Egganvegen 33','Sjetnemarka','','NORWAY','N-7081','+47 48054144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 08:42:44',0,NULL,8,1,17,0,NULL,'sprestoy'),(7802,700481935002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','sprestoy','prestoy@yahoo.no','Ståle Prestøy','Egganvegen 33','Sjetnemarka','','NORWAY','N-7081','+47 48054144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 08:42:44',0,NULL,3,1,2,1,NULL,'sprestoy\r天涯方形滤镜  ND8   1\r天涯方形滤镜系列  CPL   1\r'),(7803,659739409001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','5axian','baksaj@gmail.com','János Baksa','DDRFU Maria st. 3','Pécs','Baranya','HUNGARY','7621','+36 30 496 20 32','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 09:12:27',0,NULL,8,1,17,0,NULL,'5axian'),(7804,700488962002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','5axian','baksaj@gmail.com','János Baksa','DDRFU Maria st. 3','Pécs','Baranya','HUNGARY','7621','+36 30 496 20 32','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 09:12:28',0,NULL,3,1,3,1,NULL,'5axian\r2m灯架  1\r云台    1\r柔光伞  1\r反光伞   1\rRA117729723CN\r'),(7805,700466109002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','camera2171','camera.sales@optusnet.com.au','Wayne Rogers','56 Easey street<br>Collingwood','Melbourne','Victoria','AUSTRALIA','3066','61394195247','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 09:31:16',0,NULL,8,1,17,0,NULL,'camera2171'),(7806,659715677001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','camera2171','camera.sales@optusnet.com.au','Wayne Rogers','56 Easey street<br>Collingwood','Melbourne','Victoria','AUSTRALIA','3066','61394195247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 09:31:17',0,NULL,8,1,17,0,NULL,'camera2171'),(7807,659715022001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','camera2171','camera.sales@optusnet.com.au','Wayne Rogers','56 Easey street<br>Collingwood','Melbourne','Victoria','AUSTRALIA','3066','61394195247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 09:31:17',0,NULL,3,0,4,1,NULL,'camera2171\r十个橡胶罩 :\r62mm X4, 77mm X1, 72mm X1, 67mm X1, 58mm X1, 55 mm X1, 52mm X1\r115w 220v   2\r60cm 棚   1\rYW864941795CN\r'),(7808,754050347016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.3,'hutongstore','davecrosby_uk','davecrosby@gmail.com','David Crosby','Flat 1 (Above Pizza Express)<br>1 High Street, St Martins','Stamford','Lincolnshire','UNITED KINGDOM','PE9 2LE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 09:41:41',0,NULL,8,1,17,0,NULL,'davecrosby_uk'),(7809,700496339002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','joselu_hg','jose.jhg@gmail.com','Jose Luis Hernandez','C/Marinel·lo Bosch, 39 Atc. 2ª','Terrassa','Cataluña','SPAIN','08222','937831835','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 09:42:53',0,NULL,3,1,4,1,NULL,'joselu_hg\rtripod  $16\r刘\rYW864941821CN'),(7810,769652305015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','davecrosby_uk','davecrosby@gmail.com','David Crosby','Flat 1 (Above Pizza Express)<br>1 High Street, St Martins','Stamford','Lincolnshire','UNITED KINGDOM','PE9 2LE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 09:52:22',0,NULL,3,1,2,1,NULL,'davecrosby_uk\r橡胶遮光罩 52mm   2\r橡胶遮光罩 58mm  1'),(7811,700502646002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nedman29','pedro.castanheira@biocant.pt','Pedro Castanheira','Biocant - Parque Tecnologico Cantanhede<br>Nucleo 4 Lote 3','Cantanhede','Cantanhede','PORTUGAL','3060-197','(351)933303619','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 10:08:36',0,NULL,3,1,3,1,NULL,'nedman29\rRA117729785CN\r'),(7812,700518575002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','pink_rose146','k.melrose@hotmail.com','Kathleen Johns','38 Maliwa Rd','Narara','New South Wales','AUSTRALIA','2250','0422427660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 11:18:35',0,NULL,3,1,4,1,NULL,'pink_rose146\r刘\rYW864941832CN'),(7813,700540974002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','okradarko','darko.buzdon@gmail.com','Darko Buzdon','Jeretova 48','Pula','Istra','CROATIA','52100','385916121966','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 12:33:02',0,NULL,3,1,2,1,NULL,'okradarko\r'),(7814,659795184001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','soundofdesdoe','mathiasraulin@free.fr','mathias  raulin','94 J rue moliere','montreuil','Île-de-France','FRANCE','93100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 12:49:42',0,NULL,3,1,2,1,NULL,'soundofdesdoe\r刘'),(7815,700547581002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',26.8,'hermeshine','roger299507','rlab@bigpond.net.au','Roger La Brooy','2, St. Johns Wood Rd','Mt. Waverley','Victoria','AUSTRALIA','3149','61438269196','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 12:56:15',0,NULL,3,1,3,1,NULL,'roger299507\rRA117729771CN\r'),(7816,659803380001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','zlobniq','p.karapetkov@gmail.com','Plamen Karapetkov','25 Tzar Asen Str.','Plovdiv','Plovdiv','BULGARIA','4000','+359885786740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 13:15:56',0,NULL,3,1,2,1,NULL,'zlobniq'),(7817,696437187002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','dimauzhakov','udima@inbox.ru','Dmitriy Uzhakov','Krasnodoncev<br>49a-19','Petrozavodk','Karelia','RUSSIAN FEDERATION','185001','921-018-0800','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 13:32:39',0,NULL,3,1,3,1,NULL,'dimauzhakov\r刘\rRA117729768CN\r'),(7818,769741915015,250692237909,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',2.39,'hutongstore','gordonc8193','gordoncooper2@sky.com','GORDON COOPER','24 WHITEBIRK ROAD','BLACKBURN','Lancashire','UNITED KINGDOM','BB13JD','01254601915','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 14:02:57',0,NULL,8,1,17,0,NULL,'gordonc8193'),(7819,754131041016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.39,'hutongstore','gordonc8193','gordoncooper2@sky.com','GORDON COOPER','24 WHITEBIRK ROAD','BLACKBURN','Lancashire','UNITED KINGDOM','BB13JD','01254601915','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 14:02:58',0,NULL,3,1,2,1,NULL,'gordonc8193\r接口环 55mm   1\r接口环 49mm   1\r刘'),(7820,700564963002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',7.5,'hermeshine','andras.harman','endi22@yahoo.com','Andras Harman','Egressy tér4','Debrecen','','HUNGARY','4031','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 14:03:40',0,NULL,3,1,2,1,NULL,'andras.harman'),(7821,0,110671627321,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',5.5,'hermeshine','swedchef13','swedchef13@hotmail.com','Cassandra Merolla','1584 Treetop Trl<br>Apt B','Akron','OH','UNITED STATES','44313-8641','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 14:31:07',0,NULL,3,1,1,1,NULL,'swedchef13'),(7822,0,120708476589,'67mm 67 mm Macro +8 Close-Up Close Up Filter',1,'AE3226',1.25,'hermeshine','sassygirlstyles','pmd92886@gmail.com','Patrice Dwyer','18091 Debi Lane','Yorba Linda','CA','UNITED STATES','92886','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 14:39:06',0,NULL,3,1,1,1,NULL,'sassygirlstyles\r刘'),(7823,0,120708476177,'58mm 58 mm Macro +4 Close-Up Close Up Filter',1,'AE3217',2.01,'hermeshine','dabu1104','shrib2@yahoo.com','Shrichand Bathija','32512 Jean Dr','Union City','CA','UNITED STATES','94587','(510) 471-2861','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 14:51:01',0,NULL,8,1,17,0,NULL,'dabu1104'),(7824,0,110671625537,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',2.01,'hermeshine','dabu1104','shrib2@yahoo.com','Shrichand Bathija','32512 Jean Dr','Union City','CA','UNITED STATES','94587','(510) 471-2861','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 14:51:02',0,NULL,3,1,1,1,NULL,'dabu1104\r绿叶 UV             58mm   1\r绿叶近摄镜 +4  58mm    1'),(7825,659834205001,110587046983,'New Camera shoulder bag N2 for Canon with raincover',1,'AD1104',25.99,'hermeshine','amentoi54','albper@sunrise.ch','Albert Perritaz','Buchilles 46','Boudry','','SWITZERLAND','2017','0041328414860','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 14:52:42',0,NULL,3,1,3,1,NULL,'amentoi54\rRA117729745CN\r\r'),(7826,754166554016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','sadegh_sh61','sadegh_sh61@yahoo.com','Mohammad Sadegh Shahrokhi-Dehkordi','34 Newmarket road,<br>Lewes Road,','Brighton','East Sussex','UNITED KINGDOM','BN2 3QF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 15:02:30',0,NULL,3,1,2,1,NULL,'sadegh_sh61'),(7827,0,110671625686,'62mm 3-Stage Rubber Lens Hood for D80 D90 450D 500D',1,'AB1304',0.99,'hermeshine','green_dream_sky','volya.dzemka@gmail.com','Anna Karptsova','3000 Royal Hills Dr SE<br>Apt 9H','Renton','WA','UNITED STATES','98058-3856','(206) 370-1567','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 15:18:17',0,NULL,3,1,1,1,NULL,'green_dream_sky'),(7828,659847374001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',3,'AA1305',7.4,'hermeshine','bztina','bztina@yahoo.com','Tina Gonsman','5167 1st Rd','Lake Worth','FL','UNITED STATES','33467','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 15:29:45',0,NULL,3,1,1,1,NULL,'bztina'),(7829,659856934001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','kairimantas','mantaskairys@gmail.com','Mantas Kairys','Vandentiekio 32-16','Vilnius','Lithuania','LITHUANIA','03151','+37062577639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 15:58:52',0,NULL,3,1,2,1,NULL,'kairimantas'),(7830,520286111003,130497954344,'New Fancier Complete Tripod 531BT with Ball head 531BH ',1,'AE1102',75,'hermeshine','almazkabal','bokertovstar@gmail.com','Alexandr Almazov','Shabolovka str. 65-1-35','Moscow','','RUSSIAN FEDERATION','115419','7(495)633-0038','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 16:55:52',0,NULL,3,1,5,1,NULL,'almazkabal\rCP226269149CN'),(7831,659891115001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','jasperimpala','steve.harwood@tdinsurance.com','Stephen Harwood- TD Meloche Monnex','2161 Yonge Street 8th Floor','Toronto','ON','CANADA','M4S 3A6','(416) 545-6119','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 17:24:15',0,NULL,3,0,3,1,NULL,'jasperimpala\rXXXL\rRA117729710CN\r'),(7832,700649039002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','cyrilcanada','cyrilcanada@yahoo.com','Eugene Kirillov','405 Lauderdale Drive','Maple','ON','CANADA','L6A 4K9','(416) 419-7792','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 17:32:36',0,NULL,3,1,3,1,NULL,'cyrilcanada\r刘\rRA117729808CN\r'),(7833,0,120708476358,'62mm 62 mm Macro +4 Close-Up Close Up Filter',1,'AE3218',0.99,'hermeshine','austinator92','aes1992@gmail.com','Austin Smith','1708 Murray Ave','Rockdale','TX','UNITED STATES','76567-2500','(425) 953-3326','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 18:15:41',0,NULL,3,1,1,1,NULL,'austinator92'),(7834,700675045002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','rbytes1','rbytes@gmail.com','Alexander Marchukov','Koltsova str. 22','Volgograd','n/a','RUSSIAN FEDERATION','400111','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 18:27:16',0,NULL,3,1,3,1,NULL,'rbytes1\rRA117729856CN\r\r'),(7835,769886696015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',127,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-13 18:46:23',0,NULL,3,1,4,1,NULL,'leifs123\r（欧标）\r2mx1.6m 背景架   1\r背景布  2.1x1.6m   1白\r背景布  3x1.6m       2黑+1白\r2m灯架    2\r反光伞   2\r双头灯   2  欧标\r115w   220v  灯泡  6\r灯架包   1\rYW864941810CN\r'),(7836,754278569016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',3,'AO0005',36,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-13 18:46:24',0,NULL,8,1,17,0,NULL,'leifs123'),(7837,754280670016,260619309261,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24.99,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-13 18:46:23',0,NULL,8,1,17,0,NULL,'leifs123'),(7838,700700874002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','gianfranco4222','salacius@inwind.it','Gianfranco Pistidda','via G. Deledda 167','Sassari','SS','ITALY','07100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 19:17:34',0,NULL,3,0,3,1,NULL,'gianfranco4222\rL\r刘\rRA117729666CN\r'),(7839,659943065001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','rufillo','rufillo@telefonica.net','Jose Vazquez Lopez','ACE Europe - C/ Francisco Gervas 13','Madrid','Madrid','SPAIN','28020','659347399','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 19:01:57',0,NULL,3,1,4,1,NULL,'rufillo\rYW864941843CN'),(7840,655445781018,280559946878,'Professional Photo Studio Continuous Lighting Kit boom',5,'AKT066',1000,'photographyacc','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-13 21:00:23',0,NULL,3,1,12,1,NULL,'saud-p\r申报 lighting kit  $1000\r368752975570\rDHL: 5741518226\r'),(7841,769976994015,250692239254,'New Neoprene Reversible Cover for Canon 5D II 7D L',1,'AC1304',6.1,'hutongstore','123andrewbarry','a.b.j@hotmail.co.uk','andrew barry johnson','131 southleigh road beeston','leeds','West Yorkshire','UNITED KINGDOM','ls11 5xg','01132718477','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 21:12:40',0,NULL,8,1,17,0,NULL,'123andrewbarry'),(7842,754366486016,260660052497,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.39,'hutongstore','123andrewbarry','a.b.j@hotmail.co.uk','andrew barry johnson','131 southleigh road beeston','leeds','West Yorkshire','UNITED KINGDOM','ls11 5xg','01132718477','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 21:12:41',0,NULL,8,1,17,0,NULL,'123andrewbarry'),(7843,700755690002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','lady_gris','4natasha_88@mail.ru','Головская Наталия','Набережная Авиастроителей, дом 24, кв. 139','Воронеж','','RUSSIAN FEDERATION','394004','(908)1379288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 21:12:41',0,NULL,8,1,17,0,NULL,'lady_gris'),(7844,769973807015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.39,'hutongstore','123andrewbarry','a.b.j@hotmail.co.uk','andrew barry johnson','131 southleigh road beeston','leeds','West Yorkshire','UNITED KINGDOM','ls11 5xg','01132718477','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 21:12:41',0,NULL,8,1,17,0,NULL,'123andrewbarry'),(7845,660001171001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','lady_gris','4natasha_88@mail.ru','Головская Наталия','Набережная Авиастроителей, дом 24, кв. 139','Воронеж','','RUSSIAN FEDERATION','394004','(908)1379288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 21:12:41',0,NULL,3,1,2,1,NULL,'lady_gris\r绿叶 UV  52mm  1\r绿叶 UV  58mm  1\r刘'),(7846,754366703016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.39,'hutongstore','123andrewbarry','a.b.j@hotmail.co.uk','andrew barry johnson','131 southleigh road beeston','leeds','West Yorkshire','UNITED KINGDOM','ls11 5xg','01132718477','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 21:12:42',0,NULL,3,1,3,1,NULL,'123andrewbarry\r接口环 55mm  1\r接口环 52mm   1\r接口环 77mm   1\rcanon 大胆        1\rRA117729670CN\r'),(7847,658150466018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','jean_cf','nategrey_x@hotmail.com','Jean Carlos Farias','Domingo Lucio Farias','Sao Joao Batista','Santa Catarina','BRAZIL','88240000','(48) 3265-0722','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-13 21:17:18',0,NULL,3,1,5,1,NULL,'jean_cf\rCP226269152CN\r2m架子 白+黑  1.6x2.1'),(7848,0,110671625953,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.99,'hermeshine','chitownswifey05','want_frogs@yahoo.com','RACHEL TURNER','18811 n vemto st','MARICOPA','AZ','UNITED STATES','85138-5693','(520) 510-3072','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 21:37:58',0,NULL,3,1,1,1,NULL,'chitownswifey05'),(7849,660008645001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','loosercruiser1','eaglefilms@gmail.com','Christopher Read','15 Pointe Ln<br>Apt 1A','Cullowhee','NC','UNITED STATES','28723-5868','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 21:38:51',0,NULL,3,1,1,1,NULL,'loosercruiser1'),(7850,658165789018,280556434923,'Background Support & 10x20ft Green Screen LightKit 3x6m',1,'AKT065',124,'photographyacc','aatuska91','monkeyaatu@gmail.com','Aatu Keränen','Viitostie 308','Suomussalmi','','FINLAND','89600','+358405400364','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-13 21:57:27',0,NULL,3,1,4,1,NULL,'aatuska91\r欧标\rlighting kit  $38\r刘\rYW864941806CN'),(7851,0,110671625839,'62mm 62 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT021',2.25,'hermeshine','mystic-ibis','saba.razvi@gmail.com','Saba Razvi','2376 Portland St<br>Apt 6','Los Angeles','CA','UNITED STATES','90007-1980','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 22:12:54',0,NULL,3,1,1,1,NULL,'mystic-ibis'),(7852,754396504016,260660055167,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.75,'hutongstore','moeras1980','moeras1@hotmail.com','anton moerland','crooswijck 2','St-Annaland','','NETHERLANDS','4697 CM','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-13 22:16:33',0,NULL,8,1,17,0,NULL,'moeras1980'),(7853,754395546016,260660054263,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'AA3211',2.98,'hutongstore','moeras1980','moeras1@hotmail.com','anton moerland','crooswijck 2','St-Annaland','','NETHERLANDS','4697 CM','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-13 22:16:33',0,NULL,3,1,2,1,NULL,'moeras1980\r小号灰卡   1\r爵影快门线C3    1'),(7854,700783610002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','jukkahast','jukka.hast@gmail.com','Jukka Hast','Ladamnesgatan 28','Goteborg','','SWEDEN','41679','+46707884444','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 22:35:23',0,NULL,3,1,3,1,NULL,'jukkahast\r刘\rRA117729754CN\r'),(7855,0,110671625921,'62mm CPL Circular Polarizing Filter 62 CPL Green.L ',1,'AA3311',1.82,'hermeshine','us.prolensshop','usprolensshop@threee.com','Ann Marie Peter Schenk','3895 Clairemont Dr<br>Ste B-218','San Diego','CA','UNITED STATES','92117-5833','(858) 483-1909','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 22:36:06',0,NULL,8,1,17,0,NULL,'us.prolensshop'),(7856,0,120708476328,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',2.02,'hermeshine','us.prolensshop','usprolensshop@threee.com','Ann Marie Peter Schenk','3895 Clairemont Dr<br>Ste B-218','San Diego','CA','UNITED STATES','92117-5833','(858) 483-1909','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 22:36:06',0,NULL,3,1,1,1,NULL,'us.prolensshop\r绿叶 UV  62mm   1\r绿叶 CPL  62mm   1\r庄'),(7857,754417838016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','n30filou','ath.triantafyllou@gmail.com','ATHANASIOS TRIANTAFYLLOU','21, FALIROU STREET','ATHENS','ATTIKI','GREECE','11742','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-13 23:23:40',0,NULL,3,1,2,1,NULL,'n30filou\r庄'),(7858,0,120708476210,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',1.82,'hermeshine','arbolito','virginitagarcia@hotmail.com','Virginia Pena','6730 Longmeade Ln','Orlando','FL','UNITED STATES','32822','(407) 658-0418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 00:07:37',0,NULL,3,1,1,1,NULL,'arbolito\r庄'),(7859,660068165001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Francisco alves, 222<br>Vl. dos Remédios','Osasco ','Sao paulo','BRAZIL','06296160','55-11-93530450','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 01:22:11',0,NULL,3,1,3,1,NULL,'davidcinegra\r刘\rRA117729799CN\r'),(7860,700825716002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','beokiwi','churchcoaching@gmail.com','Berthold E. Olbrich','8 Gordon Craig Place<br>Algies Bay','Walkworth','','NEW ZEALAND','0920','094255996','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 01:24:43',0,NULL,3,1,6,1,NULL,'beokiwi\r刘\rEE442466372CN'),(7861,0,110671625663,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',2.52,'hermeshine','backitup','schnepfer@chartermi.net','Chris Schnepf','6317 Santa Anita dr','Saginaw','MI','UNITED STATES','48603-6176','(989) 497-0743','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 01:54:46',0,NULL,3,1,1,1,NULL,'backitup\r刘'),(7862,0,120705979344,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',2.76,'hermeshine','bigb.koop','bently.kooper@hotmail.com','Bently Joiner','10013 S Maplewood Ave','tulsa','OK','UNITED STATES','74137-5541','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 02:43:48',0,NULL,3,1,1,1,NULL,'bigb.koop\r刘'),(7863,660087708001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','pictureperf','photopro@aol.com','Ronald M. Witherspoon','151 Kay St','Buffalo','NY','UNITED STATES','14215','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 02:45:35',0,NULL,3,1,1,1,NULL,'pictureperf\r刘'),(7864,660104671001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',61,'hermeshine','fotofilia','sngfotografia@gmail.com','María Teresa Godoy León','Alonso de Córdova 3773, Vitacura','Santiago','Región Metropolitana','CHILE','7630492','(56) 6-8499240','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 04:26:47',0,NULL,3,1,3,1,NULL,'fotofilia\rRA117729683CN'),(7865,770113003015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','bob9038','b_alam9038@msn.com','bobby alam','44 gooseley lane','east ham','London','UNITED KINGDOM','e66ap','02085489038','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 04:53:03',0,NULL,3,1,3,1,NULL,'bob9038\r英标\rRA117729697CN'),(7866,660109819001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','kot_rrr','kotolom@gmail.com','Denis Ovchinnikov','Titova street 46','Almaty','','KAZAKHSTAN','050019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 04:53:49',0,NULL,3,1,2,1,NULL,'kot_rrr'),(7867,660116188001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','willtipp','willtipp@hotmail.com','willie Tipp','7742 Redlands St<br>Unit D3038','playa del rey','CA','UNITED STATES','90293','(310) 488-3011','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 05:36:15',0,NULL,3,1,1,1,NULL,'willtipp'),(7868,660116514001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','shelbyappp','shelbyapp@bigpond.com','steven wright','21 Furner Ave','Camden','New South Wales','AUSTRALIA','2570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 05:47:52',0,NULL,3,1,2,1,NULL,'shelbyappp'),(7869,700883684002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','kiznito','jmanuelmorante@gmail.com','jose manuel nuñez morante','pl/ jazmin nº5 6ºd','alcala de henares','Madrid','SPAIN','28803','679786781','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 06:27:38',0,NULL,3,1,3,1,NULL,'kiznito\rRA117729635CN\r'),(7870,700891889002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE3104',29.04,'hermeshine','willyodd','willy.kommedal@gmail.com','Willy Odd Kommedal','Tomasbakken 8','Hundvaag','Rogaland','NORWAY','4085','+4790980860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:09:03',0,NULL,3,1,3,1,NULL,'willyodd\rRA117729533CN'),(7871,660134489001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:25:32',0,NULL,8,1,17,0,NULL,'dimonio08'),(7872,660133087001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:25:37',0,NULL,8,1,17,0,NULL,'dimonio08'),(7873,700892849002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:25:37',0,NULL,8,1,17,0,NULL,'dimonio08'),(7874,660133143001,110417009860,'58mm 58 mm Macro +4 Close-Up Close Up Filter',1,'AE3217',5.9,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:25:39',0,NULL,3,1,4,1,NULL,'dimonio08\r橡胶遮光罩 58mm   1\r绿叶 UV  58mm   1\r爵影红外 canon    1\r绿叶 CPL  58mm\r绿叶  58mm  ND8 1\r三脚架 伟峰 wf-6662A+ 6160H 球台   1\r刘\rYW864941784CN'),(7875,660132301001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 07:25:40',0,NULL,8,1,17,0,NULL,'dimonio08'),(7876,660133112001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:25:41',0,NULL,8,1,17,0,NULL,'dimonio08'),(7877,754547180016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'AA1304',3.76,'hutongstore','tania0122','taniabanyard@rocketmail.com','tania banyard','90<br>western avenue','HERNE BAY','Kent','UNITED KINGDOM','CT6 8UF','01227370908','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 08:13:08',0,NULL,3,1,2,1,NULL,'tania0122\r'),(7878,700904892002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','maxiki1330813','homy@rambler.ru','Ryashintsev Maksim','30 let Pobedy<br>d.4, kv.40','Volgodonsk','Rostov Region','RUSSIAN FEDERATION','347381','7-928-133-08-13','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 08:28:51',0,NULL,3,1,3,1,NULL,'maxiki1330813\rRA117729290CN'),(7879,770170902015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','mododorico','info@mododorico.com','Andrea Ghigliazza','Via santa caterina 26','Varazze','SV','ITALY','17019','3487333113','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 09:19:32',0,NULL,3,1,2,1,NULL,'mododorico\r申报：20$， Light Cube Box\r庄'),(7880,770207600015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','deore_g','george_karydas@yahoo.com','George Karydas','Filippou 27','Serres','Serres','GREECE','62122','+306972530977','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 11:12:42',0,NULL,3,1,3,1,NULL,'deore_g\r庄\rRA117728144CN\r'),(7881,660190317001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','kulkuri82','pasi_hartikka@yahoo.com','Pasi Hartikka','Viikinkitie 2 C 14','Vantaa','','FINLAND','01200','+358 40 534 2802','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 11:39:14',0,NULL,3,1,3,1,NULL,'kulkuri82\r接口环是52mm的\r庄\rRA117728484CN\r'),(7882,770224075015,250600475807,'New Rainproof & Warm Protector for 7D 550D 5D D700 D90',1,'AA3102',12.99,'hutongstore','lucaseata679','lucaseata679@libero.it','melody cafè','via ruffo augusto 20','arcole','VR','ITALY','37041','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 12:08:54',0,NULL,8,1,17,0,NULL,'lucaseata679'),(7883,770223914015,250600475807,'New Rainproof & Warm Protector for 7D 550D 5D D700 D90',1,'AA3102',12.99,'hutongstore','lucaseata679','lucaseata679@libero.it','melody cafè','via ruffo augusto 20','arcole','VR','ITALY','37041','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 12:08:54',0,NULL,3,1,3,1,NULL,'lucaseata679\r防寒罩   2\r申报：15$, Camera rain cover\rRA117729003CN'),(7884,660201667001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',3,'AA1214',23.94,'hermeshine','foveal','funglammd@aol.com','Fung Lam','3838 California St<br>Rm 812','San Francisco','CA','UNITED STATES','94118-1510','','NoPaymentFailure','CheckoutComplete','Other','2011-04-14 12:19:47',0,NULL,3,1,1,1,NULL,'foveal\r徐'),(7885,754640193016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','hallbrant','markus.hallbrant@gmail.com','Dag Hällbrant','Tranbärsvägen 112','Floda','','SWEDEN','44837','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 13:25:35',0,NULL,3,1,2,1,NULL,'hallbrant\r徐'),(7886,770254570015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','chriswallace0007','jennhodges40@hotmail.com','chris wallace','20 coningsby drive','winsford','Cheshire','UNITED KINGDOM','cw74bx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 13:29:45',0,NULL,3,1,2,1,NULL,'chriswallace0007\r徐'),(7887,660222255001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','gtrsleeper','mrkissyfur@hotmail.com','chris roberts','1/10 green glen rd','ashmore','Queensland','AUSTRALIA','4214','0417411317','NoPaymentFailure','CheckoutComplete','AU_Other','2011-04-14 13:36:45',0,NULL,3,1,4,1,NULL,'gtrsleeper\r2m宽背景架   白 + 黑  1.6x2.1\r庄\rYW864941736CN'),(7888,700985240002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',16.99,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:47:41',0,NULL,8,1,17,0,NULL,'sergioaraujo2006'),(7889,660224137001,110426880442,'JJC JN-24 Neoprene Lens Case 100x240mm for 100-300 Lens',1,'AC2204',13.9,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:47:42',0,NULL,8,1,17,0,NULL,'sergioaraujo2006'),(7890,660223858001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',2,'AC1201',9.8,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:47:42',0,NULL,3,1,3,1,NULL,'sergioaraujo2006\r镜头筒 小号   2\rJJC 镜头筒 JN24   1\r防雨罩     1\r庄\rRA117728475CN\r'),(7891,770271618015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','jonjg_spareparts','amazonman67@hotmail.com','Cheryl Terry','26 mallory road<br>Bishops tachbrook','Leamington spa','Warwickshire','UNITED KINGDOM','Cv339qx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 14:20:05',0,NULL,3,1,2,1,NULL,'jonjg_spareparts\r庄'),(7892,657793944001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',71.88,'hermeshine','heart.beth.ann','bskabar@gmail.com','Ed O\'Connor','PO Box 861','Talkeetna','AK','UNITED STATES','99676-0861','','NoPaymentFailure','CheckoutComplete','Other','2011-04-14 14:33:36',0,NULL,7,0,18,0,NULL,'heart.beth.ann\r反光板 100cm x150cm   1\r反光板支架   1\r'),(7893,0,110672018345,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',2.2,'hermeshine','pramodrukshan','pramod@kandynet.net','rukshan nugaliyadda','19930 Poinciana','Redford','MI','UNITED STATES','48240-1654','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 14:38:28',0,NULL,3,1,1,1,NULL,'pramodrukshan\r庄'),(7894,0,120708872461,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',9.6,'hermeshine','usgrantwon','baroda1@gmail.com','Baroda Ra','12685 Germane Ave<br>Apt 12','Apple Valley','MN','UNITED STATES','55124-4375','(612) 850-2029','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:38:37',0,NULL,3,1,1,1,NULL,'usgrantwon\r庄'),(7895,0,110672018749,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',2.81,'hermeshine','cmon1988','cmon198888@yahoo.com','CRAIG ON','1638 Bayhill Drive','Oldsmar','FL','UNITED STATES','34677','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:39:57',0,NULL,8,1,17,0,NULL,'cmon1988'),(7896,660242179001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','cmon1988','cmon198888@yahoo.com','CRAIG ON','1638 Bayhill Drive','Oldsmar','FL','UNITED STATES','34677','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:46:50',0,NULL,3,1,1,1,NULL,'cmon1988\r绿叶 渐变镜 72mm\r绿叶 渐变镜 77mm   1\r庄'),(7897,0,110672018642,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',2.02,'hermeshine','fxstchip','chipwarren@sbcglobal.net','Chip T Warren','3238 Cottonwood Dr','Saint Charles','MO','UNITED STATES','63301-0108','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:58:06',0,NULL,3,1,1,1,NULL,'fxstchip\r庄'),(7898,701006788002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','binhndoan','binh_n_doan@yahoo.com','binh doan','540 Bonita Ave<br>Spc 111','San Jose','CA','UNITED STATES','95116-3310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 14:58:42',0,NULL,3,1,1,1,NULL,'binhndoan\rNikon 52mm   2 \rNikon 72mm    1\rCanon 58mm   1\rCanon 72mm   1\r肩带 nikon    1\r肩带 canon    1\r肩带 pentax    1庄\r'),(7899,0,120708871976,'Adjustable Padded Camera Neck shoulder Strap for Canon',1,'AB1404',1.04,'hermeshine','binhndoan','binh_n_doan@yahoo.com','binh doan','540 Bonita Ave<br>Spc 111','San Jose','CA','UNITED STATES','95116-3310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 14:58:43',0,NULL,8,1,17,0,NULL,'binhndoan'),(7900,0,110672017862,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',3.25,'hermeshine','binhndoan','binh_n_doan@yahoo.com','binh doan','540 Bonita Ave<br>Spc 111','San Jose','CA','UNITED STATES','95116-3310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 14:58:43',0,NULL,8,1,17,0,NULL,'binhndoan'),(7901,0,120708871881,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',1,'AB1405',1.25,'hermeshine','binhndoan','binh_n_doan@yahoo.com','binh doan','540 Bonita Ave<br>Spc 111','San Jose','CA','UNITED STATES','95116-3310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 14:58:44',0,NULL,8,1,17,0,NULL,'binhndoan\r'),(7902,658428687018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','zhychologic','zheett@hotmail.com','zhychologic Shop','P.O.Box 301<br>Pattaya Post Office','Pattaya City','Chon Buri','THAILAND','20260','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-14 15:47:17',0,NULL,5,0,18,0,NULL,'zhychologic'),(7903,660266916001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','kvpoppe','kpopplewell@gmail.com','Ken Popplewell','14007 FM 346 W','Bullard','TX','UNITED STATES','75757','(903) 258-1852','NoPaymentFailure','CheckoutComplete','Other','2011-04-14 15:58:31',0,NULL,3,1,3,1,NULL,'kvpoppe\r刘\rRA117728467CN\r'),(7904,0,120708872033,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',1.8,'hermeshine','joyblueyes','cjperkins@att.net','Chris Perkins','1512 W Mesa Ave','Fresno','CA','UNITED STATES','93711-1942','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 16:04:05',0,NULL,3,1,1,1,NULL,'joyblueyes\r庄'),(7905,701029303002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','mauri.2010','maurizio.pellizer@gmail.com','maurizio pellizer','levja 5','Koper','slovenia','SLOVENIA','6000','0038641948989','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 16:04:27',0,NULL,3,1,3,1,NULL,'mauri.2010\r欧标\r庄\rRA117728158CN\r'),(7906,754716689016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','mandygalaxy','mandywilby21@googlemail.com','Darren Law','4 ASH STREET<br>WOMBWELL','BARNSLEY','South Yorkshire','UNITED KINGDOM','S73 8EW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 16:37:23',0,NULL,3,1,2,1,NULL,'mandygalaxy\r庄'),(7907,660281474001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','sledge99.1','carl@full-sail.com','Carl Perry','2506 Gravel Dr','Fort Worth','TX','UNITED STATES','76118-6903','(817) 975-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 16:38:24',0,NULL,3,1,1,1,NULL,'sledge99.1\r庄'),(7908,660347114001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','djcowboy50','micvester@hotmail.com','Michel Sylvestre','396 Audouart','Québec','QC','CANADA','G1C 6M2','(418) 666-6548','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 19:06:36',0,NULL,3,1,2,1,NULL,'djcowboy50\r庄'),(7909,660352803001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','ardiani2009','keni25_ch@hotmail.com','muharrem gashi','verger-rond 8','neuchatel','','SWITZERLAND','2000','0041762885785','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 19:18:19',0,NULL,3,1,4,1,'YW864941740CN\r','ardiani2009\r庄\r'),(7910,0,110672017824,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',3.45,'hermeshine','dherndon72','dtherndon@comcast.net','Diane Herndon','2705 Wildwood Dr','Brunswick','GA','UNITED STATES','31520-4346','(912) 230-4167','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 19:30:27',0,NULL,3,1,1,1,NULL,'dherndon72\r庄'),(7911,701122481002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','torpedoruso','antonio23666@hotmail.com','Antonio López','C/Ravel nº1 portal 4º 5ºA','Almeria','Andalucía Ceuta y Melilla','SPAIN','04007','679170103','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 19:35:48',0,NULL,3,1,3,1,NULL,'torpedoruso\r刘\rRA117728060CN\r'),(7912,701122726002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','pulleirofernando','tricolordelsur@hotmail.com','Fernando Pulleiro','25 de Mayo 635<br>Piso 6','Montevideo','','URUGUAY','11000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 19:36:51',0,NULL,3,1,3,1,NULL,'pulleirofernando\r庄\rRA117728073CN\r'),(7913,701123311002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','gacero','gerardoacero@gmail.com','Gerardo Acero','cl81 110-34 int 8 apto 504','Bogotá D.C.','Bogotá Distrito Capital','COLOMBIA','111011','(571) 4359899','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 19:44:15',0,NULL,3,1,3,1,NULL,'gacero\r刘\rRA117728087CN\r'),(7914,769880340015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','balvess','bgalvess@gmail.com','Bruno Alves','Travessa Helena Vieira da Silva, N.º 259 – 1.6<br>4450-573','Leça da Palmeira','Matosinhos','PORTUGAL','4450-573','229982310','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 20:19:05',0,NULL,3,1,2,1,NULL,'balvess\r刘'),(7915,769589934015,250692242373,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'AA1307',134.4,'hutongstore','lorenzofinanziere','caravellolorenzo@libero.it','gruppo cineamatori delle apuane','via pascoli 17','carrara','MS','ITALY','54033','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 20:27:43',0,NULL,8,1,17,0,NULL,'lorenzofinanziere\r刘'),(7916,0,110672018581,'Green-L 62mm Graduated Neutral Density ND Grey Filter',1,'AA3318',2.25,'hermeshine','us.prolensshop','usprolensshop@threee.com','Ann Marie Peter Schenk','3895 Clairemont Dr<br>Ste B-218','San Diego','CA','UNITED STATES','92117-5833','(858) 483-1909','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 20:39:27',0,NULL,3,1,1,1,NULL,'us.prolensshop\r庄'),(7917,754851672016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','davidclimb85','david.toncic@gmail.com','David Tončič','Tomšičeva 17/B','Idrija','Slovenia','SLOVENIA','0386','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 20:41:17',0,NULL,3,1,2,1,NULL,'davidclimb85\r(包装前仔细检查一下货)\r刘'),(7918,770470116015,250790265292,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.55m',1,'AO0001',150,'hutongstore','lorenzofinanziere','caravellolorenzo@libero.it','gruppo cineamatori delle apuane','via pascoli 17','carrara','MS','ITALY','54033','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-14 20:43:09',0,NULL,3,1,4,1,NULL,'lorenzofinanziere\rNIKON 镜头盖 67mm    1\r三脚架 伟峰 EI-717    1\r2mX3m背景架   1\r2m 灯架   2\r2mX3m 背景布（绿）   1\r115w 220v 灯泡   2\r50x70  棚 欧标   2\r灯架包   1\r刘\rYW864941751CN\r'),(7919,701155382002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','heleenab','heleenrink@wanadoo.nl','Rink Post Tanktransporten B.V.','Vaart zz 124','Appelscha','','NETHERLANDS','8426 AL','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 20:48:36',0,NULL,3,0,3,1,NULL,'heleenab\rXL\r庄\rRA117728135CN\r\r'),(7920,660396690001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','esmemou','esmemou@hotmail.com','E Pugh c/o M Traverzo','2114 Farrington Street','Dallas','TX','UNITED STATES','75207','2812366895','NoPaymentFailure','CheckoutComplete','Other','2011-04-14 20:56:52',0,NULL,3,1,1,1,NULL,'esmemou\r庄'),(7921,660397071001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','janka90125','90125@chello.sk','Marek Smatrala','Soltesovej 32','Bratislava','Bratislava','SLOVAK REPUBLIC','81108','+00421905923198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:58:09',0,NULL,3,1,2,1,NULL,'janka90125\r刘'),(7922,660399966001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','scream2525','christianvall6@hotmail.com','FCO. JAVIER MARTINEZ FARALDO','c/ RODODENDRO, 82-84','RIVAS-VACIAMADRID','Madrid','SPAIN','28522','665649056','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 21:07:44',0,NULL,3,1,4,1,NULL,'scream2525\r刘\rYW864941762CN\r'),(7923,660403938001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','leofotografias','leo.fotografias@hotmail.com','Leonardo Pimentel Magalhães','Rua: Manoel Samora, nº 108<br>Bairro: Bromélias','Timóteo','Minas Gerais','BRAZIL','35180-510','(31) 8625-5202','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 21:26:02',0,NULL,3,1,3,1,NULL,'leofotografias\r刘\rRA117728127CN\r'),(7924,660461895001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 01:03:02',0,NULL,8,1,17,0,NULL,'dvdguychatter2\r刘'),(7925,660464907001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 01:15:01',0,NULL,3,1,2,1,NULL,'dvdguychatter2\r刘\r爵影红外 5 in 1   1\rGGS 550D    1'),(7926,660465843001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','10marinkangel','marinkangel@yahoo.com','marishka karamyan','35 esterbrooke ave apt 809','north york','ON','CANADA','m2j 2c5','(416) 826-4184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 01:19:10',0,NULL,3,1,2,1,NULL,'10marinkangel\r庄'),(7927,659605855001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',22.99,'hermeshine','olinghouse','scott@minerslunchbox.com','Miner\'s Lunchbox','5655 Riggins Ct<br>Ste 15','Reno','NV','UNITED STATES','89502-6565','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 01:46:42',0,NULL,3,1,1,1,NULL,'olinghouse\r庄'),(7928,660475747001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','diggindiogi','joebrenckman@comcast.net','Joseph Brenckman','300 W Price St','Linden','NJ','UNITED STATES','07036','(908) 590-4512','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 01:57:28',0,NULL,3,1,1,1,NULL,'diggindiogi\r庄'),(7929,660485603001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','mtgravy','garvinweb+ebay@gmail.com','Lisa Sung','222 Rainbow Pl','Milpitas','CA','UNITED STATES','95035-8751','(613) 366-8882','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 02:42:42',0,NULL,3,1,1,1,NULL,'mtgravy\r刘'),(7930,660486518001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','curtissp6e','jimaroc@cox.net','Jim Cady','2671 Nye Street','Henderson','NV','UNITED STATES','89074','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 02:44:05',0,NULL,3,1,1,1,NULL,'curtissp6e\r刘'),(7931,701257019002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','topgumf16','topgum@gmail.com','Raymond M Klein','400 Morgan St','Suisun City','CA','UNITED STATES','94585-2841','707 399 9318','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 02:55:42',0,NULL,3,1,3,1,NULL,'topgumf16\r50-70柔光棚 通用塑料卡口  1\r1.6x2.1m 背景布 黑色   1\rRA117728113CN\r'),(7932,660487843001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','topgumf16','topgum@gmail.com','Raymond M Klein','400 Morgan St','Suisun City','CA','UNITED STATES','94585-2841','707 399 9318','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 02:55:42',0,NULL,8,0,17,0,NULL,'topgumf16'),(7933,0,110672017789,'82mm 82 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT054',2.55,'hermeshine','ungvs','ung88@yahoo.com','victor Ung','10041 bismark dr','Huntington beach','CA','UNITED STATES','92646-3701','(714) 372-2766','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 03:05:59',0,NULL,3,1,1,1,NULL,'ungvs'),(7934,701267095002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','gil*riodejaneiro','gilmardamasio1@hotmail.com','gilmar damasio','Av. José Mendonça de Campos 101<br>Bairro Mutondo','São Gonçalo','Rio de Janeiro','BRAZIL','24450265','(021)2601-2578','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 03:40:48',0,NULL,3,1,3,1,NULL,'gil*riodejaneiro\rRA117728498CN\r'),(7935,0,120708477793,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',2.26,'hermeshine','chadwick9.9','gemini9.9@netzero.com','chad coots','3088 Wadsworth Rd<br># 4','norton','OH','UNITED STATES','44203-5265','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 04:00:18',0,NULL,3,1,1,1,NULL,'chadwick9.9\r刘'),(7936,770444853015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','sakaedor','danitower@hotmail.com','Juan Daniel Bello Cano','c/Escota, 1<br>Cádiz','Rio San Pedro (Puerto Real)','Andalucía Ceuta y Melilla','SPAIN','11519','607957933','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 04:27:54',0,NULL,3,1,2,1,NULL,'sakaedor\r刘'),(7937,660512561001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','jpvillaverde','jpablo@omnisciens.com','Juan Pablo Villaverde','Riobamba 1914 Dto 1','Rosario','Santa Fe','ARGENTINA','2000','(0341) 155209165','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 05:09:07',0,NULL,3,1,2,1,NULL,'jpvillaverde\r刘'),(7938,770650506015,250692241383,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',20,'hutongstore','nagydarab10','nagydarab2@gmail.com','Róbert Vancsura','Közvágóhíd utca 7','Budapest','','HUNGARY','1151','0036303117788','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 07:08:52',0,NULL,3,1,3,1,NULL,'nagydarab10\rRA117728095CN\r'),(7939,701306131002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','bigdavemc08','barwickdavid96@yahoo.com','david barwick','11517 Windcrest Ln','san diego','CA','UNITED STATES','92128-6409','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 07:26:26',0,NULL,3,1,1,1,NULL,'bigdavemc08'),(7940,701318275002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','nikki355','nikkihaskell355@msn.com','Nicole Haskell','21 Bunker Ave','Nanango','Queensland','AUSTRALIA','4615','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 08:33:30',0,NULL,3,0,3,1,NULL,'nikki355\r绿色\rRA117728507CN'),(7941,701326271002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','thealmightybenwa','february_6th@hotmail.com','Benny Southall','6 Spowers Cicruit','Holder','Australian Capital Territory','AUSTRALIA','2611','0262888391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:08:49',0,NULL,8,1,17,0,NULL,'thealmightybenwa'),(7942,660554299001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',5,'AA1304',12.2,'hermeshine','thealmightybenwa','february_6th@hotmail.com','Benny Southall','6 Spowers Cicruit','Holder','Australian Capital Territory','AUSTRALIA','2611','0262888391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:08:53',0,NULL,8,1,17,0,NULL,'thealmightybenwa'),(7943,660552885001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','thealmightybenwa','february_6th@hotmail.com','Benny Southall','6 Spowers Cicruit','Holder','Australian Capital Territory','AUSTRALIA','2611','0262888391','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 09:08:55',0,NULL,8,1,17,0,NULL,'thealmightybenwa'),(7944,701324893002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','thealmightybenwa','february_6th@hotmail.com','Benny Southall','6 Spowers Cicruit','Holder','Australian Capital Territory','AUSTRALIA','2611','0262888391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:09:06',0,NULL,8,1,17,0,NULL,'thealmightybenwa'),(7945,660554514001,110533631327,'Padded Camera Neck shoulder Strap for Canon 550D 7D',1,'AB1404',8.9,'hermeshine','thealmightybenwa','february_6th@hotmail.com','Benny Southall','6 Spowers Cicruit','Holder','Australian Capital Territory','AUSTRALIA','2611','0262888391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:09:16',0,NULL,3,1,3,1,NULL,'thealmightybenwa\rlenspen   2\rCANON 镜头盖  77mm   5\r摄影背心 黑色薄 canon  XL  1\r防寒罩   1\r肩带 canon   1\rRA117728419CN\r'),(7946,770685082015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','dubby66','dubstemp@hotmail.co.uk','Jonathan Stemp','17 Muirfield Road','Woking','Surrey','UNITED KINGDOM','GU213PW','01483828267','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-15 09:16:45',0,NULL,3,1,2,1,NULL,'dubby66'),(7947,660556921001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','bluesmansur','ramrif@hotmail.com','Ramón Rivera Freire','San Antonio,6 1º C','ALGECIRAS','Cadiz','SPAIN','11201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:21:28',0,NULL,3,1,2,1,NULL,'bluesmansur'),(7948,770702502015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','lajos.andrejkovics','lajos@grandiflorum.net','IBM ISC - Lajos Andrejkovics','Apollo Business Centre II<br>Mlynske nivy 49','Bratislava','','SLOVAK REPUBLIC','82109','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 10:15:55',0,NULL,3,1,2,1,NULL,'lajos.andrejkovics\r刘'),(7949,701345824002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','chickiecyk','cynthia.y.kam@gmail.com','Cynthia Kam','po box 11','east Kew','Victoria','AUSTRALIA','3102','0403082365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 10:37:11',0,NULL,3,1,2,1,NULL,'chickiecyk\r庄'),(7950,701352825002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','zamirram55','zamirram@gmail.com','Rami zamir','Yasur 25','arad','IL','ISRAEL','89078','0546703723','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 11:04:31',0,NULL,3,1,3,1,NULL,'zamirram55\r欧标\r庄\rRA117728780CN\r'),(7951,660592763001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','b_usher','busher04@aim.com','Brandon Usher','2092 S Potter Rd','Lancaster','SC','UNITED STATES','29720-7664','(803) 804-7834','NoPaymentFailure','CheckoutComplete','Other','2011-04-15 11:53:09',0,NULL,3,1,1,1,NULL,'b_usher\rM\r庄'),(7952,701365629002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','rcares','rodolfo.cares@gmail.com','Rodolfo Cares Moreno','Pasaje Dos 2862','Independencia','Metropolitana','CHILE','8380730','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 11:58:24',0,NULL,3,1,3,1,NULL,'rcares\r刘\rRA117728745CN\r'),(7953,755151502016,260660053205,'New Neoprene Reversible Bag Cover for Large-DSLR  L',1,'AC1302',6.1,'hutongstore','scotty.robson','scotty@clanrobson.co.uk','Scott Robson','Orange (PB-G-080)<br>The Point, 37 North Wharf Road','Paddington','London','UNITED KINGDOM','W2 1AG','07896567106','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-15 14:10:19',0,NULL,3,1,2,1,NULL,'scotty.robson\r庄'),(7954,0,110672018282,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',3.54,'hermeshine','dandwjones','debrakay2006@aol.com','Debra Jones','7620 Opal Rd','Warrenton','VA','UNITED STATES','20186-8679','(540) 347-5714','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 14:17:08',0,NULL,3,1,1,1,NULL,'dandwjones\r庄'),(7955,660638371001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','gambitsworld65','microshitcankissmyhairywhitebutt@hotmail.com','ian MacDonald','#102 10505 70ave','Edmonton','AB','CANADA','t6h2g1','(780) 436-7512','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 14:32:18',0,NULL,3,1,3,1,NULL,'gambitsworld65\r刘\rRA117728569CN'),(7956,770778738015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','akim_s','akimaso@googlemail.com','Tomas Mika','Mlynska 1179/8','Cesky Tesin','','CZECH REPUBLIC','73701','00420723266304','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 14:35:43',0,NULL,8,1,17,0,NULL,'akim_s'),(7957,770777690015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','akim_s','akimaso@googlemail.com','Tomas Mika','Mlynska 1179/8','Cesky Tesin','','CZECH REPUBLIC','73701','00420723266304','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 14:35:43',0,NULL,8,1,17,0,NULL,'akim_s'),(7958,755144747016,260660055262,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',8,'hutongstore','akim_s','akimaso@googlemail.com','Tomas Mika','Mlynska 1179/8','Cesky Tesin','','CZECH REPUBLIC','73701','00420723266304','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 14:35:45',0,NULL,8,1,17,0,NULL,'akim_s'),(7959,770771126015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',12.2,'hutongstore','akim_s','akimaso@googlemail.com','Tomas Mika','Mlynska 1179/8','Cesky Tesin','','CZECH REPUBLIC','73701','00420723266304','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 14:35:44',0,NULL,3,1,3,1,NULL,'akim_s\r倒影板（白黑）   1\r45w 5500k 灯泡  2\r80cm  2in1   1\r双灯头   欧标  1  庄\rRA117728541CN\r\r'),(7960,770428541015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','akim_s','akimaso@googlemail.com','Tomas Mika','Mlynska 1179/8','Cesky Tesin','','CZECH REPUBLIC','73701','00420723266304','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-15 14:35:44',0,NULL,3,1,3,1,NULL,'akim_s\r柔光伞——换成——银光伞\r庄\rRA117728714CN\r'),(7961,701417035002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',2,'AB1407',10.98,'hermeshine','jaroslawkurek','jaroslaw.kurek@poczta.neostrada.pl','Jarosław Kurek','Kalinowa 1<br>skr.poczt. 84','Nadarzyn','mazowieckie','POLAND','05-830','22 7398568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 14:53:07',0,NULL,3,1,2,1,NULL,'jaroslawkurek\r庄'),(7962,660641265001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','salmon404','apuusti6@welho.com','Aki Puustinen','Kyösti Kallion tie 10 D 34','Helsinki','','FINLAND','00570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 14:53:22',0,NULL,3,1,2,1,NULL,'salmon404\r刘'),(7963,753670649016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',14.5,'hutongstore','jmtriky','fuentesjm2002@yahoo.es','Jose Manuel Fuentes Canalejo','Marcenado, 20  3-D','Madrid','Madrid','SPAIN','28002','669170417','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 15:21:17',0,NULL,3,1,3,1,NULL,'jmtriky\r庄\rRA117728538CN'),(7964,660655225001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','denjigunoff','jigunoff@tut.by','Denis Jigunoff','ul. Prushinskih<br>dom 12 kv. 2','Minsk','Minsk','BELARUS','220112','375298624942','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 15:24:59',0,NULL,3,1,3,1,NULL,'denjigunoff\r庄\rRA117728609CN'),(7965,660658966001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','dherrymar','herrymar@hotmail.com','DAVID HERRAIZ MARTINEZ','CALLE RAMON Y CAJAL 28, LA CAIXA, CUARTE DE HUERVA','ZARAGOZA','Aragón','SPAIN','50410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 15:38:15',0,NULL,3,1,2,1,NULL,'dherrymar\r庄'),(7966,660575408001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','frankedisson','heyaaaa@inbox.lv','Aleksandrs Puzijs','Balta 24-70','Riga','','LATVIA','LV 1055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 16:03:39',0,NULL,3,1,2,1,NULL,'frankedisson\r欧标\r刘'),(7967,755226718016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','vicaraucaria','vitorutad@gmail.com','Vítor da Cunha','Avenida Padre António Carneiro, nº200','Areosa-','Viana do Castelo','PORTUGAL','4900-590','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 17:12:46',0,NULL,3,1,2,1,NULL,'vicaraucaria\r庄'),(7968,701470306002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','alimov2007','naalimov@yahoo.com','Alimov Oleg','Berliner str.27 B','Wittenberg','','GERMANY','06886','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 17:25:46',0,NULL,3,1,3,1,NULL,'alimov2007\r庄\r、'),(7969,701477251002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','russian727','amalykhin@earthlink.net','Subhon Khodjaev','Saharov 11/2 kv 10','Kishinev','','MOLDOVA, REPUBLIC OF','2024','(373) 692-5278 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 17:43:33',0,NULL,3,1,3,1,NULL,'russian727\r刘\rRA117728515CN'),(7970,701490872002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',26.8,'hermeshine','peteart','peteart2@yahoo.com','Peter Kober','138 Rose Haven Rd','Somers','CT','UNITED STATES','06071-1215','(860) 698-6746','NoPaymentFailure','CheckoutComplete','Other','2011-04-15 18:15:32',0,NULL,3,1,1,1,NULL,'peteart\r庄'),(7971,660737367001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','severinkaradzhov12','cccp0887@gmail.com','severin karadzhov','61A block, floor 5, apt.511 Studentski grad distr.','Sofia','Bulgaria/Sofia/Sofia','BULGARIA','1700','0897811819','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 18:57:47',0,NULL,3,1,2,1,NULL,'severinkaradzhov12\r.庄'),(7972,701511091002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','viktorpro','alouds@yandex.ru','Viktor Prokopishen','ul. Lenina, dom 8, kv. 115','Komsomolsk','Poltavskaya oblast','UKRAINE','39800','380676014720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 19:00:40',0,NULL,3,1,2,1,NULL,'viktorpro\r庄'),(7973,660770717001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','m.petrosyan','valyagharibyan@rambler.ru','Valentina Gharibyan','Davitashen 2 district 37a-32','Yerevan','','ARMENIA','0054','055101565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 20:18:25',0,NULL,3,1,2,1,NULL,'m.petrosyan\r刘'),(7974,701571018002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','faustm01','faustm@uol.com.br','Marcelo Faustino','Rua Duque Costa, 495 apto 52 Bloco 4<br>Jd Marajoara','São Paulo','São Paulo','BRAZIL','04671-160','55 11 81798694','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 21:29:03',0,NULL,3,1,5,1,NULL,'faustm01\r欧标\r刘\rCP226269121CN\r'),(7975,770996801015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','daminimandan','dan_bird2003@hotmail.com','Dan bird','251 scartho road<br>scartho','grimsby','Lincolnshire','UNITED KINGDOM','dn332ea','01472328749','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-15 21:34:10',0,NULL,3,1,4,1,NULL,'daminimandan\r庄\rYW864941655CN'),(7976,701575634002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','mannavis','manavisk@hotmail.com','Mannavis Kostas','136 Papanikolaoy st.','Thessaloniki','Thessaloniki','GREECE','57010','+306978102100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 21:41:59',0,NULL,3,1,2,1,NULL,'mannavis\r庄'),(7977,771009334015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','vencaxxx','v.vesely@centrum.cz','Václav Veselý','Blatenská 4020','Chomutov','','CZECH REPUBLIC','43003','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 22:03:02',0,NULL,3,1,2,1,NULL,'vencaxxx\r刘'),(7978,701599633002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','sabnton','tlavin1@telus.net','Tony Lavin','859 165a st','Surrey','BC','CANADA','V4A9C4','(778) 686-9520','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 23:12:42',0,NULL,3,1,3,1,NULL,'sabnton\r庄\rRA117728524CN'),(7979,755418477016,260660054359,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',1.58,'hutongstore','hayder_123','rizjani@hotmail.com','rizwan sheikh','1 cowell way','blackburn','Lancashire','UNITED KINGDOM','bb2 1qz','01254581577','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 00:50:49',0,NULL,3,1,2,1,NULL,'hayder_123\r庄'),(7980,701623556002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','hwanggoh','hwanggoh79@yahoo.com','chen hwang goh','G190, Lrg33, Tmn Sejati Indah<br>Sungai Petani,','sungai petani','Kedah','MALAYSIA','08000','012-4933020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 00:56:03',0,NULL,3,1,2,1,NULL,'hwanggoh\r庄'),(7981,701624366002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','francisco_bs','franciscobs@gmail.com','Francisco Batalla Sánchez','C/ Villardondiego 23, 2º-B','Madrid','Madrid','SPAIN','28032','687993669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 00:59:39',0,NULL,3,1,4,1,NULL,'francisco_bs\r2套 \rlighting kit  $20\r庄\rYW864941666CN'),(7982,660887351001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','carmellino','carmel_mallia196@hotmail.com','Carmel Mallia','35 st anthony street','Zebbug','europe','MALTA','Zbg 2233','+35621467464','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-16 04:30:32',0,NULL,8,0,17,0,NULL,'carmellino'),(7983,701668210002,120439964418,'MACRO CLOSE UP Filter Lens kit +2 +3 +4 +8 40d d80 d90',1,'AKT012',23.6,'hermeshine','carmellino','carmel_mallia196@hotmail.com','Carmel Mallia','35 st anthony street','Zebbug','europe','MALTA','Zbg 2233','+35621467464','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 04:33:12',0,NULL,3,1,3,1,NULL,'carmellino\r67mm +2 +3 +4 +8    1\r+4如果没有了，发67mm cpl\r摄影背心 Nikon 老款  XL  1\r庄\rRA117728590CN\r'),(7984,771144167015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','niksahdus','nv.partanen@gmail.com','Niko Partanen','Kauppakatu 15 B 30','Jyväskylä','Keski-Suomi','FINLAND','40100','0408391457','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-16 07:08:22',0,NULL,3,1,2,1,NULL,'niksahdus\r刘'),(7985,660921008001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','fahimul277','fahimul27@gmail.com','Fahimul Hoque','10 Tuxedo Court<br>Apt 314','Scarborough','ON','CANADA','M1G3S4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 07:45:08',0,NULL,3,1,2,1,NULL,'fahimul277\r庄'),(7986,771178246015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','sakaedor','danitower@hotmail.com','Juan Daniel Bello Cano','c/Escota, 1<br>Cádiz','Rio San Pedro (Puerto Real)','Andalucía Ceuta y Melilla','SPAIN','11519','607957933','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-16 09:20:45',0,NULL,3,1,2,1,NULL,'sakaedor\r刘'),(7987,701722306002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','absancakli16','absancakli@msn.com','Abdüsselam Sancaklı','Dr. İsmail Niyazi Kurtulmuş Ögrenci Yurdu Topkapı Mah.<br>Kahılbağı sokak. No:3','Istanbul','Fatih','TURKEY','34093','905068499460','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 09:24:29',0,NULL,3,1,2,1,NULL,'absancakli16\r刘'),(7988,660950589001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','olimax60','oliveh@scarlet.be','Olivier Hennebert','20 Place de la gare','Bruxelles','','BELGIUM','1150','0486463907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 09:54:15',0,NULL,3,1,3,1,NULL,'olimax60\r申报：  microphone  $15\r庄\rRA117728612CN\r'),(7989,660960860001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','kasem001','kasemc@gmail.com','Kasem Chaisukpirom','205/125 Pattanakarn Road<br>Prawet','Bangkok','','THAILAND','10250','66-81-423-2847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 10:41:10',0,NULL,3,0,11,1,NULL,'kasem001\r72mm接口环  1\r托架  1\rND8   1'),(7990,701757202002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','eyalwaiss1','eyalwaiss@gmail.com','eyal waiss','Mordehai Elkahi 532/5','jerusalem','israel','ISRAEL','93807','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-16 11:44:10',0,NULL,3,1,3,1,NULL,'eyalwaiss1\rRA117728728CN\r'),(7991,660974769001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','denfilyukov','lokystaff@mfilm.ru','Denis Filyukov','Eniseyskaya str.17-1-77','Moscow','','RUSSIAN FEDERATION','129327','+79255026348','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 11:31:00',0,NULL,3,1,3,1,NULL,'denfilyukov\r庄\rRA117728688CN\r'),(7992,660998656001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','mecklaowd87','mecklaowd@gmail.com','Hassan Maklada','mail box - 5625','Daliat El Carmel','','ISRAEL','30056','0578165062','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 12:55:01',0,NULL,3,1,11,1,NULL,'mecklaowd87\r'),(7993,701782058002,120661195323,'Green-L 62mm Graduated Neutral Density ND Grey Filter',1,'AA3318',7.41,'hermeshine','photoshopix','photoshopix@hotmail.com','yves cambier','terkammenstraat 1','bogaarden','','BELGIUM','1670','023803424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 13:14:25',0,NULL,3,1,2,1,NULL,'photoshopix\r庄'),(7994,661017732001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','keonigmann','kodzo@list.ru','Anton Negonov','Artilleriyskaya 56-119','Kaliningrad','','RUSSIAN FEDERATION','236016','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 13:55:44',0,NULL,3,1,2,1,NULL,'keonigmann\r庄'),(7995,661027539001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',3.55,'hermeshine','pepsi_cola747','carol_mcallister_@hotmail.com','Carol McAllister','36 Alex Avenue','Wheelers Hill','Victoria','AUSTRALIA','3150','0395748271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:26:17',0,NULL,8,1,17,0,NULL,'pepsi_cola747'),(7996,661029303001,110414374077,'55mm 55 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT019',4.87,'hermeshine','pepsi_cola747','carol_mcallister_@hotmail.com','Carol McAllister','36 Alex Avenue','Wheelers Hill','Victoria','AUSTRALIA','3150','0395748271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:31:29',0,NULL,3,1,2,1,NULL,'pepsi_cola747\r52mm 接口环  1\r55mm 接口环  1\r托架   1\r刘'),(7997,701813798002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','willyodd','willy.kommedal@gmail.com','Willy Odd Kommedal','Tomasbakken 8','Hundvaag','Rogaland','NORWAY','4085','+4790980860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:46:56',0,NULL,3,1,3,1,NULL,'willyodd\r刘\rRA117728759CN\r'),(7998,661066396001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','brada113','zlatko.srbeli@ka.htnet.hr','Zlatko Srbelj','Zagrebacka 35','Velika Gorica','','CROATIA','10410','+385916225795','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 16:11:34',0,NULL,3,0,2,1,NULL,'brada113\r渐变红   1\r庄'),(7999,701850243002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','hantolic','hrvoje.antolic@gmail.com','Hrvoje Antolic','Hrvoja Macanovica 11','Zagreb','','CROATIA','10000','+(385)91-2410642','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 16:30:41',0,NULL,3,1,2,1,NULL,'hantolic\r庄'),(8000,771349233015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','shahrouz.z','shahrouz_shz@yahoo.com','Mr Shahrouz Zanganeh','57 Rozel Square','Manchester','Lancashire','UNITED KINGDOM','M3 4FQ','01612798681','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 16:38:02',0,NULL,3,1,2,1,NULL,'shahrouz.z\r庄'),(8001,0,110672018144,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',1.98,'hermeshine','simoncifer','simonhfu@netscape.net','Simon Fu','5120 Kauffman Ave','Temple City','CA','UNITED STATES','91780-3945','(626) 287-6274','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-16 18:21:01',0,NULL,3,1,1,1,NULL,'simoncifer\rsony 肩带   1\r52-canon 反接环   1\r庄'),(8002,771409544015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','decethymnus','pekimworthy@btinternet.com','Peter Kenworthy-Browne','The Old Vicarage','Staverton','Northamptonshire','UNITED KINGDOM','NN11 6JJ','01327704667','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 18:25:03',0,NULL,3,1,2,1,NULL,'decethymnus\r庄'),(8003,661147306001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','alberbond','alberbond@eresmas.com','Alberto Fernandez Gonzalez','paseo de la Florida 40-5A','Oviedo','Asturias','SPAIN','33012','984189588','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-16 19:14:35',0,NULL,3,1,4,1,NULL,'alberbond\rtripod  $20\r庄\rYW864941670CN'),(8004,701960202002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','rentavet1','rentavet@zoominternet.net','John M Jones','PO Box 488<br>Baker Animal Hospital','Clark','PA','UNITED STATES','16113-0488','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-16 20:29:03',0,NULL,3,1,1,1,NULL,'rentavet1\r庄'),(8005,661190680001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','senaystar','vanovanya@bigmir.net','Semen Starzhinskiy','Gogolya street<br>dom 78 kvartira 57','boyarka','Kiyvska oblast','UKRAINE','08150','(063)310-0686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 20:58:00',0,NULL,3,1,3,1,NULL,'senaystar\r庄\rRA117728691CN\r'),(8006,755859949016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','sorry-to-see-it-go','coldcurry@hotmail.co.uk','Dominic Kerridge','76 Lower Oldfield PARK','Bath','Somerset','UNITED KINGDOM','ba2 3hp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 21:36:56',0,NULL,3,1,2,1,NULL,'sorry-to-see-it-go\r庄'),(8007,701985933002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','1619bison','siso_2000@yahoo.com','Peter Chen','TH15 - 6063 Iona Drive','Vancouver','BC','CANADA','V6T 0B1','(604) 210-0185','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 21:38:38',0,NULL,3,1,2,1,NULL,'1619bison\r庄'),(8008,521266708003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','soloilfatolivinse011','soloilfatolivinse@hotmail.it','massimo stefanelli','strada camporelle 19','nole','TO','ITALY','10076','011 9297991','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 22:03:16',0,NULL,3,1,2,1,NULL,'soloilfatolivinse011\r庄'),(8009,701995040002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','pavelpervushin','pspervushin@gmail.com','Pavel Pervushin','Voznesenskaya 80a-27','Sergiev Posad','','RUSSIAN FEDERATION','141300','8-926-5548066','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-16 22:06:20',0,NULL,3,1,5,1,NULL,'pavelpervushin\r欧标\r刘\rCP226269118CN'),(8010,661223973001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','oddjohan2004','odd.lundberg@odont.uib.no','Odd Johan Lundberg','Erdalsveien 41','Erdal','','NORWAY','5306','+4790192671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 22:28:00',0,NULL,3,1,2,1,NULL,'oddjohan2004\r庄'),(8011,702045912002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','jazz_papa','uflathm@cpcus.jnj.com','Ullrich Flathmann','310 Tyler Court','New Hope','PA','UNITED STATES','18938','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 01:18:27',0,NULL,3,1,1,1,NULL,'jazz_papa\r庄'),(8012,661312823001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','chevelleboy_67','chevelleboy_67@yahoo.com','Breck Byington','PO Box 335<br>6935 N 2500 W','Honeyville','UT','UNITED STATES','84314-0335','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 05:16:52',0,NULL,3,1,1,1,NULL,'chevelleboy_67\r庄'),(8013,702097374002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','clkuv','valpaso@fastwebnet.it','Valle Luca','VIA Maestro Martino  7','VERONA','VR','ITALY','37131','+393495574380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 05:50:55',0,NULL,3,1,2,1,NULL,'clkuv\r庄'),(8014,661350590001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','polarfoxi','polarfox@polarfox.net','Mikko Ruohola','Kulmalantie 1 A 3','Vanha-Ulvila','','FINLAND','28450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:15:38',0,NULL,3,1,2,1,NULL,'polarfoxi\r刘'),(8015,771694362015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','lilutchm','lilutch@hotmail.com','Lillo Mendola','Rue des liégeois 11','Bruxelles','','BELGIUM','1050','02-6475218','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 08:26:44',0,NULL,3,1,2,1,NULL,'lilutchm\r庄'),(8016,702139786002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:44:44',0,NULL,8,1,17,1,NULL,'phylax57\r庄'),(8017,702141201002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:48:08',0,NULL,8,1,17,0,NULL,'phylax57'),(8018,702142179002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:52:08',0,NULL,3,1,3,1,NULL,'phylax57\r72mm 接口环   1\r托架  1\r渐变蓝   1\rCPL   1\r刘\rRA117728436CN\r'),(8019,702171771002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','sandro1w','sandro1w67@hotmail.it','Giusy Grasso','via catania 18','floridia','SR','ITALY','96014','3358266652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 10:17:36',0,NULL,3,1,2,1,NULL,'sandro1w\r庄'),(8020,702172688002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','hockey_guy99','galway.brendan@gmail.com','Brendan Galway','15 Atlantic Place','Beaumont Hills','New South Wales','AUSTRALIA','2155','61437856783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 10:18:51',0,NULL,3,1,2,1,NULL,'hockey_guy99\r刘'),(8021,659641590018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','usk1877','ukhan@orangemodels.ca','Usman Khan','111 Peter Street, Suite 107','Toronto','ON','CANADA','M5V2H1','(416) 830-9039','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-17 11:09:53',0,NULL,3,1,5,1,NULL,'usk1877\r灯泡是110v的\r刘\rCP226269135CN\r'),(8022,771769013015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',18.5,'hutongstore','rok_pop','rok.popovic@gmail.com','Rok Popovič','Pot k cuvajnici 9','Vnanje Gorice','','SLOVENIA','1351','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 11:17:18',0,NULL,3,1,3,1,NULL,'rok_pop\r庄\rRA117728731CN\r'),(8023,661427396001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','micmoo2005','mic.moo.2005@gmail.com','Michinori Mouri','Hamanomiya 171-1','Nachikatuurachou  Higashimurogun','Wakayama','JAPAN','6495314','09076890011','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 11:59:25',0,NULL,3,1,2,1,NULL,'micmoo2005\r庄'),(8024,756112570016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','lele_elena','zbrskx@yahoo.com','Elena Zaborskikh','60 fontwell Close Harrow Weald','London','London','UNITED KINGDOM','HA3 6DE','4477209188','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 12:00:11',0,NULL,3,1,2,1,NULL,'lele_elena\r庄'),(8025,702222312002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','imellado','iker.mellado@gmail.com','Iker Mellado Blanco','Buztintxulo nº 3 3 izda','San Sebastian','GUIPUZCOA','SPAIN','20015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 12:46:12',0,NULL,3,1,2,1,NULL,'imellado\r庄'),(8026,702231555002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',5.99,'hermeshine','sisco_5','sisco_5@abv.bg','Svilen Titov','Okolovraste Pat No 253, Mladost 4<br>Business Park Sofia, INA Trading','Sofia','Sofia','BULGARIA','1766','00359885332445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 13:04:02',0,NULL,3,1,2,1,NULL,'sisco_5\r庄'),(8027,756160871016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','alanthompson5','judiththompson5@gmail.com','Alan Thompson','5 Tynedale Crescent','Lisburn','Antrim','UNITED KINGDOM','BT28 3JY','02892665083','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 13:13:44',0,NULL,3,1,2,1,NULL,'alanthompson5\r庄'),(8028,702243637002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','junjunpang','jun-pang@hotmail.com','jun pang','1 Rosedale Ave Wattlepark','Adelaide','South Australia','AUSTRALIA','5066','0883317443','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-17 13:35:33',0,NULL,3,1,3,1,NULL,'junjunpang\r刘\rRA117728626CN\r'),(8029,661465238001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','10mikhail10','mikbasov@gmail.com','Mikhail Basov','Varshavskoe shosse<br>108-1-239','Moscow','Moscow','RUSSIAN FEDERATION','117639','903-773-97-69','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-17 13:38:23',0,NULL,3,1,3,1,NULL,'10mikhail10\r庄\rRA117728630CN\r'),(8030,702245354002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','filmstudio2010','zurafilm@yahoo.com','Zurab Katamadze','6909 6th Ave<br>Apt 1R','Brooklyn','NY','UNITED STATES','11209','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'filmstudio2010\r庄\r、'),(8031,702291002002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','takisgreekman67','panagiotisbp@gmail.com','THEODORA VUDICLARI','PROMITHEOS 4a','ATHENS','GREECE','GREECE','17674','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 15:24:27',0,NULL,3,1,2,1,NULL,'takisgreekman67\r刘'),(8032,756239211016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','vitpict','alfakapital@navigator.lv','Vitalijs Nevidomskis','Dzelzavas 76/2-61','Riga','','LATVIA','LV-1082','(371)25971410','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 15:40:04',0,NULL,3,1,2,1,NULL,'vitpict\r庄'),(8033,661522640001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1304',5,'hermeshine','erdavis1','erdavis1@bellsouth.net','Everett R Davis','129 Creekside Dr','Dallas','GA','UNITED STATES','30157-7373','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 15:43:48',0,NULL,3,1,1,1,NULL,'erdavis1\r注意数量\r庄'),(8034,661526280001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','v65magnasales','v65magnaebayer@hotmail.com','Charles Smith','1516 Clermont Rd','Durham','NC','UNITED STATES','27713','(919) 423-0834','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 15:58:33',0,NULL,3,1,1,1,NULL,'v65magnasales\r庄'),(8035,771938173015,250599985982,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',2.48,'hutongstore','wwsong79','wwsong@gmail.com','SONG WEI WEN','1B, LORONG 1,<br>JALAN GAMBIR','SIBU','SARAWAK','MALAYSIA','96000','6084349772','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 16:23:47',0,NULL,3,1,2,1,NULL,'wwsong79\r刘'),(8036,0,120711003203,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',3.99,'hermeshine','lbw65red','lisa65red@gmail.com','Lisa Weiner','35 Jean Pl','Syosset','NY','UNITED STATES','11791','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 16:48:37',0,NULL,3,1,1,1,NULL,'lbw65red\r庄'),(8037,756323206016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','lomaf123','lomafulton@talktalk.net','loma fulton','30 mitchell avenue','workington','Cumbria','UNITED KINGDOM','ca141ab','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-17 17:27:07',0,NULL,3,1,4,1,NULL,'lomaf123\r（英标）\r刘\r英国物流手里有一票，已经直接安排从英国转了，单号YW864870922CN'),(8038,661621350001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','stanleyfamily2011','stanleyfamily96@hotmail.com','Vanessa Stanley','96 Alfredo Duarte House Edinburgh Estate','Gibraltar','Gibraltar','GIBRALTAR','GX11A','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 17:59:21',0,NULL,3,1,2,1,NULL,'stanleyfamily2011\r刘'),(8039,772050010015,250599412421,'Green.L 67mm 67 Neutral Density ND8 Filter ND 8 New',2,'AE2312',8.6,'hutongstore','electronicparts321','ivotsolov@yahoo.com','Ivailo  Tsolov','Kr.Pishurka 1','Vratsa','Vratsa','BULGARIA','3000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 18:21:46',0,NULL,3,1,2,1,NULL,'electronicparts321\r注意数量\r刘'),(8040,661664113001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Rua Minas Gerais, 328<br>Vila Santana','Valinhos','Sao paulo','BRAZIL','13274080','55 19 3849-7661','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-17 18:46:43',0,NULL,3,1,3,1,NULL,'davidcinegra\r庄\rRA117728643CN'),(8041,756426448016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','thegoo0_0','dermotdu@eircom.net','dermot dunne','44 balally park, dundrum','dublin','Dublin','IRELAND','d16','0879566595','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 18:55:45',0,NULL,3,1,2,1,NULL,'thegoo0_0\r刘'),(8042,661693553001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','silverbrp','audi80silver@rambler.ru','Pavel Bakhteev','15-1-72 Musy Jalilia','Moscow','','RUSSIAN FEDERATION','115580','+7-926-294-43-17','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 19:25:28',0,NULL,3,1,2,1,NULL,'silverbrp\r刘'),(8043,772137997015,250692239997,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.99,'hutongstore','tubenutdave','tubenutdave.smith@virgin.net','Dave Smith','33 Mauldeth Road<br>heaton Mersey','Stockport','Cheshire','UNITED KINGDOM','SK4 3ND','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 19:33:49',0,NULL,3,1,2,1,NULL,'tubenutdave\r刘'),(8044,772132685015,250600523459,'Shutter Release Remote Cord For Canon 500D 450D RS-60E3',1,'AA3210',2.98,'hutongstore','f-nielsen','inkognito65@gmail.com','Frank Nielsen','Løkkenvej 428','Brønderslev','','DENMARK','9700','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 19:44:07',0,NULL,3,1,2,1,NULL,'f-nielsen\r刘'),(8045,661746963001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','rlip6245','rdlonnie@gmail.com','Ronald Lipman','5800 Nicholson Ln<br>Apt 808','Rockville','MD','UNITED STATES','20852-2964','','NoPaymentFailure','CheckoutComplete','Other','2011-04-17 21:00:51',0,NULL,3,1,1,1,NULL,'rlip6245\r尺寸：2XL\r庄'),(8046,772215862015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',63.99,'hutongstore','muntazer10','garcinia03@yahoo.com','Muntaz Abu Bakar','55 Trinity Square<br>Lombard Street1','Dublin ','Dublin','IRELAND','2','0852707282','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-17 21:15:35',0,NULL,3,1,4,1,NULL,'muntazer10\r庄\rYW864941692CN'),(8047,702546033002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','adrianleys2010','adrianleys@hotmail.com','Perez, Vanesa','Sullivan 1200 Edif. 51 Dep. F<br>Barrio Policial','San Antonio de Padua','Buenos Aires','ARGENTINA','1718','0220-4835898','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-17 21:22:39',0,NULL,3,1,3,1,NULL,'adrianleys2010\r庄\rRA117728657CN'),(8048,661771592001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','howerdal','anders.howerdal@telia.com','Anders Howerdal','Solhemsgatan 20','Gislaved','none','SWEDEN','33234','037114400','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-17 21:38:50',0,NULL,3,1,3,1,NULL,'howerdal\r庄\rRA117728705CN\r'),(8049,772235507015,250692237341,'IR Wireless Remote Control for Nikon D90/D80/D60 ML-L3',1,'AA2201',2.75,'hutongstore','anowarul2006','pritha_moni@hotmail.com','Anowarul Kamal','K  F  C<br>East Gate Shoping Centre.  (Food Court)','Inverness.','Highland','UNITED KINGDOM','IV1  1LQ','07985281231','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 21:54:00',0,NULL,3,1,2,1,NULL,'anowarul2006\r刘\r\\\r'),(8050,772273450015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','chamling_keta','sherockedme@yahoo.com','samir rai','17 albany street','middlesbrough','Cleveland','UNITED KINGDOM','ts1 4db','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 23:28:04',0,NULL,3,1,2,1,NULL,'chamling_keta\r刘'),(8051,702618490002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','stormdelrosario','mannydelrosario@yahoo.com','Maani Del Rosario','5495 Coolbrook Avenue','Montreal','QC','CANADA','H3X2L3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 00:54:59',0,NULL,3,1,2,1,NULL,'stormdelrosario\r刘'),(8052,661845697001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',2,'AA1211',6.8,'hermeshine','hilltopper23','beaman_rg@yahoo.com','RANDALL BEAMAN','2332 Ridgeway Rd','MEMPHIS','TN','UNITED STATES','38119-7414','(901) 820-0544','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 01:33:23',0,NULL,3,1,1,1,NULL,'hilltopper23\r庄'),(8053,702638201002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','inness207','innessphoto@securespeed.net','Inness  Photo Service','25 Plaza Dr<br>Ste 6','Scarborough','ME','UNITED STATES','04074-6900','(207) 883-7860','NoPaymentFailure','CheckoutComplete','Other','2011-04-18 01:49:59',0,NULL,3,1,1,1,NULL,'inness207\rxl\r庄'),(8054,756659177016,260660054946,'YongNuo SF-18 Flash Battery Pack 8*AA for Nikon SB800',1,'AB3309',32.99,'hutongstore','scooter2462','willys@shermanlaws.com','Wilfredo Santiago','61 Town Center Court # 1401','Scarborough','ON','CANADA','M1P 5C5','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 02:15:26',0,NULL,3,1,3,1,NULL,'scooter2462\r庄\rRA117728665CN\r'),(8055,661863593001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','5144ryan','migramcrae@yahoo.com','Ryan McRae','1544 E Irene Dr','Casa Grande','AZ','UNITED STATES','85122-8697','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 02:30:21',0,NULL,3,1,1,1,NULL,'5144ryan\r庄'),(8056,660116309018,280522563067,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','ppnc12','pollux_chung@yahoo.com','Pollux Chung','3019 Graveley Street','Vancouver','BC','CANADA','V5K 3K5','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-18 02:35:06',0,NULL,3,1,5,1,NULL,'ppnc12\r2m背景架 +2块 绿色的\r  背景布 1.6x2.1 庄\rCP226344661CN'),(8057,0,110672017749,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',0.99,'hermeshine','huaguosan','shop94556@gmail.com','K C Hua','109 Alta Mesa Court','Moraga','CA','UNITED STATES','94556','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 03:18:54',0,NULL,3,1,1,1,NULL,'huaguosan\r庄'),(8058,702666013002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','lw463','boguo@aol.com','Bo Guo','6705 185th St','Fresh Meadows','NY','UNITED STATES','11365-3511','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 03:22:33',0,NULL,3,1,1,1,NULL,'lw463\r庄'),(8059,702668293002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','beowulf_cam','shauncoleman@rogers.com','Shaun Coleman','60 Haddington Street','Cambridge','ON','CANADA','N1R3P9','(519) 240-1212','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 03:30:37',0,NULL,3,1,3,1,NULL,'beowulf_cam\r刘\rRA117728674CN\r'),(8060,702670122002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','nathalee10','yo.nat_buh@hotmail.com','nathalee hernandez','carr.853 k.m 5.1 bo. barrazas, carolina , PR<br>p.o box 1110 00986 carolina','carolina','PR','UNITED STATES','00986','(787) 548-9586','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 03:40:09',0,NULL,3,1,1,1,NULL,'nathalee10\r庄'),(8061,661882283001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','failure.online','x.deadlyfishy.x@gmail.com','Brady Lee','N10275 171st St','Boyceville','WI','UNITED STATES','54725-9527','(715) 225-9061','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 03:49:39',0,NULL,3,1,1,1,NULL,'failure.online\r1.6x2.1 黑色\r刘'),(8062,702675257002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','jantine57','hofman.tina@yahoo.com','jantine hofman','209 racecourse rd','leongatha','Victoria','AUSTRALIA','3953','0356624512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 04:14:16',0,NULL,3,1,2,1,NULL,'jantine57\r庄'),(8063,702681424002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','marzum01','mario@marzuki.co.nz','Mario Marzuki','Lvl 4 CallPlus Business Centre<br>110 Symonds Street, Auckland Central','Auckland','Auckland','NEW ZEALAND','1010','099196236','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 04:36:31',0,NULL,3,1,2,1,NULL,'marzum01\r庄'),(8064,661900339001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','genadyd','genadyd@gmail.com','Genady Dubnik','Mivtza Harel 20 Str.','Rishon Lezion','','ISRAEL','75443','(972)506235314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 05:38:46',0,NULL,3,1,2,1,NULL,'genadyd\r庄'),(8065,702698944002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','ppnc12','pollux_chung@yahoo.com','Pollux Chung','3019 Graveley Street','Vancouver','BC','CANADA','V5K 3K5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 06:21:50',0,NULL,3,1,5,1,NULL,'ppnc12\r刘\rCP226269104CN\r'),(8066,661915381001,110583709836,'NEW 62mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT045',28,'hermeshine','yowonn','yotang@time.net.my','Mr. Tang Yow Onn','19,Jalan Bunga Melur 14<br>Taman Muda, Cheras','Kuala Lumpur','WP','MALAYSIA','56100','0122975572','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 07:03:59',0,NULL,3,1,3,1,NULL,'yowonn\r庄\rRA117728440CN\r'),(8067,702713960002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','emiltan79','emiltndn@yahoo.com','Emil Tandian','Blk 5004, #03-12 Ang Mo Kio Ave 5<br>TECHplace II','default','','SINGAPORE','569872','+6598561576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 08:33:56',0,NULL,8,1,17,0,NULL,'emiltan79'),(8068,702714818002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','emiltan79','emiltndn@yahoo.com','Emil Tandian','Blk 5004, #03-12 Ang Mo Kio Ave 5<br>TECHplace II','default','','SINGAPORE','569872','+6598561576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 08:34:04',0,NULL,8,1,17,0,NULL,'emiltan79'),(8069,661925569001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','emiltan79','emiltndn@yahoo.com','Emil Tandian','Blk 5004, #03-12 Ang Mo Kio Ave 5<br>TECHplace II','default','','SINGAPORE','569872','+6598561576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 08:34:05',0,NULL,8,1,17,0,NULL,'emiltan79'),(8070,702717050002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','emiltan79','emiltndn@yahoo.com','Emil Tandian','Blk 5004, #03-12 Ang Mo Kio Ave 5<br>TECHplace II','default','','SINGAPORE','569872','+6598561576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 08:34:05',0,NULL,3,1,3,1,NULL,'emiltan79\r77mm ring  1\rstar6 星光镜   1\r广角托架  1\r渐变灰   1\rRA117728422CN'),(8071,702730758002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','oldman-garage','oldmangarage@gmail.com','Donny Tong','35 jalan pp 4/13<br>taman putra prima','puchong','selangor','MALAYSIA','47130','012-2966223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 09:16:25',0,NULL,3,1,2,1,NULL,'oldman-garage\r徐'),(8072,702735099002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','eddyhuang','simply-eddy@hotmail.com','Eddy Huang','Block 233 Hougang Street 21 #04-340','default','','SINGAPORE','530233','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 09:31:42',0,NULL,8,1,17,0,NULL,'eddyhuang'),(8073,661946799001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','eddyhuang','simply-eddy@hotmail.com','Eddy Huang','Block 233 Hougang Street 21 #04-340','default','','SINGAPORE','530233','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 09:36:40',0,NULL,3,1,9,1,NULL,'eddyhuang\rwt600   1\r6662a 快装板  1\r104231201104180107'),(8074,661959763001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mauri.2010','maurizio.pellizer@gmail.com','maurizio pellizer','levja 5','Koper','slovenia','SLOVENIA','6000','0038641948989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 10:32:42',0,NULL,3,1,2,1,NULL,'mauri.2010'),(8075,772496803015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','iheartsunshine01','sunshine_ying92@yahoo.com.au','Ying Lim','Ramsay Hall<br>20 Maple St','London','London','UNITED KINGDOM','W1T 5HB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 12:08:38',0,NULL,3,1,2,1,NULL,'iheartsunshine01\r庄'),(8076,661985077001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','juraaa','juraaa@mail.ru','Yury Gich','Österlånggatan 15B','Trollhättan','Centrum','SWEDEN','46131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 12:13:34',0,NULL,3,1,3,1,NULL,'juraaa\r刘\rRA022493418CN'),(8077,661209794001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',231.05,'hermeshine','teatrodemarionetaslaestrella','iberians@hotmail.com','Alberto Gomez Sanchis','Av./Pais Valenciano nº32  Esc.2ª  1ºA','Villajoyosa','ALICANTE','SPAIN','03570','677072979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 12:43:56',0,NULL,3,1,4,1,NULL,'teatrodemarionetaslaestrella\r4灯头 伞孔  1 欧标\r佳能红外   1\r50-70 通用卡口棚  1\r115w 220v   4\r肩架   1\r渐变灰  1\r77mm canon 镜头盖  1\r斜臂  1\r2m 灯架  1\r77mm 接口环  1\r托架   1\r刘\rYW864941176CN\r'),(8078,702800476002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','m_r_t','buyuknacarmurat@mynet.com','Murat Buyuknacar','Yucel Buro Mob.San. ve Tic.AS.<br>3. O.S.B. Celal Dogan Blv. No=38 - Baspinar','Gaziantep','TURKEY','TURKEY','27600','3423379550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 13:41:00',0,NULL,3,1,2,1,NULL,'m_r_t\r庄'),(8079,662009441001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','selma110011','selma.hodz@gmail.com','selma hodzic','bilica 5<br>donja mahala','mostar','','BOSNIA AND HERZEGOVINA','88000','+38763428212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 13:43:07',0,NULL,3,1,2,1,NULL,'selma110011\r庄'),(8080,702820540002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','ribesella','carlosrosal@gmail.com','Marta Rodriguez Moro','C/ Modesto Lafuente, Nº 15, 4º - 3','Madrid','Madrid','SPAIN','28003','637522177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 14:47:10',0,NULL,3,1,2,1,NULL,'ribesella\r庄'),(8081,662032411001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 15:00:24',0,NULL,3,1,2,1,NULL,'vio\r庄'),(8082,662042237001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','marco_dian','dian.marco@gmail.com','Marco Dian','Via P. Picasso 41','Peseggia','VE','ITALY','30030','339 8593761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 15:28:47',0,NULL,3,1,2,1,NULL,'marco_dian\r申报：Lens hood，5$\r刘'),(8083,662056856001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','cybertonio666','cybertonio@terra.es','José Antonio Peñas Lázaro','Pedro Saputo 14, 1ºA','Zaragoza','Aragón','SPAIN','50018','616467953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:15:06',0,NULL,3,1,2,1,NULL,'cybertonio666\r刘'),(8084,702853172002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','banditbikerchick333','bandit3364@yahoo.com','Dawn Berndt','2047 W Farwell Ave','Chicago','IL','UNITED STATES','60645-4982','(773) 592-1243','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 16:21:36',0,NULL,3,1,1,1,NULL,'banditbikerchick333\r庄'),(8085,702853093002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','rmsoares','rafael.msoares@terra.com.br','Rafael Mello','Avenida Nilo Peçanha<br>50 33º ANDAR 3301','Rio de Janeiro','Rio de Janeiro','BRAZIL','20020100','55 21 3824-2208','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 16:21:39',0,NULL,3,1,3,1,NULL,'rmsoares\r王\rRA022493404CN\r、'),(8086,702858208002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:43:55',0,NULL,8,1,17,0,NULL,'stiu1983'),(8087,702855263002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',3,'AE1201',14.4,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:43:56',0,NULL,8,1,17,0,NULL,'stiu1983'),(8088,702850075002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 16:43:56',0,NULL,8,1,17,0,NULL,'stiu1983'),(8089,662059568001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',59,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 16:43:57',0,NULL,8,1,17,0,NULL,'stiu1983'),(8090,662065063001,110606921919,'New Portable 50cm 20\"x20\" Soft Box Softbox for Flash ',2,'AB3328',101.98,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:43:57',0,NULL,3,1,4,1,NULL,'stiu1983\r滤镜套装：10片镜+卡座+58mm环\r柔光伞   2\r3片装的滤镜袋   3\rCanon  老款背心（M）    1\r灯架  2m    2\r闪光的柔光箱   50cm   2\r申报：Lighting kit，25$\r庄\rYW864941180CN'),(8091,662062542001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 16:43:58',0,NULL,8,1,17,0,NULL,'stiu1983'),(8092,772623238015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','mm5pb','mmooreqc@tiscali.co.uk','M.Moore','5,Paper Buildings<br>Temple','London','London','UNITED KINGDOM','EC4Y 7HB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 17:18:53',0,NULL,3,1,2,1,NULL,'mm5pb\r刘'),(8093,662094376001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','el_supahfly','flydelivery@gmail.com','Alexander Nazarov','11-Mitskevich str., Ap.9','Rivne','Rivne region','UKRAINE','33013','+380503753590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 17:42:58',0,NULL,3,1,2,1,NULL,'el_supahfly\r刘'),(8094,772645646015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','bydemofilo2010','bydemofilo@gmail.com','jose demofilo camacho carrasco','galdames nº92<br>ayamonte','huelva','Andalucía Ceuta y Melilla','SPAIN','21400','671084038','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-18 17:58:21',0,NULL,3,1,3,1,NULL,'bydemofilo2010\r王\rRA022493395CN\r、'),(8095,772678792015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','521pebe','patblackledge@msn.com','Pat Blackledge','181 Liverpool Road South, Burscough','Ormskirk','Lancashire','UNITED KINGDOM','L40 7RE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 18:48:05',0,NULL,3,1,2,1,NULL,'521pebe\r数量！！\r刘'),(8096,702927565002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','momomo25','momomo25@hotmail.com','Monique Schaefer','183a putnam pike','dayville','CT','UNITED STATES','06241-1626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 19:04:54',0,NULL,8,1,17,0,NULL,'momomo25'),(8097,772690885015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',2,'AD1401',12.4,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 19:07:18',0,NULL,8,1,17,0,NULL,'leifs123'),(8098,772688104015,250692236379,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT009',55,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 19:07:19',0,NULL,8,1,17,0,NULL,'leifs123'),(8099,772686395015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-18 19:07:19',0,NULL,3,1,4,1,NULL,'leifs123（欧标）\r反光伞    2\r2m灯架   2\r双灯头   2\r反光伞   2\r背景架2mx2m    1\r背景布 1.6    2（黑白各一块）\r灯架包  1\r申报：20￡，\rlighting kit？\r刘\rYW864941143CN'),(8100,662147971001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',3.79,'hermeshine','momomo25','momomo25@hotmail.com','Monique Schaefer','183a putnam pike','dayville','CT','UNITED STATES','06241-1626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 19:27:33',0,NULL,3,1,1,1,NULL,'momomo25\rEW-73B   1\r62mm  橡胶遮光罩    1\r庄'),(8101,662180576001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','robert2348','robertgibsonb@hotmail.com','Robert Gibson','Casilla 10-03-45','Ibarra','Imbabura','ECUADOR','EC-100140','(593) 062-6520 ext.: 73','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 20:38:58',0,NULL,3,1,2,1,NULL,'robert2348\r庄'),(8102,702976359002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','vaidulencijus3706','vaidulencijus@gmail.com','Vaidas Azubalis','Amatu g. 3','Moletai','Utena region','LITHUANIA','LT-33102','+37065679130','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 20:44:18',0,NULL,3,1,3,1,NULL,'vaidulencijus3706\r庄\rRA022493191CN'),(8103,662177441001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','xtrimal','xtrimal@gmail.com','Leonid Shmigun','Pionerskaya st.3 - 37','Vuktil','Respublika Komi','RUSSIAN FEDERATION','169570','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 21:03:37',0,NULL,3,1,3,1,NULL,'xtrimal\r刘\rRA022494002CN'),(8104,660472332018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','goyngreen','carlottapoole@hotmail.com','Mark A. Poole','1588 Los Angeles Ave','ventura','CA','UNITED STATES','93004-3216','(805) 649-5285','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 21:19:03',0,NULL,3,1,4,1,NULL,'goyngreen\r灯泡是110v\r庄\rYW864941154CN'),(8105,0,120711002739,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.25,'hermeshine','ministerfortson','admin@ministerfortson.com','Minister Fortson','2321 Juanita Cir','North Las Vegas','NV','UNITED STATES','89032-3519','(702) 762-3185','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 21:37:38',0,NULL,3,1,1,1,NULL,'ministerfortson\r庄\r、'),(8106,662204969001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','carlotta611','avonwoman1@gmail.com','Carlotta Roberts','381 Meadow Lark Ln','Banning','CA','UNITED STATES','92220','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 21:40:06',0,NULL,3,1,1,1,NULL,'carlotta611\r庄\r、'),(8107,662209369001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','thank.you.come.again','akifergin@live.com','Akif Ergin','115B N 34th St<br>Apt 7-B','PHILADELPHIA','PA','UNITED STATES','19104-4904','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 21:53:58',0,NULL,3,1,1,1,NULL,'thank.you.come.again\r庄\r、'),(8108,703012217002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','keithpyt','keithpyt@yahoo.com','Keith A. Pytlinski','2343 Corlson Pl','Simi Valley','CA','UNITED STATES','93063-2717','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 22:21:18',0,NULL,3,1,1,1,NULL,'keithpyt\r庄\r、'),(8109,703023300002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','lunadrift','lunadrift@gmail.com','Bu Wang','1920 Powell Campus Ctr','Alfred','NY','UNITED STATES','14802','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 23:00:39',0,NULL,3,1,1,1,NULL,'lunadrift\r庄\r、'),(8110,660549215018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','namadnats','rocketlabz@gmail.com','Ruben Alvarez','5100 boul de Maisonneuve Ouest 5th Floor','Montreal','QC','CANADA','H4A3T2','(514) 451-6922','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-19 01:54:23',0,NULL,3,1,6,1,NULL,'namadnats\r灯泡是110v\r申报 lighting kit  $20\r王\rEE442466412CN'),(8111,703068744002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mogly73','etienneducharme@videotron.ca','Etienne Ducharme','1027, Rue Ronsard','Deux-Montagnes','QC','CANADA','j7r6n2','(450) 974-2526','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 01:55:16',0,NULL,3,1,2,1,NULL,'mogly73\r刘'),(8112,662281371001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',4.95,'hermeshine','whl36512','weihan_lin@yahoo.com','Weihan Lin','2916 Colton Ct','Lisle','IL','UNITED STATES','60532-4411','(630) 579-1825','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 02:35:55',0,NULL,3,1,1,1,NULL,'whl36512\r庄'),(8113,660577577018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','george.ym.siu','george.ym.siu@gmail.com','Yuet SIU','28/2 Wattle Cres','Pyrmont','New South Wales','AUSTRALIA','2009','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-19 03:55:01',0,NULL,3,1,4,1,NULL,'george.ym.siu\r澳标    王\rYW864941165CN'),(8114,757207699016,260660056652,'New Padded shoulder Neck Strap for Canon 500D 5DII 40D',1,'AB1404',2.99,'hutongstore','ksorweide25','ksorweide@gmail.com','kara sorweide','427 W 13th Ave','spokane','WA','UNITED STATES','99204-3758','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 04:17:38',0,NULL,3,1,1,1,NULL,'ksorweide25\r、'),(8115,703102822002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','lucablight32','rahal_roog@hotmail.com','Christian Erwanda','212/547 Flinders Lane','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 04:29:16',0,NULL,3,1,2,1,NULL,'lucablight32\r'),(8116,662303654001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','rwir7405','richard@a3logistics.net','Richard Wirski','PO BOX 2208','Seaford','Victoria','AUSTRALIA','3198','0397867007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 04:31:50',0,NULL,3,1,3,1,NULL,'rwir7405\r注意是铁接口那个         王\rRA022493364CN\r'),(8117,0,110671625976,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',51.93,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 05:19:55',0,NULL,3,0,3,1,NULL,'traderseamer\r52mm 渐变灰  1\r72mm +4 近摄镜   1\r58mm 渐变灰  1\r67mm uv   1\r52mm uv  10\r58mm uv  10\r1.264\r'),(8118,772920332015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','bisseryo','bisser_yordanov@mail.bg','Bisser Yordanov','Lyulin 10, bl 133, ent1, fl 5, apt 18','Sofia','Sofia','BULGARIA','1335','359898776059','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 06:05:14',0,NULL,3,1,2,1,NULL,'bisseryo'),(8119,662320497001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','luliag','xemenia@hotmail.com','Juliah Sharron','6 Bolgers Lane','St. John\'s','NL','CANADA','a1c1k8','(709) 691-9451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 06:18:21',0,NULL,3,1,2,1,NULL,'luliag'),(8120,757237267016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',3,'AO0005',23.97,'hutongstore','2006walvin','christinewalvin@btinternet.com','christine walvin','brairwood<br>the common','hucknall','Nottinghamshire','UNITED KINGDOM','ng15 6qb','01159638606','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 06:41:30',0,NULL,3,0,3,1,NULL,'2006walvin\r2.1x1.6m   3（黑+红+粉）\rRA022493165CN'),(8121,703125936002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','rlbrett','bobbylbrett@yahoo.com','Robert Brett','15960 Doublegrove St','La Puente','CA','UNITED STATES','91744','(626) 536-0433','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 06:43:54',0,NULL,3,1,1,1,NULL,'rlbrett'),(8122,662340565001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','danielephoto','danieleomma@hotmail.com','Daniele Omma / FRAEN','Via Pordoi, 5','Settimo Milanese','MI','ITALY','20019','3487249558','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 08:06:40',0,NULL,3,1,3,1,NULL,'danielephoto\rreflector holder $15\rRA022493214CN'),(8123,660286486001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','japoneva','eva.aurio@gmail.com','EVA MARIA TORRECILLA ALLO','AURIO PRINTER C/ MARCELINO ALVAREZ, 18 - LOCAL POSTERIOR','MADRID','Madrid','SPAIN','28017','637454949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 08:18:06',0,NULL,3,1,2,1,NULL,'japoneva\r\\'),(8124,703139578002,120544017355,'YONGNUO Flash Battery Pack SF-17 Nikon SB800 SD-8A ',1,'AB3315',41.99,'hermeshine','znegg1','zneg1@verizon.net','Arnold Gallardo','9015 205th St','Hollis','NY','UNITED STATES','11423-2730','','NoPaymentFailure','CheckoutComplete','Other','2011-04-19 08:00:58',0,NULL,3,1,1,1,NULL,'znegg1'),(8125,772957233015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','derrinal','kenm.harrison@gmail.com','Ken Harrison','Avenue de Burbure 124a','Wezembeek-Oppem','','BELGIUM','1970','027850088','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 08:42:36',0,NULL,3,1,2,1,NULL,'derrinal\r注意是2个\r庄'),(8126,703150407002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','muhd2005','amir@mdamirpp.net','Muhammad Amir H Umarali','No. 898<br>Kampung Kiudang','Tutong','','BRUNEI DARUSSALAM','TE1543','(673) 8866648','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 08:55:24',0,NULL,3,0,3,1,NULL,'muhd2005\rXL\r庄\rRA022493245CN\r、'),(8127,757275273016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','swordyg','gajdoscsabi@gmail.com','Csaba Gajdos','Hóvirág u. 3/a','Kárász','Hungary','HUNGARY','7333','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 09:19:06',0,NULL,3,1,3,1,NULL,'swordyg\r庄\rRA022493982CN\r、'),(8128,662359257001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','suzana1','suzanahorvat@gmail.com','Suzana Ludaš','Šumska 14, Brdovec','Zaprešić, Prigorje brdovečko','Croatia','CROATIA','10291','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 09:39:40',0,NULL,3,1,3,1,NULL,'suzana1\r庄\rRA022493965CN\r、'),(8129,662361033001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 10:07:37',0,NULL,3,1,3,1,NULL,'saud-p\r刘   、\rRA022493863CN\rRA022493877CN\r'),(8130,703140483002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',2,'AO0009',141.8,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 10:07:38',0,NULL,3,1,3,1,NULL,'saud-p\r和下面的反光板支架一起，看看能发几个小包出去\r刘   、\rRA022493885CN\rRA022493894CN'),(8131,703175013002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','saltiks','akifsaltik@hotmail.com','akif saltik','yilmaz iletisim topraklik mh. no  26-1<br>gun market karsisi garaj mevki','denizli','merkez','TURKEY','20100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 10:52:01',0,NULL,3,1,3,1,NULL,'saltiks\rL\r庄\rRA022493948CN\r、'),(8132,703181218002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','123.clem1','clementsylvain500@yahoo.ca','Clement Sylvain','49 Wilson St','Wallaceburg','ON','CANADA','n8a 5a5','(519) 627-6985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:18:47',0,NULL,3,1,2,1,NULL,'123.clem1\r庄'),(8133,703183501002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','cyavasoglu','yavasoglu@gmail.com','Caglar YAVASOGLU','Erdem Sokak 6/2<br>Kurtulus / Cebeci','Ankara','','TURKEY','06600','+905326789817','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 11:28:37',0,NULL,3,1,6,1,' EE520583295CN','cyavasoglu\r庄'),(8134,662393176001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','junctionflyer','finnan@wwy.org','Dennis Finnan','1754 Bell Ridge Ct','Grand Junction','CO','UNITED STATES','81506-4011','(970) 242-3900','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 12:07:51',0,NULL,8,1,17,0,NULL,'junctionflyer'),(8135,772964331015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',59,'hutongstore','kalletappinen','timo.flinkkila@kolumbus.fi','Timo Flinkkilä','Hyökkäläntie 10 A 6','Tuusula','','FINLAND','04300','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-19 12:17:58',0,NULL,3,1,4,1,NULL,'kalletappinen\r庄\r2x2m         背景架   1\r1.6x2.1m   背景布 \r  3（黑+白+灰）\rYW864941202CN'),(8136,703204259002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',2,'AKT056',106,'hermeshine','tulnikov','tulneek@gmail.com','Aleksandr Tulnikov','Savushkina, 24, app 32','Astrakhan','','RUSSIAN FEDERATION','414056','+79270799195','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 12:55:03',0,NULL,3,1,5,1,NULL,'tulnikov\r刘\rCP226269095CN'),(8137,0,120710988343,'Green.L 67mm Neutral Density ND8 Filter ND 8 67',1,'AE2312',2.52,'hermeshine','surffishjim','jim.kehler@reddrum.net','Jim Kehler','2500 Caprice Ln','Amelia Island','FL','UNITED STATES','32034-8980','(904) 491-1678','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 13:18:01',0,NULL,8,1,17,0,NULL,'surffishjim'),(8138,0,110674134245,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',1,'AE2308',2.52,'hermeshine','surffishjim','jim.kehler@reddrum.net','Jim Kehler','2500 Caprice Ln','Amelia Island','FL','UNITED STATES','32034-8980','(904) 491-1678','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 13:18:01',0,NULL,3,1,1,1,NULL,'surffishjim\r绿叶 ND8  67mm    1\r绿叶 ND8  52mm    1\r庄\r、'),(8139,0,120710988419,'Green.L 72mm Neutral Density ND8 Filter ND 8 72',1,'AE2313',3.52,'hermeshine','madacheng','hbj8@cdc.gov','Hongwei Jia','455 Villa Place Ct','Tucker','GA','UNITED STATES','30084-1958','(678) 380-5318','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 13:38:37',0,NULL,8,1,17,0,NULL,'madacheng'),(8140,0,110674134514,'Green.L 72mm Neutral Density ND4 Filter ND 4 72',1,'AE2306',3.6,'hermeshine','madacheng','hbj8@cdc.gov','Hongwei Jia','455 Villa Place Ct','Tucker','GA','UNITED STATES','30084-1958','(678) 380-5318','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 13:38:38',0,NULL,3,1,1,1,NULL,'madacheng\r绿叶 ND8 72mm    1\r绿叶 ND4 72mm    1\r庄\r、'),(8141,0,120710988587,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',0.99,'hermeshine','mosquitoebites24','lhyme_lopez@yahoo.com','Lhyme Lopez','2105 Spence Cir<br>Apt 10','Jonesboro','AR','UNITED STATES','72401-7235','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 13:45:58',0,NULL,3,1,1,1,NULL,'mosquitoebites24\r庄\r、'),(8142,0,120710988669,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',1.25,'hermeshine','beanbridge','rbrmaliniak@hotmail.com','Brigitte Maliniak','7940 State Rd','Port Hope','MI','UNITED STATES','48468','(989) 428-5065','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 14:01:59',0,NULL,3,1,1,1,NULL,'beanbridge\r庄\r、'),(8143,662416431001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','kata141kata','katahorvat14@gmail.com','Kata Horvat','Šumska 14<br>Brdovec','Prigorje Brdovečko','','CROATIA','10291','00385989601830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 14:35:24',0,NULL,3,1,3,1,NULL,'kata14\r庄\rRA022493925CN\r、'),(8144,773066065015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',4.5,'hutongstore','kirstmonty','kirstmonty@hotmail.com','K.Greenhalgh','31 farndon Way','Birmingham','West Midlands','UNITED KINGDOM','B235XU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 14:41:31',0,NULL,8,1,17,0,NULL,'kirstmonty'),(8145,772996337015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',4.5,'hutongstore','kirstmonty','kirstmonty@hotmail.com','K.Greenhalgh','31 farndon Way','Birmingham','West Midlands','UNITED KINGDOM','B235XU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 14:41:31',0,NULL,3,1,2,1,NULL,'kirstmonty\r中号内胆包 canon   2\r庄'),(8146,662438820001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','davekui','singkuiwong@yahoo.co.uk','Wong Sing Kui','Block119, bukit merah view #16-89','default','','SINGAPORE','152119','91666242','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 14:55:23',0,NULL,3,1,11,1,NULL,'davekui\r庄\r、'),(8147,0,110674134573,'Green.L 77mm Neutral Density ND4 Filter ND 4 77',1,'AE2307',8.2,'hermeshine','junctionflyer','finnan@wwy.org','Dennis Finnan','1754 Bell Ridge Ct','Grand Junction','CO','UNITED STATES','81506-4011','(970) 242-3900','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 15:39:11',0,NULL,3,1,1,1,NULL,'junctionflyer\r绿叶 渐变镜 77mm   1\r绿叶 ND4  77mm    1\r庄\r、'),(8148,0,120710988643,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',1.75,'hermeshine','george35209','gbrowder@gmail.com','George Browder','2041 S Moonlit Pt','Homosassa','FL','UNITED STATES','34448-2164','(352) 621-9108','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 15:41:44',0,NULL,3,1,1,1,NULL,'george35209\r庄\r、'),(8149,703265621002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dnportero','dnportero@retemail.es','Daniel Nevado Portero','Avda. San Francisco Javier nº 24 (Edf. Sevilla 1) - 10ª Plta. (última puerta)','Sevilla','Sevilla','SPAIN','41018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 16:17:08',0,NULL,3,1,2,1,NULL,'dnportero\r庄'),(8150,0,110674145643,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.59,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 17:02:18',0,NULL,3,1,1,1,NULL,'zeroone12345\r58-58mm  双阳环    1\r52-58mm  双阳环    1\r52mm  接口环    1\r庄\r、'),(8151,662485772001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','bart1628','btw_lee@hotmail.com','Bert Lee','5577 Argyle Street','Vancouver','BC','CANADA','V5P3J5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 17:13:23',0,NULL,3,1,2,1,NULL,'bart1628\r庄'),(8152,0,120710988481,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',3.82,'hermeshine','frojas','ab4qc@yahoo.com','Felipe Rojas','2020 Woods River Ln','Duluth','GA','UNITED STATES','30097-7963','(678) 499-2720','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 17:16:32',0,NULL,3,1,1,1,NULL,'frojas\r庄\r、'),(8153,757448545016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.25,'hutongstore','tzepuly','case@lesfauves.net','Mr Davide Caselli','91 Kenworthy Road','London','London','UNITED KINGDOM','E9 5RB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 17:40:08',0,NULL,3,1,2,1,NULL,'tzepuly\r庄'),(8154,700878622002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','javiermendoza2010','mendoza6313@att.net','Miguel A Mendoza','134 kennedy dr<br>trlr 44','medway','OH','UNITED STATES','45341-1279','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-19 17:46:18',0,NULL,3,1,4,1,NULL,'javiermendoza2010\rreflector holder $20\r王  \rYW864941235CN'),(8155,703301659002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','bayteo','teo_s@inwind.it','Matteo Schiavo','Via Giorgio La Pira, 3','MELENDUGNO','LE','ITALY','73026','3208908782','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 17:51:10',0,NULL,3,1,3,1,NULL,'bayteo\r申报 light stand  $15\r王\rRA022493934CN\r、'),(8156,662502161001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','jacoboo28','jjmarsa@hotmail.com','luis','camino viejo puerto lajas n.78A','spain','Canarias','SPAIN','35600','637392694','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 17:54:25',0,NULL,3,1,3,1,NULL,'jacoboo28\r4个灯泡      庄\rRA022493951CN\r、'),(8157,703305297002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','toors22','n_kozulins@inbox.lv','Nauris Kozulins','Maskavas 309 - dz.94','Riga','Latvia','LATVIA','LV-1063','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 17:59:41',0,NULL,3,1,2,1,NULL,'toors22\r庄'),(8158,662514107001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','photocat67','jaclancy@msn.com','Ann Clancy','865 Regal Path Ln','Decatur','GA','UNITED STATES','30030','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 18:19:05',0,NULL,3,1,1,1,NULL,'photocat67\r庄\r、'),(8159,662500502001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','myvnev','matyunin_yv@mail.ru','YURIY VITALIEVICH MATYUNIN','PODGORNOGO 28-3','NEVINNOMISSK','STAVROPOLSKIY','RUSSIAN FEDERATION','357112','78655477839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 18:31:13',0,NULL,3,1,2,1,NULL,'myvnev\r庄'),(8160,662523999001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',45.8,'hermeshine','salmon404','apuusti6@welho.com','Aki Puustinen','Kyösti Kallion tie 10 D 34','Helsinki','','FINLAND','00570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 18:40:57',0,NULL,3,1,3,1,NULL,'salmon404\r欧标\r庄\rRA022493917CN\r、'),(8161,773193763015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','rosalie_1701','rosalie1701@gmail.com','Rosalie Micallef','42 Caros<br>Triq l-Ghasel','Mosta','','MALTA','MST 2522','0035621437337','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 19:03:54',0,NULL,3,1,2,1,NULL,'rosalie_1701\r庄'),(8162,773210782015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',48,'hutongstore','chainsawpete2010peter','jackiestewart555@btinternet.com','peter bratley','1 mason street','workington','Cumbria','UNITED KINGDOM','ca143eq','0190063570','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-19 19:31:05',0,NULL,3,1,4,1,NULL,'chainsawpete2010peter\rlighting kit $20\r刘\rYW864941261CN'),(8163,703354885002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','bebelumin','jpmichael@free.fr','Jean-Pierre Michael','21 Grande rue de Chandelles','Coulombs','Centre','FRANCE','28210','0660761523','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 19:43:41',0,NULL,8,1,17,0,NULL,'bebelumin'),(8164,662553496001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','bebelumin','jpmichael@free.fr','Jean-Pierre Michael','21 Grande rue de Chandelles','Coulombs','Centre','FRANCE','28210','0660761523','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 19:43:42',0,NULL,3,1,4,1,NULL,'bebelumin\r717 155cm    1\r717手柄一个\rtripod $28\r王\rYW864941272CN'),(8165,773242593015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','art_udaya','sayhi_udaya@hotmail.com','Udaya','94 Roxeth Green Avenue','Harrow','Middlesex','UNITED KINGDOM','HA2 8AQ','02088648098','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 20:25:50',0,NULL,3,1,3,1,NULL,'art_udaya\r王\rRA022493259CN\r、'),(8166,662573042001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mikhail.kuperman','kuperman.mikhail@gmail.com','Mikhail Kuperman','Syezzhinskaya 37 21','Saint-Petersburg','','RUSSIAN FEDERATION','197198','+7 911 1527861','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 20:26:04',0,NULL,3,1,2,1,NULL,'mikhail.kuperman\r刘'),(8167,0,110674134738,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',0.99,'hermeshine','atlantic_xpress','9.99@comcast.net','Alexander Eychis','1075 Fawn Dr','Southampton','PA','UNITED STATES','18966-4310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 23:27:10',0,NULL,3,1,1,1,NULL,'atlantic_xpress\r庄\r、'),(8168,773322233015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',125,'hutongstore','davielilley','david@love4leisure.com','David Lilley','40 Heritgae Drive','Clowne','Derbyshire','UNITED KINGDOM','S434ST','01246819480','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-19 23:48:16',0,NULL,3,1,4,1,NULL,'davielilley\r（英标）\r庄\rlightingkit  $35\rYW864941283CN\r'),(8169,757623356016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','torbjorn.fjellestad','xrtno@hotmail.com','Torbjørn Fjellestad','Gamle Nøstegaten 13b','Bergen','','NORWAY','5010','+4748020062','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-19 23:49:08',0,NULL,3,1,4,1,NULL,'torbjorn.fjellestad\r（欧标）\rYW864941434CN\r'),(8170,703449047002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','mgrande','jbrhoward@aol.com','Jerry Howard','3302 N. Salida del Sol','chandler','AZ','UNITED STATES','85224','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 00:22:53',0,NULL,3,1,1,1,NULL,'mgrande\r庄\r、'),(8171,703454668002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','eokhan','okhanh@hotmail.com','okhan HORASANLI','yeni belediye is mrk. Mudanya<br>Kat 6 D:126','Bursa','Turkey','TURKEY','16000','00905445440411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 00:53:28',0,NULL,3,1,2,1,NULL,'eokhan\r庄\r、'),(8172,662658463001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','bonchoo','morekrit@hotmail.com','CHOONIAH LAO','59/72 NAKANIWAS48, Moo4,<br>NAKANIWAS STREET,','LADPROW','Bangkok','THAILAND','10230','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 01:25:00',0,NULL,3,1,3,1,NULL,'bonchoo\r庄\rRA022493996CN\r、'),(8173,773378464015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','bulapom','ebay@bulapom.com','Rajiv   Kumar','18 Dowland House<br>4 Holbrook Close','Enfield','Middlesex','UNITED KINGDOM','EN14UJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-20 02:56:18',0,NULL,3,1,2,1,NULL,'bulapom\r庄'),(8174,662690881001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',2,'AD1401',19.8,'hermeshine','maximk1985','viciouskms@mail.ru','Maxim Kurmanov','Свердлова 30-35','Новкузнецк','Кемеровская обл','RUSSIAN FEDERATION','654080','89133117362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 03:49:12',0,NULL,3,1,11,1,NULL,'maximk1985\r庄'),(8175,662710043001,110498795544,'New soft box photography studio lighting Set',2,'AKT016',194,'hermeshine','crocopk1','la_goran@yahoo.com','Goran Zeric','klepperdans 4','Capelle a/d Ijssel','','NETHERLANDS','2907rc','0627266858','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,7,1,18,0,NULL,'crocopk1\r欧标\r115w 220v 灯泡  4个\r灯架  2m   4\r柔光箱 50-70cm 单灯头  4 欧标\r包  2'),(8176,662712922001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','axonalex','alexbycomp@gmail.com','Alexandr Axon','pr. Mira 180 / 5','Chernigov','','UKRAINE','14037','+380634690949','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 06:14:24',0,NULL,3,1,3,1,NULL,'axonalex\r庄\rRA117739990CN'),(8177,662714655001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','crocopk1','la_goran@yahoo.com','Goran Zeric','klepperdans 4','Capelle a/d Ijssel','','NETHERLANDS','2907rc','0627266858','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'crocopk1\r'),(8178,662719624001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','eddyhuang','simply-eddy@hotmail.com','Eddy Huang','Block 233 Hougang Street 21 #04-340','default','','SINGAPORE','530233','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 06:47:03',0,NULL,3,0,3,1,NULL,'eddyhuang\r58mm 3-stage Rubber lens hood (2 pieces)\r62mm 3-stage Rubber lens hood (2 pieces)\r67mm 3-stage Rubber lens hood (2 pieces)\r72mm 3-stage Rubber lens hood (2 pieces)\r77mm 3-stage Rubber lens hood (2 pieces)\rRA117739986CN\r\r'),(8179,757730798016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','sweetycatone','piocam@maltanet.net','pio camilleri','nid d\'amour<br>triq Francis Attard','naxxar','malta europe','MALTA','nxr1170','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 07:05:36',0,NULL,3,1,2,1,NULL,'sweetycatone\r\\'),(8180,703561252002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','ribolov','tigr_2002@ukr.net','Andrii Oliinyk','Politehnichna 31b<br>apartment 9','Kiev','','UKRAINE','03055','+380675086636','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 09:33:14',0,NULL,3,1,2,1,NULL,'ribolov\r刘\\'),(8181,754613997016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','magic_yogie_bear','elmos_home@hotmail.com','Murray Orr','4/74 Pohlman Street','Southport','Queensland','AUSTRALIA','4215','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-20 09:37:02',0,NULL,3,1,4,1,NULL,'magic_yogie_bear\r澳标  \r布换成白色的   刘\rYW864941305CN\r'),(8182,703565290002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','vmyr','vladymyrshcherbina@gmail.com','Volodymyr Shcherbina','Kryvoriz\'ka 33-21','Zaporizhzhya','UA','UKRAINE','69039','80612659217','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 09:58:23',0,NULL,3,1,3,1,NULL,'vmyr\r庄\rRA117728396CN\r\\'),(8183,662757639001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','xanthulina','maria_gounari@hotmail.com','Maria Gounari','Solokfleous 5','Nicosia','Palluriotissa','CYPRUS','1046','0035799828975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:03:53',0,NULL,3,1,2,1,NULL,'xanthulina\r刘\\'),(8184,658103543001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','slimyfishy','frazierphotography@gmail.com','Ian S Frazier','765 Agate St<br>Apt 7','San Diego','CA','UNITED STATES','92109-1046','(858) 926-8299','NoPaymentFailure','CheckoutComplete','Other','2011-04-20 10:14:07',0,NULL,3,1,1,1,NULL,'slimyfishy\r庄\r、'),(8185,662770869001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','bedstefarbil','abe.bremer@mail.dk','Benthe Sørensen','Præstevænget 2A<br>Guderup','6430 Nordborg','Sønderjylland','DENMARK','6430','74459322','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 11:05:44',0,NULL,3,0,3,1,NULL,'bedstefarbil\r背心 Nikon 老款 - L\r刘\rRA117728379CN\r\\'),(8186,703587805002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','tjhunni','tj_thinktomorrowsok@yahoo.com','Trudy Scarborough','54 Morris Drive','Billingshurst','West Sussex','UNITED KINGDOM','RH14 9SF','07799741034','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 11:33:01',0,NULL,3,0,3,1,NULL,'tjhunni\r庄XL\rRA117728382CN\r\\'),(8187,662784844001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','iamlado','vorobyevvladimir@mail.ru','Vladimir Vorobyev','Mira 34/1 kv.11<br>tel +7 (701) 747-69-20','Astana','Aqmola obl','KAZAKHSTAN','010000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 12:04:18',0,NULL,3,1,3,1,NULL,'iamlado\r刘\rRA117728334CN\r\\'),(8188,757824259016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',2,'AA1301',3.74,'hutongstore','craigibear','paddygahan@yahoo.co.uk','Pat Gahan','184 Seven Oaks','Sarsfield Road','Dublin','IRELAND','10','0857290252','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 13:34:24',0,NULL,8,1,17,0,NULL,'craigibear'),(8189,773526776015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','craigibear','paddygahan@yahoo.co.uk','Pat Gahan','184 Seven Oaks','Sarsfield Road','Dublin','IRELAND','10','0857290252','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 13:34:24',0,NULL,3,1,2,1,NULL,'craigibear\r58mm Canon 镜头盖    2\r58mm 橡胶遮光罩   1\r庄\\'),(8190,773545700015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','ale23bee','blue_notorius@yahoo.it','Alessandra Bettin','Via Loredan, 43','Stra\'','VE','ITALY','30039','049-502819','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 13:58:26',0,NULL,8,1,17,0,NULL,'ale23bee'),(8191,773546070015,250599986868,'Large size Neoprene Lens Pouch Case 90mm x 220mm',1,'AC1203',3.28,'hutongstore','ale23bee','blue_notorius@yahoo.it','Alessandra Bettin','Via Loredan, 43','Stra\'','VE','ITALY','30039','049-502819','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 13:58:26',0,NULL,3,1,2,1,NULL,'ale23bee\rCanon 小号胆包   1\r大号镜头筒    1\r刘\\'),(8192,662817883001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','webixe','webmaster@webixe.com','Pierre-Olivier Beaudry','1842 préfontaine','montreal','QC','CANADA','h1w2p1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 14:09:54',0,NULL,3,1,3,1,NULL,'webixe\r庄\rRA117728405CN\r\\'),(8193,773596546015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','nbrimmer','neilbrimmer@gmail.com','Neil Brimmer','1/2, Paradise Flats,<br>Triq L-Ahwa Zammit,','Qormi','-','MALTA','QRM05','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 16:06:29',0,NULL,3,1,2,1,NULL,'nbrimmer\r数量： 2\r刘\\'),(8194,661603036001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','abnsariel','danbakov@globalnet.hr','Daniel Bakovic','Antuna Stipancica 24','Zagreb','','CROATIA','10000','3831697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 16:36:55',0,NULL,3,1,2,1,NULL,'abnsariel\r庄、'),(8195,662862732001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',4.95,'hermeshine','microlab629648','witazzew@yandex.ru','Natalia Ulanova','ul. Nikulinskaya-23 korp-2 kv.547','Moscow','','RUSSIAN FEDERATION','119602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 16:42:42',0,NULL,3,1,2,1,NULL,'microlab629648\r刘\r绿叶 CPL  58mm   1\r绿叶 CPL  52mm   1\r、'),(8196,662862050001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','microlab629648','witazzew@yandex.ru','Natalia Ulanova','ul. Nikulinskaya-23 korp-2 kv.547','Moscow','','RUSSIAN FEDERATION','119602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 16:42:42',0,NULL,8,1,17,0,NULL,'microlab629648\r'),(8197,773625362015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','deano1793','beadleboy@hotmail.com','Dean Scource','30 Bridges View<br>Bensham','Gateshead','Tyne and Wear','UNITED KINGDOM','NE8 1NZ','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-20 17:11:43',0,NULL,3,1,4,1,NULL,'deano1793\rlighting kit $26\r庄\r英标\rYW864941342CN'),(8198,703680806002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','wisky_studio','wisky@wisky.ru','Andrey Guryanov','Komsomolskaya st. 37, ap 147','Kirov','','RUSSIAN FEDERATION','610001','+7(922)995-7575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:30:18',0,NULL,3,1,2,1,NULL,'wisky_studio\r庄、'),(8199,661196487018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','zhychologic','zheett@hotmail.com','zhychologic Shop','P.O.Box 301<br>Pattaya Post Office','Pattaya City','Chon Buri','THAILAND','20260','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-20 17:30:37',0,NULL,3,1,6,1,NULL,'zhychologic\r！！！顺道给他加黑白背景布的边角料各一块——客户要样品。  刘\rEE442466514CN\r'),(8200,703701960002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',4,'AE3102',31.56,'hermeshine','yanivnadav19722','yanivnadav1@gmail.com','yaniv nadav','ha\'ela 48<br>06','maale adumim','maale adumim','ISRAEL','98534','97225903987','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:57:18',0,NULL,3,1,3,1,NULL,'yanivnadav19722\r刘\rRA117728317CN\r\\'),(8201,662894897001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','panssari','panzerwag@gmail.com','Jukka-Pekka Berg','Perkiönkatu 85 A 15','Tampere','','FINLAND','33900','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:57:30',0,NULL,3,1,2,1,NULL,'panssari\r庄、'),(8202,703715649002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','sl2007i','shlomi-levi@usa.net','SHLOMI LEVI','P.O BOX 624','HOLON','','ISRAEL','58105','050-7773987','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 18:21:52',0,NULL,3,1,2,1,NULL,'sl2007i\r刘、'),(8203,662923012001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',5,'AC3301',72.8,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 18:59:35',0,NULL,3,1,5,1,NULL,'nixette_nixette\r庄\rCP226344406CN\r'),(8204,701119968002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','shafraleks','ka_za@walla.co.il','Aleksei Shafranov','Rosmarin 39 apt. 21','Jerusalem','','ISRAEL','93743','+972547977996','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 19:43:37',0,NULL,3,1,2,1,NULL,'shafraleks\r刘、'),(8205,702245354002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','filmstudio2010','zurafilm@yahoo.com','Zurab Katamadze','6909 6th Ave<br>Apt 1R','Brooklyn','NY','UNITED STATES','11209','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 09:19:35',0,NULL,7,0,18,0,NULL,'filmstudio2010'),(8206,662997972001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','subaruoleg','olegsubaru@yahoo.com','Oleg Pereverzy','Yarden 25/15','Nazareth illit','','ISRAEL','17850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 22:13:34',0,NULL,3,1,2,1,NULL,'subaruoleg\r庄、'),(8207,703815761002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 22:37:36',0,NULL,3,1,4,1,NULL,'leifs123\r（欧标）\r申报：30$，Lighting kit\r1.6×2.1m 背景布   3  （一块白的，两块黑色）\r2mx 1.6m背景架    1\r2m灯架    2\r反光伞      2\r双灯头      2\r115w 220v  灯泡    4\r灯架包     1\r庄\rYW864941390CN\r'),(8208,663004617001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 22:40:26',0,NULL,8,1,17,0,NULL,'leifs123\r'),(8209,663005162001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','lagaffe2008','fabiomcfonseca@yahoo.com.br','Fabio Fonseca','Rua Sylvio da Rocha Pollis<br>201 bloco04 apt.908','Rio de Janeiro','RJ - Barra da Tijuca','BRAZIL','22793-395','55-21-91915953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 22:41:30',0,NULL,8,1,17,0,NULL,'lagaffe2008\r'),(8210,703817381002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','lagaffe2008','fabiomcfonseca@yahoo.com.br','Fabio Fonseca','Rua Sylvio da Rocha Pollis<br>201 bloco04 apt.908','Rio de Janeiro','RJ - Barra da Tijuca','BRAZIL','22793-395','55-21-91915953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 22:41:31',0,NULL,3,1,5,1,NULL,'lagaffe2008\r庄\r2m灯架   2\rB座    2\r柔光伞   2\r反光伞   1\r庄\rCP226344410CN\r'),(8211,663019245001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','horse_trailer','lmckay1@cogeco.ca','Lawrence H McKay','679 Vanier St.','Windsor','ON','CANADA','N8X3E4','(519) 250-8226','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 00:19:55',0,NULL,3,1,3,1,NULL,'horse_trailer\r刘\rXL\rRA117728365CN\r\\'),(8213,773850882015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','nunomls','cabacita@gmail.com','NUNO SANTOS','DOMUS PACIS<br>RUA SAO VICENTE DE PAULO, 32','FÁTIMA','PORTUGAL','PORTUGAL','2495-438','00351916309872','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 02:27:08',0,NULL,3,1,2,1,NULL,'nunomls\r庄、'),(8212,703870002002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','katchlightphotog','prwebster@comcast.net','patrick webster','2865 Minuet Ave.','West Valley City','UT','UNITED STATES','84119','','NoPaymentFailure','CheckoutComplete','Other','2011-04-21 02:15:00',0,NULL,3,1,3,1,NULL,'katchlightphotog\r庄\rRA117728325CN\r\\'),(8214,663059739001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','vincevincevincevincevince','vince.dyer@gmail.com','Vincent Dyer','30 Jackson st<br>Coorparoo','Brisbane','Queensland','AUSTRALIA','4151','0738436911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 02:36:21',0,NULL,3,1,2,1,NULL,'vincevincevincevincevince\r刘、'),(8215,663086135001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','cleosantana2009','cleosantana2@yahoo.com.br','CLEÓMENES SOARES SANTANA','AV: JOÃO DE BARROS ,201 APTº 901<br>BOA VISTA','RECIFE','PERNAMBUCO','BRAZIL','50050-180','81 3088.3027','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 05:01:37',0,NULL,3,1,2,1,NULL,'cleosantana2009'),(8216,703902531002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',26.8,'hermeshine','bmonye','bjmonye@mobileemail.vodafonesa.co.za','Bonolo Monye','31 Sunesis Greenhills Estate<br>corner Pine and Robina road','Greenhills','Gauteng','SOUTH AFRICA','1759','+27829552527','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 05:26:50',0,NULL,3,1,3,1,' RA117739646CN\r','bmonye\r摄影背心 冬夏  L    1\r灯架 84cm   1\r王'),(8217,663090242001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','korcule-kolieska.sk','alain.roger@gmail.com','alain roger','Helsinska 17','kosice','','SLOVAK REPUBLIC','04013','0904880544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 05:31:24',0,NULL,3,1,2,1,NULL,'korcule-kolieska.sk'),(8218,663090999001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','planetshop','planetshop@rcn.com','Peter Miller','52 W 91st St','New York','NY','UNITED STATES','10024-1418','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 05:52:14',0,NULL,3,1,1,1,NULL,'planetshop'),(8219,663096317001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','mitokondrium0621','koszegi89@gmail.com','Tamás Kőszegi','Vajda János utca 25','Velence','Fejér megye','HUNGARY','2481','36307180472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 06:10:00',0,NULL,3,1,3,1,NULL,'mitokondrium0621\rRA022493735CN'),(8220,703947669002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','dvdcollector2008','ajshih@gmail.com','Andrew Shih','138 White Branch Ct','Buffalo Grove','IL','UNITED STATES','60089-1595','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 09:22:38',0,NULL,3,1,1,1,NULL,'dvdcollector2008\r刘\\'),(8221,703951735002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','wolvf','wolvf@aol.com','A l Jefferson','128 Hazelton St','Ridgefield Park','NJ','UNITED STATES','07660-1141','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 09:42:51',0,NULL,3,1,1,1,NULL,'wolvf\r庄\\'),(8222,703952460002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','dannir2010','dannir10@gmail.com','Daniel Israel','6 Moran St.','Kiryat Tivon','Israel','ISRAEL','36530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 09:50:02',0,NULL,3,1,11,1,NULL,'dannir2010\r刘\r\\'),(8223,663145169001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','donalex24','mamont24@gmail.com','Alexander Donin','Hasukah, 12b, 1','Rishon Lecion','','ISRAEL','75491','(054) 4548338','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 10:29:30',0,NULL,3,0,3,1,NULL,'donalex24\r庄\rRA117739147CN\r\\'),(8224,663158993001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','spets1980','bindasne@mail.ru','Andrey Spetsialnyy','Odesskaya, 48, \"B\"<br>of. 206, Rusfinance','Krasnodar','Krasnodar region','RUSSIAN FEDERATION','350020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 11:40:45',0,NULL,3,1,3,1,NULL,'spets1980\r刘\rRA117739155CN\r\\'),(8225,663160046001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','galser71','galser2@mail.ru','Siarhei Halkin','Karatkevich street, 18/1/97','Vitebsk','Belarus','BELARUS','210038','+375-29-5151763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 11:56:37',0,NULL,3,1,3,1,NULL,'galser71\r庄\rRA117739062CN\r\\'),(8226,758284231016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','fenwick2362','shfenwick@talktalk.net','STEPHEN FENWICK','29 St John Street','Retford','Nottinghamshire','UNITED KINGDOM','DN22 6JY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 12:08:48',0,NULL,3,1,2,1,NULL,'fenwick2362\r刘\\'),(8227,663171445001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','budda001','isaev.foto@gmail.com','Isaeva Tatyana Timofeevna','Leni Golikova d.28 kv.15','St-Petersburg.','','RUSSIAN FEDERATION','198262','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 12:39:13',0,NULL,8,1,17,0,NULL,'budda001'),(8228,703987245002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',6,'AA1310',32.94,'hermeshine','budda001','isaev.foto@gmail.com','Isaeva Tatyana Timofeevna','Leni Golikova d.28 kv.15','St-Petersburg.','','RUSSIAN FEDERATION','198262','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 12:39:13',0,NULL,8,1,17,0,NULL,'budda001'),(8229,703986966002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',5,'AA2203',17.5,'hermeshine','budda001','isaev.foto@gmail.com','Isaeva Tatyana Timofeevna','Leni Golikova d.28 kv.15','St-Petersburg.','','RUSSIAN FEDERATION','198262','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 12:39:14',0,NULL,3,1,3,1,NULL,'budda001\rlenspen               6\r爵影红外 sony    5\r橡胶遮光罩          10（尺寸如下）\r------\r55mm - 2 \r62mm - 2\r67mm - 2 \r72mm - 2 \r77mm - 2\r刘     790\rRA117739076CN\r\\'),(8230,758305353016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','ephovid','info@ephos.gr','ΓΙΩΡΓΟΣ ΣΕΪΡΛΗΣ','ΒΟΥΛΗΣ 16','ΑΘΗΝΑ','προεπιλογή','GREECE','11563','+302103237508','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-21 13:20:59',0,NULL,3,1,4,1,'YW864941386CN ','ephovid\r刘(欧标）\rGeorge Seirlis\r16 Voulis str \r10563 Athens Greece\rtel +30 210 3237508\r\r'),(8231,704007712002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','bmonye','bjmonye@mobileemail.vodafonesa.co.za','Bonolo Monye','31 Sunesis Greenhills Estate<br>corner Pine and Robina road','Greenhills','Gauteng','SOUTH AFRICA','1759','+27829552527','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 14:00:34',0,NULL,8,1,17,0,NULL,'bmonye'),(8232,704015164002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','erictran911','erictran911@yahoo.com','eric tran','2548 McLaughlin Ave','San Jose','CA','UNITED STATES','95121-2749','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 14:18:27',0,NULL,3,1,1,1,NULL,'erictran911\r庄\\'),(8233,758325475016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','joruba75','joruba@freemail.hu','Zsolt Biczó','Gárdonyi G. 60.','Kozármisleny','Baranya','HUNGARY','7761','+36/30-520-0338','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 14:20:19',0,NULL,3,1,2,1,NULL,'joruba75\r刘\\'),(8234,704016546002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','eladher81','eladher@gmail.com','elad herskovici','yafe nof 39/7<br>22208','nahariyya','nahariyya','ISRAEL','22208','0523413111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 14:29:42',0,NULL,3,1,2,1,NULL,'eladher81\r庄\\'),(8235,774042176015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','albas1591','alan@baseley.name','Alan Baseley','46 Woodburn Avenue, Earlsheaton','Dewsbury','West Yorkshire','UNITED KINGDOM','WF12 8LJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 14:43:23',0,NULL,3,1,2,1,NULL,'albas1591\r刘\\'),(8236,663213296001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','dariopenadario','dariopena@hotmail.com','Dario Duraes Ferreira Pena','Rua Emilio Pinheiro Barros, 239<br>Apt. 301','Belo Horizonte','Minas Gerais','BRAZIL','30360130','(31) 3297-5188','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 15:05:35',0,NULL,3,1,2,1,NULL,'dariopenadario\r庄\\'),(8237,0,120711872733,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.99,'hermeshine','impal864','impal864@aol.com','Tim Stacey','935 Lotz Way','Suisun City','CA','UNITED STATES','94585','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 15:14:48',0,NULL,3,1,1,1,NULL,'impal864\r刘\\'),(8238,773768395015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 15:23:16',0,NULL,8,1,17,0,NULL,'turisam'),(8239,758064684016,260660053713,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',7.8,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 15:23:17',0,NULL,8,1,17,0,NULL,'turisam'),(8240,773768212015,250692237477,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',7.75,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 15:23:17',0,NULL,8,1,17,0,NULL,'turisam'),(8241,773767986015,250692240278,'Remote Control Cord Shutter Nikon D80 D70s​ MC-DC1',1,'AA3208',2.98,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 15:23:18',0,NULL,3,1,3,1,'RA117739907CN\r ','turisam\r反光伞  1\r单灯头 欧标  1\r爵影快门线 RS-N2   1\r倒影板（白黑）    1\r刘\r'),(8242,663225498001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','falkone2001','tfalkovskyy@yahoo.co.uk','Taras Falkovskyy','8 Brodivska St.','Zolochiv','Lviv','UKRAINE','80700','+380973149336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 16:00:56',0,NULL,3,1,3,1,NULL,'falkone2001\r注意是铁接口那个\rRA117739938CN\r、'),(8243,0,110674973270,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',3.1,'hermeshine','el-supremo','peter.haas@gmail.com','Peter Haas','144 S 3rd St<br>Unit 401','San Jose','CA','UNITED STATES','95112','(408) 230-8703','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 16:11:37',0,NULL,3,1,1,1,NULL,'el-supremo\r刘\\'),(8244,0,120711872764,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',0.99,'hermeshine','naturesorigin','katkat@gmail.com','Joseph Kyo','9 Bienvenu Dr','Foothill Ranch','CA','UNITED STATES','92610','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-04-21 16:28:07',0,NULL,3,1,1,1,NULL,'naturesorigin\r庄\\'),(8245,0,110674973243,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',1.04,'hermeshine','mtdiablo1','steve.sorgatz@gmail.com','Stephen Sorgatz','26 Millbrook Ct','Danville','CA','UNITED STATES','94526','','NoPaymentFailure','CheckoutComplete','Other','2011-04-21 16:39:14',0,NULL,3,1,1,1,NULL,'mtdiablo1\r王\r\\'),(8246,0,120711872399,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',1.04,'hermeshine','cutiger99','kaktug@triad.rr.com','Kurt B. Aktug','7755 Fording Bridge Rd.','Kernersville','NC','UNITED STATES','27284','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 16:50:28',0,NULL,3,1,1,1,NULL,'cutiger99\r庄\\'),(8247,0,120711872623,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',0.99,'hermeshine','fxstchip','chipwarren@sbcglobal.net','Chip T Warren','3238 Cottonwood Dr','Saint Charles','MO','UNITED STATES','63301-0108','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 16:54:17',0,NULL,3,1,1,1,NULL,'fxstchip\r刘\\'),(8248,663256140001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','sjon7050','gaudydivinephotography@yahoo.com','Simone Jones','P.O. Box 2898','Sanford','FL','UNITED STATES','32772-2898','(407) 233-9147','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 17:21:01',0,NULL,3,1,1,1,NULL,'sjon7050\r庄\\58mm'),(8249,0,110674972659,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',1.29,'hermeshine','davichinanyc','davichina@gmail.com','FEN CHEN','8870 62nd DR','REGO PARK','NY','UNITED STATES','11374','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 17:22:11',0,NULL,3,1,1,1,NULL,'davichinanyc\r刘\\'),(8250,701640536002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 17:35:24',0,NULL,3,1,2,1,NULL,'princessvideo\r庄、'),(8251,704080854002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','alex-lifan','alexl61@walla.co.il','Alex Liflyandchik','Liber Ze\'ev 1/21','Netanya','','ISRAEL','42524','+(972)524453838','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 17:49:25',0,NULL,3,1,2,1,NULL,'alex-lifan\r刘\\'),(8252,704100404002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','karnag9','blade-master2008@yandex.ru','Sergey Druzhin','M. Zhukova 16-3, 41','Tula','Tul\'skaya obl','RUSSIAN FEDERATION','300036','89038414422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 18:40:46',0,NULL,3,1,2,1,NULL,'karnag9\r庄、'),(8253,0,120711872457,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',1.05,'hermeshine','2903jmp3','mkauf@charter.net','Matthew Kaufman','2903 S 9th St','Sheboygan','WI','UNITED STATES','53081-6843','(920) 452-1404','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 19:02:06',0,NULL,3,1,1,1,NULL,'2903jmp3\r刘\\'),(8254,704086006002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',61.99,'hermeshine','restudiorml','rpedrito@hotmail.com','RAUL MARTORELL LURBE','C/ PURISIMA, 12 BAJO','L\'ELIANA','Comunidad Valenciana','SPAIN','46183','647094821','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 19:16:16',0,NULL,3,1,4,1,' ','restudiorml\r庄\rYW864941423CN\r、'),(8255,663313134001,110583709805,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',25,'hermeshine','vivekiny2k','vivek.cinci@gmail.com','vivek yadav','7781 clearwater ct','mason','OH','UNITED STATES','45040-9593','(513) 237-1947','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 19:48:26',0,NULL,3,1,1,1,NULL,'vivekiny2k\r刘\r58mm cpl   1\r58mm ND8   1\r58mm 渐变灰   1\r4片装的滤镜袋   1\r（不发近摄镜了）'),(8256,704145128002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','oletangen','fjern_kontrollen@hotmail.com','Marianne Borg','Paasche Aasensvei 9','default','Hønefoss','NORWAY','3514','99042651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 20:31:15',0,NULL,3,1,3,1,NULL,'oletangen\r庄\rRA022493758CN\r\\'),(8257,704141581002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','themetalgod400','firebird.formula.400@gmail.com','Runar Hanssen','Skog','Hamnvik','','NORWAY','9450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 20:33:46',0,NULL,3,1,3,1,NULL,'themetalgod400\r刘\rRA117739915CN\r、'),(8258,663337229001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','onlinephotostuff','onlinepstuff@gmail.com','ONLINE PHOTO STUFF','525 EAST OHIO ST','PITTSBURGH','PA','UNITED STATES','15212','(412) 231-1717','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 20:55:26',0,NULL,3,1,1,1,NULL,'onlinephotostuff\r庄\\'),(8259,663344411001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','sergport13','portyannikoff@mail.ru','Sergei Portyannikov','Dubovskogo 46<br>102','Novocherkassk','Rostov Region','RUSSIAN FEDERATION','346400','+79198780414','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 21:19:02',0,NULL,3,1,3,1,NULL,'sergport13\r王\rRA117728277CN\r\\'),(8260,663351545001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','solsuny','solsuny@gmail.com','Soledad Ruiz y Blanco','Monroe 4050 1º B','Ciudad de Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 21:40:56',0,NULL,3,1,2,1,NULL,'solsuny\r庄\\'),(8261,758524225016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','nicola.nordin','nicolanordin@hotmail.com','Nicola Nordin','Bergdalen 8','Stockholm','Sundbyberg','SWEDEN','17279','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 22:07:57',0,NULL,3,1,3,1,NULL,'nicola.nordin\r申报：GIFT\r刘\rRA117739120CN\r\\'),(8262,704182920002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','taras9889','ragip.candan@gmail.com','Ragip Candan','6445 sok.18/14 Yali mah.Karsiyaka','IZMIR','NA','TURKEY','35550','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 22:24:40',0,NULL,3,1,2,1,NULL,'taras9889\r庄\\'),(8263,774250776015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','nathsuell2002','nathaliasuellen.com@gmail.com','nathalia suellen','Rua 756, nº 81 - Casa de Pedra','Volta Redonda','Rio de Janeiro','BRAZIL','27257220','99642555','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-21 22:48:22',0,NULL,3,1,5,1,NULL,'nathsuell2002\r布为：灰+黑\r王\rCP226344468CN'),(8264,0,120711872890,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.25,'hermeshine','george35209','gbrowder@gmail.com','George Browder','2041 S Moonlit Pt','Homosassa','FL','UNITED STATES','34448-2164','(352) 621-9108','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'george35209\r王\\'),(8265,663377522001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','c_beach2','cbeach2@embarqmail.com','Clarence Beach','1239 Maple View Dr','Charlottesville','VA','UNITED STATES','22902','(434) 979-3236','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 23:18:33',0,NULL,3,1,1,1,NULL,'c_beach2\r庄\\'),(8266,663384798001,110419742275,'Green.L 62mm Neutral Density ND8 Filter ND 8 62',1,'AE2311',6.2,'hermeshine','studiovirtus','comercial@studiovirtus.com.br','Marcelo Ramon','Rua Alfredo Mendes da Silva, 327-apto 61','São paulo','SP','BRAZIL','05525000','551128672365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 23:53:43',0,NULL,3,1,2,1,NULL,'studiovirtus\r王、'),(8267,704218248002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','dmcd6897','solidsoul19@hotmail.com','Daniel McDonald','229-108 Elliott st.','Whitehorse','YT','CANADA','Y1A 6C4','(867) 334-9107','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 00:47:00',0,NULL,3,0,3,1,NULL,'dmcd6897\r庄2XL\rRA117728263CN\r\\'),(8268,704232821002,120619188563,'NEW 67mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT046',30,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 01:43:35',0,NULL,3,1,2,1,NULL,'dvdguychatter2\r王\r、'),(8269,663411895001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','raulteofilo','pr.rauljesus@gmail.com','Raul Jesus','rua fernando pessoa nº59 rc','Forte da Casa','Vila franca de xira','PORTUGAL','2625-416','0351 934483917','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 01:49:27',0,NULL,3,1,2,1,NULL,'raulteofilo\r王、'),(8270,0,120711872607,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',0.99,'hermeshine','arclu88','lupeng0515@gmail.com','Peng  Lu','3101 Beau Jardin Dr<br>Apt 302','Lansing','MI','UNITED STATES','48910-8537','(517) 643-6779','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 02:01:16',0,NULL,3,1,1,1,NULL,'arclu88\r王\\'),(8271,774314252015,250692239955,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',23,'hutongstore','gazihysa','ghysa@yahoo.com','Gus Hysa','299 Adams Ave','Staten Island','NY','UNITED STATES','10306','(917) 567-1200','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 02:28:28',0,NULL,3,1,3,1,NULL,'gazihysa\r王\rRA117739133CN\r\\'),(8272,0,110674972593,'New 55mm ring adapter replacement for cokin P series',1,'AA2209',1.25,'hermeshine','richgian','richgian@frii.com','Richard Giansiracusa','891 Eagle Ridge Ct','Loveland','CO','UNITED STATES','80537','(970) 663-0316','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 03:13:48',0,NULL,3,1,1,1,NULL,'richgian\r王\\'),(8273,663439636001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',20,'hermeshine','5076andrew','ajmoylan2@optusnet.com.au','Andrew Moylan','PO Box 632<br>Forestville','sydney','New South Wales','AUSTRALIA','2087','0294511097','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-04-22 04:03:26',0,NULL,3,1,2,1,NULL,'5076andrew\r\\'),(8274,704264502002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','tc123micthis','randomgarland@hotmail.com','Tim Cofield','8503 Hilltop Dr','Ooltewah','TN','UNITED STATES','37363-6841','(423) 715-5183','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 04:04:35',0,NULL,3,1,1,1,NULL,'tc123micthis\r\\'),(8275,663448719001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','mirosajnic77','miro@grafika-grafoprint.hr','miroslav sajnic','gacka 12','zagreb','bestovje','CROATIA','10437','00385912019822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 05:12:26',0,NULL,3,1,3,1,NULL,'mirosajnic77\r庄\rRA117740009CN\r、'),(8276,704293374002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','cks_f','cks_f@yahoo.com.my','Fazdly Kamal','No 383 Jalan KS6<br>Kulim Square','Lunas','Kedah','MALAYSIA','09600','0193314930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 07:11:52',0,NULL,3,1,2,1,NULL,'cks_f\r、'),(8277,663305212001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',6.98,'hermeshine','agastyaalfath','agastya.alfath@gmail.com','Agastya Fauzan Alfath','Perumahan Reni Jaya Blok A5 No 5<br>Pondok Petir, Sawangan','Depok','Jawa Barat','INDONESIA','16517','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 08:04:38',0,NULL,3,1,2,1,NULL,'agastyaalfath\rnikon-52反接环   1\r52-52 双阳环   1\r、'),(8278,758671419016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','camilleri4','lar_eri@hotmail.com','Natalie Camilleri','29, Luigi Billion Street','Pembroke','Malta','MALTA','PBK1372','0035621372804','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 08:06:10',0,NULL,3,1,2,1,NULL,'camilleri4\r\\'),(8279,704307317002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','chappo59','karl.genser@aon.at','Karl Genser','ORF Studio Steiermark<br>Marburgerstrasse 20','Graz','','AUSTRIA','8042','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 08:19:07',0,NULL,3,0,3,1,'RA117739924CN ','chappo59\rL  \r'),(8280,663495009001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','carlosss18','carlosss18ro@yahoo.com','Marius Florin Stan','str. Prieteniei 8, bl. N, sc. A, ap. 7<br>Constanta','Constanta','','ROMANIA','900303','0040726365260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 09:13:19',0,NULL,3,1,3,1,' RA117739796CN\r','carlosss18\r刘'),(8281,663505336001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','redback5112','bridgewater5112@optusnet.com.au','John Bridgewater','17 Halsey Road, Elizabeth East','Adelaide','South Australia','AUSTRALIA','5112','0882871797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 09:52:38',0,NULL,3,1,2,1,NULL,'redback5112\r刘'),(8282,704331617002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','ashisusu11','ashisusu@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','3332205045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 10:02:06',0,NULL,3,1,3,1,' RA117739717CN\r','ashisusu11\r欧标\rlight $15\r刘'),(8283,758738928016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',2,'AA2209',4.5,'hutongstore','8877thomasb','tb.1@blueyonder.co.uk','Thomas Boyle','59 Byron Street<br>G/R','Dundee','Angus','UNITED KINGDOM','DD3 6QU','01382804286','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-22 12:01:30',0,NULL,3,1,2,1,NULL,'8877thomasb\r刘'),(8284,704366237002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','alkulovefoto','almudenafotografia@gmail.com','Almudena Lara','Azorin,10,4A<br>18003','Granada','Andalucía Ceuta y Melilla','SPAIN','18003','653308005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 12:28:59',0,NULL,3,1,3,1,'RA117739629CN\r ','alkulovefoto\r刘'),(8285,774468000015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','photographer1506','edwarddullard@gmail.com','EDWARD DULLARD','13 DE LA SALLE PLACE','KILKENNY CITY','COUNTY KILKENNY','IRELAND','056','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 12:29:51',0,NULL,3,1,2,1,NULL,'photographer1506\r王'),(8286,663454773001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','talmerli','talmerli@yahoo.com','Todd Almerli','570 E Slifer St','Portage','WI','UNITED STATES','53901-1257','(608) 408-7659','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 12:53:44',0,NULL,3,1,1,1,NULL,'talmerli\r王'),(8287,663552806001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1304',5,'hermeshine','foxfordshrimp','desp27@wanadoo.fr','Pascal Despeaux','6 route neuve<br>Le Bourg','Asnières par Cormeilles','Haute-Normandie','FRANCE','27260','06 08 76 54 30','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 13:07:03',0,NULL,3,1,2,1,NULL,'foxfordshrimp\r王'),(8288,704381706002,120654651653,'Pro Photo Vest Blue for Nikon D90 D300s D7000 D80  user',1,'AA2117',32,'hermeshine','kmar69888','keith.martinet@gmail.com','Keith Martinet','13 Ahwahnee Street<br>P.O. Box 708','San Juan Bautista','CA','UNITED STATES','95045','(408) 710-2339','NoPaymentFailure','CheckoutComplete','Other','2011-04-22 13:23:52',0,NULL,3,0,1,1,NULL,'kmar69888\rXXL\r王'),(8289,704388497002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','denskiter','4elogram@mail.ru','Denis Skiter','Leningradskiy 3-64','New Urengoy','Tumenskaya obl','RUSSIAN FEDERATION','629305','951-992-9200','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 13:57:58',0,NULL,3,1,3,1,'RA117739632CN\r ','denskiter\r王'),(8290,663568012001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','crni1985','ivan_crnjak@net.hr','Ivan Crnjak','Karlovacka 8','Sesvete','ZG','CROATIA','10360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 14:02:10',0,NULL,8,1,17,0,NULL,'crni1985'),(8291,663569373001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','crni1985','ivan_crnjak@net.hr','Ivan Crnjak','Karlovacka 8','Sesvete','ZG','CROATIA','10360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 14:07:09',0,NULL,8,1,17,0,NULL,'crni1985\r'),(8292,0,110674973177,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',5.94,'hermeshine','eloquentimages','larrya.harrison@gmail.com','Larry Harrison','197 Pinelli Dr','Piscataway','NJ','UNITED STATES','08854','(732) 858-1699','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 15:07:34',0,NULL,3,1,1,1,NULL,'eloquentimages\r49mm 接口环  1\r52mm 接口环  1\r62mm 接口环  1\r72mm 接口环  1\r77mm 接口环  1\r82mm 接口环  1\r刘\r'),(8293,704429142002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','b3tho','herberth007@gmail.com','Herberth Bezerra','S.Q.N 411 Bloco F apto. 303','Brasília','Distrito Federal','BRAZIL','70.866-060','06181751965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:04:09',0,NULL,8,1,17,0,NULL,'b3tho'),(8294,663603681001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','b3tho','herberth007@gmail.com','Herberth Bezerra','S.Q.N 411 Bloco F apto. 303','Brasília','Distrito Federal','BRAZIL','70.866-060','06181751965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:04:09',0,NULL,3,1,2,1,NULL,'b3tho\r橡胶遮光罩 67mm  1\r橡胶遮光罩 52mm  1\r王'),(8295,663606765001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','susanhaynes','susan@haynesaudio.com','Susan Haynes','532 N K St','Livermore','CA','UNITED STATES','94551-6821','(925) 606-1086','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 16:08:04',0,NULL,3,1,1,1,NULL,'susanhaynes\r王'),(8296,704432389002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','aaydagul','aydagul@gmail.com','Aysan Aydagul','Yesilbahce Mah. 1480 Sokak<br>2. Erenkus Apt. No:42/3','Antalya','','TURKEY','07160','+902423129520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:08:39',0,NULL,3,1,2,1,NULL,'aaydagul\r王'),(8297,663614614001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','khikays','cate_tolosa@yahoo.com','Catherine Tolosa','4057 Jason Place','Victoria','BC','CANADA','v8n4t5','(250) 891-5521','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:39:14',0,NULL,3,1,2,1,NULL,'khikays\r刘'),(8298,704446621002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','lan-mas-ter','vacaciones@rambler.ru','Gennadiy Zuev','st. Kolcevay 159/1 - 57','Ufa','Bashkortostan','RUSSIAN FEDERATION','450038','917-345-2848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:49:43',0,NULL,3,1,2,1,NULL,'lan-mas-ter'),(8299,663632405001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 17:20:23',0,NULL,3,1,3,1,' RA117739685CN\r','igrom78\r肩架   1\rlenspen   2\r刘'),(8300,704463243002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',2,'AKT051',23,'hermeshine','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 17:34:44',0,NULL,8,1,17,0,NULL,'igrom78'),(8301,663640094001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','eugeneyeo92','oblivion247@hotmail.com','Eugene Yeo','Blk 345 Hougang Avenue 7<br>#02-555','default','','SINGAPORE','530345','98527557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 17:40:35',0,NULL,3,1,11,1,NULL,'eugeneyeo92\r王'),(8302,663685383001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','djbi','jibeliste@hotmail.com','Jean-Baptiste Lévy','44 allée de Bassac','Colomiers','Midi-Pyrénées','FRANCE','31770','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 19:32:29',0,NULL,3,1,4,1,' YW864941460CN\r','djbi\rtripod $20'),(8303,704517485002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','zandermatt','risto.piiroinen@gmail.com','Risto Piiroinen','Norkkokuja 3 A 5','Vantaa','','FINLAND','01360','+358400618504','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 19:48:10',0,NULL,3,1,3,1,' RA117739819CN\r','zandermatt\r王'),(8304,0,120711872815,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',0.99,'hermeshine','busub01210','sub9902@yahoo.com','TRUMAN P','5710 KNOLLWELL WAY','San Jose','CA','UNITED STATES','95138-1652','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 20:18:15',0,NULL,3,1,1,1,NULL,'busub01210\r庄'),(8305,663703901001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','dewalt962','cvacca01@comcast.net','Carl Vaccarino','460 Capri J','Delray Beach','FL','UNITED STATES','33484','(561) 499-8499','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 20:20:16',0,NULL,3,1,1,1,NULL,'dewalt962\r庄'),(8306,0,120710988058,'Green.L 55mm Neutral Density ND4 Filter ND 4 55',1,'AE2302',1.04,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:42',0,NULL,8,1,17,0,NULL,'traderseamer'),(8307,0,110674134400,'Green.L 62mm Neutral Density ND4 Filter ND 4 62',1,'AE2304',1.04,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:42',0,NULL,8,1,17,0,NULL,'traderseamer'),(8308,0,110674134377,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',1.75,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:43',0,NULL,8,1,17,0,NULL,'traderseamer'),(8309,0,120710987989,'Green.L 52mm Neutral Density ND4 Filter ND 4 52',1,'AE2301',1.04,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:44',0,NULL,8,1,17,0,NULL,'traderseamer'),(8310,0,120710988317,'Green.L 67mm Neutral Density ND4 Filter ND 4 67',1,'AE2305',0.99,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:44',0,NULL,8,1,17,0,NULL,'traderseamer'),(8311,0,110674134346,'Green.L 58mm Neutral Density ND4 Filter ND 4 58',1,'AE2303',1.8,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:45',0,NULL,8,1,17,0,NULL,'traderseamer'),(8312,0,120710988103,'Green.L 55mm Neutral Density ND8 Filter ND 8 55',1,'AE2309',0.99,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:45',0,NULL,8,1,17,0,NULL,'traderseamer\r'),(8313,0,110674134420,'Green.L 62mm Neutral Density ND8 Filter ND 8 62',1,'AE2311',2.25,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:46',0,NULL,3,1,1,1,' ','traderseamer\r绿叶 ND4  52mm  1\r绿叶 ND4  55mm  1\r绿叶 ND4  58mm  1\r绿叶 ND4  62mm  1\r绿叶 ND4  67mm  1\r绿叶 ND8  55mm  1\r绿叶 ND8  58mm  1\r绿叶 ND8  62mm  1\r徐\r405g'),(8314,704566774002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','bpoalm','olimpiada@gmail.com','Brandon P Olimpiada','2600 Woody Creek Ct','Cameron Park','CA','UNITED STATES','95682-9231','(916) 588-6301','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 22:08:26',0,NULL,3,1,1,1,NULL,'bpoalm\r庄'),(8315,663754004001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','luizfernandoborgesnomura','fernandonomura@hotmail.com','luiz fernando borges nomura','nagasaka 1 chome 172 kopo station park-A 104<br>nagasaka 1 chome 172 kopo station park-A 104','kani-shi','Gifu','JAPAN','509-0257','080-36482104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 23:14:25',0,NULL,3,1,3,1,' RA117739544CN\r','luizfernandoborgesnomura\r刘'),(8316,663755953001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','luizfernandoborgesnomura','fernandonomura@hotmail.com','luiz fernando borges nomura','nagasaka 1 chome 172 kopo station park-A 104<br>nagasaka 1 chome 172 kopo station park-A 104','kani-shi','Gifu','JAPAN','509-0257','080-36482104','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 23:20:53',0,NULL,3,1,3,1,' RA117739677CN\r','luizfernandoborgesnomura\r刘'),(8317,774581419015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','sandyjardine1979','sandy.jardine1979@hotmail.co.uk','mark jardine','11 moorefield','banbridge','Down','UNITED KINGDOM','bt324de','07725099073','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-22 23:22:18',0,NULL,3,1,2,1,NULL,'sandyjardine1979\r王'),(8318,663789601001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','otakubrasil','peter@yamatocorp.com.br','carlos afonso','av almirante cochrane nr 194 cj 44','Santos -SP','São Paulo','BRAZIL','11040002','+551391012604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 02:02:53',0,NULL,3,1,2,1,NULL,'otakubrasil\r王'),(8319,704636227002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3301',5.5,'hermeshine','sbabaq','sbaback@netcabo.pt','Nelson Nunes','Rua General Humberto Delgado,<br>Edificio Lameiros, Bloco 4, 3ºEsq','Vila Franca de Xira','Vila Franca de Xira','PORTUGAL','2600-154','+351962749779','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 03:32:36',0,NULL,3,1,2,1,NULL,'sbabaq\r王'),(8320,663809760001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','dimage2004','yuejian@yahoo.com','Bryan Wu','61 Insmill Cres.','Ottawa','ON','CANADA','K2T1G4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 03:54:00',0,NULL,3,1,2,1,NULL,'dimage2004\r刘'),(8321,663810477001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',5,'AA2205',17.5,'hermeshine','neburlopez','ru.lopez.a@gmail.com','Rube Lopez','Lord Cochrane 209, Dpto 510, Torre Sur','Santiago','Stgo/ Stgo/ Region Metropolitana','CHILE','8330414','56990461920','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 03:58:40',0,NULL,3,1,3,1,' RA117739725CN\r','neburlopez\r5个\r王'),(8322,663826331001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','ppnc12','pollux_chung@yahoo.com','Pollux Chung','3019 Graveley Street','Vancouver','BC','CANADA','V5K 3K5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 05:43:37',0,NULL,3,1,3,1,' RA117739734CN\r','ppnc12\r王'),(8323,704660882002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','doniks','sby6ek@gmail.com','Daniyar Kenebayev','Abay 16-54<br>7017551926','Almaty','','KAZAKHSTAN','050013','007-7017551926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 06:03:51',0,NULL,3,1,2,1,NULL,'doniks\r刘'),(8324,704668192002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','usacat1978','savtchuk@rambler.ru','YURIY SAVCHUK','4825 FORSTER AVE','SCHILLER PARK','IL','UNITED STATES','60176','(773) 225-0738','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-23 06:47:11',0,NULL,3,1,1,1,NULL,'usacat1978\r庄'),(8325,774842914015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','johndorney','johnrobertdorney@hotmail.com','John Dorney','Loughane','Vicarstown','Cork','IRELAND','default','0214385815','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 07:09:40',0,NULL,3,1,2,1,NULL,'johndorney\r王'),(8326,662209669018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','mutleq','mato-2008@hotmail.com','Mutleq Alotaibi','2 Nobleman place<br>Hamilton East','Hamilton','Waikato','NEW ZEALAND','3216','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-23 07:20:23',0,NULL,3,1,6,1,NULL,'mutleq\r澳标\r再加2mx2m 背景架  一套 白 + 黑\r刘+庄\rEE442466488CN\r'),(8327,704667821002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','k1tahaei','k1_tahaei@yahoo.com','Kayvan Tahaei','CMiC<br>4850 Keele Street','Toronto','ON','CANADA','M3J 3K1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 07:23:16',0,NULL,3,1,3,1,'RA117739561CN\r ','k1tahaei\r王'),(8328,662210294018,280663394346,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','mutleq','mato-2008@hotmail.com','Mutleq Alotaibi','2 Nobleman place<br>Hamilton East','Hamilton','Waikato','NEW ZEALAND','3216','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-23 07:23:17',0,NULL,8,1,17,0,NULL,'mutleq'),(8329,774846849015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','vasko9','vasko.chobanov@gmail.com','Vasil Chobanov','ul. Koliu Ficheto 3, et. 4','Plovdiv','Plovdiv','BULGARIA','4003','+359897059886','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 07:26:17',0,NULL,3,1,2,1,NULL,'vasko9\r王'),(8330,759132456016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',2,'AA1315',4.4,'hutongstore','butchielad','mark@butcher92.freeserve.co.uk','Mark Butcher','31 Napier Street','Dalton-in-Furness','Cumbria','UNITED KINGDOM','LA158HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-23 08:27:07',0,NULL,3,1,2,1,NULL,'butchielad\r2套    刘'),(8331,663855237001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','ardiani2009','keni25_ch@hotmail.com','muharrem gashi','verger-rond 8','neuchatel','','SWITZERLAND','2000','0041762885785','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 08:27:23',0,NULL,3,1,4,1,'YW864941456CN\r ','ardiani2009\rDV support $20\r还需要放一个肩架的配件一起发\r王'),(8332,704691136002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',151.6,'hermeshine','juanfernandez2007','placido@rodriguez.name','Plácido Rodriguez','Raimundo Fdez. Villaverde, 49 - 11 DR','Madrid','Madrid','SPAIN','28003','656310120','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 08:50:04',0,NULL,3,1,4,1,' YW864941445CN\r','juanfernandez2007\r刘'),(8333,774872357015,250599364923,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon New',2,'AA3303',4.6,'hutongstore','octavian_p','octavian1406@yahoo.com','Paul Octavian Anca','str. Romancierilor nr. 5, bl. C14, sc.B, ap. 77','Bucharest','Sector 6','ROMANIA','061791','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 09:07:57',0,NULL,8,1,17,0,NULL,'octavian_p'),(8334,774872214015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','octavian_p','octavian1406@yahoo.com','Paul Octavian Anca','str. Romancierilor nr. 5, bl. C14, sc.B, ap. 77','Bucharest','Sector 6','ROMANIA','061791','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 09:07:58',0,NULL,8,1,17,0,NULL,'octavian_p'),(8335,774872297015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',2,'AA3317',9.6,'hutongstore','octavian_p','octavian1406@yahoo.com','Paul Octavian Anca','str. Romancierilor nr. 5, bl. C14, sc.B, ap. 77','Bucharest','Sector 6','ROMANIA','061791','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 09:07:58',0,NULL,3,1,3,1,' RA117714057CN','octavian_p\r绿叶 UV  58mm  2\r绿叶 CPL  58mm  1\r刘\r绿叶 渐变镜 58mm   2\r'),(8336,774872729015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',23.49,'hutongstore','don.lund','jacoblund89@gmail.com','Jacob Lund','Vintervej 15, 2. sal nr 24','Aarhus V','','DENMARK','8210','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 09:12:58',0,NULL,3,1,3,1,' RA117739748CN\r','don.lund\r王'),(8337,704718498002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','pastandpresentphoto','jillhatcher@msn.com','Jill Hatcher','4622-109th ave se','Snohomish','WA','UNITED STATES','98290','(206) 778-3001','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-23 11:00:14',0,NULL,8,1,17,0,NULL,'pastandpresentphoto'),(8338,663887349001,110419738256,'Green.L 67mm Neutral Density ND4 Filter ND 4 67',1,'AE2305',6.7,'hermeshine','pastandpresentphoto','jillhatcher@msn.com','Jill Hatcher','4622-109th ave se','Snohomish','WA','UNITED STATES','98290','(206) 778-3001','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-23 11:00:15',0,NULL,8,1,17,0,NULL,'pastandpresentphoto'),(8339,663886483001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','pastandpresentphoto','jillhatcher@msn.com','Jill Hatcher','4622-109th ave se','Snohomish','WA','UNITED STATES','98290','(206) 778-3001','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 11:00:15',0,NULL,3,1,1,1,NULL,'pastandpresentphoto\rlenspen   1\r绿叶 ND4  67mm  1\r绿叶 渐变镜 67mm  1\r庄'),(8340,704726254002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','370deivux','dnutautas@yahoo.com','deivis nutautas','architektu 88 57','vilnius','','LITHUANIA','lt-04107','+37068616569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 11:36:31',0,NULL,3,1,5,1,' CP226344454CN\r','370deivux\r王'),(8341,699462959002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','rgbeme','meisrg82@yahoo.com','gary ryan','4709 roosevelt ave','middletown','OH','UNITED STATES','45044-6235','(513) 265-1884','NoPaymentFailure','CheckoutComplete','Other','2011-04-23 12:12:35',0,NULL,3,1,4,1,' YW864941493CN\r','rgbeme\rlighting kit  $25\r刘'),(8342,759217618016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','judazuk','peter.lennartsson@gmail.com','Peter J Lennartsson','Ronnebergavagen 8A','Eslov','Skane','SWEDEN','24134','+46763191343','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-23 13:32:37',0,NULL,3,1,4,1,' YW864941482CN\r','judazuk\rlighting kit  $40\r欧标\r庄'),(8343,774959137015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','reitermaniac1','sebastian.lessner@unitybox.de','Sebastian Lessner','Calvinstraße 13','Düsseldorf','','GERMANY','40597','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 13:55:46',0,NULL,8,1,17,0,'fangbo ','reitermaniac1'),(8344,759228279016,260660051619,'Medium size Neoprene Lens Pouch fit 17-85mm 18-70mm M',1,'AC1202',2.48,'hutongstore','reitermaniac1','sebastian.lessner@unitybox.de','Sebastian Lessner','Calvinstraße 13','Düsseldorf','','GERMANY','40597','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 14:08:43',0,NULL,3,1,2,1,'test ','reitermaniac1\r镜头筒 小号  1\r镜头筒 中号   1\r刘'),(8345,704767297002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','ryrvikryrvik','medolaonas@hotmail.se','magnus ryrvik kjäll','hjortmossegatan 32','trollhättan','västra götaland','SWEDEN','46151','0520203000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:13:13',0,NULL,3,1,4,1,' YW864941541CN','ryrvikryrvik\rlight stand  $25\r刘\r\r'),(8346,774971222015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','froistedt76','johan@superspecial.se','Johan Fröistedt','Mimergatan 1A','Västerås','','SWEDEN','72214','+46706775876','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 14:29:36',0,NULL,3,1,2,1,NULL,'froistedt76\r王'),(8347,704779626002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',2,'AB1306',7.58,'hermeshine','fernand5233','fernr@videotron.ca','Fernand Roy','468 Zephyr','Laval','QC','CANADA','H7X2P8','(450) 689-6266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:55:17',0,NULL,8,1,17,0,NULL,'fernand5233'),(8348,663947371001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','fernand5233','fernr@videotron.ca','Fernand Roy','468 Zephyr','Laval','QC','CANADA','H7X2P8','(450) 689-6266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:55:18',0,NULL,8,1,17,0,NULL,'fernand5233'),(8349,704778388002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1307',7.58,'hermeshine','fernand5233','fernr@videotron.ca','Fernand Roy','468 Zephyr','Laval','QC','CANADA','H7X2P8','(450) 689-6266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:55:19',0,NULL,3,1,3,1,' RA117739782CN\r','fernand5233\r橡胶遮光罩 72mm   2\r橡胶遮光罩 58mm  1\r橡胶遮光罩 77mm 2 \r庄\r\r'),(8350,759264418016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','el.der','helder.hjf@gmail.com','Helder Fernandes','PRACETA COLÉGIO DE GAIA Nº 240 - 3C','Vila Nova de Gaia','Vila Nova de Gaia','PORTUGAL','4400-090','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 15:38:44',0,NULL,3,1,2,1,NULL,'el.der\r王'),(8351,775002574015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','smarston2610','stuart.marston@ntlworld.com','stuart marston','10<br>Malton Road','North Hykeham, Lincoln','Lincolnshire','UNITED KINGDOM','LN6 8HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-23 15:54:16',0,NULL,3,1,2,1,NULL,'smarston2610\r王'),(8352,775048948015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','postondemand','huwjenkins@uk2.net','huw jenkins','Avenida Marques De L\'Argentera 5, 1b','barcelona','Cataluña','SPAIN','08003','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 17:32:39',0,NULL,3,1,3,1,' RA117739751CN\r','postondemand\r庄'),(8353,704731186002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','julianapelucio','julianapelluccio@yahoo.com.br','Juliana Pelucio','Rua Tenente Ulisses, 25<br>Centro','Itaguara','Minas Gerais','BRAZIL','35514000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 17:53:14',0,NULL,3,1,5,1,'CP226344445CN\r','julianapelucio\r欧标'),(8354,664015796001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','heckcare_der','heckcare.der@gmail.com','Heng Derrick','Blk 641 Rowell Road #11-50','Singapore','','SINGAPORE','200641','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 18:11:43',0,NULL,3,1,11,1,' ','heckcare_der\r庄'),(8355,664024740001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',4,'AE3601',72,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 18:30:14',0,NULL,3,1,4,1,'YW864941563CN\r ','leifs123\r申报：bulbs   $18\r刘'),(8356,759345062016,260660052183,'New 62mm Ring adapter for Cokin P Series Filter Holder',1,'AA2211',2.25,'hutongstore','woody0872','hotwoody72@yahoo.co.uk','GARY WOODS','5 MORRISON HOUSE<br>DERWENT CRESENT','ARNOLD','Nottinghamshire','UNITED KINGDOM','NG5 6TE','01159261180','NoPaymentFailure','CheckoutIncomplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'woody0872\r刘'),(8357,664027336001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','vissyboy','vissysdg@yahoo.co.uk','Sedlan George','58 Birch Court,<br>Sherman gardens','Chadwell heath, Romford','Essex','UNITED KINGDOM','RM6 4AP','02085864045','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 18:37:48',0,NULL,3,1,3,1,' RA117739663CN\r','vissyboy\r刘'),(8358,775108638015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.26,'hutongstore','killrabbit','david_jfcarvalho@hotmail.com','David Carvalho','Praca Lourenco de Carvalho<br>n28 3 Direito','Almeirim','Almeirim','PORTUGAL','2080-043','00351916397746','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 19:34:28',0,NULL,3,1,2,1,NULL,'killrabbit\r刘'),(8359,664058093001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','leenick','kayorinite3@hotmail.com','Nick Dussault','23 Weymond Crescent','Riverview','NB','CANADA','e1b 5h7','(506) 852-1592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 19:54:55',0,NULL,8,1,17,0,' ','leenick'),(8360,704889387002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','leenick','kayorinite3@hotmail.com','Nick Dussault','23 Weymond Crescent','Riverview','NB','CANADA','e1b 5h7','(506) 852-1592','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 19:57:44',0,NULL,3,0,3,1,' RA117739853CN\r','leenick\r摄影背心 Canon  老款 L    1\r永诺 Canon ttl线  3m       1\r\r庄'),(8361,759387351016,260660051264,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',4.3,'hutongstore','gdiggerru','gdigger@gmail.com','Anton Labunsky','Molostovykh, 16-4-126','Moscow','','RUSSIAN FEDERATION','111558','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 20:05:22',0,NULL,8,1,17,0,NULL,'gdiggerru'),(8362,775124288015,250692239254,'New Neoprene Reversible Cover for Canon 5D II 7D L',1,'AC1304',6.1,'hutongstore','gdiggerru','gdigger@gmail.com','Anton Labunsky','Molostovykh, 16-4-126','Moscow','','RUSSIAN FEDERATION','111558','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 20:05:23',0,NULL,8,1,17,0,NULL,'gdiggerru'),(8363,759386999016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','gdiggerru','gdigger@gmail.com','Anton Labunsky','Molostovykh, 16-4-126','Moscow','','RUSSIAN FEDERATION','111558','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 20:05:23',0,NULL,3,1,3,1,' RA117739840CN\r','gdiggerru\r大号内胆包canon     1\r带水平仪 热靴保护盖  1\r永诺 SF18- CANON   1\r王'),(8364,664065084001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','rusty92310','ruslan923@rambler.ru','Ruslan Losaev','Rothschild 12. entrance 2. apartament 3.<br>רוטשילד 12. כניסה ב\'. דירה 3','Bat-yam','','ISRAEL','59326','0527363975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 20:14:28',0,NULL,3,1,2,1,NULL,'rusty92310\r刘'),(8365,704893297002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','miguel7cardoso','miguelmscardoso@gmail.com','Miguel Cardoso','Avenida João Corte Real, 232, 2ºdt','Barra - Ílhavo - Aveiro','Portugal','PORTUGAL','3830-751','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 20:14:28',0,NULL,3,1,2,1,NULL,'miguel7cardoso\r刘'),(8366,704906492002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','arte3512','pet_son@hotmail.com','Peter Scheuer','Furuslätten 60','Gothenburg','Billdal','SWEDEN','42735','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 20:46:30',0,NULL,3,1,3,1,' RA117739805CN\r','arte3512\rXL\r庄'),(8367,664092325001,110583709836,'NEW 62mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT045',28,'hermeshine','melemele94','mlpm@hotmail.fr','Marie-Line Périllat-Mercerot','11 rue Gabrielle','Charenton-le-pont','Île-de-France','FRANCE','94220','0143684889','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 21:32:28',0,NULL,8,1,17,0,NULL,'melemele94'),(8368,664071657001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 21:37:29',0,NULL,8,1,17,0,NULL,'saud-p'),(8369,664073382001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 21:37:31',0,NULL,3,1,3,1,'RA117739822CN\r RA17739181CN','saud-p\r反光板支架  1\r背景架2m x 3m  \r分两个小包发  \r庄'),(8370,664095472001,110566018317,'62mm 3-Stage Rubber Lens Hood for D80 D90 450D 500D',1,'AB1304',3.79,'hermeshine','melemele94','mlpm@hotmail.fr','Marie-Line Périllat-Mercerot','11 rue Gabrielle','Charenton-le-pont','Île-de-France','FRANCE','94220','0143684889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 21:44:06',0,NULL,3,1,3,1,' RA117739765CN\r','melemele94\r62mm 橡胶遮光罩   1\r绿叶 CPL  62mm   1\r绿叶 ND8  62mm   1\r绿叶 近摄+8  62mm   1\r绿叶 渐变灰  62mm   1\r4片装滤镜袋    1\r庄'),(8371,759430105016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','mount_productions','mount@gibraltar.gi','Mark Montovio','502/503 Watergardens','Waterport Wharf','Gibraltar','GIBRALTAR','gibb','00 350 40338','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 21:48:31',0,NULL,3,1,3,1,' RA117739592CN\r','mount_productions\r王'),(8372,704932501002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jevanamstel','evamstel@gmail.com','Amstel van Eduard','Buizerdweg 42','Alkmaar','','NETHERLANDS','1826GH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 22:05:10',0,NULL,3,1,2,1,' ','jevanamstel\r王'),(8373,664121936001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','crni1985','ivan_crnjak@net.hr','Ivan Crnjak','Karlovacka 8','Sesvete','ZG','CROATIA','10360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 23:32:13',0,NULL,3,1,2,1,NULL,'crni1985\r绿叶 UV  58mm  1\r绿叶 UV  77mm   2\r刘'),(8374,704960282002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','cleosantana2009','cleosantana2@yahoo.com.br','CLEÓMENES SOARES SANTANA','AV: JOÃO DE BARROS ,201 APTº 901<br>BOA VISTA','RECIFE','PERNAMBUCO','BRAZIL','50050-180','81 3088.3027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 23:57:47',0,NULL,3,1,3,1,' RA117739779CN\r','cleosantana2009\r王'),(8375,664136647001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','agagarin','gagarin239@yahoo.com','andrey gagarin','54 maplewood ave','newton','MA','UNITED STATES','02459-2526','(617) 965-7138','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 00:44:06',0,NULL,8,1,17,0,NULL,'agagarin'),(8376,704968158002,120458030272,'Marco O Flash o-flash Ring Light For SB900 580EXII F175',1,'AO0026',38.49,'hermeshine','agagarin','gagarin239@yahoo.com','andrey gagarin','54 maplewood ave','newton','MA','UNITED STATES','02459-2526','(617) 965-7138','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 00:44:06',0,NULL,8,1,17,0,NULL,'agagarin'),(8377,664130924001,110419738256,'Green.L 67mm Neutral Density ND4 Filter ND 4 67',1,'AE2305',6.7,'hermeshine','agagarin','gagarin239@yahoo.com','andrey gagarin','54 maplewood ave','newton','MA','UNITED STATES','02459-2526','(617) 965-7138','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 00:44:07',0,NULL,8,1,17,0,NULL,'agagarin'),(8378,664135048001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',7.98,'hermeshine','agagarin','gagarin239@yahoo.com','andrey gagarin','54 maplewood ave','newton','MA','UNITED STATES','02459-2526','(617) 965-7138','NoPaymentFailure','CheckoutComplete','Other','2011-04-24 00:44:08',0,NULL,8,1,17,0,NULL,'agagarin'),(8379,704965097002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','agagarin','gagarin239@yahoo.com','andrey gagarin','54 maplewood ave','newton','MA','UNITED STATES','02459-2526','(617) 965-7138','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 00:44:08',0,NULL,3,1,3,1,' RA117739575CN\r','agagarin\r绿叶 CPL  67mm   1\rcanon 电子触点      1\r绿叶 ND4  67mm   1\r绿叶 UV  67mm      1\ro-flash f175             1\r徐\r895g'),(8380,705003231002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','drjyeo12','drjyeo@gmail.com','John Yeo','850, Piasau Park','Miri','Sarawak','MALAYSIA','98000','013-8367001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 03:14:06',0,NULL,3,1,2,1,' ','drjyeo12\r庄'),(8381,705015512002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','tachezza','chesworthta@bigpond.com','terry chesworth','328 cabbage tree rd','williamtown','New South Wales','AUSTRALIA','2318','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 04:22:57',0,NULL,3,1,4,1,' YW864941526CN\r','tachezza\r王'),(8382,664180302001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','reginacinegra','regina_fotos@hotmail.com','Regina Yansen Faria','Francisco alves, 222<br>Remédios','Osasco','São Paulo','BRAZIL','06296160','55 11 3696-1882','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 04:26:32',0,NULL,3,1,3,1,' RA117739589CN\r','reginacinegra\r王'),(8383,663554832001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','alex_r_54','alexxxey_45r@mail.ru','Алексей Полохин','космическая 211, кв. 3192','Новосибирск','Новосибирская область','RUSSIAN FEDERATION','630092','8 913 754 1343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 05:03:55',0,NULL,3,1,2,1,NULL,'alex_r_54\r庄'),(8384,664190337001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','beyond_id','dina_anggraeni@hotmail.com','Yozandra','Jl. irigasi danita timur dalam 1 blok C1/11 RT10/14<br>Telp : 08129665829','Bekasi Timur','Jawa Barat','INDONESIA','17112','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 05:39:44',0,NULL,3,1,2,1,NULL,'beyond_id\r庄'),(8385,759554404016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',3,'AA1301',5.61,'hutongstore','newthebeaut','stevenewton55@hotmail.com','Stephen Newton','10 Hazel Drive<br>Ripley','Woking','Surrey','UNITED KINGDOM','GU23 6LQ','01483224154','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-24 06:19:31',0,NULL,3,1,2,1,NULL,'newthebeaut\r庄'),(8386,705048947002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0005',12.8,'hermeshine','smokebigbird70','barton54@bigpond.com','Jill Barton','9 James Cook AV','Singleton','New South Wales','AUSTRALIA','2330','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-04-24 07:41:36',0,NULL,3,0,2,1,' ','smokebigbird70\r白色\r庄'),(8387,664212919001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','steeeevie','steeevie@gmx.at','Stefan Renner','Anton-Haidinger-Siedlung 8/8/2','Rotheau an der Traisen','','AUSTRIA','3153','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 07:42:28',0,NULL,8,1,17,0,NULL,'steeeevie'),(8388,705048730002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','steeeevie','steeevie@gmx.at','Stefan Renner','Anton-Haidinger-Siedlung 8/8/2','Rotheau an der Traisen','','AUSTRIA','3153','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 07:42:30',0,NULL,3,1,4,1,' YW864941515CN\r','steeeevie\r背景布 1.6  x3m    1（粉色）\r100*150 5合1 反光板   1\r反光板支架    1\r燕文 一票两件  反光板和布一票， 反光板支架一票\r申报： reflector holder  $25\r刘'),(8389,705048919002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','steeeevie','steeevie@gmx.at','Stefan Renner','Anton-Haidinger-Siedlung 8/8/2','Rotheau an der Traisen','','AUSTRIA','3153','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 07:42:33',0,NULL,8,0,17,0,NULL,'steeeevie'),(8390,704379472002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','cypher779','drobyshev.ev@gmail.com','Evgeniy Drobyshev','Perervinskiy bl. 21-1-275','Moscow','Moscow','RUSSIAN FEDERATION','109469','+79099418736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 08:05:03',0,NULL,3,1,3,1,' RA117739615CN\r','cypher779\r看看是否2kg以下\r刘\r'),(8391,664220889001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','blueheron2002','ronswords@comcast.net','Ronald J Swords','6123 N Lidgerwood St<br>Apt 305','Spokane','WA','UNITED STATES','99208-1056','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 08:15:43',0,NULL,3,1,1,1,NULL,'blueheron2002\r庄'),(8392,705074992002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','ital-nyah','sold18@hotmail.com','Dan Sjölund','Loftagatan 1B','Gamleby','Kalmar','SWEDEN','59432','0046733867735','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 09:23:46',0,NULL,3,1,3,1,'RA117739898CN\r ','ital-nyah\r庄'),(8393,775401858015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','uguraci80','uguraci@gmail.com','UGUR ERBASOL','mehmetcik bulvari no:55/14 uckuyular karabaglar','IZMIR','','TURKEY','35350','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 11:53:25',0,NULL,3,1,2,1,NULL,'uguraci80\r申报：GIFT/\r庄\r\r'),(8394,775418629015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','edwardnapthine','enapthin@gmail.com','Edward Napthine','14 Gardner Ln','Kensington Banks','Victoria','AUSTRALIA','3031','0433997887','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 12:36:10',0,NULL,3,1,2,1,NULL,'edwardnapthine\r庄'),(8395,705146451002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','irishpjeongco2010','irishpjeongco@yahoo.com.ph','Irish Jeongco','Ta-al Street Phase 5, Alta Tierra Village, Jaro','Iloilo City','','PHILIPPINES','5000','0333206210','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 13:34:20',0,NULL,3,1,2,1,NULL,'irishpjeongco2010\r庄'),(8396,0,110677756384,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.99,'hermeshine','shanoobilly','azeemdadream27@yahoo.com','Azeem qureshi','8 Saint Andrews Ln','Annandale','NJ','UNITED STATES','08801-1620','(908) 400-7342','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 14:34:23',0,NULL,3,1,1,1,NULL,'shanoobilly\r庄'),(8397,0,110677756305,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',0.99,'hermeshine','johnhz','jjjjjjjjjjjjohn@yahoo.com','John Harasimowicz','7701 Hemlock Ave','Gary','IN','UNITED STATES','46403-2162','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 14:34:44',0,NULL,3,1,1,1,NULL,'johnhz\r庄'),(8398,0,110677756646,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.99,'hermeshine','professorc_123','professor_frog@hotmail.com','Thomas Campbell','30500 Bermont Rd','Punta Gorda','FL','UNITED STATES','33982-9711','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 14:36:46',0,NULL,3,1,1,1,NULL,'professorc_123\r庄'),(8399,0,110677757103,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',0.99,'hermeshine','normancha','alanzh@comcast.net','Alan Zhang','2125 Bucolic Ct<br>Xech Information Systems','Nolensville','TN','UNITED STATES','37135-9541','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 14:36:54',0,NULL,3,1,1,1,' ','normancha\r庄'),(8400,0,110677756134,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',0.99,'hermeshine','fishing26508','fishing26508@yahoo.com','Clayton  Eakin','1460 Smithtown Rd','Morgantown','WV','UNITED STATES','26508','(304) 276-7866','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 15:06:14',0,NULL,3,1,1,1,NULL,'fishing26508\r庄'),(8401,775495168015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','solowing0220','godgundam0220@live.com','Lim wee yang','choa chu kang street 52 block 545 #12-12','default','','SINGAPORE','680545','+6597886807','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 15:35:39',0,NULL,3,1,11,1,NULL,'solowing0220\r庄'),(8402,663629802001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','districtland','sia.annie89@gmail.com','Annie Sia Kin Toh','No 15, Jalan Wangsa Budi 4<br>Jalan Wangsa Melawati','Kuala Lumpur','wilayah persekutuan','MALAYSIA','53300','0178507755','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 15:50:57',0,NULL,3,1,3,1,' RA117739650CN\r','districtland\r庄'),(8403,705197224002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','zoomer_vn','dzungtranvn@gmail.com','TRAN Tiendung','Unit 5/52<br>McKillop','GEELONG','Victoria','AUSTRALIA','3220','0413638811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 15:57:35',0,NULL,3,1,2,1,NULL,'zoomer_vn\r庄'),(8404,664358760001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','floydtherappa','awknoflicek@ole.augie.edu','Andrew Knoflicek','2505 S Jefferson Ave','Sioux Falls','SD','UNITED STATES','57105-3413','(605) 339-3088','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 16:06:12',0,NULL,3,1,1,1,NULL,'floydtherappa\r庄'),(8405,664375991001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','clw1','ag668@lafn.org','Calvin Weisberger','538 11th St','Santa Monica','CA','UNITED STATES','90402','(310) 393-2932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 16:20:16',0,NULL,3,1,1,1,' ','clw1\r庄'),(8406,664383722001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','nowell63','noel_carson@hotmail.com','NOEL  CARSON','CARRANTULLA','CLAREMORRIS ','Mayo','IRELAND','default','0949364883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 16:37:08',0,NULL,3,1,2,1,' ','nowell63\r庄'),(8407,664417725001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','nathanael2003','ramonaandsunil@rogers.com','Ramona Ramjit','26 Meandering Trail','Scarborough','ON','CANADA','M1B6E8','(416) 284-5856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 17:39:41',0,NULL,3,1,2,1,NULL,'nathanael2003\r庄'),(8408,775585686015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','bigyingyang','mikegistrong@hotmail.co.uk','Mike Coughlan','19 Kings Ave','Corsham','Wiltshire','UNITED KINGDOM','SN13 0EF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-24 17:59:37',0,NULL,3,1,2,1,NULL,'bigyingyang\r庄'),(8409,664446752001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','2639717','hcard@stny.rr.com','Harold F Card','22 Lake street<br>po 334','morris','NY','UNITED STATES','13808','(607) 263-9717','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 18:24:38',0,NULL,3,1,1,1,NULL,'2639717\r庄'),(8410,705282246002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','shourov007','shourov007@hotmail.com','Toufiq Hasan','Unit 13/53 King George street','Victoria Park','Western Australia','AUSTRALIA','6100','0434435219','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 18:26:46',0,NULL,3,1,2,1,NULL,'shourov007\r庄'),(8411,775622716015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'AA3211',2.98,'hutongstore','mogeykmelllor','kevin.dmellor@yahoo.co.uk','Kevin Mellor','6 Glencoe Close<br>Holmes Chapel','Crewe','Cheshire','UNITED KINGDOM','CW47HX','01477535087','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-24 18:45:22',0,NULL,3,1,2,1,NULL,'mogeykmelllor\r庄'),(8412,705294400002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','advmuscle','marvin@medical-massage.net','Advanced Muscle Care','11231 Richmond Ave.<br>Ste D110','Houston','TX','UNITED STATES','77082','','NoPaymentFailure','CheckoutComplete','Other','2011-04-24 18:47:26',0,NULL,3,1,3,1,' RA117739884CN\r','advmuscle\r刘'),(8413,0,110677756709,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',2.25,'hermeshine','palermo22','palermo22@aol.com','Gerald K Kandel','924 Bea Court','Nipomo','CA','UNITED STATES','93444-6622','(805) 343-0848','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 18:48:27',0,NULL,3,1,1,1,' ','palermo22\r庄'),(8414,759882912016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','sonfr123','sonelius@hotmail.com','Fredrik Sonelius','Torpagatan 14','Jönköping','','SWEDEN','55333','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 19:00:44',0,NULL,3,1,2,1,NULL,'sonfr123\r庄\r'),(8415,664484851001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','gerena4jc787','gerena4jc@gmail.com','Angel Gerena','5351 Hillock Way','Orlando','FL','UNITED STATES','32810','(407) 731-3437','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 19:32:41',0,NULL,3,1,1,1,NULL,'gerena4jc787\r庄'),(8416,0,110677756571,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',0.99,'hermeshine','gmoratz','gamoratz@gmail.com','gary moratz','5936 Jellico Ave','encino','CA','UNITED STATES','91316','(818) 983-3248','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 20:29:51',0,NULL,3,1,1,1,NULL,'gmoratz\r庄'),(8417,0,110677757008,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',1.51,'hermeshine','tradertodd2','million2one@netzero.net','Todd Tinsley','13320 Bar C','San Antonio','TX','UNITED STATES','78253-5203','(210) 679-5562','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 20:32:08',0,NULL,3,1,1,1,NULL,'tradertodd2\r庄'),(8418,664519954001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','vinfinite','vtn86@hotmail.com','vinh nguyen','1781 Chatfield Cir','stockton','CA','UNITED STATES','95209-4240','(209) 598-0915','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 20:42:50',0,NULL,3,1,1,1,NULL,'vinfinite\r庄'),(8419,664530293001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','ricabras','photobrasil@gmail.com','Ricardo Brasil','Rua Mucu nº 10 apto 102, Alto da Boa Vista','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531-180','5521-2570-4633','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 21:07:53',0,NULL,3,1,2,1,' ','ricabras\r庄'),(8420,705374022002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','mkwb3','mkwb@sbcglobal.net','Katherine Boruch','105 Grace Ln','Fox River Grove','IL','UNITED STATES','60021','(847) 516-1190','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 21:24:37',0,NULL,3,1,1,1,' ','mkwb3\r庄'),(8421,705394950002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','michalw84','michalwallentinsen@hotmail.com','Michal Wallentinsen','Marmorveien 4','Nedenes','Aust-Agder','NORWAY','4823','92677669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 22:45:42',0,NULL,3,1,2,1,NULL,'michalw84\r庄'),(8422,664566510001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','artemyevvitaly','applemarkt@mail.com','Artemyev Vitaly','str. Fadeeva 65-127','Samara','','RUSSIAN FEDERATION','443081','9277058003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 22:59:06',0,NULL,3,1,2,1,NULL,'artemyevvitaly\r庄'),(8423,664565660001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','texurastar','texurastar@verizon.net','W.A. Mason','2547 Bent Oaks Dr','Colonial Heights','VA','UNITED STATES','23834-1700','(804) 640-4116','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 23:01:38',0,NULL,3,1,1,1,NULL,'texurastar\r庄'),(8424,664585914001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',2,'AB1203',16,'hermeshine','boricua11411','lortiz2@wi.rr.com','Laureano Ortiz','N1615 Bluebird dr.','Lake Geneva','WI','UNITED STATES','53147','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 00:08:04',0,NULL,3,1,1,1,NULL,'boricua11411\r庄'),(8425,0,110677756622,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',1.98,'hermeshine','silver-quest','c2farr@yahoo.com','Charles Farrier','1548 Glenmore Ave','Baton Rouge','LA','UNITED STATES','70808','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 01:07:12',0,NULL,3,1,1,1,NULL,'silver-quest\r庄\r72mm nikon  镜头盖   1\r72mm uv    1\r'),(8426,705459471002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',2,'AB1407',10.98,'hermeshine','jazz_papa','uflathm@cpcus.jnj.com','Ullrich Flathmann','310 Tyler Court','New Hope','PA','UNITED STATES','18938','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 01:51:17',0,NULL,3,1,1,1,' ','jazz_papa\r刘'),(8427,705461039002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','lewsh','lewsinhoe8@yahoo.com','SIN HOE LEW','BLK 134 TECK WHYE LANE, #07-377','default','','SINGAPORE','680134','67602209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 01:55:14',0,NULL,3,1,11,1,NULL,'lewsh\r刘'),(8428,0,110677756242,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',2.25,'hermeshine','mlou5288','manwlouie@netzero.com','Man Louie','1926 Clove Rd','Staten Island','NY','UNITED STATES','10304-1633','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 02:57:59',0,NULL,3,1,1,1,NULL,'mlou5288\r庄'),(8429,705479630002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','abx1982','robert_bonilla@hotmail.com','Robert E. Bonilla','A7 Urb Santa Marta','San German','PR','UNITED STATES','00683-4402','(787) 717-3269','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 03:01:41',0,NULL,3,1,3,1,'RA117739836CN\r ','abx1982\r庄'),(8430,705481325002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','wilfredjohn2009','wilfredpaulse@gmail.com','Wilfred Paulse','Rua Cel. Bernadino d Melo 4705/c 79<br>Bairro da Luz,','Nova Iguaçu','Rio de Janeiro','BRAZIL','26262-070','55-21-26697051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 03:07:46',0,NULL,3,1,2,1,NULL,'wilfredjohn2009\r庄'),(8431,0,120714815130,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',0.99,'hermeshine','thrifty_crystal','puppawuppa@yahoo.com','crystal herrera','14811 West Rd<br>Apt 4107','houston','TX','UNITED STATES','77095-3188','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 03:20:24',0,NULL,3,1,1,1,' ','thrifty_crystal\r庄'),(8432,0,110677756442,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',1.11,'hermeshine','n555wp','pilot4hire@mac.com','Woor Pardo','6514 Farthing Dr','Colorado Springs','CO','UNITED STATES','80906-8651','(703) 626-6917','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 03:39:27',0,NULL,3,1,1,1,NULL,'n555wp\r'),(8433,0,120714815736,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',1.98,'hermeshine','charlestonsasha','charlestonsasha@hotmail.com','Alexander Pozyuban','8221 Pleasant Ridge Dr','North Charleston','SC','UNITED STATES','29420-8326','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 03:53:49',0,NULL,3,1,1,1,' ','charlestonsasha\r67mm  Canon 镜头盖   1\r58mm  Canon 镜头盖   1\r庄'),(8434,664645142001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','fashionchic543','kuanalex@hotmail.com','Jessica Kuan','1105-8288 SABA Road','Richmond','BC','CANADA','V6Y 4C8','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 04:29:31',0,NULL,3,1,3,1,'RA117739955CN\r','fashionchic543\r庄'),(8435,664654034001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','qadsha','qadsha@yahoo.com','qadeer shams','90545-629 markahm rd','scarborough','ON','CANADA','m1h 3g7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 04:39:18',0,NULL,3,1,2,1,' ','qadsha\r庄'),(8436,0,110677756540,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',0.99,'hermeshine','dennis.urgo','dsurgo@hotmail.com','Dennis Urgo','705 Summit St','Eveleth','MN','UNITED STATES','55734-1441','(218) 780-9123','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 05:07:26',0,NULL,3,1,1,1,NULL,'dennis.urgo\r庄'),(8437,0,120714815533,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',0.99,'hermeshine','rockster888','marvinchoi2003@yahoo.com','marvin choi','1922 Shoreline Dr','missouri city','TX','UNITED STATES','77459-1680','(832) 283-8444','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 05:35:39',0,NULL,3,1,1,1,' ','rockster888\r庄'),(8438,705497026002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','tarasovd','wardogs@mail.ru','Tarasov Dmitry','Trofimova, 36-1','Kemerovo','Kemerovskaya obl','RUSSIAN FEDERATION','650004','7-908-944-83-69','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 05:57:15',0,NULL,3,1,3,1,' RA117739941CN\r','tarasovd\r刘'),(8439,664666648001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',2,'AB1301',6.68,'hermeshine','chriswwg','chriswwg2@gmail.com','Chris Wong','52A, Jalan Perdana 6/3,<br>Pandan Perdana,','Kuala Lumpur','WP','MALAYSIA','55300','0123782832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 06:04:10',0,NULL,3,1,2,1,' ','chriswwg\r庄'),(8440,775026914015,250621659362,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',188.95,'hutongstore','morkemyndy','centaur2002@libero.it','gabriele tosti','V.le Roma 80','Predappio','FO','ITALY','47016','0543922584','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 06:37:07',0,NULL,3,1,4,1,'YW864941552CN\r ','morkemyndy\r庄\r欧标\r80cm 5合1  反光板   1\r反光板支架     1\r100x150cm 5in1 反光板   1\r4灯头柔光箱×2\r灯架×3\r45w灯泡×8\r灯架包   1\r----\r燕文 1票2件\r申报：Lighing kit / 40$'),(8441,705496329002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','puttanon2010','n_puttanon@hotmail.com','supeyamas puttanon','68/75 moo.10 thambon bangmaenang ','bang yai','nonthaburi','THAILAND','11140','081636453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 06:49:01',0,NULL,3,1,2,1,NULL,'puttanon2010'),(8442,760169735016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','sergiosl','sergiosl.pt@gmail.com','Sergio S Lopes','Estrada de Vilar, 55 1º dir','Aveiro','Aveiro','PORTUGAL','3810-195','(351) 234345422','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 08:49:08',0,NULL,3,1,2,1,' ','sergiosl'),(8443,705544908002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','bergythebergfull','davidbowers@optushome.com.au','David Bowers','32 Grandview Road<br>Box Hill South','Melbourne','Victoria','AUSTRALIA','3128','0403803856','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 08:53:43',0,NULL,3,1,3,1,' RA117739535CN\r','bergythebergfull'),(8444,0,110677756500,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',0.99,'hermeshine','lezst3','lzheng95@yahoo.com','Lei Zheng','1617 Queen Charlotte Dr<br>Apt 2','Sunnyvale','CA','UNITED STATES','94087','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 09:36:28',0,NULL,3,1,1,1,' ','lezst3\r庄'),(8445,664717675001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',61,'hermeshine','torero_loco','torero0@gmail.com','Daniel GIMENEZ ALBA','avda cordoba 25','Yecla','Murcia','SPAIN','30510','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 09:55:18',0,NULL,3,1,4,1,' YW864488981CN','torero_loco\rreflector holder  $20\r刘'),(8446,775968065015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','561934','mukundbhai@ntlworld.com','Mukundbhai Patel','56, Bardolph Street','Leicester','Leicestershire','UNITED KINGDOM','LE4 6EF','01162332172','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-25 10:46:02',0,NULL,3,1,4,1,' YW864489003CN','561934\rtripod  $25\r王'),(8447,705574770002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sharikas1976','sharikh.abdulaziz@gmail.com','abdulaziz alsharikh','P. O. Box 8171','Dhahran','East','SAUDI ARABIA','31311','00966504825572','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 10:52:34',0,NULL,3,1,3,1,'RA117739235CN ','sharikas1976\r刘\r'),(8448,760224418016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','sms2info','holowaty@gmail.com','Bartlomiej Holowaty','32 The Moorings<br>Bailick Road','Midleton','Cork','IRELAND','default','214630311','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 11:40:31',0,NULL,3,0,2,1,NULL,'sms2info\r庄'),(8449,705586695002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','g_stman','guysht123@gmail.com','guy shtibelman','haarava 98','Nesher','','ISRAEL','36863','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 11:44:12',0,NULL,3,1,3,1,'RA17739266CN RA117739408CN\r','g_stman\r分2个挂号小包发\r刘\r'),(8450,664750161001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','bibd0531','hubymaera@hotmail.com','Pg Omarali Saifuddin Pg Tengah','No.22 Spg.105 Jln Kuala Lurah<br>Kg.Limau Manis','Bandar Seri Begawan','Pengkalan Batu','BRUNEI DARUSSALAM','BH2323','+6738246319','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 11:58:06',0,NULL,3,1,3,1,'RA117739221CN ','bibd0531\r庄\r'),(8451,663160353018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'',200,'photographyacc','glumazojd','sansei.foto@gmail.com','Alexander Chizhov','Street pestelya house 2 apartment 25','Moscow','','RUSSIAN FEDERATION','127490','+7-926-597-34-01','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-25 12:09:07',0,NULL,8,1,17,0,NULL,'glumazojd'),(8452,663160728018,280663394249,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','glumazojd','sansei.foto@gmail.com','Alexander Chizhov','Street pestelya house 2 apartment 25','Moscow','','RUSSIAN FEDERATION','127490','+7-926-597-34-01','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-25 12:10:19',0,NULL,3,1,5,1,' CP226269064CN\r','glumazojd\r（欧标）\r2mx2m 背景架   1\r1.6mx2m 背景布   1（白）\r2m 灯架  3\r斜臂    1\r50x70cm 单灯头 棚   3\r115w 220v 灯泡   3\r灯架包    1\r庄'),(8453,760234791016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','j_ruiz','jordi_ruiz@hotmail.com','Jordi Ruiz Baeza','Studio Cocina<br>Avd/ Casalduch nº47','Castellon','Comunidad Valenciana','SPAIN','12005','669941866','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 12:11:00',0,NULL,3,1,3,1,NULL,'j_ruiz\r庄\rRA117739218CN\r'),(8454,705607005002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 12:55:17',0,NULL,3,1,2,1,NULL,'andrewespuni1979\r庄'),(8455,705612289002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','lup1ne','lup1ne@hotmail.com','Tom Wheeler','19 Boyce Av<br>Briar Hill','Melbourne','Victoria','AUSTRALIA','3088','0403300076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 13:15:59',0,NULL,3,1,2,1,' ','lup1ne\r庄'),(8456,776024500015,250600523459,'Shutter Release Remote Cord For Canon 500D 450D RS-60E3',1,'AA3210',2.98,'hutongstore','inoxcrompekka','pekka.nikander@netti.fi','pekka nikander','nerdrumintie<br>31','pyhtää','Oletus','FINLAND','49270','0405519235','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 13:29:40',0,NULL,3,1,2,1,NULL,'inoxcrompekka\r庄'),(8457,664782030001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',2,'AA1208',7.16,'hermeshine','biotrufas','dmelchordiaz@yahoo.com','DAVID MELCHOR DIAZ','C/ Rozabella 4, Ed. Bruselas, PYRO<br>Complejo Europa Empresarial','Las Rozas','Madrid','SPAIN','28290','654227693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 13:54:52',0,NULL,3,1,2,1,NULL,'biotrufas\r庄'),(8458,664794817001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','2011.rober','bennett.ok@gmail.com','Roberto Bennett','Medrano 1950, 12° A','Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1425','Invalid Request','NoPaymentFailure','CheckoutComplete','NotSelected','2011-04-25 14:50:39',0,NULL,3,1,2,1,' ','2011.rober\r庄'),(8459,705641661002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','dc251978','dtm225@gmail.com','Dennis Chen','14296 brant ct','corona','CA','UNITED STATES','92880','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 14:53:22',0,NULL,3,1,1,1,' ','dc251978'),(8460,705648044002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','celesao55','celesao5@hotmail.com','john moraitis','nikolaou moutou 11','itea','fokida','GREECE','33200','+306937292448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 15:12:01',0,NULL,3,1,2,1,' ','celesao55\r庄'),(8461,705649271002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','fernt2003','ftortora@gmail.com','Fernando Tortora','Alsina 875 Piso 2','Buenos Aires','Buenos Aires','ARGENTINA','1087','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 15:19:20',0,NULL,3,1,2,1,NULL,'fernt2003\r庄'),(8462,776068367015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','remiaus','akestanolatienes@gmail.com','Jon Ribera Medina','Betolaza num.7bis bajo dcha','Bilbo','País Vasco','SPAIN','48002','689708226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 15:19:37',0,NULL,3,1,2,1,NULL,'remiaus\r庄'),(8463,776087552015,250692238930,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','singersax','drury.lizzie@gmail.com','Elizabeth Drury','41 The Strand<br>Topsham','Exeter','Devon','UNITED KINGDOM','EX3 0AY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 16:01:34',0,NULL,3,1,2,1,NULL,'singersax'),(8464,0,120714815256,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.99,'hermeshine','lyla3','creegeller@yahoo.com','Tracy Cree','PO Box 915','Storrs Mansfield','CT','UNITED STATES','06268-0915','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 16:17:47',0,NULL,3,0,1,1,NULL,'lyla3\r庄'),(8465,760337089016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','vidicigor21','vidicigor@gmail.com','Igor Vidic','Mlakarjeva ulica 11','4208 Šenčur','Slovenija','SLOVENIA','+386','0038640419360','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 16:35:09',0,NULL,3,1,2,1,NULL,'vidicigor21\r庄'),(8466,664851357001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','paula9156','garyk9156@hotmail.com','Gary Kirkpatrick','11311 Bertrand Ave','Granada Hills','CA','UNITED STATES','91344','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 17:05:51',0,NULL,3,0,1,1,NULL,'paula9156\r52mm (2)\r55mm (2)\r58mm (1)\r62mm (1)\r67mm (2)\r72mm (1)\r77mm (1)\r庄'),(8467,760355788016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','panos_pc2246','panios_ast@yahoo.gr','Panagiotis   Hatzipananis','Campos    Iou','Ios     Cyclades','Greece','GREECE','84001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 17:10:34',0,NULL,3,1,2,1,NULL,'panos_pc2246\r庄'),(8468,705695364002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','victorarandagarcia','victorarandagarcia@yahoo.es','Víctor Aranda García','Av. Blasco Ibañez, 64. Esc: B. Pta: 5','Valencia','Comunidad Valenciana','SPAIN','46021','600336126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 17:13:24',0,NULL,3,1,3,1,'RA117739178CN\r ','victorarandagarcia\r庄\r'),(8469,705691850002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','vcha8330','vince@vincechanblog.ca','Vincent Chan','91 Durie St.','Toronto','ON','CANADA','M6S 3E7','(416) 762-1255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 18:00:15',0,NULL,8,1,17,0,NULL,'vcha8330'),(8470,664855782001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','vcha8330','vince@vincechanblog.ca','Vincent Chan','91 Durie St.','Toronto','ON','CANADA','M6S 3E7','(416) 762-1255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 18:00:16',0,NULL,3,1,3,1,'RA117739164CN ','vcha8330\r单灯头    2\r反光伞    1\r庄\r'),(8471,705702263002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','david_chapple','melanie_chapple@yahoo.co.uk','David Chapple','Venn Hayes<br>Higher Metcombe','Ottery St Mary','Devon','UNITED KINGDOM','EX11 1SR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 18:13:06',0,NULL,3,1,2,1,NULL,'david_chapple.\r庄'),(8472,664332416001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','amasya05','kuntayebay@gmail.com','Kuntay Aktaş','Libya caddesi<br>96 lar sitesi 6/6','Ankara','Kolej','TURKEY','06420','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 18:15:26',0,NULL,3,1,3,1,'RA117739252CN\r','amasya05\r刘\r\r'),(8473,664920698001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','jmaphotographic','jmasoccer@aol.com','Jamie Antonioli','3142 Oakwood Ln','Alamo','CA','UNITED STATES','94507','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 19:19:19',0,NULL,3,1,1,1,' ','jmaphotographic\r庄'),(8474,705788748002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','stanislaw999*123','rude@tesco.net','Andrew Rudolf','70 Canterbury Drive<br>Washinborough','Lincoln','Lincolnshire','UNITED KINGDOM','ln4 1sx','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 20:12:58',0,NULL,3,1,3,1,'RA117739249CN\r','stanislaw999*123\r刘\r'),(8475,664962021001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','oshri3','yaniv.oshri@gmail.com','Oshri Yaniv','alumim 28<br>47','Kiryat-Netafim','','ISRAEL','44815','972-052-6330258','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 21:28:36',0,NULL,3,1,3,1,'RA17739354CN \rRA117739337CN\r','oshri3\r分2个挂号小包发\r刘'),(8476,760513027016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','jeeg.1975','biagio.pelligra@gmail.com','Biagio Pelligra','via Toselli 136','Palermo','PA','ITALY','90143','3931111376','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 21:45:18',0,NULL,3,1,2,1,NULL,'jeeg.1975\r庄'),(8477,776290299015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',18.3,'hutongstore','saabze','zebaas@me.com','Laurens Wilming','5 Pinhoe Drive','Haverhill','Suffolk','UNITED KINGDOM','CB9 7WF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 21:49:29',0,NULL,3,1,3,1,NULL,'saabze\r庄\rRA17739270CN'),(8478,760517974016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','norad100','mj12templar@gmail.com','Oliver Galea','Blk 1, Flat 7, Appt. 21-09-1964,<br>Triq tal-Fieres,','Kirkop','','MALTA','KKP 1541','(356) 99062891','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 21:53:29',0,NULL,3,1,2,1,' ','norad100\r庄'),(8479,776300826015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','mattakadeimos','matt.wagg@ntlworld.com','Matt Wagg','63 Hart Avenue','Sandiacre','Nottinghamshire','UNITED KINGDOM','NG105FY','01159398955','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 22:16:26',0,NULL,3,1,3,1,NULL,'mattakadeimos\r庄\rRA17739306CN'),(8480,760527751016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','tomonners','onners@hotmail.com','Thomas ONLEY','1 St Peter\'s Road<br>Newchurch','Rossendale','Lancashire','UNITED KINGDOM','BB4 9EZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 22:22:01',0,NULL,3,1,2,1,NULL,'tomonners\r庄'),(8481,705844254002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','aimee-2605','ayjones@bigpond.net.au','Aimee Jones','6 Doveleys Rd','Como West','New South Wales','AUSTRALIA','2226','0400768428','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 22:50:09',0,NULL,3,0,3,1,NULL,'aimee-2605（已入库）\r3XL\r庄\rRA17739297CN'),(8482,705848358002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',3,'AE1201',14.4,'hermeshine','mgrande','jbrhoward@aol.com','Jerry Howard','3302 N. Salida del Sol','chandler','AZ','UNITED STATES','85224','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 23:03:31',0,NULL,3,1,1,1,NULL,'mgrande\r庄'),(8483,776325487015,250801607283,'Light Stands 2m /6\'56\" for photo studio lighting ×2 NEW',1,'AKT031',35,'hutongstore','dfbugeja','david@artandconservation.net','david bugeja','22, Our Saviour Street,','Qrendi','','MALTA','QRD 1700','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 23:31:29',0,NULL,3,1,3,1,'RA17739345CN \rRA117739310CN\r','dfbugeja\r注意数量！\r分两个小包发\r刘'),(8484,665025496001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','2000hero','viviwallart@gmail.com','SHI HUA CHEN','4842 S KENYON ST','SEATTLE','WA','UNITED STATES','98118-4133','(206) 227-6096','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 00:32:52',0,NULL,3,0,1,1,NULL,'2000hero\r白色\r庄\r'),(8485,665026852001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','vcrazy111','zenvcrazy111@gmail.com','Vi Tran','303 Pennyhill Dr','San Jose','CA','UNITED STATES','95127-1829','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 00:34:15',0,NULL,3,1,1,1,NULL,'vcrazy111\r庄'),(8486,705875309002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','ricabras','photobrasil@gmail.com','Ricardo Brasil','Rua Mucu nº 10 apto 102, Alto da Boa Vista','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531-180','5521-2570-4633','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 00:46:29',0,NULL,3,1,3,1,'RA17739283CN ','ricabras\r2XL\r庄\r'),(8487,665068516001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','saavpiz','daniel_piz@hotmail.com','Daniel Saavedra','Carrera 20 # 51 - 46 apto 301','Bogota','Cundinamarca','COLOMBIA','11001000','3005642135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 03:25:14',0,NULL,3,1,2,1,NULL,'saavpiz\r庄'),(8488,665070064001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','dbuker','djbecommerce@gmail.com','Daniel J. Buker','1111 E Tennessee St<br>Fla Dental Association','Tallahassee','FL','UNITED STATES','32308-6937','(850) 345-9922','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 03:29:34',0,NULL,3,1,1,1,' ','dbuker\r庄'),(8489,760625056016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',120,'hutongstore','jkegholm','kalle@jkegholm.dk','Kalle Egholm','Bellisallé 14','Horsens','','DENMARK','DK8700','004561304107','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 03:47:45',0,NULL,3,1,4,1,' YW864488992CN','jkegholm\r欧标\rlighting kit $26\r王'),(8490,760627156016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','bigtors70','bigtors@gmail.com','Aleksejs Jegorovs','26 Montfort','Monaghan','Monaghan','IRELAND','default','3534762856','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 03:54:09',0,NULL,3,1,2,1,NULL,'bigtors70\r庄'),(8491,665084522001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','sergejstrelchenko2010','sergej.strelchenko@mail.ru','Сергей Стрельченко','Фрунзе 14<br>Фрунзе 14','станица Платнировская','Краснодарский край Кореновский район','RUSSIAN FEDERATION','353177','89284162835','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 04:57:18',0,NULL,8,1,17,0,NULL,'sergejstrelchenko2010'),(8492,665085218001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','sergejstrelchenko2010','sergej.strelchenko@mail.ru','Сергей Стрельченко','Фрунзе 14<br>Фрунзе 14','станица Платнировская','Краснодарский край Кореновский район','RUSSIAN FEDERATION','353177','89284162835','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 04:59:48',0,NULL,3,1,5,1,' CP26269055CN','sergejstrelchenko2010\r肩架   2'),(8493,705932898002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','delatapu88','felipe_molinad@yahoo.com','felipe molina','5/162 old south head road<br>bellevue hill','sydney','New South Wales','AUSTRALIA','2023','0447976759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 05:02:11',0,NULL,3,1,2,1,NULL,'delatapu88\r庄'),(8494,665092922001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',65.96,'hermeshine','almearaj','aalmiraj5@gmail.com','Abdullah Jaffar Makki AlMearaj','P.O. Box 20028','Qateef','','SAUDI ARABIA','31911','00966503893668','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 05:55:20',0,NULL,3,1,3,1,NULL,'almearaj\r看看两个斜臂有没有可能在2kg以下， 如果不行，就发两个小包\rRA117739385CN'),(8495,665099326001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','phreak_cz','krizjakub@yahoo.com','Mr. Jakub Kriz','Rooseveltova 2129','Litvinov','','CZECH REPUBLIC','436 01','00420724044447','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 06:31:49',0,NULL,8,1,17,0,NULL,'phreak_cz'),(8496,705949232002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','phreak_cz','krizjakub@yahoo.com','Mr. Jakub Kriz','Rooseveltova 2129','Litvinov','','CZECH REPUBLIC','436 01','00420724044447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 06:33:52',0,NULL,8,1,17,0,' ','phreak_cz'),(8497,665100069001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','phreak_cz','krizjakub@yahoo.com','Mr. Jakub Kriz','Rooseveltova 2129','Litvinov','','CZECH REPUBLIC','436 01','00420724044447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 06:34:54',0,NULL,3,1,3,1,'RA117739399CN ','phreak_cz\r2m 灯架   1\r双灯头 欧标  1\r反光伞    1\r庄\r'),(8498,665102497001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','molchanov_r','molchanov_roman@mail.ru','Роман Молчанов','ул.Бирюзова д.31 корп. 1 кв. 252','г. Рязань','','RUSSIAN FEDERATION','390039','89206346666','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 06:48:45',0,NULL,3,1,3,1,'RA117739371CN ','molchanov_r\r庄\r'),(8499,665119312001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','biker1011985','biker@email.ua','Evgen Stadnik','164a Chapaeva Street, Apt.29','Alchevsk','Luganskaya oblast','UKRAINE','94207','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-04-26 08:42:30',0,NULL,3,1,3,1,' RA117739500CN','biker1011985\r庄'),(8500,760691231016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','becs308','becsgoodrum@yahoo.co.uk','Miss R Goodrum','7 The Glebe<br>Thorverton','Exeter','Devon','UNITED KINGDOM','EX5 5LS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 09:01:00',0,NULL,3,1,2,1,NULL,'becs308'),(8501,705940882002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','kikrisda','kasadit@yahoo.com','Krisda Indrasthitya','Faculty of Architecture<br>KMITL.','Lardkabang','Bangkok','THAILAND','10520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 09:11:16',0,NULL,3,1,2,1,NULL,'kikrisda'),(8502,705980465002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','2010darkcloud1985','s.dark123@gmail.com','Spiriadis Alexandros','Panormou 6','Xanthi','προεπιλογή','GREECE','67100','2541100998','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 09:27:31',0,NULL,3,1,3,1,' RA117739439CN','2010darkcloud1985\r庄'),(8503,704681607002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',78.9,'hermeshine','houser1974','torralb@gmail.com','Carlos Torralba Ruiz','Avda. Condesa de Chinchon 17 , Ch 11','Boadilla del Monte','Madrid','SPAIN','28660','656359068','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 09:36:43',0,NULL,3,1,4,1,' YW864488863CN','houser1974\r2m背景架（ 白 黑）\rbackground support $25\r庄'),(8504,705993704002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','dnshall','dnshall@yahoo.com','Dennis Hall','2716 Cedar Street','Berkeley','CA','UNITED STATES','94708','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 10:26:04',0,NULL,3,1,1,1,' ','dnshall\r庄'),(8505,665140384001,110414475072,'16chan Wireless Remote Control Set for OLYMPUS RM-UC1',1,'AA3206',18.5,'hermeshine','liliborisova','liligb@abv.bg','Lili Borisova','Aleksandar Stamboliyski 25','Golyama Brestnitsa','Lovech/Yablanitsa','BULGARIA','5753','0899911134','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 10:33:00',0,NULL,3,1,2,1,NULL,'liliborisova'),(8506,665150247001,110618888297,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380  user',1,'AA2121',32,'hermeshine','visistudio','visi_photographer@hotmail.com','ERVIS BOSTANXHI','Ave Gjergj Kastrioti no.12<br>Lagja no 12','KORCA','AL','ALBANIA','7000','+355672065800','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 10:43:35',0,NULL,3,1,3,1,'RA117739425CN ','visistudio\rxl\r庄'),(8507,776504277015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','jaronyka','jaroslava.krajcova@gmail.com','Jaroslava Oprendek Krajčová','P. Jilemnického 838/37','Svit','','SLOVAK REPUBLIC','05921','00421 911 952 634','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 10:56:40',0,NULL,3,1,2,1,NULL,'jaronyka\r庄'),(8508,706027052002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','lgianoni82','lgianoni@hotmail.com','Lorena Gianoni','Luis B. Cavia 2888','Montevideo','Montevideo','URUGUAY','11300','598 98 842 086','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 12:40:52',0,NULL,3,1,3,1,' RA117739487CN','lgianoni82\rXL\r庄'),(8509,776539841015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','baklan4ikof','saveleva.da@gmail.com','Дарья Савельева','3-я Владимирская д.8/1 кв. 8','Москва','','RUSSIAN FEDERATION','111123','(926)3455526','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 13:05:56',0,NULL,3,1,2,1,' ','baklan4ikof\r庄'),(8510,706034424002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','vokoda','vokoda@gmail.com','Dániel János Vokó','Vörösmarty utca 55 3/9','Budapest','','HUNGARY','1064','+36204943627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 13:07:34',0,NULL,3,1,3,1,'RA117739495CN ','vokoda\r庄'),(8511,663270116001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','pavelpi88','pi88@yandex.ru','Pavel A Groisman','D.Rishkanu 11-a apt.6','Kishinev','-','MOLDOVA, REPUBLIC OF','2024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 13:08:14',0,NULL,3,1,2,1,NULL,'pavelpi88\r庄'),(8512,0,120711872890,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.25,'hermeshine','george35209','gbrowder@gmail.com','George Browder','2041 S Moonlit Pt','Homosassa','FL','UNITED STATES','34448-2164','(352) 621-9108','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 13:46:34',0,NULL,7,1,17,0,' ','george35209\r庄'),(8513,776562813015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','jonesnet57','jonesnet57@yahoo.co.uk','Martin Jones','167 College Road','Deal','Kent','UNITED KINGDOM','CT146BX','01304367434','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 13:50:31',0,NULL,8,1,17,0,NULL,'jonesnet57'),(8514,760778775016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','jonesnet57','jonesnet57@yahoo.co.uk','Martin Jones','167 College Road','Deal','Kent','UNITED KINGDOM','CT146BX','01304367434','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 13:50:32',0,NULL,8,1,17,0,NULL,'jonesnet57'),(8515,776562814015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','jonesnet57','jonesnet57@yahoo.co.uk','Martin Jones','167 College Road','Deal','Kent','UNITED KINGDOM','CT146BX','01304367434','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 13:50:33',0,NULL,3,1,3,1,' RA117739473CN','jonesnet57\r反光板  80cm 5合1   1\r橡胶遮光罩 52mm    1\r橡胶遮光罩 72mm    1\r庄\r'),(8516,760786545016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','abonentas00','ajarasius@yahoo.com','Arturas Jarasius','Vyduno al. 25a-1','Kaunas','Kaunas','LITHUANIA','50289','+37067535735','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 14:12:39',0,NULL,3,1,2,1,NULL,'abonentas00\r庄'),(8517,665220142001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','mkarpienia','marcin.karpienia@gmail.com','Marcin Karpienia','5B<br>Jamaica Street','Inverness','Highland','UNITED KINGDOM','IV3 8DP','01463240148','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-04-26 15:03:54',0,NULL,3,1,2,1,NULL,'mkarpienia\r庄'),(8518,665221061001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','cmontechi','carloslm@uol.com.br','Carlos Oliveira','Av Bem Te Vi 362 ap 53C','Sao Paulo','SP','BRAZIL','04524030','551155356430','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 15:06:44',0,NULL,3,1,2,1,NULL,'cmontechi\r刘'),(8519,760817265016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','tomfromiceland','beele899@planet.nl','Geert van der Beele','van Eyckstraat  38','Maasbree','','NETHERLANDS','5993CV','077-4652641','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 15:31:37',0,NULL,3,1,2,1,NULL,'tomfromiceland\r王'),(8520,665236092001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','legna.nabetse','gelesteban@gmail.com','Angel Esteban Rubio Fernandez','Iglesia 26','Olmeda del Rey - Cuenca','Castilla-La Mancha','SPAIN','16216','696726409','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 15:52:27',0,NULL,3,0,3,1,' RA117739411CN','legna.nabetse\rXL\r庄'),(8521,776613639015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','tykelock','richwilliams2001uk@yahoo.co.uk','RICHARD WILLIAMS','18A RECTORY VIEW','LOCKINGTON','East Riding of Yorkshire','UNITED KINGDOM','YO259SG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 15:57:14',0,NULL,3,1,2,1,NULL,'tykelock\r王'),(8522,706102407002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','olenka253','olgausa@yandex.ru','Olga Ilinykh','821 Livania Ln','Lexington','ky','UNITED STATES','40509-1758','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-26 16:41:49',0,NULL,3,1,3,1,'RA117739442CN ','olenka253\r刘'),(8523,760897918016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.3,'hutongstore','promethius7','promethius747@hotmail.com','Ivan Hocking','38 Nodder Road','Sheffield','South Yorkshire','UNITED KINGDOM','S138DD','01142391224','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 18:18:19',0,NULL,3,1,2,1,NULL,'promethius7\r刘'),(8524,760913924016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7.99,'hutongstore','hemligamalin','brand.malin@gmail.com','Malin Brand','Södra Ravingatan 8','Forshaga','','SWEDEN','66730','+4654181909','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 18:55:44',0,NULL,3,1,2,1,NULL,'hemligamalin\r转接环   52mm   1\r渐变灰  1\r卡座      1\r刘'),(8525,706147951002,120553897299,'Wireless Flash Sync Trigger Receiver NEW pt-04tm ',1,'AB3322',19.99,'hermeshine','lemuag','ergamu@gmail.com','David Lozano Abad','C/ Lagos de Coronas 34,  3ºC','Zaragoza','Aragón','SPAIN','50011','655429392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 18:32:22',0,NULL,3,1,2,1,NULL,'lemuag\r王'),(8526,705118028002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','krisino2009','krisino@inbox.lv','Kristaps Hohs','Baldones str.6','Ogre','','LATVIA','LV-5001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 19:21:06',0,NULL,3,1,2,1,NULL,'krisino2009\r刘'),(8527,706177845002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','910bradfordlane','xtremeist9@gmail.com','Laure Connelly','662 Trackside Dr','Aberdeen','NC','UNITED STATES','28315-5004','(910) 281-4535','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 19:32:59',0,NULL,3,1,1,1,' ','910bradfordlane\r庄'),(8528,0,120714815883,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',0.99,'hermeshine','2009jrbsr','jimbettesr@gmail.com','James Bette','145 Biscayne Dr','Athens','GA','UNITED STATES','30606-1801','(706) 353-2742','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 19:35:49',0,NULL,3,1,1,1,NULL,'2009jrbsr\r庄'),(8529,706186151002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dwuw12','dwuw12@hotmail.com','Andrew Fredrickson','2422 S Gray Dr','Lakewood','CO','UNITED STATES','80227-3958','(720) 936-4126','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 19:49:50',0,NULL,3,1,1,1,' ','dwuw12\r庄'),(8530,706189000002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','foh83','freddy_thort@hotmail.com','freddy onaja hirano','pasaje los jaspes 184 balconcillo - la victoria','lima','lima','PERU','lima 13','005112661393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 19:55:55',0,NULL,3,1,2,1,NULL,'foh83\r王'),(8531,760955525016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','cupplesey','andy.cupples@gmail.com','Andrew Cupples','Flat 9, Roscoe House<br>7 Wood End Rd, Erdington','Birmingham','West Midlands','UNITED KINGDOM','B24 8AA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 20:00:39',0,NULL,3,1,2,1,NULL,'cupplesey\r王'),(8532,706196428002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','2011oleb','ole-b@hotmail.com','Ole B Hella','Radoeyvegen 2135','Manger','','NORWAY','5936','+47 41233689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:12:07',0,NULL,3,1,3,1,'RA117739368CN ','2011oleb\r王'),(8533,665352555001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','tostegroo_001','tostegroo@yahoo.com.br','Fabio Toste','Rua Almerina Rebuci, 283','São Bernardo do Campo','São Paulo','BRAZIL','09690-040','551143611228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:21:38',0,NULL,3,1,2,1,NULL,'tostegroo_001\r刘'),(8534,665358510001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','nnkp','pham_kim@hotmail.com','Pham Kim','Gueta 2','Savigny','','SWITZERLAND','1073','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:34:38',0,NULL,3,1,2,1,NULL,'nnkp\r刘'),(8535,706208158002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','chudo_alex','chudo1978@yandex.ru','ALEXEY CHUDINOVSKIKH','MAKLINA str., 63а-49','KIROV','KIROVSKAYA OBLAST','RUSSIAN FEDERATION','610035','+79536810128','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:39:01',0,NULL,3,0,2,1,NULL,'chudo_alex\r粉\r1.6x3m'),(8536,706245915002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',60,'AA1310',329.4,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 22:21:24',0,NULL,3,1,5,1,' CP26269047CN','blinker-182\r庄'),(8537,706264839002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','stillenma','mikestill@5615.com','Mike Still','14 Indian Ridge Dr<br>Mike Still And Associates','leominster','MA','UNITED STATES','01453-5233','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 23:34:07',0,NULL,3,1,1,1,NULL,'stillenma\r庄\r'),(8538,663861070018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'',280,'photographyacc','neuf-occas31','jjalmero@asiaindustrie.com','Sophie BARBE','9 chemin d\'auzeville, Bat E12','TOULOUSE','Midi-Pyrénées','FRANCE','31400','06.11.08.05.05','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-26 23:46:37',0,NULL,3,1,4,1,'YW864488852CN ','neuf-occas31\r欧标\r2m 灯架   3\r斜臂   1\r50x70cm 单灯头  3\r115W 220V 灯泡  3\r2x2m 背景架  1\r1.6x2.1m 背景布  2（黑+白）\r灯架包  1\r申报：40$ / Lighting Kit\r刘'),(8539,761052673016,260660053068,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',23.9,'hutongstore','crazy.ted','crazy_ted55@hotmail.com','Teddy Serriere','59 rue de la libération','bruyeres le chatel','idf','FRANCE','91680','06.75.90.71.06','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-26 23:54:11',0,NULL,3,1,3,1,' RA117739456CN','crazy.ted\r刘'),(8540,706291561002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','axoi1138','aksoy@thisisforyou.com.au','Onur Aksoy','21 Finisterre Drive Keysborough','Melbourne','Victoria','AUSTRALIA','3173','610402834825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 01:23:33',0,NULL,3,1,2,1,NULL,'axoi1138\r刘'),(8541,0,110677756796,'Adjustable Padded Camera Neck shoulder Strap for Canon',1,'AB1404',2.5,'hermeshine','roccooneout1','rtwater1@earthlink.net','Roman  Tkach','1722 Village Dr','Lynden','WA','UNITED STATES','98264-1283','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 03:28:28',0,NULL,3,1,1,1,NULL,'roccooneout1\rcanon和nikon肩带各一条'),(8542,665486362001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','mauricegubiani','mauricegubiani@yahoo.co.uk','Maurice Gubiani c/o OTEK','Level 1, 222 St Kilda Rd<br>St Kilda','Melbourne','Victoria','AUSTRALIA','3182','0409707982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 05:19:35',0,NULL,3,1,3,1,'RA117714105CN\r\\ ','mauricegubiani\r王'),(8543,706354887002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dekalos','sdekalo@gmail.com','shahar dekalo','hamelaacha 2','ramat hasharon','israel','ISRAEL','47445','0544578957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 06:38:46',0,NULL,3,1,2,1,NULL,'dekalos\r王'),(8544,706358058002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mroy3824','nanie3@globetrotter.net','mario roy','60, boul. notre-dame','pont-rouge','QC','CANADA','g3h 3k6','(418) 873-2975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 07:02:42',0,NULL,3,1,3,1,'RA117714026CN\r ','mroy3824\r王'),(8545,665504955001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','doraditoalvarado','tavobuenaonda@hotmail.com','octavio garcia','7 Gurney Pl, page','Canberra','Australian Capital Territory','AUSTRALIA','2614','0423865333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 07:11:35',0,NULL,3,1,2,1,NULL,'doraditoalvarado\r王'),(8546,706366154002,120582352724,'New 49mm ring adapter replacement for cokin P series',1,'AA2207',3.55,'hermeshine','stopframe','andrey@yarigin.com','Andrey Yarigin','Pushkinskaya street<br>6-88','Scherbinka','Moscow region','RUSSIAN FEDERATION','142172','+7(926)495-0860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 07:42:08',0,NULL,8,1,17,0,NULL,'stopframe'),(8547,706365917002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',2,'AKT018',9.74,'hermeshine','stopframe','andrey@yarigin.com','Andrey Yarigin','Pushkinskaya street<br>6-88','Scherbinka','Moscow region','RUSSIAN FEDERATION','142172','+7(926)495-0860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 07:42:10',0,NULL,3,1,3,1,'RA17714012CN\r\\ ','stopframe\r52mm 环架   2\r49mm 接口环    2\r王'),(8548,776551493015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','andreccarvalho','andrecostacarvalho@gmail.com','Andre Carvalho','Praceta Mario de Sa Carneiro<br>n-5 10-Esq','Odivelas','','PORTUGAL','2675-235','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 08:24:42',0,NULL,3,1,3,1,' RA117714193CN','andreccarvalho\r欧标\r申报 light $20\r王'),(8549,776975185015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','tziras','info@theodoreziras.com','Theodoros Ziras','Egosthenon 42-44<br>Galatsi','Athens','Athens','GREECE','11146','(+30)6936743993','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-27 08:33:15',0,NULL,3,1,4,1,' YW866010531CN','tziras\r欧标\rlighting kit $40\r王'),(8550,776973458015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.25,'hutongstore','pbrito55','pedro.j.n.brito@gmail.com','Pedro Brito','Ericsson T.<br>Ed. Infante D. Henrique','Quinta da Fonte','Paço de Arcos','PORTUGAL','2770192','00351934466350','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 08:33:27',0,NULL,8,1,17,0,NULL,'pbrito55'),(8551,761175140016,260660055035,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'AKT006',40,'hutongstore','pbrito55','pedro.j.n.brito@gmail.com','Pedro Brito','Ericsson T.<br>Ed. Infante D. Henrique','Quinta da Fonte','Paço de Arcos','PORTUGAL','2770192','00351934466350','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 08:33:28',0,NULL,3,1,3,1,'RA117714202CN','pbrito55\r58mm 环架   1\r10片状套装\r\r52mm 接口环  1\r王'),(8552,761179567016,260675928086,'New Small Camera bag lens case D2 for Canon 500D 450D',1,'AO0033',5,'hutongstore','playteam1234','vonnie@ryder1241.fsnet.co.uk','Yvonne Ryder','7 Greenway<br>Coppenhall','Crewe','Cheshire','UNITED KINGDOM','CW1 4JN','01270583593','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 08:43:47',0,NULL,3,1,2,1,NULL,'playteam1234'),(8553,761180619016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','andiermann','aw012e3054@blueyonder.co.uk','andrew watts','15 malcolm road<br>shirley','solihull','West Midlands','UNITED KINGDOM','b90 2ah','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 08:47:05',0,NULL,3,1,2,1,NULL,'andiermann'),(8554,761184723016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','andrew_fish','andrew@thefishtank.info','Andrew Fish','59 Fourth Avenue','Edwinstowe','Nottinghamshire','UNITED KINGDOM','NG21 9PQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 09:04:17',0,NULL,3,1,2,1,' ','andrew_fish\r庄'),(8555,665531827001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',92,'hermeshine','silygrl56','llgeorge6@comcast.net','Linda L. George','17524 114th St E','Bonney Lake','wa','UNITED STATES','98391','(253) 297-1831','NoPaymentFailure','CheckoutComplete','Other','2011-04-27 09:25:31',0,NULL,3,1,4,1,' YW866010494CN','silygrl56\r灯泡是110v的\r庄'),(8556,706390726002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','sundsdal','csundsdal@gmail.com','Christian Sundsdal','Vestre Kvartergade 7d, st','Hvidovre','Denmark','DENMARK','2650','0045 31198080','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 09:55:33',0,NULL,3,1,4,1,' YW866010483CN','sundsdal\r小号镜头筒   1\r717AH   1\rballhead  $22\r王'),(8557,665536028001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','sundsdal','csundsdal@gmail.com','Christian Sundsdal','Vestre Kvartergade 7d, st','Hvidovre','Denmark','DENMARK','2650','0045 31198080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 09:55:34',0,NULL,8,1,17,0,NULL,'sundsdal'),(8558,665541249001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',26,'AE3103',254.8,'hermeshine','vladimirzeonmaster','zeonmaster@yandex.ru','vladimir morgunov','kiev-32<br>post office box  №278','Kiev','ua','UKRAINE','01032','(050) 387  0299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 10:07:46',0,NULL,3,1,5,1,'     CP227020208CN','vladimirzeonmaster\r庄'),(8559,665540386001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',68.95,'hermeshine','prg8303','foruse@inbox.ru','Roman Podvysotskiy','kurchatov st., 3-18','Obninsk','Kaluga','RUSSIAN FEDERATION','249037','+79056433839','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 10:32:54',0,NULL,3,1,5,1,' \r\rCP227020199CN\r','prg8303\r2m 弹簧灯架 红盒  1\r反光板支架    1\r庄\r'),(8560,665554991001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','yevgeniy9','euzar@hotmail.com','Lyubov Litvin','Levit Medical Arts Pavilion<br>1220 Avenue P','Brooklyn','NY','UNITED STATES','11229','(718) 376-1004','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 11:06:01',0,NULL,3,1,1,1,NULL,'yevgeniy9\r庄'),(8561,665555706001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','attesom','lamiscusi@libero.it','Federico Gilberto Cambielli','viale Trento e Trieste , 39','Tradate','VA','ITALY','21049','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 11:09:36',0,NULL,3,1,2,1,NULL,'attesom\r庄'),(8562,706418900002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','johnnycipika','cipry_kungfu_06@yahoo.com','Ciprian Baltag','9 rue general vouillemont','Bar sur aube','Champagne-Ardenne','FRANCE','10200','0601380815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 11:42:20',0,NULL,3,1,2,1,NULL,'johnnycipika\r王'),(8563,665563854001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 11:49:30',0,NULL,3,1,3,1,' RA117714065CN\rRA117714159CN\r','saud-p\r分成2个挂号小包发\r王'),(8564,664014446018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','missty66','aagadi.steph@live.fr','AAGADI STEPHANIE','130 ANCIENNE ROUTE DE LABRUGUIERE<br>RESIDENCE LES PASTELS APT C02','CASTRES','Midi-Pyrénées','FRANCE','81100','0629135308','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-27 11:51:03',0,NULL,3,1,4,1,'YW866010520CN ','missty66\r王\rlighting kit $26\r欧标'),(8565,777035135015,250690849529,'Background Support & Light Kit 3m x 6m 10 x 20ft white ',1,'AKT038',134,'hutongstore','skabet589','carie_16_2003@hotmail.com','carie clack','49 st anslems road','hayes','Middlesex','UNITED KINGDOM','ub3 4sd','07719824063','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-27 11:53:42',0,NULL,3,1,4,1,' YW866010516CN','skabet589\r2x3m 背景架    1\r3x6m 背景布    1（白）\r2m 灯架   2\r双灯头     2 英标\r柔光伞    2（！）\r\r45w  灯泡   4\r灯架包    1\r庄\r'),(8566,706429183002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','jphotographyb','jamesbianchi88@gmail.com','James Bianchi','13, Olive Street<br>The Gardens','St Julains','Malta','MALTA','stj 1953','0035621359413','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 12:20:41',0,NULL,3,1,2,1,NULL,'jphotographyb\r王'),(8567,777068005015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0005',15.98,'hutongstore','traygleeson17','traygleeson@yahoo.co.uk','Tracey Gleeson','16 Killucan Manor Green<br>Rathwire','Mullingar','Westmeath','IRELAND','default','0449376544','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 13:34:45',0,NULL,3,0,2,1,' ','traygleeson17\r1.6x2.1m      背景布   2（蓝+粉）'),(8568,777083656015,250692242296,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',2,'AA3314',8.56,'hutongstore','stefan588','stefan11schulz@gmx.de','Stefan Schulz','Von der Heydt 31','Ibbenbüren','','GERMANY','49477','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 14:12:56',0,NULL,3,1,2,1,' ','stefan588\r庄'),(8569,665622305001,110419742422,'Green.L 67mm Neutral Density ND8 Filter ND 8 67',1,'AE2312',6.7,'hermeshine','luizweb','luizantoniogsimoes@gmail.com','Luiz Simoes','Rua Olavo de Paula Borges, 83<br>ap. 23-B','Santos','São Paulo','BRAZIL','11035-130','13-3236-8826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 15:10:36',0,NULL,3,1,2,1,NULL,'luizweb'),(8570,706485645002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','danieltamir2009','danitamir@walla.co.il','daniel tamir','sivtey israel 41','haifa','israel','ISRAEL','26277','+97248400678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 15:30:49',0,NULL,3,1,2,1,NULL,'danieltamir2009\r庄'),(8571,0,110677409268,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',0.99,'hermeshine','wolfguy2010','cwhr2010@yahoo.com','Kevin Smith','52509 Railroad St','La Pine','OR','UNITED STATES','97739-9511','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 15:34:27',0,NULL,3,1,1,1,NULL,'wolfguy2010\r庄'),(8572,665637241001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','sunny_logic2','jswarner2001@hotmail.com','Jack Warner','9a Eastlake Road<br>Camberwell','London','London','UNITED KINGDOM','SE5 9QJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 15:54:06',0,NULL,3,1,2,1,' ','sunny_logic2'),(8573,0,120714452027,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.49,'hermeshine','yurila71','yuri_lausberg@hotmail.com','Yuri Lausberg','916 129th PL NE','Bellevue','WA','UNITED STATES','98005-2610','(425) 681-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 16:00:07',0,NULL,3,1,1,1,NULL,'yurila71\r庄'),(8574,665646737001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','tuzik_nnov','tuzikebay@gmail.com','Oleg Zozulya','pr. Gagarina, d. 103, kv. 45','Nizhniy Novgorod','','RUSSIAN FEDERATION','603137','(910) 870 4210','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 16:19:38',0,NULL,3,1,3,1,' RA117714145CN','tuzik_nnov\r庄'),(8575,664122742018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',36,'photographyacc','liandiex','gpkokkinos@gmail.com','Giannis Kokkinos','5 Trapezountos str','Thessaloniki','','GREECE','55236','+306944315310','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,8,1,17,0,NULL,'liandiex'),(8576,664125275018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','liandiex','gpkokkinos@gmail.com','Giannis Kokkinos','5 Trapezountos str','Thessaloniki','','GREECE','55236','+306944315310','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117714220CN ','liandiex\r45w 5500k 灯泡    4\rNikon 三角包  D3   1\r庄   0.902'),(8577,665196863001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','aspire1640z','diman1640z@mail.ru','Дмитрий Алымов','14 Декабря, 4, 10','Узловая','Тульская обл','RUSSIAN FEDERATION','301602','+79207530720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 17:24:28',0,NULL,3,1,2,1,NULL,'aspire1640z\r王'),(8578,777174141015,250599389839,'55mm CPL Circular Polarizing Filter 55 CPL Green.L New',1,'AA3309',3.38,'hutongstore','dan_e_bernt','danerlend@hotmail.com','Dan Erlend Berntsen','Manglerudvn 22','Oslo','','NORWAY','0678','92648228','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 17:42:40',0,NULL,8,1,17,0,NULL,'dan_e_bernt'),(8579,777182653015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','dan_e_bernt','danerlend@hotmail.com','Dan Erlend Berntsen','Manglerudvn 22','Oslo','','NORWAY','0678','92648228','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 17:54:13',0,NULL,3,1,2,1,NULL,'dan_e_bernt\r绿叶 CPL  55mm   1\r绿叶 CPL  58mm    1\r庄'),(8580,706543499002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','captainfuture','michael@rauch.com','Michael Rauch','Wingender Strasse 35','Neuss','GERMANY','GERMANY','41462','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 18:05:33',0,NULL,8,0,17,0,NULL,'captainfuture'),(8581,665687269001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','captainfuture','michael@rauch.com','Michael Rauch','Wingender Strasse 35','Neuss','GERMANY','GERMANY','41462','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 18:08:42',0,NULL,3,0,3,1,' RA117714114CN','captainfuture\r摄影背心 黑色薄 canon  XXL  1\r摄影背心 \rCanon  老款 \rXXL      1\r庄'),(8582,0,120714451938,'100% Genuine Lenspen lens cleaning tools NIB free S&H',1,'AA1310',3.25,'hermeshine','ankvn2000','ankvn@hotmail.com','W. P. L. (Kevin)','1614 251st St','Harbor City','CA','UNITED STATES','90710-2602','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 18:44:25',0,NULL,3,1,1,1,' ','ankvn2000\r庄'),(8583,0,110677409295,'55mm 55 mm Macro +4 Close-Up Close Up Filter',1,'AE3216',1.29,'hermeshine','dmsoho','dmetzpa@aim.com','Don Metz','149 Countryview Dr','Mc Kees Rocks','PA','UNITED STATES','15136-1252','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 19:15:42',0,NULL,3,1,1,1,NULL,'dmsoho\r庄'),(8584,777240002015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','angelo.2003','angelo2003@infinito.it','angelo de luca','Antonio Labriola, 6','grosseto','GR','ITALY','58100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 19:30:09',0,NULL,3,1,3,1,' RA117714176CN','angelo.2003\r庄\rbulbs  $10'),(8585,0,110677409667,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',0.99,'hermeshine','gmoratz','gamoratz@gmail.com','gary moratz','5936 Jellico Ave','encino','CA','UNITED STATES','91316','(818) 983-3248','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 19:57:21',0,NULL,3,1,1,1,NULL,'gmoratz\r庄'),(8586,0,110677409517,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.99,'hermeshine','rajan52s','rajan52s@gmail.com','SUNIL RAJAN','12 Rockland Dr','Jericho','NY','UNITED STATES','11753-1409','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 20:53:00',0,NULL,3,1,1,1,NULL,'rajan52s\r庄'),(8587,761476596016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','shorty.jude','shorty.jude@btopenworld.com','Judith Lipp','16 Ashton Gardens<br>Gartcosh','Glasgow','North Lanarkshire','UNITED KINGDOM','G698EF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 20:53:15',0,NULL,3,0,2,1,NULL,'shorty.jude\r换成“Canon 小号内胆包    1”\r庄'),(8588,665767243001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','taraa76','hdenizli@gmail.com','HAKAN DENİZLİ','TUNUS CADDESİ<br>No:95 Kavaklıdere','ANKARA','','TURKEY','06680','5325251986','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:01:14',0,NULL,3,1,2,1,NULL,'taraa76\r王'),(8589,665770711001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','komishukov','komishuko@gmail.com','Konstantin Mishukov','PILKONTIE 11','JOENSUU','','FINLAND','80130','358-505670104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:10:41',0,NULL,3,1,2,1,NULL,'komishukov\r王'),(8590,706629677002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','zoran1961','zoran.valencic@gmail.com','Zoran Valenčič','Cesta na Markovec 27','Koper','','SLOVENIA','6000','05 0562753','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 21:14:43',0,NULL,3,0,3,1,' RA117714128CN','zoran1961\rXXXL\r庄'),(8591,0,110677409599,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.99,'hermeshine','rainy2sunny','rstump@rochester.rr.com','Robert  L Stump','40A Whitney Ridge Road<br>Apt 8','Fairport','NY','UNITED STATES','14450','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 21:27:25',0,NULL,8,1,17,0,NULL,'rainy2sunny'),(8592,0,110677409356,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.99,'hermeshine','rainy2sunny','rstump@rochester.rr.com','Robert  L Stump','40A Whitney Ridge Road<br>Apt 8','Fairport','NY','UNITED STATES','14450','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 21:27:25',0,NULL,8,1,17,0,NULL,'rainy2sunny'),(8593,0,120714451996,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',2.21,'hermeshine','rainy2sunny','rstump@rochester.rr.com','Robert  L Stump','40A Whitney Ridge Road<br>Apt 8','Fairport','NY','UNITED STATES','14450','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 21:27:27',0,NULL,3,1,1,1,NULL,'rainy2sunny\r橡胶遮光罩 52mm    1\r橡胶遮光罩 58mm    1\r橡胶遮光罩 72mm    1\r庄'),(8594,706635802002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:31:38',0,NULL,8,1,17,0,NULL,'bobi1330'),(8595,665779334001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:34:10',0,NULL,3,1,2,1,NULL,'bobi1330\rCANON 镜头盖  67mm   1\rNIKON 镜头盖 67mm     1\r王'),(8596,0,120714452530,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',0.99,'hermeshine','add0987','druhzin@yahoo.com','Terry Pitman','807 Kings Mill Rd<br>Apt 138','Greenwood','IN','UNITED STATES','46142-1795','(765) 343-2150','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 22:09:11',0,NULL,3,1,1,1,NULL,'add0987\r庄'),(8597,761515785016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','kazysk','kazys.simutis@gmail.com','Mr Kazys Simutis','3rd Floor, Block B, Ulster Bank Group Centre, George\'s Quay<br>Dublin 2','Dublin','Dublin','IRELAND','2','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 22:25:18',0,NULL,3,1,2,1,NULL,'kazysk\r庄'),(8598,777330114015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','johanfolkesson','johan.folkesson@gmail.com','Johan Folkesson','Erik Tegels väg 19','Spånga','','SWEDEN','16340','0706484484','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 22:32:09',0,NULL,3,1,2,1,NULL,'johanfolkesson\r庄'),(8599,706655950002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',2,'AB1305',7.58,'hermeshine','shellcottage','fcrover@gmail.com','John Allaman','1205 S Orange Ave','Sarasota','FL','UNITED STATES','34239','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 22:37:17',0,NULL,3,1,1,1,NULL,'shellcottage\r庄'),(8600,0,110677409442,'62mm 3-Stage Rubber Lens Hood for D80 D90 450D 500D',1,'AB1304',0.99,'hermeshine','thegaryharris','thegaryharris@msn.com','Gary Harris, Jr.','6651 Falling Branch Rd','Fairlawn','VA','UNITED STATES','24141-8449','(540) 998-9086','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 23:15:53',0,NULL,3,1,1,1,NULL,'thegaryharris\r庄'),(8601,665809552001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','kirum28','thanaratep@yahoo.com','THANARA  TEP','30 Carmody Parade','North Lakes','Queensland','AUSTRALIA','4509','0353343368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 23:24:23',0,NULL,3,1,2,1,NULL,'kirum28'),(8602,0,110677409237,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',1.36,'hermeshine','arbolito','virginitagarcia@hotmail.com','Virginia Pena','6730 Longmeade Ln','Orlando','FL','UNITED STATES','32822','(407) 658-0418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 23:37:44',0,NULL,3,1,1,1,NULL,'arbolito\r庄'),(8603,665815687001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','babel1*miles777','lbcurado@gmail.com','Luís Barros Curado','Estrada dos Bernardos, Lote 60<br>Manique de Baixo','Alcabideche','Cascais','PORTUGAL','2645-456','919191074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 23:51:16',0,NULL,3,1,2,1,NULL,'babel1*miles777'),(8604,665823886001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','olafbonsai','abg@bedinialejandro.com','Alejandro Bedini','Nexus<br>ENRIQUE MAC IVER - 440 piso 15','Santiago','RM','CHILE','8320123','0057-2-4208504','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 00:30:22',0,NULL,8,0,17,0,NULL,'olafbonsai'),(8605,706683025002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','olafbonsai','abg@bedinialejandro.com','Alejandro Bedini','Nexus<br>ENRIQUE MAC IVER - 440 piso 15','Santiago','RM','CHILE','8320123','0057-2-4208504','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 00:30:23',0,NULL,3,1,3,1,' RA117714131CN','olafbonsai\r摄影背心 黑色厚 sony  XL\r摄影背心 Nikon 老款  XXL\r庄'),(8606,665825480001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',7.98,'hermeshine','13766899433','woshidaixiao@gmail.com','Xiao Dai','216 Verano PL','Irvine','CA','UNITED STATES','92617','(408) 896-8778','NoPaymentFailure','CheckoutComplete','Other','2011-04-28 00:34:45',0,NULL,3,1,1,1,NULL,'13766899433\r王'),(8607,706715119002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','ahennell','andrew@hennell.com.au','Andrew Hennell','PO Box 8016<br>(21 Woollum Crescent)','Rivett','Australian Capital Territory','AUSTRALIA','2611','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 02:35:56',0,NULL,3,1,2,1,NULL,'ahennell\r庄'),(8608,665857317001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','nj_muttonchop','nj_mutton@hotmail.com','Nick  Mutton','30 Eucalyptus drive','Sydney','New South Wales','AUSTRALIA','2120','0199806751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 02:59:41',0,NULL,3,1,2,1,' ','nj_muttonchop\r庄\r'),(8609,665859649001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','gbm417','brian.marchman@gmail.com','Brian Marchman','217 Border Rd','Goose Creek','SC','UNITED STATES','29445-9643','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 03:08:02',0,NULL,3,1,1,1,NULL,'gbm417\r庄'),(8610,706716464002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','theplayersamigo','theplayersamigo@earthlink.net','Todd Jackson','8224 Wooden Windmill Ct','Las Vegas','NV','UNITED STATES','89131-1443','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 03:50:02',0,NULL,3,1,1,1,NULL,'theplayersamigo\r庄'),(8611,664122742018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',36,'photographyacc','liandiex','gpkokkinos@gmail.com','Giannis Kokkinos','5 Trapezountos str','Thessaloniki','','GREECE','55236','+306944315310','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-04-28 04:06:25',0,NULL,7,0,18,0,NULL,'liandiex'),(8612,664125275018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','liandiex','gpkokkinos@gmail.com','Giannis Kokkinos','5 Trapezountos str','Thessaloniki','','GREECE','55236','+306944315310','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-04-28 04:06:36',0,NULL,7,0,18,0,NULL,'liandiex'),(8613,665878761001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','gbgraphics_1','gbaron@zahav.net.il','guy baron','rozanski 17/6','rehovot','','ISRAEL','76453','972-8-9463207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 05:02:04',0,NULL,8,1,17,0,NULL,'gbgraphics_1'),(8614,706743606002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','gbgraphics_1','gbaron@zahav.net.il','guy baron','rozanski 17/6','rehovot','','ISRAEL','76453','972-8-9463207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 05:02:03',0,NULL,8,1,17,0,NULL,'gbgraphics_1'),(8615,665878825001,110419738494,'Green.L 72mm Neutral Density ND4 Filter ND 4 72',1,'AE2306',7.3,'hermeshine','gbgraphics_1','gbaron@zahav.net.il','guy baron','rozanski 17/6','rehovot','','ISRAEL','76453','972-8-9463207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 05:02:05',0,NULL,8,1,17,0,NULL,'gbgraphics_1'),(8616,665878703001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','gbgraphics_1','gbaron@zahav.net.il','guy baron','rozanski 17/6','rehovot','','ISRAEL','76453','972-8-9463207','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 05:02:09',0,NULL,3,1,3,1,' RA117714247CN\rRA117714162CN\rRA117714255CN','gbgraphics_1\r2m 灯架  2\r50-70 棚  2 欧标\r包    1\r72mm ND4    1\r72mm 渐变灰   1\r1转4灯头    1\r分两个小包发\r王'),(8617,706743798002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','molchanov_r','molchanov_roman@mail.ru','Роман Молчанов','ул.Бирюзова д.31 корп. 1 кв. 252','г. Рязань','','RUSSIAN FEDERATION','390039','89206346666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 05:03:19',0,NULL,8,1,17,0,NULL,'molchanov_r'),(8618,705964939002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','molchanov_r','molchanov_roman@mail.ru','Роман Молчанов','ул.Бирюзова д.31 корп. 1 кв. 252','г. Рязань','','RUSSIAN FEDERATION','390039','89206346666','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 05:03:19',0,NULL,3,1,3,1,'RA117714445CN ','molchanov_r\r反光板 100*150 40*60 5合1  1\r爵影红外 canon    1\r'),(8619,706744393002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','leomir2','dcedl@dalunet.cz','Jan Pidrman','Dvorakova 34','Zatec','','CZECH REPUBLIC','43801','+420602785437','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 05:13:28',0,NULL,3,0,3,1,'RA117714233CN ','leomir2\rXXXL (已减库）\r王'),(8620,777439593015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','kalinindmitriy','dkphoto@yandex.ru','Dmitriy Kalinin','Nevelskogo 4-197','Vladivostok','Primorskij','RUSSIAN FEDERATION','690013','+7-904-627-0183','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 05:20:28',0,NULL,3,1,2,1,NULL,'kalinindmitriy\r王'),(8621,665884261001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','cepn85','serious.pet@gmail.com','Sergey Peterman','Nastavnikov st. 42 - 70','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','195279','+7-911-977-1-977','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 05:51:00',0,NULL,3,1,5,1,'CP227020239CN\r ','cepn85\r王'),(8622,665889562001,110414475072,'16chan Wireless Remote Control Set for OLYMPUS RM-UC1',1,'AA3206',18.5,'hermeshine','dodoberecz214','berecz@atknet.sk','Dodo Berecz','Rožňavská 3','Košice','','SLOVAK REPUBLIC','04011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 06:11:16',0,NULL,3,1,2,1,NULL,'dodoberecz214\r王'),(8623,777463160015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','johnecache','johnpplant@gmail.com','John Plant','4 Osprey Close<br>Beechwood','Runcorn','Cheshire','UNITED KINGDOM','WA7 3JH','01928797001','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-28 07:11:10',0,NULL,3,1,2,1,NULL,'johnecache\r王'),(8624,664377967018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','rouche2011','hattinghrachel@vodamail.co.za','Rouche Du Toit','Bloekom street 4','secunda','Mpumalanga','SOUTH AFRICA','2302','+27825903125','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-28 07:37:17',0,NULL,3,1,3,1,'RA117714397CN \rRA117714383CN\rRA117714370CN','rouche2011\r分别记录一下3个小包多重  \r王\r1.89     1.994   0.656'),(8625,706769467002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','rouche2011','hattinghrachel@vodamail.co.za','Rouche Du Toit','Bloekom street 4','secunda','Mpumalanga','SOUTH AFRICA','2302','+27825903125','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 07:37:18',0,NULL,8,0,17,0,NULL,'rouche2011'),(8626,777471611015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','joan-rompe5066','joan-rompe@telefonica.net','joan bagur garrido','calle gelosos, 1','ciutadella de menorca','Baleares','SPAIN','07760','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 07:47:14',0,NULL,3,1,2,1,NULL,'joan-rompe5066\r欧标'),(8627,706769537002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','perryrimanda2010','perry.rimanda@gmail.com','perry rimanda','Aplikanusa Lintasarta<br>Menara Thamrin Lt.19 Jl. MH Thamrin Kav.3','Jakarta','DKI Jakarta','INDONESIA','10250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 08:09:30',0,NULL,3,1,2,1,NULL,'perryrimanda2010'),(8628,665912701001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','algirdasj','alibuchas@gmail.com','Algirdas Jankauskas','Gedvydžių 29-71','Vilnius','','LITHUANIA','06310','867651243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 08:15:07',0,NULL,3,1,2,1,NULL,'algirdasj'),(8629,706715983002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','nameohname','psychonoetic@gmail.com','Fotios Vrionis','70 LYNDEN STREET, CAMBERWELL 3124','MELBOURNE','Victoria','AUSTRALIA','3124','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 08:24:52',0,NULL,3,1,2,1,NULL,'nameohname'),(8630,706778386002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vigakuguitarist','vigakuguitarist@yahoo.com','Glenn Rodriguez','48552 Morgan Ln','Newberry Springs','CA','UNITED STATES','92365-9298','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 08:50:17',0,NULL,3,1,1,1,' ','vigakuguitarist\r庄'),(8631,665922498001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:05:15',0,NULL,3,1,2,1,NULL,'bobi1330\r庄'),(8632,706789800002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','rikif_123','spamy@fotoreport.eu','Richard Frydl - HBC REALITY','Nadrazni 535/15','Ostrava','CZECH REPUBLIC','CZECH REPUBLIC','70200','+420737005500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:24:37',0,NULL,3,1,3,1,'RA117714335CN ','rikif_123\r王'),(8633,706796630002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vatchravee_t','vatchravee@hotmail.com','Vatchravee Tasnavijitvong','297/29, Chaiwiwat3 Village, Soi Wat Bua Kwan<br>Ngamwongwan Road, Bangkrasau, Muang','Nonthaburi','Nonthaburi','THAILAND','11000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:57:32',0,NULL,3,1,2,1,NULL,'vatchravee_t\r庄'),(8634,706794566002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','kristijanorlic','info@arijanova.hr','Kristijan Orlić','Put Pudarice 1','ZADAR','ZADAR','CROATIA','23000','+385 23 31 60 60','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:04:18',0,NULL,3,1,3,1,' RA117714349CN','kristijanorlic\r刘 '),(8635,777503792015,250599945807,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',1.85,'hutongstore','freakingweird','markmurphywexford@gmail.com','Mark Murphy','Tomfarney<br>Clonroche','Enniscorthy, T-087-6771820','Wexford','IRELAND','N30','0876771820','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 10:20:42',0,NULL,3,1,2,1,NULL,'freakingweird\r庄'),(8636,706802968002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','djpetabyte','goda@gmx.at','Peter Goda','Am Dechantriegel 22','Voitsberg','','AUSTRIA','8570','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:32:22',0,NULL,3,1,2,1,NULL,'djpetabyte\r庄\r'),(8637,706814543002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','potpot03','jayemcar@yahoo.co.uk','jay carag','8 Maudlin Vale<br>Trim, Co. Meath','Trim','comeath','IRELAND','default','0469483601','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 11:16:52',0,NULL,3,1,2,1,NULL,'potpot03\r庄'),(8638,706816952002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','sergeybaykal','guran38@yandex.ru','Sergey Tumolskiy','ul. Lenina dom 40, kv. 42','Irkutsk','RU','RUSSIAN FEDERATION','664003','+79025109440','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 11:25:40',0,NULL,3,1,3,1,'RA117714264CN ','sergeybaykal\rL     王'),(8639,706817258002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','demonod','dick_an@hotmail.com','Sherley Nobin','Nicholson road le fou lane','vacoas','mauritius','MAURITIUS','230','+2306971479','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 11:27:35',0,NULL,3,1,8,1,' CP26269033CN','demonod\r注意是河北的那个\r有1.6x2.1 白色背景布 一块\r王'),(8640,665955914001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','ivicabrujo','bodul@bodul.com','Ivica Brusic','Brusici 24','Malinska','Croatia','CROATIA','51511','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 11:36:07',0,NULL,3,1,3,1,'RA117714278CN ','ivicabrujo\r王'),(8641,761718992016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','057noel','nbernes1@eircom.net','noel bernes','mendips cottage<br>windsor','coolrain','Laois','IRELAND','default','0578735892','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 11:53:12',0,NULL,3,1,2,1,NULL,'057noel\r庄'),(8642,0,110677409488,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',0.99,'hermeshine','george35209','gbrowder@gmail.com','George Browder','2041 S Moonlit Pt','Homosassa','FL','UNITED STATES','34448-2164','(352) 621-9108','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 12:06:06',0,NULL,3,1,1,1,NULL,'george35209\r庄\r'),(8643,665963579001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','sophiec23','sophie230986@gmail.com','Sophie Constant','Bk A1 Emile Basset Saint Croix','Port Louis','Port Louis','MAURITIUS','742CU001','+2307719962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 12:07:19',0,NULL,3,1,2,1,' ','sophiec23\r庄'),(8644,706839634002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','jkup3146','mit@jankupec.net','Jan Kupec','Hoenggerstrasse 136','Zuerich','','SWITZERLAND','8037','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 12:54:57',0,NULL,3,1,4,1,' YW866010575CN','jkup3146\r欧标\rlighting kit $27\r庄'),(8645,665978023001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','turboatom','mmx310@gmail.com','Oleksandr Mazuryak','Chervonoarmiska 101 77','Chernivtsi','Chernivetska','UKRAINE','58013','+380509511122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:01:58',0,NULL,3,1,2,1,NULL,'turboatom\r庄'),(8646,665983785001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ezrati','ezrati_david@walla.com','david ezrati','tiltan<br>8','oranit','','ISRAEL','44813','9720502677337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:22:33',0,NULL,3,1,2,1,' ','ezrati\r庄'),(8647,706847183002,120619188583,'NEW 72mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT047',32,'hermeshine','ivrgoc','ivrgoc@yahoo.com','Sanja Majcan','Ljubijska 8','Zagreb, Dubrava','','CROATIA','10040','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 13:23:42',0,NULL,3,1,3,1,'RA117714318CN ','ivrgoc\r庄'),(8648,706871465002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','montfort48','jc.parmantier@free.fr','PARMANTIER  Jean Claude','34 Bd Saint Aignan','NANTES','Pays de la Loire','FRANCE','44100','0614836008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 14:49:42',0,NULL,3,1,2,1,NULL,'montfort48\r庄'),(8649,666011411001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','lucasalvadore','luca@salvadore.ch','Luca Salvadore','Av. des Alpes 64','Montreux','','SWITZERLAND','1820','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 15:00:54',0,NULL,3,1,4,1,' YW866010564CN','lucasalvadore\rtripod $16\r庄'),(8650,706876972002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','pm.romero','d.mente@hotmail.com','Pablo Martin Romero','Rep. Argentina 221','Santa Lucía','Canelones','URUGUAY','90700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 15:06:28',0,NULL,3,1,3,1,'RA117714304CN','pm.romero\r刘'),(8651,706882801002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','elainor','adrian7386@gmail.com','Adrian Ong','11A, Forsyth Street','Kingsford','New South Wales','AUSTRALIA','2032','0433977939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 15:25:47',0,NULL,3,1,2,1,NULL,'elainor\r庄'),(8652,706891120002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','zerokhan','karotmarin@hotmail.com','Carlos Marín Aguilar','c/ del rey    Nº 62     piso 2º D','Aranjuez','Madrid','SPAIN','28300','918918736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 15:51:13',0,NULL,3,1,2,1,NULL,'zerokhan\r庄'),(8653,706896693002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','casaluca2004','casaluca@hotmail.com','LUCA CASAGRANDE','VIALE S.MARCO 70 MESTRE','VENEZIA','VE','ITALY','30173','041-976292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 16:09:13',0,NULL,3,1,4,1,'YW866010553CN ','casaluca2004\r800w红头灯     1\r800w  220v 灯泡     1\r灯本身就是欧标吧\r王'),(8654,761825344016,260660053205,'New Neoprene Reversible Bag Cover for Large-DSLR  L',1,'AC1302',6.1,'hutongstore','debauchery72','debsiporter@googlemail.com','Debi Porter - Children\'s Finance','Room 316, Oldway Mansion<br>Torquay Road','Paignton','Devon','UNITED KINGDOM','TQ3 2TE','01803206259','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-28 16:47:02',0,NULL,3,1,2,1,NULL,'debauchery72\r庄'),(8655,665973028001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','anato01','smart2bay@yandex.ru','Anatoliy Alekseev','86 Golovatogo Str.','Krasnodar','ru','RUSSIAN FEDERATION','350004','+7(903)4538945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 17:37:52',0,NULL,3,1,3,1,'RA117714352CN ','anato01\r刘'),(8656,706936647002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','raymonddelonpoh','raymonddelon@msn.com','Raymond Delon Poh','101 Telok Ayer Street #03-03<br>Singapore','default','','SINGAPORE','068574','+6597699996','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 17:56:22',0,NULL,3,1,3,1,'RA117714406CN ','raymonddelonpoh\r王'),(8657,777734947015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','alanslotus','alan.paterson5@ntlworld.com','Alan   Paterson','13 Littlefield Close, Ash','Aldershot','Hampshire','UNITED KINGDOM','GU12 6TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-28 19:22:52',0,NULL,3,0,2,1,NULL,'alanslotus\r白色\r庄\r'),(8658,706998847002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','micro1973','ebay@niechcial.de','Thorsten Niechcial','Buddenbergstraße 23','Selm','','GERMANY','59379','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 20:13:55',0,NULL,8,1,17,0,NULL,'micro1973'),(8659,706999523002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','micro1973','ebay@niechcial.de','Thorsten Niechcial','Buddenbergstraße 23','Selm','','GERMANY','59379','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:15:19',0,NULL,3,1,3,1,'RA117714295CN ','micro1973\rsony 单肩包  A1    1\r爵影红外 sony       1\r刘'),(8660,664625235018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','solidagoart','solidagoart2010@hotmail.it','marco scarparo','via pertini,21(ex via torino)','gessate','MI','ITALY','20060','3478109706','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-28 20:22:46',0,NULL,3,1,4,1,'YW866010542CN ','solidagoart\r欧标\r庄'),(8661,777779639015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','boldon.lad','normanharvey@btinternet.com','Norman Harvey','AP 1030<br>Urb. Camposol','Mazarron','Murcia','SPAIN','30875','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 20:41:12',0,NULL,3,1,2,1,NULL,'boldon.lad\r庄'),(8662,666148603001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','david19731','chauvin85@aol.com','chauvin david','31 rue jean jaures','saint maixent','deux sevres','FRANCE','79400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:52:16',0,NULL,3,1,2,1,NULL,'david19731\r庄'),(8663,666162920001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','jmcv','jmvazquez@cusbro.com','Jose Maria VAZQUEZ','Balcarce 353 6to. \'14\'','Buenos Aires','South America','ARGENTINA','1064','(54-1)4446-5623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 21:34:04',0,NULL,3,1,2,1,NULL,'jmcv\r庄'),(8664,666166175001,110419738256,'Green.L 67mm Neutral Density ND4 Filter ND 4 67',1,'AE2305',6.7,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 21:43:28',0,NULL,3,1,2,1,NULL,'dvdguychatter2\r庄'),(8665,707047230002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','rudolfflachs','rudolf.flachs@centrum.cz','Rudolf Flachs','Na hrade 1118','Ricany','Praha-vychod','CZECH REPUBLIC','25101','602341972','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 22:26:16',0,NULL,3,1,3,1,'RA117714321CN ','rudolfflachs\r2XL\r王'),(8666,777824135015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','fwacsmum','agbofamily@agbofamily.plus.com','Stephanie Agbo','21 Hallett Road','Ansford','Somerset','UNITED KINGDOM','BA77LG','01963350261','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-28 22:32:15',0,NULL,3,1,2,1,' ','fwacsmum\r庄'),(8667,707045747002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','r.fonseca','ricardo_fonseca@live.com.pt','Ricardo Fonseca','Rua do Mercado nº28 3860-126','Avanca','default8','PORTUGAL','3860-126','(351) 926157786','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 22:32:31',0,NULL,3,1,2,1,NULL,'r.fonseca\r庄'),(8668,707055881002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','jamballa13','jaycool1320@yahoo.com','Jared Fullerton','1320 Fulton Ave<br>Apt C2','Bronx','NY','UNITED STATES','10456','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 22:58:47',0,NULL,3,1,1,1,' ','jamballa13\r刘'),(8669,666192206001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jumiroc','jumiroc@gmail.com','Juan M.  Roca Ripoll','Av. Argentina, 8, 1º, A','Palma de Mallorca','Baleares','SPAIN','07011','971288891','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 23:23:14',0,NULL,3,1,2,1,NULL,'jumiroc\r庄'),(8670,707092629002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','svafar2005','svafarr@hotmail.com','Svafar Ragnarsson','Esjugrund 16','Reykjavik','','ICELAND','116','+354 8609727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 01:21:08',0,NULL,3,1,2,1,' ','svafar2005\r庄'),(8671,664715669018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',57,'photographyacc','johnmac6969','john.macmaster@anz.com','john macmaster','8 Addison Avenue','Tarneit','Victoria','AUSTRALIA','3029','0424171334','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-04-29 01:23:54',0,NULL,3,1,3,1,'RA117714281CN ','johnmac6969\r45w 5500k 灯泡    2\r2B柔    1套    \r刘'),(8672,707101463002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','zuma_r6','cryhar@yahoo.com','Crystal  Harris','3009 3rd Ave W','Hibbing','MN','UNITED STATES','55746-2434','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-29 02:02:06',0,NULL,3,0,1,1,NULL,'zuma_r6\r庄'),(8673,762062986016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',3,'AA1310',11.34,'hutongstore','brandon_cro','brandonccronin@hotmail.com','Brandon Cronin','22 Liosdara<br>Oakpark','Tralee','Kerry','IRELAND','default','0667120952','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 02:41:37',0,NULL,3,1,2,1,NULL,'brandon_cro\r庄'),(8674,666251541001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','mli94','qiuranke@mac.com','Na Li','14317 Outpost Way','North Potomac','MD','UNITED STATES','20878','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-29 03:42:12',0,NULL,3,1,1,1,NULL,'mli94'),(8675,666264150001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','monchr366','viennasv@yahoo.com','Vienna Vogelezang','49 Berkshire Dr','Howell','NJ','UNITED STATES','07731-2355','(732) 814-4436','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-29 05:15:44',0,NULL,3,1,1,1,NULL,'monchr366'),(8676,666290121001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','ivrgoc','ivrgoc@yahoo.com','Jelena Alpeza (kod Grgec)','Liganjska 6','Zagreb, Dubrava','','CROATIA','10040','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 07:32:54',0,NULL,3,1,3,1,'RA117714785CN\r ','ivrgoc\r'),(8677,777977137015,250692241184,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',4,'AE3601',51.96,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-29 08:27:00',0,NULL,8,1,17,0,NULL,'leifs123'),(8678,777977867015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',49.98,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-29 08:29:34',0,NULL,3,1,4,1,' YW866010586CN\r','leifs123\r115w 220v  8'),(8679,666231833001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',40,'hermeshine','braderbob','bob_azrul@yahoo.com','AZRUL NIZAM ABD. RAHIM','1007<br>SCHOEMAN STREET','ARCADIA','PRETORIA','SOUTH AFRICA','0083','27123425990','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 09:33:10',0,NULL,8,1,17,0,NULL,'braderbob'),(8680,707186783002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','braderbob','bob_azrul@yahoo.com','AZRUL NIZAM ABD. RAHIM','1007<br>SCHOEMAN STREET','ARCADIA','PRETORIA','SOUTH AFRICA','0083','27123425990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 09:33:09',0,NULL,8,1,17,0,NULL,'braderbob'),(8681,666312593001,110417014177,'72mm 72 mm Macro +8 Close-Up Close Up Filter',1,'AE3227',8.5,'hermeshine','braderbob','bob_azrul@yahoo.com','AZRUL NIZAM ABD. RAHIM','1007<br>SCHOEMAN STREET','ARCADIA','PRETORIA','SOUTH AFRICA','0083','27123425990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 09:33:09',0,NULL,8,1,17,0,NULL,'braderbob'),(8682,666313081001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','braderbob','bob_azrul@yahoo.com','AZRUL NIZAM ABD. RAHIM','1007<br>SCHOEMAN STREET','ARCADIA','PRETORIA','SOUTH AFRICA','0083','27123425990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 09:33:08',0,NULL,3,1,3,1,'RA117714834CN\r ','braderbob\r6片装 （ 渐变灰， 渐变橙，渐变蓝，ND2, ND4， ND8) +滤镜袋\r72mm 环架   1\r72mm +8   1\rnikon 52mm 反接环   1'),(8683,664819617018,280666902955,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',7.99,'photographyacc','chloehayden2011','sallyanneharp@hotmail.com','anne harpley','80<br>Laver Road','Mount Brown','New South Wales','AUSTRALIA','2530','0242623665','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-04-29 10:12:38',0,NULL,3,1,2,1,NULL,'chloehayden2011'),(8684,707206186002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','ecosieteeu','ecosiete@yahoo.es','Jose Romera Puga','Crevillente 2 bis','Santa Maria Del Aguila','Almeria','SPAIN','04710','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 11:08:43',0,NULL,8,1,17,0,NULL,'ecosieteeu'),(8685,707205883002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','ecosieteeu','ecosiete@yahoo.es','Jose Romera Puga','Crevillente 2 bis','Santa Maria Del Aguila','Almeria','SPAIN','04710','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 11:08:44',0,NULL,3,1,4,1,' YW866010612CN\r','ecosieteeu\r6662A 快装板   1\r三脚架  伟峰 WF-6662A    1\rtripod $16\r王'),(8686,762180855016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','charly151008','bubbling_beauty@hotmail.com','Charlotte Foster','21 Woodhill Gardens','Leeds','West Yorkshire','UNITED KINGDOM','LS16 7DD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-29 11:20:08',0,NULL,3,1,2,1,NULL,'charly151008\r庄'),(8687,666337547001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','kupodivu','dzzeri@seznam.cz','Martin Rejsa','103','Vidlata Sec','Czech Republic','CZECH REPUBLIC','57001','777327520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 11:35:02',0,NULL,3,1,2,1,NULL,'kupodivu\r庄'),(8688,762193284016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','wardystephen','wardstephen@gmail.com','Stephen Ward','Gaybrook','Mullingar','Westmeath','IRELAND','','0879863293','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 12:11:42',0,NULL,3,1,2,1,NULL,'wardystephen\r庄'),(8689,666357870001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','suzzuka','capatcha@gmail.com','Vilen Shushenachev','Sakhalinskaya st.<br>38 - 81','Vladivostok','Primorsky Kray','RUSSIAN FEDERATION','690080','+7 914 7060447','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 13:44:40',0,NULL,3,1,5,1,'CP227020361CN\r ','suzzuka\r欧标\r再加一个50cm的棚   \r王'),(8690,707251702002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','fela81fela','feladales@gmail.com','Fela Waddy','154 Hampshire Grove NW','Calgary','AB','CANADA','T3A5B3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 14:06:53',0,NULL,3,1,5,1,'CP227020358CN\r ','fela81fela\r庄'),(8691,666382033001,110544584989,'16chan Wireless  Control Cord for Canon 40D 50D 5D 5DII',1,'AA3204',18.5,'hermeshine','montresor_123','alain.crozemarie@orange.fr','alain crozemarie','23 rue braniky','montresor','Centre','FRANCE','37460','0679700268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 14:28:02',0,NULL,8,1,17,0,' ','montresor_123'),(8692,666381884001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',87,'hermeshine','montresor_123','alain.crozemarie@orange.fr','alain crozemarie','23 rue braniky','montresor','Centre','FRANCE','37460','0679700268','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 14:28:03',0,NULL,3,1,4,1,'YW866010925CN ','montresor_123\r三脚架 伟峰 WF-6663A     1\ryn159- C3     1   \r'),(8693,666391097001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','alfkro2010','amkpart@gmail.com','Alfred Kroese','level 1<br>55 Hume Street','Crows Nest','New South Wales','AUSTRALIA','2065','0412888951','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 14:57:57',0,NULL,8,1,17,0,NULL,'alfkro2010'),(8694,666390673001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','alfkro2010','amkpart@gmail.com','Alfred Kroese','level 1<br>55 Hume Street','Crows Nest','New South Wales','AUSTRALIA','2065','0412888951','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 14:57:58',0,NULL,8,1,17,0,NULL,'alfkro2010'),(8695,707266685002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','alfkro2010','amkpart@gmail.com','Alfred Kroese','level 1<br>55 Hume Street','Crows Nest','New South Wales','AUSTRALIA','2065','0412888951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 14:57:58',0,NULL,3,1,4,1,' YW866010590CN\r','alfkro2010\r反光板支架    2\r灯架  2m    2\r斜臂   1\rreflector holder  $30\r王\r'),(8696,666393966001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','soundstarstudios','soundstarstudios@gmail.com','SOUNDSTARSTUDIOS Nico Larisch','Neumarkter Str. 17<br>2. Stock 089-78796600','München','','GERMANY','81673','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 15:05:18',0,NULL,3,1,3,1,' RA117714627CN\r','soundstarstudios'),(8697,707274354002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','gforce3d','hmanshar@g.risd.edu','Haim Mansharoff','P.O.Box 17395','Tel Aviv','','ISRAEL','61172','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 15:21:28',0,NULL,3,1,3,1,' RA117714600CN\r','gforce3d\r欧标'),(8698,666401764001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','ibico1974','kenneth.augdal@gmail.com','Kenneth Augdal','Ishavsvegen 69B','Tromsø','Troms','NORWAY','9010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 15:30:50',0,NULL,3,0,3,1,'RA117731191CN ','ibico1974\r1.6x2.1m 灰+黑'),(8699,707279387002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','lentiayus','sudadoidet@yandex.ru','Aleksei Ratnikov','Lipetskaya 14K1, 304','Moscow','RU','RUSSIAN FEDERATION','115404','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 15:38:02',0,NULL,3,1,2,1,NULL,'lentiayus\r庄'),(8700,666410370001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','cmontechi','carloslm@uol.com.br','Carlos Oliveira','Av Bem Te Vi 362 ap 53C','Sao Paulo','SP','BRAZIL','04524030','551155356430','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 15:56:50',0,NULL,3,1,3,1,'RA117714967CN\r ','cmontechi'),(8701,707294781002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','fadzbiz','fadzfaiz@yahoo.com','FADZILAH A. FAIZ','55, JALAN SS21/46,<br>DAMANSARA UTAMA,','PETALING JAYA','SELANGOR','MALAYSIA','47400','012-6408814','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 16:23:01',0,NULL,3,1,9,1,NULL,'fadzbiz\r英标\r王'),(8702,762313979016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','leftshoeleftshoe1','leftshoeleftshoe@hotmail.com','bothwell dube','32 The Lawn<br>Westgrove Estate, Donnybrookhill,','Douglas','Cork','IRELAND','default','0863128579','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 17:35:18',0,NULL,3,1,2,1,NULL,'leftshoeleftshoe1\r白色\r庄'),(8703,762314098016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','marcel77sk','marcel@totojeventure.sk','Marcel Gejdos','Pruzinskeho 3','Zlate Moravce','','SLOVAK REPUBLIC','953 01','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 17:35:44',0,NULL,3,1,3,1,'RA117714511CN\r ','marcel77sk'),(8704,666465601001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',34,'hermeshine','jaakkorajala','killer_jax@yahoo.com','Jaakko Rajala','Eerikinkatu 29 B 28','Turku','','FINLAND','20100','+358400641108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 18:37:54',0,NULL,8,1,17,0,NULL,'jaakkorajala'),(8705,666463966001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','jaakkorajala','killer_jax@yahoo.com','Jaakko Rajala','Eerikinkatu 29 B 28','Turku','','FINLAND','20100','+358400641108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 18:37:56',0,NULL,3,1,3,1,'RA117714595CN\r ','jaakkorajala\r欧标\r45w 5500k 灯泡  2\r柔光箱 50-70cm 单灯头   1'),(8706,666475668001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','dai_fabio_dai','fabioborra@alice.it','Fabio Borra','via sabin<br>24','Cattolica','RN','ITALY','47841','3334772527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 18:55:30',0,NULL,3,1,2,1,NULL,'dai_fabio_dai\r庄'),(8707,707270427002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','vangia7','vanessa288@live.it','giacomo romandini','via dei laghi, 15','martinsicuro','TE','ITALY','64014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 19:13:30',0,NULL,3,0,3,1,'RA117714763CN','vangia7\r1.6x3m 白色'),(8708,707364134002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','ignakismo','ignakismo@hotmail.com','Iñaki González Cuesta','Avenida Cardenal Herrera Oria 121 3º C','Santander','Cantabria','SPAIN','39011','605496329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 19:24:01',0,NULL,3,1,2,1,' ','ignakismo\r庄'),(8709,666492941001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','amachu','mcruzmata@ptvtelecom.com','Maria Cruz Mata','C/ Murcia nº 6 1º B','Cordoba','Andalucía Ceuta y Melilla','SPAIN','14010','957252662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 19:41:15',0,NULL,3,1,2,1,NULL,'amachu\r庄'),(8710,665018295018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',400,'photographyacc','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-29 20:30:43',0,NULL,3,1,8,1,'CP227020335CN\r ','saud-p\r灯架  2m   6\r斜臂   2\r50x70 单灯头 棚   6\r115w 220v    6\r灯架包   2\r王   13.87'),(8711,666503489001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 20:30:44',0,NULL,3,1,3,1,'RA117714865CN\rRA117714879CN\r','saud-p\r分2个小包'),(8712,707392397002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','hcigelo','olegich@apollo.lv','Oleg Vovchenko','Gipsa 2 -1','Riga','','LATVIA','LV-1048','+37129940911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 20:37:38',0,NULL,3,1,2,1,NULL,'hcigelo\r庄'),(8713,778261932015,250709193068,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38.99,'hutongstore','ivars55555','ivarslusis@gmail.com','Ivars Lusis','42 Spruce Court<br>Ashleigh Downs','Tralee','Kerry','IRELAND','default','0862116497','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 21:06:13',0,NULL,3,1,4,1,'YW866010645CN\r ','ivars55555\rreflector holder  $20\r刘'),(8714,662710043001,110498795544,'New soft box photography studio lighting Set',2,'AKT016',194,'hermeshine','crocopk1','la_goran@yahoo.com','Goran Zeric','klepperdans 4','Capelle a/d Ijssel','','NETHERLANDS','2907rc','0627266858','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 22:12:43',0,NULL,3,1,4,1,'YW866010634CN\r ','crocopk1\r欧标\r2m 灯架    4\r50x70单灯头   4\r115w 220v      4\r灯架包    2\rlighting kit $26\r庄\r'),(8715,762437461016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','c.aroon','aroon2702@hotmail.com','Aroon Chanpimpab','Victoria Hall Block F<br>Flat 12 room 2','Newcastle','Tyne and Wear','UNITED KINGDOM','NE2 1XH','077 83977537','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-29 22:20:27',0,NULL,3,1,2,1,NULL,'c.aroon\r庄'),(8716,778290134015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','tomgee3','tiptoptom@talktalk.net','Thomas George','418 Field of Dreams<br>Findhorn','Forres','Moray','UNITED KINGDOM','IV36 3TA','07952549539','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-29 22:25:46',0,NULL,3,1,2,1,NULL,'tomgee3\r庄'),(8717,666558636001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','boyadjy','fred.boyadjian@gmail.com','frederic boyadjian','31 rue charles de gaulle<br>App G','alfortville','Ile-de-France','FRANCE','94140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 23:19:42',0,NULL,3,1,2,1,NULL,'boyadjy\r庄'),(8718,718375541017,270741930246,'QR Quick Release Plate Video Tripod Head 717 EI-717AH',1,'AB1204',7.8,'photographyacc','chilla1142','kahuna@bigpond.net.au','P PEACOCK','42 LAKE BREEZE DRIVE','WINDAROO','Queensland','AUSTRALIA','4207','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-04-30 01:06:31',0,NULL,3,1,2,1,NULL,'chilla1142\r庄'),(8719,666590961001,110618902967,'Pro Photo Vest Blue for Canon 500D 550D 7D 60D  user',1,'AA2116',32,'hermeshine','naprakarn','naprakarn@hotmail.com','Nopparat Klaewklong','TPC Plc.<br>8 I-1 road mabtaphud','Muang','Rayong','THAILAND','21150','081-437-8714','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-30 01:59:16',0,NULL,3,1,3,1,'RA117714998CN\r ','naprakarn\rXL-已入库'),(8720,666599576001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',7.98,'hermeshine','1adamsheehy','exfriendofsigmaxigrantwinner@hotmail.com','Adam Sheehy','21 Linden St<br>Apt 205','Quincy','MA','UNITED STATES','02170-1825','','NoPaymentFailure','CheckoutComplete','Other','2011-04-30 02:42:59',0,NULL,3,1,1,1,NULL,'1adamsheehy\r庄'),(8721,0,120714452362,'62mm 62 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT021',0.99,'hermeshine','eloquentimages','larrya.harrison@gmail.com','Larry Harrison','197 Pinelli Dr','Piscataway','NJ','UNITED STATES','08854','(732) 858-1699','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-30 02:51:25',0,NULL,3,1,1,1,NULL,'eloquentimages\r庄'),(8722,707489062002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','raysan12','raymond@valeo-mtl.com','Raymond Lafontaine','425 Greeley Rd','Springfield','VT','UNITED STATES','05156-8808','(819) 847-4756','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-30 03:17:08',0,NULL,3,1,1,1,NULL,'raysan12\r庄'),(8723,706475841002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','ss321ss321','crazzypics@gmail.com','Sameer Salloum','218 Wadsworth St','Syracuse','NY','UNITED STATES','13203-1048','(315) 254-6501','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-30 04:02:34',0,NULL,3,1,1,1,NULL,'ss321ss321\r庄'),(8724,707523415002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rash10','ran.shalom@gmail.com','Ran Shalom','31 Ashkenazi st.','Tel-Aviv','Tel-Aviv','ISRAEL','69864','+972 54 5429589','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 07:09:57',0,NULL,3,1,2,1,NULL,'rash10\r庄'),(8725,666645229001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','homiricardo','homiricardo@yahoo.com','Ricardo Jurado Sendra','Passeig de la Riera 168 4 3','rubi','Barcelona','SPAIN','08191','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-30 07:29:52',0,NULL,3,1,4,1,'YW866010623CN\r ','homiricardo\rtripod $16'),(8726,707533006002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','aligator_smile','achurch1988@hotmail.com','Alex Churchill','4/43 Linden ave','Boambee East','New South Wales','AUSTRALIA','2452','0266585210','PayPalPaymentInProcess','CheckoutComplete','AU_Other','0000-00-00 00:00:00',0,NULL,3,0,3,1,'RA117714984CN\r ','aligator_smile\r\r1.6x2.1  白色+黑色'),(8727,707551539002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','loffy_thriller','margeta@gmail.com','Marin Margeta','cim<br>crkvena','Mostar','Mostar','BOSNIA AND HERZEGOVINA','88000','0038763408551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 09:13:27',0,NULL,3,1,3,1,'RA117714635CN\r ','loffy_thriller'),(8728,707552465002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gabor1960','vocsok@yahoo.com','Gabor Marsal','Segesvar u. 43.','Budapest','','HUNGARY','1194','+3612826915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 09:18:02',0,NULL,3,1,2,1,NULL,'gabor1960\r庄'),(8729,665210718018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','shaz01','rochmckenzie@hotmail.com','lachlan mckenzie','Lot 5 Tregarthen Rd','Summertown','South Australia','AUSTRALIA','5141','0421282264','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-04-30 10:40:53',0,NULL,3,1,2,1,NULL,'shaz01'),(8730,666692982001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','stinesmiseth','stinesm@yahoo.com','Stine Smiseth','Erling Skjalgssons gt 1C','Oslo','','NORWAY','0267','0047 41 51 10 15','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 11:06:15',0,NULL,3,1,2,1,NULL,'stinesmiseth\r庄'),(8731,665235108018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','sez87','sarahc104@hotmail.com','sarah connolly','1B Clarendon Cres','basin View','New South Wales','AUSTRALIA','2540','','PayPalPaymentInProcess','CheckoutComplete','AU_RegisteredParcelPost','0000-00-00 00:00:00',0,NULL,7,1,18,0,NULL,'sez87'),(8732,707595032002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','roadspider51','jddz1@netscape.net','Joseph D. Zunich','2221 Yale Ave','Maplewood','MO','UNITED STATES','63143-1420','(314) 781-4646','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 12:17:15',0,NULL,3,1,1,1,' ','roadspider51\r庄'),(8733,665236872018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',200,'photographyacc','sez87','sarahc104@hotmail.com','sarah connolly','1B Clarendon Cres','basin View','New South Wales','AUSTRALIA','2540','','PayPalPaymentInProcess','CheckoutComplete','ExpeditedInternational','0000-00-00 00:00:00',0,NULL,7,1,18,1,NULL,'sez87\r澳标\r另外再加一套 河北的背景架 （1.6x2.1 白色背景布）\rlighting kit  $35'),(8734,778504934015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',43,'hutongstore','emregologlu','info@emregologlu.com','Ali Emre Göloğlu','Kızılelma Cad. Münifpaşa Sk.<br>Dilek Saray Ap. No:44 D:8 Fındıkzade','Fatih / İstanbul','','TURKEY','34093','+90 533 929 35 90','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-30 13:03:22',0,NULL,3,1,3,1,'RA117714922CN\r ','emregologlu'),(8735,666737748001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','00xander00','ottino02@tin.it','Lorenzo Ottino','corso adda, 62','Vercelli','VC','ITALY','13100','+393478825573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 13:50:45',0,NULL,3,1,2,1,NULL,'00xander00\r庄'),(8736,707638802002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','bessonov1987','bessonov87@gmail.com','Elena Bessonova','Kutuzova 189-35','Tiraspol','','MOLDOVA, REPUBLIC OF','3300','(373) 777 - 56745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 14:50:26',0,NULL,3,1,2,1,NULL,'bessonov1987\r庄'),(8737,707638752002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','azmyl10790','azmil_ferrari@hotmail.com','Azmil Yusman Josni','Flat 654, A1, Jalan Sungai Pandan, Kampung Mumong','Kuala Belait','Belait','BRUNEI DARUSSALAM','KA1931','6738165480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 15:11:37',0,NULL,3,1,2,1,NULL,'azmyl10790\r庄'),(8738,707650989002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','thayakorn','thayakornv@yahoo.com','Mr.Thayakorn Vhongthamsathit','164 Summakorn Villege,<br>Sukhaphiban 3 Road,','Khet Saphansoung','Bangkok','THAILAND','10240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 15:27:17',0,NULL,3,1,2,1,NULL,'thayakorn\r庄'),(8739,778574615015,250692240862,'Wireless Remote Shutter Release for Nikon D200/D300​/D3',1,'AA3201',11.47,'hutongstore','itru7159','ian.trudgian@sky.com','Ian Trudgian','Flat 2<br>23 Trenance Road','St Austell','Cornwall','UNITED KINGDOM','PL255AJ','01726400164','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 15:44:10',0,NULL,3,1,2,1,NULL,'itru7159\r庄'),(8740,778605720015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','mark-p-white','markphilipwhite@yahoo.com','Mark White','3 Lamb Hill Close','Sheffield','South Yorkshire','UNITED KINGDOM','S13 8FT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 16:52:44',0,NULL,3,1,2,1,NULL,'mark-p-white\r庄'),(8741,762744074016,260660056304,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','salad7016','andrew.gough@blueyonder.co.uk','A GOUGH','30 MARSTON ROAD<br>RUSSELLS HALL','DUDLEY','WEST MIDLANDS','UNITED KINGDOM','DY1 2PA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 16:53:55',0,NULL,3,1,2,1,NULL,'salad7016\r庄'),(8742,707700873002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','jhaber8v0d','jhaber@optonline.net','jordan haber','1 Greenbriar Ln','dix hills','NY','UNITED STATES','11746-5313','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 17:44:56',0,NULL,3,1,1,1,NULL,'jhaber8v0d\r庄'),(8743,707716531002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','climbman69','oguzhanapaydin@hotmail.com','OGUZHAN APAYDIN','S.DEMİRSOY MH HARMAN SOK. 232 BLOK NO:50/4 TURKİS BLOKLARI<br>AYDINLIK EVLER','ANKARA','ANKARA','TURKEY','06130','+905325511504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 18:24:43',0,NULL,3,1,2,1,NULL,'climbman69\r庄'),(8744,666845017001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','borderlightphoto','ishkra@tiscali.it','Scapaticci Fabio','Viale Faenza 26/5','Milano','MI','ITALY','20142','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 18:49:33',0,NULL,3,1,2,1,' ','borderlightphoto\r庄'),(8745,666852570001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','mjardeen','ebay@jardeen.com','Michael Jardeen','305 N K St<br>Apt 4','Tacoma','WA','UNITED STATES','98403-1661','(253) 312-1919','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 19:07:38',0,NULL,3,1,1,1,NULL,'mjardeen\r庄'),(8746,707755350002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','tkachelik','karborund@ya.ru','Igor Tkach','str. Shevchenka 2, apartment 53','Brovary','Kievskaya obl','UKRAINE','07401','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 20:01:02',0,NULL,3,1,2,1,NULL,'tkachelik\r庄'),(8747,665437109018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0035',7.99,'photographyacc','justa1204','justa1204@hotmail.com','Justyna Pietrzkiewicz','ul.Cegielniana 6<br>Posada Zarszyn','Zarszyn','','POLAND','38-530','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-04-30 21:20:45',0,NULL,8,1,17,0,NULL,'justa1204'),(8748,707787440002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','nik_nis_018','cvetkovicn018@yahoo.com','Milan Stojkovic','Dimitrija Tucovica 145','Nis','','SERBIA','18000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 21:33:05',0,NULL,3,1,3,1,'RA117714573CN\r ','nik_nis_018'),(8749,666908919001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','valenova','eva.valenova@gmail.com','Eva Manakova','Banselova 37','Bratislava','','SLOVAK REPUBLIC','82104','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 21:41:29',0,NULL,3,1,2,1,NULL,'valenova\r庄'),(8750,777580475015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',5,'AO0005',39.95,'hutongstore','tristan2101','tristanedgar@yahoo.co.uk','tristan edgar','7 warrenfield court, deighton','huddersfield','West Yorkshire','UNITED KINGDOM','hd2 1lh','01484348160','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 21:42:35',0,NULL,3,0,3,1,'RA117715208CN ','tristan2101\r(5块红色的）'),(8751,707819900002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','nirsarignir','nir_sarig1@walla.co.il','nir sarig','amirim<br>12','tel aviv','north tel aviv','ISRAEL','69357','0544775228','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-30 23:21:43',0,NULL,3,1,3,1,'RA117714936CN\r RA117714851CN\r','nirsarignir\r发红盒的灯架给他吧， 分两个小包发'),(8752,707835788002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','suzzuka','capatcha@gmail.com','Vilen Shushenachev','Sakhalinskaya st.<br>38 - 81','Vladivostok','Primorsky Kray','RUSSIAN FEDERATION','690080','+7 914 7060447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 00:24:37',0,NULL,8,1,17,0,NULL,'suzzuka'),(8753,666957114001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','thunderbird48','thunderbirdartgallery@yahoo.com','Charly Moore/Overland Canyon Tours','48-A-Lake Powell Blvd.','Page','AZ','UNITED STATES','86040','(928) 608-4072','NoPaymentFailure','CheckoutComplete','Other','2011-05-01 01:04:05',0,NULL,3,1,1,1,NULL,'thunderbird48\rM\r庄'),(8754,666967640001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','wsbranson','branson@ndsupernet.com','Wade Branson','930 Shinagle Drive','Dickinson','ND','UNITED STATES','58601','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 01:48:23',0,NULL,3,1,1,1,NULL,'wsbranson\r庄'),(8755,707858635002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','pv008','davehollis@blueyonder.co.uk','DAVE HOLLIS','7 MADDOCKS HILL','WARMINSTER','WILTSHIRE','UNITED KINGDOM','BA12 8DJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 02:02:44',0,NULL,8,1,17,1,NULL,'pv008\r庄'),(8756,707877829002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','kykyky_99','kyang_99@yahoo.com','Ke yang','28 John Beal Dr','Garnet Valley','PA','UNITED STATES','19060-1126','(610) 732-3585','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 03:31:33',0,NULL,3,1,1,1,NULL,'kykyky_99\r庄'),(8757,666989728001,110419738256,'Green.L 67mm Neutral Density ND4 Filter ND 4 67',1,'AE2305',6.7,'hermeshine','cheekim82','cheekim82@yahoo.com.sg','Foo Chee Kim','Block 134 Ang Mo Kio Avenue 3 #09-1689<br>Singapore','default','','SINGAPORE','560134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 03:40:40',0,NULL,3,1,11,1,NULL,'cheekim82'),(8758,707870556002,120454220127,'Green.L 58mm Neutral Density ND4 Filter ND 4 58',1,'AE2303',6.2,'hermeshine','donyzac','jozachar@indiana.edu','Joe Zachariah','30 Severance Cir<br>Apt 517','Cleveland Heights','OH','UNITED STATES','44118-1527','(765) 461-2160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 04:10:20',0,NULL,8,1,17,0,NULL,'donyzac'),(8759,666969105001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','donyzac','jozachar@indiana.edu','Joe Zachariah','30 Severance Cir<br>Apt 517','Cleveland Heights','OH','UNITED STATES','44118-1527','(765) 461-2160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 04:10:20',0,NULL,8,1,17,0,NULL,'donyzac'),(8760,707870430002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',6.2,'hermeshine','donyzac','jozachar@indiana.edu','Joe Zachariah','30 Severance Cir<br>Apt 517','Cleveland Heights','OH','UNITED STATES','44118-1527','(765) 461-2160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 04:10:21',0,NULL,3,1,1,1,NULL,'donyzac\r绿叶 ND4  58mm   1\r绿叶 ND8  58mm   1\r爵影红外 5 in 1      1\r庄'),(8761,707902103002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','sunshaker0','sunshaker@gmail.com','Ken Vale','305-359 Railway Avenue','Stratford','ON','CANADA','N5A 2J3','(519) 574-4811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 05:57:47',0,NULL,3,1,2,1,NULL,'sunshaker0\r庄'),(8762,707909273002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bamboo2u','crazybluepanda@gmail.com','Khanh Vuong','303 Pamela Rd','Monrovia','CA','UNITED STATES','91016-5038','(626) 841-8160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 06:39:45',0,NULL,3,1,1,1,NULL,'bamboo2u\r庄'),(8763,665557968018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','tonylu1017','lulala25@hotmail.com','Tony xiao jun lu','16/23-25 sherbrook road','hornsby','New South Wales','AUSTRALIA','2077','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-01 06:56:28',0,NULL,3,1,2,1,' ','tonylu1017'),(8764,707914472002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',22.9,'hermeshine','caring4parents','chrisacuff@ymail.com','Christopher K Acuff','311 SW 2nd St','Perkins','OK','UNITED STATES','74059-3505','(405) 334-2805','NoPaymentFailure','CheckoutComplete','Other','2011-05-01 07:09:13',0,NULL,3,1,1,1,NULL,'caring4parents\r庄'),(8765,667033901001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','junjunpang','jun-pang@hotmail.com','jun pang','1 Rosedale Ave Wattlepark','Adelaide','South Australia','AUSTRALIA','5066','0883317443','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 07:52:40',0,NULL,3,1,4,1,'YW866010660CN\r ','junjunpang\rlight stand  $20\r刘'),(8766,707937855002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',2,'AC3303',17.58,'hermeshine','koi0_18','vilkuna.k@gmail.com','Kyösti Vilkuna','Rihlaperä 3','Jyväskylä','Länsi-Suomen lääni','FINLAND','40630','(+358) 0400-627378','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 08:44:33',0,NULL,3,1,3,1,'RA117714658CN\r ','koi0_18'),(8767,763073524016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','kerekes29','egyszeriember@gmail.com','Kerekes Zoltán','Mátyás Flórián tér 3.','Pécs','Baranya','HUNGARY','7631','0036302261783','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 10:05:08',0,NULL,3,1,3,1,'RA117714560CN\r ','kerekes29'),(8768,665620588018,280666902955,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',7.99,'photographyacc','justa1204','justa1204@hotmail.com','Katarzyna Pietrzkiewicz','ul.Ogrodowa 33<br>Posada Zarszyn','Zarszyn','podkarpackie','POLAND','38-530','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-01 10:42:13',0,NULL,3,1,2,1,NULL,'justa1204\rcanon 三角包  1\rsony 三角包   1\r王  519'),(8769,665619755018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','kittenkatyte','kate_cu@hotmail.com','Kate Nicolaou','93 Ruby Way','Braybrook','Victoria','AUSTRALIA','3019','0401805024','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-01 10:42:17',0,NULL,3,1,4,1,'YW866010656CN\r ','kittenkatyte\r河北的架子 + 1.6x2.1 白色背景布  1\rbackground support   $20\r王'),(8770,665627509018,280666791794,'New foto Studio 20x27\"/50​x70cm Softbox Universal Mount',1,'AE2203',30,'photographyacc','alanmkchan','mk_junk_box@hotmail.com','Alan Chan','Department of Transport<br>Level 9, 121 Exhibition Street','Melbourne','Victoria','AUSTRALIA','3000','0396556560','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-01 11:04:14',0,NULL,3,1,3,1,'RA117714587CN\r ','alanmkchan'),(8771,707984271002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','jurajstipetic1','juraj.stipetic@hotmail.com','Juraj Stipetic','K. Zvonimira 15','Kutina','Croatia','CROATIA','44320','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 11:18:18',0,NULL,3,1,3,1,'RA117714953CN\r','jurajstipetic1\r+8换成+4'),(8772,707948625002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',3,'AA3312',17.97,'hermeshine','maswino','w_1_no@yahoo.com','Winantu Rahardja','Jl. Gedong Kuning Selatan No. 17A','Yogyakarta','Daerah Istimewa Yogyakarta','INDONESIA','55198','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 11:21:20',0,NULL,3,1,2,1,NULL,'maswino\r庄'),(8773,778999080015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','ghvilks1983','ghvilks@inbox.lv','Gundars Helds','Dammes 1-47','Riga','','LATVIA','LV-1069','(371) 26165280','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 12:14:45',0,NULL,3,1,2,1,NULL,'ghvilks1983'),(8774,667092526001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','nosugarrr','honeyoff@gmail.com','Volha Tashkinava','Sedyh street, 34-64','Minsk','','BELARUS','220103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 12:28:14',0,NULL,3,1,3,1,'RA117714539CN\r ','nosugarrr'),(8775,708013395002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','samysamy35','samy.35@voila.fr','samy alamine','28 allée de la Sambre','VITRE','Bretagne','FRANCE','35500','0671745788','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 13:04:01',0,NULL,3,1,3,1,'RA117714556CN\r ','samysamy35'),(8776,667142430001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','sanyi_muzsik','muzsiksa@gmail.com','Sandor Muzsik','Mindszenti, 12.','Szegvár','','HUNGARY','6635','+36302623860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 13:41:28',0,NULL,3,1,2,1,NULL,'sanyi_muzsik\r庄'),(8777,665690763018,280667309914,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',7.8,'photographyacc','sam3512002','samriggio79@hotmail.com','Sam RIGGIO','26 Ervine Close','Sunbury','Victoria','AUSTRALIA','3429','0409199578','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-01 14:05:14',0,NULL,3,1,2,1,NULL,'sam3512002\r庄'),(8778,667161490001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',3,'AE3301',41.94,'hermeshine','amperel2010','service@amperel.co.il','Amperel Danny','Shderot Jerusalem 168 Street<br>P.O. Box 2161','Holon','Israel','ISRAEL','58829','+97235594299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:31:37',0,NULL,3,1,3,1,'RA117714525CN\r ','amperel2010'),(8779,708056293002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','astral-v','vovaman@hotmail.com','Vova kaziev','Ahazav 13/10','Bene Aish','','ISRAEL','60860','0548023388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:46:08',0,NULL,3,1,2,1,NULL,'astral-v\r庄'),(8780,708054622002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','loraine_detera','loraine_detera@yahoo.com','Christine Loraine Detera','PO Box 24200, Conference Street<br>WestBay Area','Doha','','QATAR','24200','0097455026214','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:48:06',0,NULL,3,1,3,1,'RA117714499CN\r ','loraine_detera'),(8781,763211062016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','mihiro','evilrufus@gmail.com','chia yuh shu','10 Melton Avenue<br>Camberwell','Melbourne','Victoria','AUSTRALIA','3124','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 15:32:40',0,NULL,3,1,2,1,NULL,'mihiro\r庄'),(8782,708078325002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',4,'AO0009',283.6,'hermeshine','ryrvikryrvik','medolaonas@hotmail.se','magnus ryrvik kjäll','hjortmossegatan 32','trollhättan','västra götaland','SWEDEN','46151','0520203000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 15:37:52',0,NULL,3,1,4,1,'YW866010704CN\r ','ryrvikryrvik\r2m的背景架   \r共4套\rbackground support $40\r庄'),(8783,763216042016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','chris_leung','chris2002abc@hotmail.com','Christopher Leung Ki Fun','36 Burnside Crescent','London','Wembley','UNITED KINGDOM','HA0 1BL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-01 15:40:41',0,NULL,3,1,2,1,NULL,'chris_leung\r庄'),(8784,779096726015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','coolrk1984','mischa_kojine@web.de','Michael Kojine','Randowstrasse 12','Hamburg','','GERMANY','22547','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-01 15:46:39',0,NULL,3,1,4,1,'YW866010693CN\r ','coolrk1984\r欧标  王'),(8785,708082231002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','medina_fjavier','medina.fjavier@gmail.com','Javier Medina Munuera','Calle del Ángel<br>Numero 2, 3C','EL ESPARRAGAL','Murcia','SPAIN','30163','610795727','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 15:46:46',0,NULL,3,1,3,1,'RA117714423CN\r ','medina_fjavier'),(8786,708098565002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nemesis3k12','nemessis_22@hotmail.com','Richard Moreno','Travesia Cendea de Olza 3, 1 piso, puerta 3','Pamplona','Navarra','SPAIN','31015','691796152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 16:19:32',0,NULL,3,1,3,1,'RA117714508CN\r ','nemesis3k12'),(8787,667257247001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','mrtroudbill','lafricain70@free.fr','Stephane Francon','21, rue Gustave Dubois','Mitry Mory','Île-de-France','FRANCE','77290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 17:36:36',0,NULL,3,1,2,1,NULL,'mrtroudbill\r庄'),(8788,667292278001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1304',5,'hermeshine','kelleyoo','kelleyre@adelphia.net','Raymond Kelley','147 E Shelby St','Junction City','KY','UNITED STATES','40440-8508','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 18:24:12',0,NULL,3,1,1,1,' ','kelleyoo\r庄'),(8789,779248632015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','fraperso','curro_perez@hotmail.com','Francisco Pérez Soto','Jardín Atalaya Bloque 1 3ºB<br>Camas','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41900','697803323','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 18:55:23',0,NULL,3,1,2,1,NULL,'fraperso\r庄'),(8790,708213092002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','sadolkz','dolzhenko.sergei@gmail.com','Sergey Dolzhenko','Ch.Valihanova st., h-19/1, r-24','Temirtau','KZ','KAZAKHSTAN','101400','77015301392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 19:08:33',0,NULL,3,1,2,1,'','sadolkz\r庄'),(8791,666932967001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','nicobaricus','jmartos99@msn.com','Juan Carlos Martos Rojas','C/ Aguila de Oro, nº 6, 4º - 2','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41006','648550166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:03:35',0,NULL,3,1,3,1,'RA117714410CN\r ','nicobaricus'),(8792,667361416001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','firstnick','tosse99@gmail.com','Nicklas Lemaitre','Trorod Kollegiet 9E','Vedbaek','','DENMARK','2950','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 20:06:04',0,NULL,3,1,3,1,'RA117714825CN\r','firstnick\r+8换成+4\rND8 换成 ND4\r'),(8793,708248364002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','aldyna','seppo_aarne@hotmail.com','seppo aarne','ruohokatu 3','pori','','FINLAND','28130','00358407357451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:10:27',0,NULL,3,1,4,1,'YW866010682CN\r ','aldyna\rreflector holder  $18\r刘'),(8794,708273353002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','ksta4539','krystian.stan@gmail.com','Krystian Staniszewski','#6F 9820-104st','Edmonton','AB','CANADA','T5K 0Z1','(780) 604-5902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:47:23',0,NULL,3,1,5,1,' CP27020344CN','ksta4539\r庄'),(8795,667381376001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','coussinrouge','x.toutchkov@wanadoo.fr','Xavier Toutchkov','5, Puy des Lauriers<br>Chemin Mouret','Aix-en-Provence','Provence-Alpes-Côte d\'Azur','FRANCE','13100','0610684461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:48:26',0,NULL,3,1,3,1,'RA117714675CN\r ','coussinrouge'),(8796,779370796015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',46.9,'hutongstore','leo_johnson','kev.bayliss@yahoo.co.uk','Kevin Bayliss','Yr Ystablau<br>Hendre Lane','Llandrinio','Powys','UNITED KINGDOM','sy22 6sf','01691831082','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-01 21:49:49',0,NULL,3,1,4,1,'YW866010730CN\r ','leo_johnson\rbackground support $20\r2m宽的+1.6x2.1 白色   \r王'),(8797,665981474018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','dalred0','vista.its.me@hotmail.com','J Redding','4 Lady Nelson Drive<br>Eli Waters','Hervey Bay','Queensland','AUSTRALIA','4655','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-01 23:04:47',0,NULL,3,1,2,1,NULL,'dalred0\r庄'),(8798,779405813015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.75,'hutongstore','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','358456326520','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 23:16:33',0,NULL,3,1,2,1,NULL,'zuhmia\r庄'),(8799,763516078016,260660051230,'Hot Shoe Cap Cover for SONY a900 a700 a350 FA-SHC1AM /B',2,'AA1205',4.6,'hutongstore','stathe174','statheros@hotmail.com','Panagiotis Statheros','Papanastasiou 63','Athens','','GREECE','10445','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 23:28:02',0,NULL,3,1,2,1,NULL,'stathe174\r庄'),(8800,708333123002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','studiokiiro','mail@studiokiiro.com','Tom Huang','22A Jellicoe Street<br>Box Hill South','Melbourne','Victoria','AUSTRALIA','3128','0398492595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 23:32:52',0,NULL,3,1,4,1,'YW866010726CN\r ','studiokiiro\r再加一个80cm 5in1 的反光板  \r一票两件\rreflector holder  $20\r刘\r'),(8801,667440231001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','studiokiiro','mail@studiokiiro.com','Tom Huang','22A Jellicoe Street<br>Box Hill South','Melbourne','Victoria','AUSTRALIA','3128','0398492595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 23:32:52',0,NULL,8,1,17,0,NULL,'studiokiiro'),(8802,763538344016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','fidelma9248','fidelmadonnelly@hotmail.com','fidelma donnelly','19 west high street<br>portgordon','buckie','scotland','UNITED KINGDOM','ab565qs','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 00:15:57',0,NULL,3,1,2,1,NULL,'fidelma9248\r庄'),(8803,708350037002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','arkitekt28','atlegoutbeek@hotmail.com','Atle Goutbeek','Granstien 11','Tvedestrand','','NORWAY','4900','004747336070','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 00:19:36',0,NULL,3,1,3,1,'RA117714692CN\r ','arkitekt28'),(8804,662714655001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','crocopk1','la_goran@yahoo.com','Goran Zeric','klepperdans 4','Capelle a/d Ijssel','','NETHERLANDS','2907rc','0627266858','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 00:23:53',0,NULL,8,0,17,0,NULL,'crocopk1'),(8805,708411162002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','slg00012007','slg0001@gmail.com','Stephanus Goenawan','8 Hannans Road','Riverwood','New South Wales','AUSTRALIA','2210','61425881689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 03:23:06',0,NULL,3,1,2,1,NULL,'slg00012007\r庄'),(8806,708434075002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','greenspanx','johnjienanwong@yahoo.com','John Wong','977 Tulare Ave','Berkeley','CA','UNITED STATES','94707-2539','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 05:23:58',0,NULL,3,1,1,1,NULL,'greenspanx\r庄'),(8807,667545133001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','rdyk4033','dykstra1114@yahoo.com','Ron Dykstra','524 S 94th St','Tacoma','WA','UNITED STATES','98444','(253) 212-1600','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 06:42:09',0,NULL,3,1,1,1,NULL,'rdyk4033\r庄'),(8808,667546105001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','toys.over.food','ebay.toysoverfood@gmail.com','TOF Moy','9602 Glenwood Rd<br># 127','Brooklyn','NY','UNITED STATES','11236-2632','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 06:49:35',0,NULL,3,0,1,1,NULL,'toys.over.food\r1.6x2.1 2块\r黑色 + 白色\r庄'),(8809,708461774002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','sollop123','evgeny.sollop@gmail.com','Yevgen Solop','kv.Eremenko,3-39','Lugansk','UKR','UKRAINE','91011','380505005275','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 07:50:28',0,NULL,3,1,3,1,'RA117714613CN\r ','sollop123'),(8810,708462335002,120598267827,'Camera shoulder bag with raincover for Canon 550D 40D',1,'AO0021',28.99,'hermeshine','neno63','neno.draganic@inet.hr','Nenad Draganic','Na moru 2<br>Mokosica','Dubrovnik','Hrvatska','CROATIA','20236','00911624166','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 07:51:24',0,NULL,3,1,3,1,'RA117714701CN\r ','neno63\rcanon R2 单肩包  1'),(8811,667566769001,110583278393,'TianYa 58mm ND8 filter New 58 Neutral Density Grey NIB',1,'AA2303',6.7,'hermeshine','dkas01','daniel.kasal@gmail.com','Daniel Kasal','Jablonova 2882/102','Prague 10','','CZECH REPUBLIC','10600','+420602738708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 08:28:06',0,NULL,3,1,2,1,' ','dkas01\r\r'),(8812,763695040016,260660053303,'New Neoprene Reversible Cover for Stand-DSLR Camera M',1,'AC1301',4.5,'hutongstore','adam.wol','adam.wolynszczak@gmail.com','Adam Wolynszczak','127 The Crescent<br>Park West Pointe','Dublin','Dublin','IRELAND','D12','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 09:41:47',0,NULL,3,1,2,1,NULL,'adam.wol\r庄'),(8813,779593568015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','dianer40','dianerussell64@talktalk.net','Diane Russell','3 Lanfine View','Darvel','East Ayrshire','UNITED KINGDOM','KA170FE','01560321034','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-02 09:52:58',0,NULL,3,1,4,1,' YW866011393CN\r','dianer40\r英标\rlighting kit $26\r王'),(8814,667589743001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','marcelinopozo','marcelinopozoruiz@gmail.com','Marcelino Pozo Ruiz','Urb El Rocio 32','Malaga','Andalucía Ceuta y Melilla','SPAIN','29016','607540414','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 10:03:37',0,NULL,3,1,4,1,'YW866010763CN\r ','marcelinopozo\r301p 一拖二   1\r（需要测试，我来吧）\r背景架2m（白+黑）   1\rbackground support   $25\r庄'),(8815,708491507002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.95,'hermeshine','marcelinopozo','marcelinopozoruiz@gmail.com','Marcelino Pozo Ruiz','Urb El Rocio 32','Malaga','Andalucía Ceuta y Melilla','SPAIN','29016','607540414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 10:03:37',0,NULL,8,1,17,0,NULL,'marcelinopozo'),(8816,667593908001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','linehafakot','line.hafakot@gmail.com','dudu','avraam markovitch 3','rishon letsion','','ISRAEL','65654','0543082332','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 10:22:33',0,NULL,3,1,5,1,'CP227020389CN\r ','linehafakot\r欧标\r庄'),(8817,708502032002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','alexg047','alexg@alexgarcia.com','Henry Garcia','198 Amboy Road','Matawan','NJ','UNITED STATES','07747','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 10:35:31',0,NULL,3,1,1,1,NULL,'alexg047\r庄'),(8818,667599863001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','maxelereque','avezipueze@hotmail.com','Antonio Trinidad Perea','C/ Lorca Nº 29','Dos Hermanas','Andalucía Ceuta y Melilla','SPAIN','41700','955084520','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 10:45:57',0,NULL,3,1,4,1,'YW866010752CN\r ','maxelereque\rtripod  $20\rft-686\r王'),(8819,763724840016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',38.99,'hutongstore','foto.drazen','foto.priganica@gmail.com','Drazen Priganica','Calle de la Hoz 24','Oliva','Comunidad Valenciana','SPAIN','46780','693288507','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 11:14:14',0,NULL,3,1,4,1,'YW866010741CN\r ','foto.drazen\rlight stand $20\r刘'),(8820,708515950002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','motorfoto','motorind@mail.ru','Dmitry Vladimirovich Motorin','Mira st.76 kv 100','Nizhnevartovsk','RU','RUSSIAN FEDERATION','628624','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 11:28:22',0,NULL,8,0,17,0,NULL,'motorfoto'),(8821,667612367001,110618888297,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380  user',1,'AA2121',32,'hermeshine','motorfoto','motorind@mail.ru','Dmitry Vladimirovich Motorin','Mira st.76 kv 100','Nizhnevartovsk','RU','RUSSIAN FEDERATION','628624','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 11:28:22',0,NULL,3,0,3,1,'RA117715004CN\r ','motorfoto(已减库）\r摄影背心 红色薄 sony  XXL   1\r摄影背心 黑色厚 sony XXXL   1\r'),(8822,667614163001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','bjornasb','rog-asb@online.no','Bjørn Roger Asbjørnsen','Tølløseveien 6','Ås','','NORWAY','N-1430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 11:32:14',0,NULL,3,1,3,1,'RA117714689CN\r ','bjornasb'),(8823,708521691002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','ripple*butterfly','ripple_effected666@hotmail.com','Kellie Hoy','12 Wooles Ave','Warrnambool','Victoria','AUSTRALIA','3280','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 11:48:21',0,NULL,3,1,4,1,'YW866010796CN\r ','ripple*butterfly\r澳标\r布是1.6x2.1 白色\rlighting kit  $30\r庄'),(8824,763736751016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','evapomposo','evapomposo@hotmail.com','Eva Pomposo','49a Northdown Street\r\nKing\'s Cross','London','London','UNITED KINGDOM','N1 9BL','02078338415','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 11:49:56',0,NULL,3,1,2,1,NULL,'evapomposo\r庄'),(8825,667630347001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','ylim8951','acidburn0828@yahoo.com.sg','Yi Chieh Lim','Unit 17, 15 Clarence Road. Indooroopilly','Brisbane','Queensland','AUSTRALIA','4068','0738767140','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 12:30:18',0,NULL,3,1,3,1,'RA117714817CN ','ylim8951'),(8826,708543515002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','joker.gb','lombardo.lucap@gmail.com','Lombardo Luca','Via Pio XI Dir. De Domenico 10/a','reggio calabria','RC','ITALY','89133','3313652543','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 12:59:37',0,NULL,3,0,3,1,'RA117714896CN ','joker.gb\r实际发的是新款XL (已减库）\r申报 photo vest  $15'),(8827,763767582016,260660053640,'New TianYa Star 4 points filters for Cokin P Series',1,'AE2315',6.7,'hutongstore','jet_kit','chris.casselden@virginmedia.com','Chris J Casselden','159 Westminster Road','Sutton','Surrey','UNITED KINGDOM','SM1 3NQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:15:49',0,NULL,8,1,17,0,NULL,'jet_kit'),(8828,779666066015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.25,'hutongstore','jet_kit','chris.casselden@virginmedia.com','Chris J Casselden','159 Westminster Road','Sutton','Surrey','UNITED KINGDOM','SM1 3NQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:15:50',0,NULL,3,1,2,1,NULL,'jet_kit\r52mm 环架   1\rstar4 星光镜   1\r庄'),(8829,763775471016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.25,'hutongstore','paulhuk','paul@kilgrimol.com','Paul Higham','34,Clive Avenue','St.Annes-on-Sea','Lancashire','UNITED KINGDOM','FY8 2RX','01253727061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:36:30',0,NULL,8,1,17,0,NULL,'paulhuk'),(8830,763775948016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','paulhuk','paul@kilgrimol.com','Paul Higham','34,Clive Avenue','St.Annes-on-Sea','Lancashire','UNITED KINGDOM','FY8 2RX','01253727061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:37:45',0,NULL,8,1,17,0,NULL,'paulhuk'),(8831,763776426016,260660052333,'New 72mm Ring adapter for Cokin P Series Filter Holder',1,'AA2213',2.25,'hutongstore','paulhuk','paul@kilgrimol.com','Paul Higham','34,Clive Avenue','St.Annes-on-Sea','Lancashire','UNITED KINGDOM','FY8 2RX','01253727061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:39:18',0,NULL,8,1,17,0,NULL,'paulhuk'),(8832,763776870016,260660052497,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.25,'hutongstore','paulhuk','paul@kilgrimol.com','Paul Higham','34,Clive Avenue','St.Annes-on-Sea','Lancashire','UNITED KINGDOM','FY8 2RX','01253727061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:40:16',0,NULL,8,1,17,0,NULL,'paulhuk'),(8833,667654621001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','paulhuk','paul@kilgrimol.com','Paul Higham','34,Clive Avenue','St.Annes-on-Sea','Lancashire','UNITED KINGDOM','FY8 2RX','01253727061','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-05-02 13:50:32',0,NULL,3,1,3,1,'RA117714940CN','paulhuk\r55mm 接口环  1\r58mm 接口环  1\r72mm 接口环  1\r77mm 接口环  1\r天涯cpl    1\r\r'),(8834,763784189016,260660051940,'New 52mm 52 Ring adapter and Holder for Cokin P Series',1,'AKT018',3.62,'hutongstore','pcooley63','pcooley@eircom.net','Paul Cooley','Culleen<br>Kilmaley','Co. Clare','Eire','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 14:00:49',0,NULL,8,1,17,0,NULL,'pcooley63'),(8835,763783693016,260660052780,'New Circular Polarizing C-PL CPL Filters for Cokin P',1,'AA2326',10.99,'hutongstore','pcooley63','pcooley@eircom.net','Paul Cooley','Culleen<br>Kilmaley','Co. Clare','Eire','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 14:00:49',0,NULL,3,1,2,1,' ','pcooley63\r52mm 环架  1\rcpl   1\r庄'),(8836,779683851015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',48,'hutongstore','ufuksevki','ushevki@gmail.com','Ufuk Sevki','Erdogan Sonsal Sok.<br>Blok4 No:2','Lefkosa','KKTC / Mersin 10','TURKEY','-----','5338646064','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-02 14:01:18',0,NULL,3,1,5,1,'CP227020375CN\r ','ufuksevki\r欧标\r庄'),(8837,708577680002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',109.98,'hermeshine','eliha5','eli_hazan@012.net.il','Eli Hazan','Menahem Begin Ave<br>69/2','kiryat shmona','','ISRAEL','11632','972-54-8884031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 14:50:06',0,NULL,3,1,3,1,'RA117714715CN\rRA117714848CN\r','eliha5\r如果超过2kg就分两个发'),(8838,763811218016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','hidden_nature','leonidaspa@gmail.com','Leonidas Papadopoulos','Riga Fereou 173','Kalamata','','GREECE','24100','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-02 15:05:41',0,NULL,3,1,4,1,'YW866010785CN\r ','hidden_nature\r欧标\r申报：40$；lighting kit\r王'),(8839,667680129001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','keropino','vip-well@yandex.ru','Valeriy Taranta','Bolchoy Matrossky pereylok 1/252','Moscow','','RUSSIAN FEDERATION','107076','(903) 1234488','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 15:07:35',0,NULL,3,1,2,1,NULL,'keropino\r庄'),(8840,667733871001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','450tilou','jaboucher@videotron.ca','Jacques Boucher','130 rg ste-Julie','Notre-Dame-des-Prairies','QC','CANADA','j6e 8y6','(450) 756-1973','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 17:17:33',0,NULL,3,1,3,1,'RA117714437CN\r ','450tilou'),(8841,667733847001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','shaun.rogers.me','shaun.rogers@me.com','Shaun Rogers','Ivybridge Community College<br>Harford Road','Ivybridge','Devon','UNITED KINGDOM','PL21 0JA','07791636049','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-05-02 17:18:41',0,NULL,3,1,2,1,NULL,'shaun.rogers.me\r庄'),(8842,708650741002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','stormgod66','stormgod@gmail.com','Edward Negron','5227 ithaca ave','Los Angeles','CA','UNITED STATES','90032','(213) 840-8147','NoPaymentFailure','CheckoutComplete','Other','2011-05-02 17:39:49',0,NULL,3,1,4,1,'YW866010774CN\r ','stormgod66\r刘\r灯架发红盒的给他'),(8843,708671500002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','tugezu','tukezu@gmail.com','Tuomas Hämäläinen','Vanha Tapanilantie 62 C26','Helsinki','Uusimaa','FINLAND','00730','+358407030125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 18:16:54',0,NULL,3,1,4,1,'YW866010811CN\r ','tugezu\rlighting kit  $22\r刘'),(8844,708671921002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','grzegorzrajzer','exeloro@gmail.com','GRZEGORZ RAJZER -  AGATA STRÓŻYCKA','MAGI FABREGA 5.2.1','SURIA - BARCELONA','Cataluña','SPAIN','08260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 18:17:53',0,NULL,3,1,2,1,NULL,'grzegorzrajzer\r庄'),(8845,708702849002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',20.99,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 19:13:42',0,NULL,3,1,3,1,'RA117714485CN\r ','bobi1330\r申报：14$，Bag\rlenspen    6\rCanon 单肩包  D1    1\r'),(8846,779861961015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','romeup','romeup02@oninet.pt','Romeu Peitinho','Av. Padre Alberto Neto, 27, Bloco B, 1.º Esq.','Belas','','PORTUGAL','2605-289','00351214324261','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 19:16:13',0,NULL,3,1,2,1,NULL,'romeup'),(8847,708706238002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',3,'AKT051',34.5,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 19:20:34',0,NULL,8,1,17,0,NULL,'bobi1330'),(8848,666377681018,280663394346,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','irasema.farina','emanuelafarina@hotmail.com','Irasema Emanuela Farina','Apt2, The Plantation<br>Herbert St','Dublin','Dublin','IRELAND','D2','0851396776','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-02 19:53:14',0,NULL,3,1,4,1,'YW866010800CN\r ','irasema.farina\r申报：Lighting kit；22$\r白+黑\r庄'),(8849,667821904001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','emanyasli','ermanmanyasli@gmail.com','Erman MANYASLI','ODTU TEKNOKENT<br>GUMUS BLOKLAR C BLOK SEBIT A.Ş.','ANKARA','ODTÜ','TURKEY','06531','05334228456','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 19:59:36',0,NULL,3,1,3,1,'RA117714471CN\r ','emanyasli\r庄'),(8850,775296499015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','theresas211','jons13569@yahoo.com','Theresa Simon','225 S 9th St','North Wales','PA','UNITED STATES','19454-2913','(267) 304-0880','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 20:11:06',0,NULL,3,1,1,1,NULL,'theresas211\r庄'),(8851,779658599015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',4.52,'hutongstore','977white','blanca56@hotmail.es','blanca mesa gonzalez','pompeu fabra 10-2º/2ª','cambrils','Cataluña','SPAIN','43850','977363863','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 20:14:14',0,NULL,3,1,2,1,NULL,'977white\r橡胶遮光罩 55mm   1\r橡胶遮光罩 58mm   1\r庄'),(8852,667834333001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','deux22000','felferrari@yahoo.com.br','Felipe Ferrari','St Butia 2B<br>Campo Grande','Rio de Janeiro','RJ','BRAZIL','23040080','55 21 91157285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 20:24:59',0,NULL,3,1,2,1,' ','deux22000\r申报：GIFT；\r庄\r'),(8853,667849592001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','arases.06','arases06@gmail.com','MASANTE Patrice','679 ROUTE DE LA GRAVE','L\'ESCARENE','Provence-Alpes-Côte d\'Azur','FRANCE','06440','0980105705','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 21:04:00',0,NULL,3,1,3,1,'RA117714732CN\r ','arases.06\rXL（已入库）'),(8854,667875261001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','tadi226','pusnik.tadej@gmail.com','Tadej Pušnik','cvetkova 23','murska sobota','','SLOVENIA','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 22:14:23',0,NULL,3,1,3,1,'RA117714468CN\r ','tadi226'),(8855,779957494015,250599920440,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.25,'hutongstore','lundemann77','mch@datea.dk','Martin Lundemann Christensen','Henrik Nielsens Vej 19','Roskilde','Roskilde','DENMARK','4000','+45 51319182','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 22:15:37',0,NULL,3,1,2,1,' ','lundemann77\r庄'),(8856,708789063002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rudithesandninja','rudigaum@gmail.com','Dunross Gaum','103 Welgevonden Boulevard<br>Welgevonden Estate','Stellenbosch','Western Cape','SOUTH AFRICA','7600','+27717432212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 22:27:31',0,NULL,3,1,2,1,NULL,'rudithesandninja\r庄'),(8857,667880278001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','fcalabrese2008','fcalabrese1@hotmail.com','Francesco Calabrese','234 Flournoy St','San Francisco','CA','UNITED STATES','94112-3911','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 22:33:03',0,NULL,3,1,3,1,'RA117715049CN ','fcalabrese2008\r庄'),(8858,708794726002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','gemsvillage.com','jcabres@gmail.com','José Cabré','C/Pamplona 45 int, bajos 9','barcelona','Cataluña','SPAIN','08005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 22:49:20',0,NULL,3,1,2,1,NULL,'gemsvillage.com\r庄'),(8859,667889136001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','spy14hun','balint.sipter@gmail.com','Balint Sipter','Hamzsabegi ut 9. III/3.','Budapest','','HUNGARY','1117','0036702578300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 23:06:35',0,NULL,3,1,2,1,NULL,'spy14hun\r庄'),(8860,708812777002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','hutchfla','hutchfla@yahoo.com','chris hutchinson','8640 SW 12th St','pembroke pines','FL','UNITED STATES','33025-3347','(954) 483-3086','NoPaymentFailure','CheckoutComplete','Other','2011-05-03 00:01:17',0,NULL,3,1,1,1,' ','hutchfla\rxl\r庄'),(8861,667910778001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','kmar69888','keith.martinet@gmail.com','Keith Martinet','13 Ahwahnee Street<br>P.O. Box 708','San Juan Bautista','CA','UNITED STATES','95045-0708','(408) 710-2339','NoPaymentFailure','CheckoutComplete','Other','2011-05-03 00:37:18',0,NULL,3,0,1,1,NULL,'kmar69888\rXXXL(已入库）\r庄'),(8862,708828646002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','kameraman1973','bladeruner@atlas.sk','Milos Villem','Perecka 4','Levice','','SLOVAK REPUBLIC','93405','+421907134513','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 00:59:38',0,NULL,3,1,3,1,'RA117714542CN\r ','kameraman1973'),(8863,667939769001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','ythpstr2b','ythpstr2b@aol.com','William Helms','5402 Gwen Ln','Pace','FL','UNITED STATES','32571','(850) 994-4508','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 02:41:14',0,NULL,3,1,1,1,' ','ythpstr2b\r庄'),(8864,667946299001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','fungm','phmui@yahoo.com','Peter H. Mui','3400 Meyer Woods Ln','Fairfax','VA','UNITED STATES','22033-1519','(703) 989-9420','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 03:08:06',0,NULL,3,1,1,1,NULL,'fungm\r庄'),(8865,707858575002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','pv008','davehollis@blueyonder.co.uk','DAVE HOLLIS','7 MADDOCKS HILL','WARMINSTER','WILTSHIRE','UNITED KINGDOM','BA12 8DJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 03:20:35',0,NULL,3,1,3,1,'RA117714882CN','pv008\r庄\r爵影无线 N1   2 '),(8866,708874750002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','orlibertha','dlauson@shaw.ca','Doug Lauson','2664 Brewster Drive','Coquitlam','BC','CANADA','V3B 7A4','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 04:13:40',0,NULL,3,0,3,1,'RA117714746CN\r ','orlibertha\rL 已入库'),(8867,666257286001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','rwir7405','richard@a3logistics.net','Richard Wirski','PO BOX 2208','Seaford','Victoria','AUSTRALIA','3198','0397867007','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 04:41:42',0,NULL,3,1,4,1,'YW866011356CN\r ','rwir7405\r庄'),(8868,666544248018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3310',6.6,'photographyacc','mircostore','mircofun@hotmail.com','Miroslav Korenik','31940 Hillcrest Avenue','Mission','BC','CANADA','V2V 1K9','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-03 06:12:13',0,NULL,3,0,2,1,NULL,'mircostore\r58mm 渐变灰   1\r庄'),(8869,708900985002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',4,'AKT061',145.6,'hermeshine','aramarmenia','aramderdzyan@gmail.com','Aram Derdzyan','72 Z. Sarkavagi st. app. 84','Yerevan','Yerevan','ARMENIA','0091','37491717010','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 06:47:15',0,NULL,3,1,5,1,'CP227020256CN\r ','aramarmenia\r2m 灯架   4\r单灯头  欧标   4\r王'),(8870,708907564002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','chema1024','chema1024@hotmail.com','Chema Perez','Apartado 397','Villagarcia de Arosa','Galicia','SPAIN','36600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 07:23:40',0,NULL,3,1,3,1,'RA117714919CN\r ','chema1024\r王'),(8871,666559461018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','gladkovmaxim','maksimk@list.ru','Gladkov Maxim','K.Sutyusheva 47-3','Petropavlovsk','SKO','KAZAKHSTAN','150000','87152527469','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-03 07:34:37',0,NULL,3,1,3,1,'RA117714661CN\r ','gladkovmaxim\r王'),(8872,780126213015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','ian29swans','melding0001@aol.com','ian melding','20 Brookville Drive<br>Skewen','Neath','Neath Port Talbot','UNITED KINGDOM','SA106SR','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-03 08:39:46',0,NULL,3,1,4,1,'YW866010833CN ','ian29swans\r王\rtripod  $25'),(8873,668017666001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','d1truo','ovidiu@webproject.ro','Cocis Petre Ovidiu','Str. Koos Ferencz nr. 13 ap. 12','Tirgu-Mures','Mures','ROMANIA','540382','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 09:40:17',0,NULL,3,1,2,1,'','d1truo\r庄'),(8874,668020404001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','marijokristo','avs@st.t-com.hr','Marijo Kristo','Vrh Visoke 18','Split','Dalmatia','CROATIA','21000','+ 385-98-21-41-51','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 09:53:30',0,NULL,3,1,3,1,'RA117731112CN ','marijokristo\r注意数量-一共5个\r王'),(8875,708943303002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','novfon','novgorodes@gmail.com','Евгений Иванов','Б.-Санктпетербургская д.117 кв.170','Великий Новгород','Новгородская область','RUSSIAN FEDERATION','173008','(7911)6413307','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 10:17:02',0,NULL,3,1,3,1,' RA117731055CN','novfon\r王'),(8876,708943537002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','stepheure','stcarrez@free.fr','Stéphane  Carrez','5, chemin des chaumières','Ferrières Haut Clocher','Haute-Normandie','FRANCE','27190','0232341848','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 10:18:48',0,NULL,3,1,3,1,'RA117731126CN ','stepheure\r庄'),(8877,779698476015,250692239254,'New Neoprene Reversible Cover for Canon 5D II 7D L',1,'AC1304',6.1,'hutongstore','spennagallo123','andrespenna@hotmail.it','andrea spennagallo','via sacragni 25','arcisate','VA','ITALY','21051','0332471515','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-03 10:27:38',0,NULL,3,1,2,1,'','spennagallo123\r庄'),(8878,668030974001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','oiaganzoma','elgar_28@hotmail.com','Ola Huse Ramstad','Svensenga 38','Oslo','Oslo','NORWAY','0882','4797617555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 10:39:59',0,NULL,3,1,2,1,'','oiaganzoma\r庄'),(8879,708958557002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',62.79,'hermeshine','ainis10','ainoras.v@gmail.com','Ainoras Vaskys','Kudirkos 51','Prienai','','LITHUANIA','59113','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 11:17:39',0,NULL,3,1,3,1,'RA117731130CN ','ainis10\r2个\r庄'),(8880,666614522018,280666791794,'New foto Studio 20x27\"/50​x70cm Softbox Universal Mount',1,'AE2203',30,'photographyacc','jbc0072000','jb.carlton@gmail.com','James Carlton','23 Portland Place','New Lambton','New South Wales','AUSTRALIA','2305','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-03 11:31:18',0,NULL,3,1,3,1,'RA117731143CN ','jbc0072000\r庄'),(8881,668043394001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','cineindiana','pacocintado@hotmail.com','Francisco Cintado Briceño','Sierra de Atapuerca 12, Portal B 6ºC','Madrid','Castilla-La Mancha','SPAIN','28050','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 11:31:23',0,NULL,3,1,2,1,NULL,'cineindiana\r庄'),(8882,708982483002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',3,'AA3301',8.25,'hermeshine','anamariaken','zaba1@sympatico.ca','Kenneth Etcher','204-10 Ruddington Drive','North York','ON','CANADA','M2K 2J7','(416) 222-9280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 12:48:18',0,NULL,3,1,2,1,NULL,'anamariaken\r庄'),(8883,668072626001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','vdichev','hakera_sl@abv.bg','Valentin Dichev','Georgi Ikonomov 63','Sliven','Sliven','BULGARIA','8800','+359898424248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 13:18:55',0,NULL,3,1,2,1,NULL,'vdichev\r庄'),(8884,764308550016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','robertvangend','rvgend@tele2.nl','Robert van Gend','Spinhuispad 79','Schiedam','','NETHERLANDS','3111PX','010-4213040','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-03 13:51:48',0,NULL,3,1,2,1,NULL,'robertvangend\r庄'),(8885,668111145001,110569973202,'New  Non Woven Fabric Backdrop 1.6m x 3m(5.2x10 ft)',2,'AO0005',61.6,'hermeshine','prodde_2007','prodde@online.no','Per Bjørnar Rødde','Kaaldfeltet<br>.','Hestvika','HESTVIKA','NORWAY','7247','004791761580','NoPaymentFailure','CheckoutComplete','AU_OtherInternational','2011-05-03 15:32:15',0,NULL,3,0,3,1,'RA117731165CN ','prodde_2007\r蓝+粉'),(8886,666689501018,280663394249,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','prodde_2007','prodde@online.no','Per Bjørnar Rødde','Kaaldfeltet<br>.','Hestvika','HESTVIKA','NORWAY','7247','004791761580','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-03 15:34:41',0,NULL,3,1,4,1,'YW866011441CN ','prodde_2007\r2m 背景架 （ 白）  \rbackground support  $20\r王'),(8887,780271601015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','photo3','idstudiophoto@gmail.com','NIKOLAOS PSATHOGIANNAKIS','GEROKOSTOPOULOU 1<br>KAROLOU KOUN 49','Patrai','Achaia','GREECE','26221','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-03 15:56:49',0,NULL,3,1,4,1,'YW866011415CN ','photo3\r欧标\r庄\r'),(8888,666699666018,280666834436,'New Small Camera bag lens case D2 for Canon 500D 450D ',1,'AO0033',8,'photographyacc','strumfvalentin','valentin.kozjak@gmail.com','Mirela Behin','Stari Golubovec 84','Lobor','','CROATIA','49253','091-589-0685','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-03 16:06:05',0,NULL,3,1,2,1,' ','strumfvalentin'),(8889,666701670018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','tsamuel-james','samuel.shelton88@gmail.com','Daniel or Samuel Shelton','PO Box 282<br>Red Hill','Brisbane','Queensland','AUSTRALIA','4059','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-03 16:09:35',0,NULL,3,1,3,1,'RA117731157CN ','tsamuel-james\r庄'),(8890,709049705002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 16:21:02',0,NULL,3,1,3,1,'RA117731072CN ','arnorolf10\r庄'),(8891,780279693015,250599919356,'New 62mm Ring adapter for Cokin P Series Filter Holder',2,'AA2211',4.5,'hutongstore','colour-blind','donald18@btinternet.com','Donald Cleary','21 Ardmore Drive','Armagh','Armagh','UNITED KINGDOM','BT60 1JB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 16:38:23',0,NULL,3,1,2,1,NULL,'colour-blind\r庄'),(8892,780296981015,250619800184,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',39,'hutongstore','ruipegas','rui.pegas@gmail.com','Rui Pegas','Rua da Fontinha 4<br>Vilarinho Melres Gondomar','Porto','Vilarinho Melres Gondomar','PORTUGAL','4515-523','(00351) 915002273','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-03 16:46:34',0,NULL,3,1,4,1,'YW866011404CN ','ruipegas\rtripod  $15'),(8893,668155576001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','juanfernandez2007','placido@rodriguez.name','Plácido Rodriguez','Raimundo Fdez. Villaverde, 49 - 11 DR','Madrid','Madrid','SPAIN','28003','656310120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 17:32:34',0,NULL,8,1,17,0,NULL,'juanfernandez2007'),(8894,668155096001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','juanfernandez2007','placido@rodriguez.name','Plácido Rodriguez','Raimundo Fdez. Villaverde, 49 - 11 DR','Madrid','Madrid','SPAIN','28003','656310120','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 17:32:34',0,NULL,8,1,17,0,NULL,'juanfernandez2007'),(8895,709074679002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',109.98,'hermeshine','juanfernandez2007','placido@rodriguez.name','Plácido Rodriguez','Raimundo Fdez. Villaverde, 49 - 11 DR','Madrid','Madrid','SPAIN','28003','656310120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 17:32:35',0,NULL,3,1,4,1,'YW866011430CN ','juanfernandez2007\r反光板 110cm 5合1   1\r摄影背心 蓝色薄 XXL   1\r闪光的柔光箱   60cm   2\rlighting accessory  $22'),(8896,668169083001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','starwealth','starwealth2008@gmail.com','Taj Karim','302 - 1155 Seymour Street','Vancouver','BC','CANADA','v6b1k2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 18:08:27',0,NULL,3,1,2,1,NULL,'starwealth\r庄'),(8897,709102717002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',26.8,'hermeshine','pentaxfriend','m.vanbalenjr@chello.nl','Thijs van Balen jr','Eenhoornstraat 3','hoek van Holland','','NETHERLANDS','3151RG','+31638824840','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 18:57:38',0,NULL,8,1,17,0,NULL,'pentaxfriend'),(8898,668183293001,110445705855,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',2,'AB1405',10.98,'hermeshine','pentaxfriend','m.vanbalenjr@chello.nl','Thijs van Balen jr','Eenhoornstraat 3','hoek van Holland','','NETHERLANDS','3151RG','+31638824840','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 18:57:39',0,NULL,3,1,3,1,'RA117731188CN ','pentaxfriend\r摄影背心 冬夏  L   1\r肩带 pentax   2\r庄'),(8899,707082582002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','xrobertojosuex','xxrunkenxx@gmail.com','roberto josue naranjo rosario','BB72 CALLE 26<br>LAS VEGAS','catano','PR','UNITED STATES','00962-6428','','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,4,1,'YW866011463CN ','xrobertojosuex\rlighting stand $20\r王'),(8900,709124747002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',1,'AA1206',5.99,'hermeshine','armdmd95','dralexmagat@aol.com','Alex reyes','617 W Huntington Dr','Monrovia','CA','UNITED STATES','91016','(626) 599-2000','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 19:16:56',0,NULL,8,1,17,0,NULL,'armdmd95'),(8901,709119985002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','armdmd95','dralexmagat@aol.com','Alex reyes','617 W Huntington Dr','Monrovia','CA','UNITED STATES','91016','(626) 599-2000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 19:16:57',0,NULL,8,1,17,0,NULL,'armdmd95'),(8902,668201506001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1304',7.4,'hermeshine','armdmd95','dralexmagat@aol.com','Alex reyes','617 W Huntington Dr','Monrovia','CA','UNITED STATES','91016','(626) 599-2000','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 19:16:57',0,NULL,8,1,17,0,NULL,'armdmd95'),(8903,668198777001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','armdmd95','dralexmagat@aol.com','Alex reyes','617 W Huntington Dr','Monrovia','CA','UNITED STATES','91016','(626) 599-2000','NoPaymentFailure','CheckoutComplete','Other','2011-05-03 19:16:58',0,NULL,3,1,3,1,'RA117731069CN ','armdmd95\rCANON 镜头盖  77mm   3\rc型大力夹   1\r带水平仪 热靴保护盖    1\r反光板支架   1\r庄'),(8904,708945009002,120582352724,'New 49mm ring adapter replacement for cokin P series',1,'AA2207',3.55,'hermeshine','e_nk','nevkos@gmail.com','Neven Kos','Rim 61','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 19:48:39',0,NULL,8,1,17,0,NULL,'e_nk'),(8905,708944294002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','e_nk','nevkos@gmail.com','Neven Kos','Rim 61','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 19:48:39',0,NULL,3,1,2,1,NULL,'e_nk\r49mm 转接环   1\r广角托架   1\r庄'),(8906,709149354002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','xtanda','xtanda@ieee.org','Denis Kristanda','PO BOX 4102','Macquarie Center','New South Wales','AUSTRALIA','2113','0402672599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 20:34:46',0,NULL,3,1,2,1,NULL,'xtanda\r庄'),(8907,668257789001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','salmon404','apuusti6@welho.com','Aki Puustinen','Kyösti Kallion tie 10 D 34','Helsinki','','FINLAND','00570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 21:08:35',0,NULL,3,1,3,1,'RA117731205CN ','salmon404\r庄'),(8908,780453680015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','pbd1997','pbd@btconnect.com','MIKE CHAPPELL','THE LAURELS<br>SPROUTES LANE','COOLHAM','WEST SUSSEX','UNITED KINGDOM','RH13 8QH','01403741004','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 21:16:25',0,NULL,3,1,2,1,NULL,'pbd1997\r庄'),(8909,668259633001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','andrey007','2003-28-11@rambler.ru','Solomon Robinovich','Neve Yaakov 110/1','Jerusalem','','ISRAEL','97350','+972545755189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 21:16:51',0,NULL,3,1,2,1,NULL,'andrey007\r庄'),(8910,668265664001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mipro83','prilepokm@gmail.com','Miroslav Prilepok','Prievozska 1','Bratislava','Slovakia','SLOVAK REPUBLIC','821 09','+421905616600','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 21:30:46',0,NULL,3,1,3,1,'RA117731086CN ','mipro83\r庄'),(8911,709193515002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','manubbk','manuzarazaga@hotmail.com','manuel zarazaga','victor grignard 7121<br>Villa Belgrano','Cordoba','Cordoba','ARGENTINA','5147','3515641243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 21:37:10',0,NULL,3,1,2,1,NULL,'manubbk\r刘'),(8912,780469032015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','jackyg3','guest327@btinternet.com','Jacky Guest','12 Mornington Close','Baughurst','Hampshire','UNITED KINGDOM','RG26 5PQ','01189812102','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 21:51:19',0,NULL,3,1,2,1,NULL,'jackyg3\r庄'),(8913,668280852001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','pichirla','rsuarez68@auna.com','Roberto Suárez','Sanchorreja, 1','Madrid','Madrid','SPAIN','28011','610700987','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 22:20:28',0,NULL,3,0,3,1,' RA117731041CN','pichirla\r2XL\r庄'),(8914,780482510015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','255255255255','dan.farmer@gmail.com','Dan Farmer','Flat 4<br>30A Craven Terrace','London','London','UNITED KINGDOM','W2 3EL','07871037891','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 22:25:55',0,NULL,3,1,2,1,NULL,'255255255255\r庄'),(8915,709211504002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','cajaibamarcos','cajaiba.marcos@gmail.com','Marcos Luis Cajaiba Do Prado','Av São João 822 Apt 103<br>Republica','São Paulo','SÃO PAULO','BRAZIL','01036-100','055-11-25523339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 22:33:49',0,NULL,3,1,3,1,'RA117731090CN ','cajaibamarcos\r庄'),(8916,668288439001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','pamy03','pamela_betancourt@yahoo.com','pamela betancourt','Metropolis calle 22 p.5','carolina','PR','UNITED STATES','00987','(787) 467-3863','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'pamy03\r庄'),(8917,764564347016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','gaggalli2','ciaranrowan@hotmail.com','Ciaran Rowan','51<br>Victoria Crescent','London','London','UNITED KINGDOM','N15 5LP','07758431626','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-03 22:48:03',0,NULL,3,1,4,1,'YW866011452CN ','gaggalli2\r英标\rlighting kit  $40\r王'),(8918,780490949015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','swr_2007','lukaszchowis@yahoo.com','Lukasz Chowis - James Paige Marketing','12 Cheshire Avenue<br>Cheshire Business Park','Lostock Gralam','Cheshire','UNITED KINGDOM','CW9 7UA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 22:52:10',0,NULL,3,1,3,1,'RA117731015CN ','swr_2007'),(8919,668296741001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','ramonpastormarco','rpastor@iberdrola.es','Ramón Pastor Marco','C/ Jorge Juan, nº 37','San Vicente del Raspeig','Alicante','SPAIN','03690','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 23:20:01',0,NULL,3,1,2,1,NULL,'ramonpastormarco\r庄'),(8920,709232859002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','anirbantaran','anirbantaran@hotmail.com','Anirban Taran','1235 Spring Green Ln','Burnsville','MN','UNITED STATES','55306','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 00:07:42',0,NULL,3,1,1,1,NULL,'anirbantaran\r庄'),(8921,764588151016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','paul_ashton01','paul_ashton01@yahoo.co.uk','Paul Ashton','200 Monton Rd<br>Monton','Eccles','Greater Manchester','UNITED KINGDOM','M30 9LJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 00:17:08',0,NULL,8,1,17,0,NULL,'paul_ashton01'),(8922,779929365015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','paul_ashton01','paul_ashton01@yahoo.co.uk','Paul Ashton','200 Monton Rd<br>Monton','Eccles','Greater Manchester','UNITED KINGDOM','M30 9LJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 00:17:08',0,NULL,3,1,3,1,'RA117731109CN ','paul_ashton01\r庄\r斜臂    1\r背景布 1.6x3m   1 (黄）'),(8923,709240424002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','kk325ic','kokang@cox.net','Kongbin Kang','16 Elmway St','Providence','RI','UNITED STATES','02906-4710','(401) 863-2628','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-04 00:30:30',0,NULL,3,1,3,1,'RA117731024CN ','kk325ic\r庄'),(8929,709290753002,120544017355,'YONGNUO Flash Battery Pack SF-17 Nikon SB800 SD-8A ',1,'AB3315',41.99,'hermeshine','mdjager','mdjager@telusplanet.net','Murray G DeJager','75 Mt. Kidd Point S.E.','Calgary','AB','CANADA','T2Z 3C5','(403) 257-4044','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 04:14:29',0,NULL,3,1,3,1,'RA117731174CN ','mdjager'),(8924,709269960002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','simongrinberg','simiongrinberg@bezeqint.net','Simon Grinberg','Herzel 208A , app10','Rehovot','','ISRAEL','76270','+972507730017','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 02:30:00',0,NULL,3,1,3,1,' RA117731038CN','simongrinberg\r庄'),(8925,668120251001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',56.9,'hermeshine','gerka9973','sibirier9973@mail.ru','Dmitry Uzentsev','4-Mikrorayon, 37-44','Tobolsk','Tumenskaya oblast','RUSSIAN FEDERATION','626150','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 02:44:21',0,NULL,3,1,5,1,'CP227020327CN ','gerka9973\r王'),(8926,709281417002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','lara_ellegance','elise.tabet@hec.ca','Elise Tabet','533 80 E Avenue','Chomedy Laval','QC','CANADA','H7V3J7','(514) 434-2432','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 03:20:08',0,NULL,8,1,17,1,NULL,'lara_ellegance\r庄'),(8927,709286051002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','lara_ellegance','elise.tabet@hec.ca','Elise Tabet','533 80 E Avenue','Chomedy Laval','QC','CANADA','H7V3J7','(514) 434-2432','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 03:44:12',0,NULL,3,1,3,1,'RA117731231CN','lara_ellegance\r王\r再加一个大力夹'),(8928,709288391002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','mdldeleon','mariardeleon8@yahoo.com','Maria De Leon','424 N 13th St','Donna','TX','UNITED STATES','78537-2818','(956) 454-2512','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 03:59:41',0,NULL,3,1,1,1,NULL,'mdldeleon\r庄'),(8930,668362173001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','ezipman','yapls2002@yahoo.com.sg','William Yap','33 Ubi Avenue 3<br>#07-50 VERTEX (Tower A)','default','','SINGAPORE','408868','91808647','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 04:33:45',0,NULL,3,1,3,1,'RA117714905CN ','ezipman\r庄'),(8931,709295438002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','mikzhukov','7648660@mail.ru','Zhukov Mikhail','korpus 440-176<br>Tsentralny prospect','Zelenograd','Moskow','RUSSIAN FEDERATION','124498','+79857648660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 04:54:02',0,NULL,3,1,2,1,NULL,'mikzhukov\r庄'),(8932,707157974002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','rachel.perkins','rachl181@hotmail.com','rachel perkins','40 clayton cres','rutherford','New South Wales','AUSTRALIA','2320','0432234108','NoPaymentFailure','CheckoutComplete','AU_Other','2011-05-04 04:56:04',0,NULL,3,0,3,1,'RA117731355CN\r ','rachel.perkins\r灰+黑'),(8933,709308959002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','boxrsnsox573','roger.vaughn@gmail.com','Roger Vaughn','502 Shamrock St','Cuba','MO','UNITED STATES','65453-1732','(573) 259-0772','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 05:59:23',0,NULL,3,1,1,1,NULL,'boxrsnsox573'),(8934,668370377001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ultradx','juan_alvarado37@msn.com','Juan C Alvarado','5536 Kalahari Ln','Las Cruces','NM','UNITED STATES','88011-7253','(575) 993-0166','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 05:57:34',0,NULL,3,1,1,1,NULL,'ultradx'),(8935,666971500018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','oystein999','oysmat@so-hf.no','Øystein Mathisen','Pettersand 58 A','Fredrikstad','','NORWAY','1614','+4741901542','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-04 06:33:26',0,NULL,3,1,2,1,NULL,'oystein999'),(8936,709331325002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','keshavsujeeun','kesh2503@yahoo.com','keshav sujeeun','astoria road, goodlands','port-louis','','MAURITIUS','230','+230 9185083','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 08:01:28',0,NULL,3,1,3,1,'RA117731214CN ','keshavsujeeun'),(8937,709333031002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',6,'AA1310',32.94,'hermeshine','edacs_247','mwallach1@msn.com','Mark Wallach','501 44th Ave SW','Vero Beach','FL','UNITED STATES','32968','(772) 473-3496','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 08:09:18',0,NULL,3,1,1,1,NULL,'edacs_247'),(8938,668406579001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','talnisim','talnisim@gmail.com','Tal Nisim','Reading 6/c','Tel Aviv','','ISRAEL','69022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 08:43:08',0,NULL,3,1,2,1,' ','talnisim\r庄'),(8939,667015518018,280666893489,'New Green.L 77mm  Gradual Grey ND4 Filter 2-Stop 77 mm',1,'AA3321',8.8,'photographyacc','janbo1960','ruzgar@tpg.com.au','Jan Ruzgar','1 Warawee Place','Hallett Cove','South Australia','AUSTRALIA','5158','0883816830','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-04 10:03:02',0,NULL,3,1,2,1,NULL,'janbo1960\r刘'),(8940,709368887002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','bluntus','handay1010@hotmail.com','Burhanuddin Hj Ahmad','No 41 Jln Kecil Agau Kg Parit,<br>Pengkalan Batu, Jln Limau Manis','Bandar Seri Begawan','Brunei','BRUNEI DARUSSALAM','BH 1123','+6738634405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 10:50:49',0,NULL,3,1,2,1,NULL,'bluntus\r'),(8941,780677001015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','jacky24460','jackycooper24460@aol.com','Jacqueline Cooper','53 Loanfern','Ballachulish','Highland','UNITED KINGDOM','PH49 4JB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 10:52:32',0,NULL,3,1,2,1,NULL,'jacky24460\r刘'),(8942,709369020002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','tanerercan','hunter09_09@hotmail.com','TANER ERCAN','TURKOCAGI CAD.NO:11','NAZİLLİ/AYDIN','','TURKEY','09800','+902563138684','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 11:03:30',0,NULL,3,1,3,1,'RA117731378CN ','tanerercan\rXL   \r王'),(8943,780676249015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','saxyrico','eric.estournet@free.fr','eric estournet','bat b2 residence chante perdrix<br>7 rue docteur girbal','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13010','0684772220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 11:05:37',0,NULL,8,1,17,0,NULL,'saxyrico'),(8944,764746590016,260660050260,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','saxyrico','eric.estournet@free.fr','eric estournet','bat b2 residence chante perdrix<br>7 rue docteur girbal','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13010','0684772220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 11:05:39',0,NULL,8,1,17,0,NULL,'saxyrico'),(8945,780677015015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','saxyrico','eric.estournet@free.fr','eric estournet','bat b2 residence chante perdrix<br>7 rue docteur girbal','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13010','0684772220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 11:05:38',0,NULL,8,1,17,0,NULL,'saxyrico'),(8946,764746028016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'',11.8,'hutongstore','saxyrico','eric.estournet@free.fr','eric estournet','bat b2 residence chante perdrix<br>7 rue docteur girbal','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13010','0684772220','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-04 11:05:40',0,NULL,3,1,4,1,'YW866010881CN','saxyrico\r反光板 100*150 5合1    1\r倒影板（白黑）   1\r反光板支架   1\r大力夹   2\r王\r一票两件'),(8947,668446772001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','swake57','reb_olivier@yahoo.fr','Olivier REB','77 rue Kellermann','METZ','Lorraine','FRANCE','57000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 11:42:44',0,NULL,3,1,4,1,'YW866011544CN ','swake57\r刘\rboom arm  $20'),(8948,709382745002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','cyber_m3nace','cybervand@gmail.com','Peter Bjorvand','Skogbrynet 17 D','Oslo','','NORWAY','0283','(+47)94263618','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 11:47:06',0,NULL,3,1,2,1,NULL,'cyber_m3nace\r庄'),(8949,668459677001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',2,'AA2205',7,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 12:30:38',0,NULL,3,1,2,1,NULL,'bobi1330\r庄'),(8950,709353837002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','carlinhos-brown','afrointheajo@hotmail.com','Carlos Torres','C/ Generalife, nº 4','Churriana de la Vega (Granada)','Andalucía Ceuta y Melilla','SPAIN','18194','622747316','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 13:10:10',0,NULL,3,1,4,1,'YW866011533CN ','carlinhos-brown\rtripod $26\r王'),(8951,780740146015,250610476275,'New Desktop Photography light Stand 10-15\" Tall ',1,'AKT010',20.9,'hutongstore','vlaw0241','veron_ron4@hotmail.com','Veronica law','56 walpole place<br>Brookhill Road','woolwich','London','UNITED KINGDOM','se18 6tp','07816158857','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 13:55:57',0,NULL,3,1,3,1,'RA117731395CN ','vlaw0241\r刘\r英标'),(8952,668446694001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','jjeusano','jjeusano@wanadoo.es','juan jose esteban usano','ortega y gasset 7 2 C','cuenca','Castilla-La Mancha','SPAIN','16004','616011768','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 14:22:46',0,NULL,3,1,4,1,'YW866011522CN ','jjeusano\r庄\rtripod $20'),(8953,780750738015,250692240407,'Shutter Release Remote Cord For Pentax K20D K200D K7',1,'AA3210',2.98,'hutongstore','ppol78','ppol@inbox.lv','Pavel Porubovs','10 Leamouth Road','Beckton, London','Essex','UNITED KINGDOM','E6 5SJ','02085912375','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 14:23:55',0,NULL,3,1,2,1,NULL,'ppol78\r刘'),(8954,709431937002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','skarp92','erikskarp@hotmail.com','Erik Skarp','Ramshult Norrgård','Mjölby','','SWEDEN','59591','0707499450','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 14:36:53',0,NULL,8,1,17,0,NULL,'skarp92'),(8955,668495963001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',59,'hermeshine','skarp92','erikskarp@hotmail.com','Erik Skarp','Ramshult Norrgård','Mjölby','','SWEDEN','59591','0707499450','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 14:39:09',0,NULL,3,1,4,1,'YW866011511CN ','skarp92\r欧标\r柔光箱 60-60cm  四灯头    2\r灯架  2m    2\rlighting kit  $26\r王'),(8956,709447613002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','webixe','webmaster@webixe.com','Pierre-Olivier Beaudry','1842 préfontaine','montreal','QC','CANADA','h1w2p1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 15:24:00',0,NULL,3,1,3,1,'RA117731364CN ','webixe\r刘'),(8957,668541461001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','viktoraraskog','banjomaniac@hotmail.com','Viktor Araskog','Högalidsgatan 11','Stockholm','','SWEDEN','11730','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 16:53:23',0,NULL,3,1,2,1,NULL,'viktoraraskog\r庄'),(8958,780630494015,250692237341,'IR Wireless Remote Control for Nikon D90/D80/D60 ML-L3',2,'AA2201',5.5,'hutongstore','dott.obelix','mirkomala@virgilio.it','Boschi Dino','Via Ariosto 2','Pianoro','BO','ITALY','40065','3339094366','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 17:24:42',0,NULL,3,1,2,1,NULL,'dott.obelix\r刘'),(8959,780832928015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','tabs4life','tab4lifes@gmail.com','Denis Vesely','Sevcenkova 19','Bratislava','','SLOVAK REPUBLIC','851 01','00421 908 636 785','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 17:30:34',0,NULL,3,1,2,1,NULL,'tabs4life\r刘'),(8960,668562017001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','vitorwood','vmcm@ci.uc.pt','Vitor Madeira','Department of Zoology<br>L. Marques de Pombal','Coimbra','Coimbra','PORTUGAL','3004-517','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:42:59',0,NULL,3,1,2,1,NULL,'vitorwood\r庄'),(8961,668566545001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','elnur1986','elnur86@gmail.com','Elnur Djafarov','bulvar Unih Lenincev dom 6 kvartira 306<br>2623-306','Naberejnie Chelny','Tatarstan','RUSSIAN FEDERATION','423827','+79179173836','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 17:53:30',0,NULL,3,0,3,1,'RA117731404CN ','elnur1986\r刘'),(8962,780232716015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','smatulevicius','saulius.matulevicius@gmail.com','Saulius Matulevicius','Laisves 22','Vilkaviskis','','LITHUANIA','70150','37068112122','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 19:46:51',0,NULL,3,1,2,1,NULL,'smatulevicius\r刘'),(8963,780931426015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','nicola.nordin','nicolanordin@hotmail.com','Nicola Nordin','Bergdalen 8','Stockholm','Sundbyberg','SWEDEN','17279','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 20:11:05',0,NULL,3,1,3,1,'RA117731316CN ','nicola.nordin\r刘'),(8964,709608816002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',2,'AO0014',15.8,'hermeshine','jho718','domingos007@hawaii.rr.com','Sisto Domingo','1419 Ala Hoku Pl','Honolulu','HI','UNITED STATES','96819-1432','(808) 833-7769','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 21:36:08',0,NULL,3,1,1,1,NULL,'jho718'),(8965,780977257015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',18.3,'hutongstore','skyline350gtdan','degraaff87@hotmail.com','Dan de Graaff','De Graaff Trailers, Langshot Stud<br>Gracious Pond Road','Chobham','Surrey','UNITED KINGDOM','GU24 8HJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 21:41:19',0,NULL,3,1,3,1,'RA117731320CN ','skyline350gtdan\r庄'),(8966,780982942015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','damiank996','damian996@googlemail.com','Damian Kaminski','Melville Data Services<br>Curriers Close','COVENTRY','West Midlands','UNITED KINGDOM','CV48AW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 21:53:43',0,NULL,3,1,3,1,'RA117731381CN ','damiank996\r刘'),(8967,765005838016,260660051619,'Medium size Neoprene Lens Pouch fit 17-85mm 18-70mm M',1,'AC1202',2.48,'hutongstore','koygirl','koy.tradera@gmail.com','Anna-Karin Nilsson','Banjogatan 23e','Karlstad','Koy','SWEDEN','65636','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 21:54:41',0,NULL,8,1,17,0,NULL,'koygirl'),(8968,764990679016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','koygirl','koy.tradera@gmail.com','Anna-Karin Nilsson','Banjogatan 23e','Karlstad','Koy','SWEDEN','65636','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 21:54:42',0,NULL,8,1,17,0,NULL,'koygirl'),(8969,780938463015,250599364923,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3303',2.3,'hutongstore','koygirl','koy.tradera@gmail.com','Anna-Karin Nilsson','Banjogatan 23e','Karlstad','Koy','SWEDEN','65636','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 21:54:42',0,NULL,8,1,17,0,NULL,'koygirl'),(8970,780936372015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','koygirl','koy.tradera@gmail.com','Anna-Karin Nilsson','Banjogatan 23e','Karlstad','Koy','SWEDEN','65636','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 21:54:43',0,NULL,3,1,3,1,' 1','koygirl\r绿叶 UV  58mm   1\r眼罩 450D/500D   1\r镜头筒 中号    1\r镜头筒 小号    1\r刘 \r   号丢了   '),(8971,668613381001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','zappeastusa2','zappusa2@gmail.com','Andrei Second','25 Walpole Park S<br>Ste 4','Walpole','MA','UNITED STATES','02081-2522','(508) 734-5382','NoPaymentFailure','CheckoutComplete','Other','2011-05-04 22:27:29',0,NULL,3,1,1,1,' ','zappeastusa2\r在运单上写上：110668199161\r刘'),(8972,668677253001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','ascaflin','acostamolina@hotmail.com','andres acosta molina','c/ san isdro labrador edf. DIANA 3 PORTAL 1 5ºB','fuengirola (malaga)','Andalucía Ceuta y Melilla','SPAIN','29640','655401560','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 22:35:48',0,NULL,3,1,4,1,'YW866010844CN ','ascaflin\r庄\rtripod $22'),(8973,765065527016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','11clifford11','cliffordxwhite@gmail.com','Clifford Phang','4 COLNE WAY','BASINGSTOKE','Hampshire','UNITED KINGDOM','RG21 4BT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 22:53:11',0,NULL,3,1,2,1,NULL,'11clifford11\r庄'),(8974,668691569001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',2.95,'hermeshine','luisrubin','luis.rubin@gmail.com','Luis Rubin','3 Shillingstone Rd','Winnipeg','MB','CANADA','R3Y 1J3','(204) 489-1422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 23:07:03',0,NULL,3,1,2,1,NULL,'luisrubin\r庄'),(8975,707533006002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','aligator_smile','achurch1988@hotmail.com','Alex Churchill','4/43 Linden ave','Boambee East','New South Wales','AUSTRALIA','2452','0266585210','NoPaymentFailure','CheckoutComplete','AU_Other','2011-05-04 23:36:27',0,NULL,7,0,18,0,NULL,'aligator_smile\r'),(8976,665235108018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','sez87','sarahc104@hotmail.com','sarah connolly','1B Clarendon Cres','basin View','New South Wales','AUSTRALIA','2540','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-04 23:41:43',0,NULL,8,1,17,0,NULL,'sez87'),(8977,665236872018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',200,'photographyacc','sez87','sarahc104@hotmail.com','sarah connolly','1B Clarendon Cres','basin View','New South Wales','AUSTRALIA','2540','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-04 23:42:45',0,NULL,3,1,4,1,'YW866011496CN ','sez87\r澳标\r背景架 2mx3m 河北   1\r灯架  2m   3\r斜臂   1\r50-70 单灯头柔光箱   3\r115w  220v   3\r灯架包   1\r1.6x2.1 白色背景布   1\r庄\r'),(8978,667326738018,280666834436,'New Small Camera bag lens case D2 for Canon 500D 450D ',1,'AO0033',8,'photographyacc','czechm878','czechm8_78@yahoo.com.au','Petr Typlt','18 Glen Street','Eastwood','New South Wales','AUSTRALIA','2122','0410781957','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-05 00:43:24',0,NULL,3,1,2,1,NULL,'czechm878\r刘'),(8979,668717631001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','ahchrisho','ahchrisho@yahoo.com.sg','Chris Ho','15 Jalan Kemajuan','default','','SINGAPORE','368981','+60127389578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 01:07:14',0,NULL,3,1,11,1,NULL,'ahchrisho'),(8980,667333170018,280666869553,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop White/Black',1,'AC3304',68,'photographyacc','dj_danielsan','dj_danielsan@hotmail.com','Daniel James Thompson','80 Croydondale Drive','Melbourne','Victoria','AUSTRALIA','3138','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-05 01:11:44',0,NULL,3,1,4,1,'YW866011485CN ','dj_danielsan\r刘'),(8981,668738380001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','stace1234','stacey_critch@hotmail.com','Stacey Critch','173 cokerill CR','Fort McMurray','AB','CANADA','t9k 2j3','(178) 020-1560 ext.: 2','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 02:39:39',0,NULL,3,1,5,1,'CP227020313CN ','stace1234\r庄\r\r灯泡是110v'),(8982,668739293001,110658437998,'Remote Shutter Release Cord for Nikon D70s D80 RE-G',1,'AA2221',4.68,'hermeshine','0520pup','r_nelson@bellsouth.net','Samuel Nelson','111 Smith rd.','Waco','GA','UNITED STATES','30182','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-05 02:44:11',0,NULL,3,1,1,1,NULL,'0520pup\r庄'),(8983,668631717001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',56.9,'hermeshine','photographyandvisualarts','ricardobandala@gmail.com','Ricardo Bandala','Av. Carranza 787 Col. Centro','San Luis Potosí','San Luis Potosí','MEXICO','78000','+524448100432','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 03:03:08',0,NULL,3,1,3,1,'RA117715097CN \rRA117715137CN','photographyandvisualarts\r分开发\r刘'),(8984,781079790015,250599384655,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3307',2.9,'hutongstore','tonysadr','t_sader@hotmail.com','Bonny Sadr','28, Buer Rd<br>Flat 5','London','London','UNITED KINGDOM','SW6 4LA','07852305701','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 03:25:06',0,NULL,8,1,18,0,NULL,'tonysadr'),(8985,765140387016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','tonysadr','t_sader@hotmail.com','Bonny Sadr','28, Buer Rd<br>Flat 5','London','London','UNITED KINGDOM','SW6 4LA','07852305701','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 03:25:07',0,NULL,3,1,2,1,NULL,'tonysadr\r绿叶 UV  77mm   1\r绿叶 渐变镜 77mm    1\r庄'),(8986,667362431018,280666903675,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',102,'photographyacc','tom_888','7om8o87@gmail.com','Tom Brunsdon','29 Currawong Street','Mornington','Victoria','AUSTRALIA','3931','0359736617','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-05 03:27:40',0,NULL,3,1,4,1,'YW866011474CN ','tom_888\rballhead  $20\r王'),(8987,668704177001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',9.98,'hermeshine','espiritkiller','andrematos@virtualmagic.com.br','Andre de Matos Alves','Rua Travessa da Imprensa, 128<br>Jardim Aliança','Osasco','São Paulo','BRAZIL','06236-180','+55 11 35994110','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 03:40:31',0,NULL,3,1,3,1,' RA117732886CN','espiritkiller\rcanon  电子触点   1\rlenspen   2\r刘'),(8988,709700519002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',109.98,'hermeshine','fototigerfoto','viktorpalkin@gmail.com','Palkina Yulia','st. D. Kovalchyk 252 kv.68','Novosibirsk','NSO','RUSSIAN FEDERATION','630082','8-913-940-86-88','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 03:40:44',0,NULL,3,1,5,1,'CP226269016CN ','fototigerfoto\r王'),(8989,668755189001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','abestrus','realtorluis@aol.com','Luis Trujillo','4736 W Allen St','Laveen','AZ','UNITED STATES','85339-2133','(602) 241-4411','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-05 04:10:26',0,NULL,3,1,1,1,NULL,'abestrus\r庄'),(8990,709713401002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','fatemaqa','love._.me009@hotmail.com','Fatema AL Medaihki','C Ring Road Navigation Plaza Oxy<br>P.O.Box : 22611','Doha','','QATAR','00974','00974-55128383','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 05:06:22',0,NULL,3,1,3,1,' RA117715018CN\r','fatemaqa\rM'),(8991,709714810002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','rm1one','lhum_1@graffiti.net','Leslie Hum','9 Jalan Sungai Emas 5A<br>Batu Ferringhi','Batu Ferringhi','Penang','MALAYSIA','11100','0124896915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 05:12:15',0,NULL,3,1,2,1,NULL,'rm1one'),(8992,668774203001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','v0xff','voxtobox@gmail.com','Vova Antonyuk','Filatova 4','Lutsk','Volyn region','UKRAINE','43018','380631788440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 06:26:26',0,NULL,3,1,2,1,NULL,'v0xff'),(8993,720754138017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','kolya_grain','274020742@mail.ru','Nikolay Pomortsev','Svobody<br>39','Kungur','Permskiy Kray','RUSSIAN FEDERATION','617470','+79655522722','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-05 06:42:10',0,NULL,3,1,5,1,'CP226269002CN ','kolya_grain\r套装里再加2个45w 灯泡\r欧标\r王'),(8994,667376603018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','kolya_grain','274020742@mail.ru','Nikolay Pomortsev','Svobody<br>39','Kungur','Permskiy Kray','RUSSIAN FEDERATION','617470','+79655522722','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-05 06:44:00',0,NULL,8,1,17,0,NULL,'kolya_grain'),(8995,668783973001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','af_133','fedorov.isr@gmail.com','Alexander Fedorov','Batya Makov<br>7/3','Rehovot','','ISRAEL','76481','+972-52-2402789','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 07:08:04',0,NULL,3,1,3,1,'RA117715070CN ','af_133\r庄'),(8996,781135038015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','snapo007','vilius.kavaliunas@gmail.com','Vilius Kavaliūnas','Neries kr. 32-26','Kaunas','','LITHUANIA','48463','+37067106414','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-05 07:43:43',0,NULL,3,1,3,1,'RA117715110CN ','snapo007\r王'),(8997,709744001002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','gomendiobay','inaki.gomendio@ehu.es','Iñaki Gomendiourrutia','Universidad del País Vasco, Rectorado','Leioa','Bizkaia','SPAIN','48940','655705314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:59:06',0,NULL,8,1,17,0,NULL,'gomendiobay'),(8998,668792172001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','gomendiobay','inaki.gomendio@ehu.es','Iñaki Gomendiourrutia','Universidad del País Vasco, Rectorado','Leioa','Bizkaia','SPAIN','48940','655705314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:59:07',0,NULL,8,1,17,0,NULL,'gomendiobay'),(8999,668792109001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','gomendiobay','inaki.gomendio@ehu.es','Iñaki Gomendiourrutia','Universidad del País Vasco, Rectorado','Leioa','Bizkaia','SPAIN','48940','655705314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:59:07',0,NULL,8,1,17,0,NULL,'gomendiobay'),(9000,668792266001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','gomendiobay','inaki.gomendio@ehu.es','Iñaki Gomendiourrutia','Universidad del País Vasco, Rectorado','Leioa','Bizkaia','SPAIN','48940','655705314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:59:08',0,NULL,3,1,3,1,'RA117715083CN ','gomendiobay\r82mm 接口环   1\r广角托架  1\r渐变橙   1\r星光镜 star6    1'),(9001,720793750017,270742403077,'New IR Wireless Remote Control for Pentax Canon Nikon ',1,'AA2205',5.48,'photographyacc','balmakov','balmakov.artmedia@gmail.com','Andrey Balmakov','100 Morozova st. app. 5','Stavropol','Stavropolskiy kray','RUSSIAN FEDERATION','355003','+79624478373','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-05 08:23:28',0,NULL,3,1,2,1,NULL,'balmakov\r庄'),(9002,668800538001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','vipi2005','pivizara@gmail.com','PILAR BALLANO','SANTA OROSIA 42 5º B','Zaragoza','Aragón','SPAIN','50010','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 08:34:13',0,NULL,3,1,3,1,'RA117715145CN ','vipi2005'),(9003,709765812002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','4x6zk','i4x6zk@013.net','shlomo shafir','4 frishman st','holon','israel','ISRAEL','58351','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 09:43:07',0,NULL,3,1,2,1,'\\ ','4x6zk\r庄'),(9004,668812318001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',7.98,'hermeshine','silvia79astro','alessandro.negro@unipd.it','Negro Alessandro','galleria Ognissanti 24<br>Padova','Padova','PD','ITALY','35120','3342498305','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 10:02:25',0,NULL,3,1,2,1,NULL,'silvia79astro\r庄'),(9005,709775984002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','aelita_23','vanesapires@yahoo.es','Vanessa Pires Alfonso','Izaro nº6 1º A Derecha','Getxo Fadura','País Vasco','SPAIN','48990','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 10:25:45',0,NULL,3,1,2,1,'\\ ','aelita_23\r庄'),(9006,781180951015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','blackwood1234','ryanblackwood1@gmail.com','Ryan Blackwood','16/7 Durar Drive','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH47JG','01314677497','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 10:33:25',0,NULL,8,1,17,0,NULL,'blackwood1234'),(9007,765240610016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'AA1304',3.76,'hutongstore','blackwood1234','ryanblackwood1@gmail.com','Ryan Blackwood','16/7 Durar Drive','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH47JG','01314677497','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 10:33:26',0,NULL,3,1,2,1,NULL,'blackwood1234\r机身盖/镜头后盖  Canon   1\rCANON 镜头盖  77mm    2'),(9008,765242185016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','tylyla','stacey.stubbs@hotmail.co.uk','Stacey Stubbs','Church View, Washfield Lane<br>Treeton','Rotherham','South Yorkshire','UNITED KINGDOM','S60 5PU','07817783006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 10:39:52',0,NULL,3,1,2,1,NULL,'tylyla\r庄'),(9009,709786914002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','markcsy','markcho73@yahoo.com.sg','sai yan cho','blk 601 woodlands drive 42<br>#07-73','Singapore','','SINGAPORE','730601','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 11:10:36',0,NULL,3,1,9,1,'A05453451','markcsy\r刘'),(9010,668837729001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','rikirp','rikirp@yahoo.fr','Rikir Philippe','17 rue du gué','Mortier','Liege','BELGIUM','4670','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 11:23:14',0,NULL,3,1,4,1,'YW866010870CN ','rikirp\r王'),(9011,667457342018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE3401',35,'photographyacc','anhtruc','nguyentruc@hotmail.com','henry nguyen','Shop 1A, Kmart Plaza<br>176-210 Burwood Hwy','Burwood East','Victoria','AUSTRALIA','3151','0398861212','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-05 11:29:22',0,NULL,3,1,3,1,'RA117715300CN \r---\rRA117715622CN\r','anhtruc\r刘\r---\r反光板支架   1\r（当时发错了，重发一下吧）'),(9012,709791265002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','memorion.0003','alcazarrico@vodafone.es','Carlos de Alcázar Rico','Avda. Las Erillas, 12-2<br>La Pañoleta','Camas','Andalucía Ceuta y Melilla','SPAIN','41900','658560003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 11:35:30',0,NULL,8,1,17,0,NULL,'memorion.0003'),(9013,781206473015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','john170665','jonathancryan@eircom.net','John Ryan','7 Cascade Park','Clonmel','Tipperary','IRELAND','default','0526190802','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-05 11:55:22',0,NULL,3,1,2,1,NULL,'john170665\r庄'),(9014,668846083001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',75,'hermeshine','mialeigh89','focuspointephotography@live.com.au','Mia Powter','1 Speedy St','Kelvin Grove','Queensland','AUSTRALIA','4059','0468689383','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2011-05-05 11:56:08',0,NULL,3,1,4,1,'YW866010914CN','mialeigh89\r刘'),(9015,667475731018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','r.o.s.s.c.o.2.0.1.1','rosscollado@gmail.com','Ross Collado','4 Barcelona Dr.','Prestons','New South Wales','AUSTRALIA','2170','0296082125','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-05 12:33:42',0,NULL,3,1,2,1,NULL,'r.o.s.s.c.o.2.0.1.1\r王'),(9016,709812211002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','eyalbm','eyalbm@gmail.com','Eyal Ben Meir','4 Sde Hemed st.','Mevasseret Zion','Israel','ISRAEL','90805','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 12:46:21',0,NULL,3,1,2,1,' ','eyalbm\r庄'),(9017,668865942001,110445705855,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',2,'AB1405',10.98,'hermeshine','56paul61','suzannesellers@bigpond.com','Paul Sellers','336 Salvado Rd, Floreat','Perth','Western Australia','AUSTRALIA','6014','0893871611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 13:09:39',0,NULL,3,1,2,1,NULL,'56paul61\r庄'),(9018,666960806018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',135,'photographyacc','xaviervillalba','xavier_avt@yahoo.com','Xavier Villalba','Urb. Madrigal, sector Monjas, Antonia Salinas y Pedro Tobar E16-116','Quito','Pichincha','ECUADOR','E16-116','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 13:19:42',0,NULL,3,1,5,1,' CP226268877CN','xaviervillalba\r庄'),(9019,781257997015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','magdowi','m.mozga@gmail.com','Magdalena Mozga','62 Whitson Walk','Edinburgh','Midlothian','UNITED KINGDOM','EH11 3BY','07913721194','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 14:20:51',0,NULL,3,1,3,1,'RA117715185CN ','magdowi\r刘'),(9020,668887819001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','milton1601','miltonramalho@uol.com.br','São Milton Silva','Rua Claudio Rossi, 752','São Paulo','São Paulo','BRAZIL','01547-000','55 11 2063 4546','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 14:29:05',0,NULL,3,1,3,1,'RA117715211CN ','milton1601\r刘'),(9021,781274181015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3306',2.6,'hutongstore','melgesmoo','hennessy@otenet.gr','GERALD HENNESSY','PO BOX 278,','FALIRAKI','RHODES','GREECE','85105','(0030) 2241086694','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-05 15:04:42',0,NULL,8,1,17,0,NULL,'melgesmoo'),(9022,781274025015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','melgesmoo','hennessy@otenet.gr','GERALD HENNESSY','PO BOX 278,','FALIRAKI','RHODES','GREECE','85105','(0030) 2241086694','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-05 15:04:43',0,NULL,3,1,4,1,' YW866010903CN','melgesmoo\r绿叶 UV  72mm   1\r三脚架 伟峰 EI-717   1\r王\r---\r9号被告知无法发到pobox地址，新地址是：\rGerald Hennessy\rMegalo Konstantiniou 3\rKalithies\r85100\rRhodes\rGreece.'),(9023,668429889001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','frdric840','ebayfrdric840@orange.fr','Fouchenneret-Albiez Frédéric','36, rue Camille LENOIR','REIMS','Champagne-Ardenne','FRANCE','51100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 17:09:58',0,NULL,8,1,17,0,NULL,'frdric840'),(9024,668831613001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','frdric840','ebayfrdric840@orange.fr','Fouchenneret-Albiez Frédéric','36, rue Camille LENOIR','REIMS','Champagne-Ardenne','FRANCE','51100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 17:09:59',0,NULL,3,1,4,1,'YW866010892CN ','frdric840\r欧标\r大号灰卡   1\r麂皮   3\r永诺 Canon ttl线  3m    1\r背景架2m x 3m   1\r3x6 背景布    1（白色）\r2m灯架   2\r50-70 单灯头柔光箱   2\r115w 220v 灯泡   4\r灯架包   1\r庄'),(9025,668431267001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','frdric840','ebayfrdric840@orange.fr','Fouchenneret-Albiez Frédéric','36, rue Camille LENOIR','REIMS','Champagne-Ardenne','FRANCE','51100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 17:10:00',0,NULL,8,1,17,0,' ','frdric840'),(9026,668430820001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','frdric840','ebayfrdric840@orange.fr','Fouchenneret-Albiez Frédéric','36, rue Camille LENOIR','REIMS','Champagne-Ardenne','FRANCE','51100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 17:10:01',0,NULL,8,1,17,0,NULL,'frdric840'),(9027,709783578002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','frdric840','ebayfrdric840@orange.fr','Fouchenneret-Albiez Frédéric','36, rue Camille LENOIR','REIMS','Champagne-Ardenne','FRANCE','51100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 17:10:02',0,NULL,8,1,17,0,NULL,'frdric840\r'),(9028,707082450002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','xrobertojosuex','xxrunkenxx@gmail.com','roberto josue naranjo rosario','BB72 CALLE 26<br>LAS VEGAS','catano','PR','UNITED STATES','00962-6428','','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,1,18,0,'','xrobertojosuex\r'),(9029,765398479016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'',11.8,'hutongstore','inglezoid','ingles@netcabo.pt','João Andrade','Av. António Augusto de Aguiar, n.º 106, 8º andar','Lisboa','Lisboa','PORTUGAL','1050-019','+351213173660','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-05 17:37:03',0,NULL,3,1,2,1,NULL,'inglezoid\r庄'),(9030,765400851016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','sigmacanon','perttie4@gmail.com','pertti eronen','oinasjärventie 463','sonkajärvi','Oletus','FINLAND','74300','(050-5385071','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-05 17:42:45',0,NULL,3,1,2,1,NULL,'sigmacanon\r庄'),(9031,668978726001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','xlorian10','jiannis2@mail.com','jiannis chloros','oik. eksikonomou 38','larisa','','GREECE','41223','0030 6948262304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 18:36:43',0,NULL,3,1,2,1,' ','xlorian10\r庄'),(9032,709950796002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',2,'AC2303',12.42,'hermeshine','gabealba','gabe_alba@yahoo.com','Gabe Alba','428 Brookside Pl','Cranford','NJ','UNITED STATES','07016-1635','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-05 19:14:26',0,NULL,3,1,1,1,' ','gabealba\r庄'),(9033,709962387002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','martin_nos','martinovic@azet.sk','Martin Nosal','Bidovce 278','Bidovce','','SLOVAK REPUBLIC','04445','+421907204097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 19:33:47',0,NULL,3,1,3,1,'RA117715199CN ','martin_nos\r王'),(9034,765520345016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','under.dradar','under.dradar@gmail.com','Darren Walsh','20 The View<br>Five Oaks','Drogheda','Louth','IRELAND','041','0864008915','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-05 21:15:54',0,NULL,3,1,2,1,NULL,'under.dradar\r庄'),(9035,664928875001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','arekuso2010','alexander.mapa.so@akersolutions.com','Alexander So','Ostersveien 6<br>Hundvåg','Stavanger','Rogaland','NORWAY','4085','9683 5792','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 22:03:20',0,NULL,3,1,2,1,'\\','arekuso2010\r庄\r'),(9036,669071594001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','thiagomu','tsframos@hotmail.com','THIAGO RAMOS','RUA JOSE VARGAS DE FIGUEIREDO<br>NUMBER 46','VARRE-SAI','RIO DE JANEIRO / RJ','BRAZIL','28375000','(22)3843-3321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 23:16:38',0,NULL,3,1,3,1,'RA117715242CN ','thiagomu\r欧标\r王'),(9037,710048646002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','memorion.0003','alcazarrico@vodafone.es','Carlos de Alcázar Rico','Avda. Las Erillas, 12-2<br>La Pañoleta','Camas','Andalucía Ceuta y Melilla','SPAIN','41900','658560003','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 23:44:01',0,NULL,3,1,3,1,'RA117715239CN ','memorion.0003\r50-70柔光棚 通用塑料卡口    1\r斜臂     1\r（小包131，燕文166）\r刘'),(9038,710052697002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','tixtu','baritado@gmail.com','Alberto sánchez Ureña','colonia pernau  3 1,1','campdevanol','Gerona','SPAIN','17530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 23:59:11',0,NULL,3,1,2,1,NULL,'tixtu'),(9039,765577614016,260660050260,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','vitoriasetubal','candeias_marco@hotmail.com','Marco Candeias','Praceta Pêro Vaz de Caminha<br>Nº 1 - 1º A','2900-798 SETÚBAL','SETÚBAL','PORTUGAL','2900-798','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 00:11:46',0,NULL,8,1,17,0,NULL,'vitoriasetubal'),(9040,765577927016,260660055182,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',15,'hutongstore','vitoriasetubal','candeias_marco@hotmail.com','Marco Candeias','Praceta Pêro Vaz de Caminha<br>Nº 1 - 1º A','2900-798 SETÚBAL','SETÚBAL','PORTUGAL','2900-798','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 00:13:10',0,NULL,8,1,17,0,NULL,'vitoriasetubal'),(9041,781526807015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','vitoriasetubal','candeias_marco@hotmail.com','Marco Candeias','Praceta Pêro Vaz de Caminha<br>Nº 1 - 1º A','2900-798 SETÚBAL','SETÚBAL','PORTUGAL','2900-798','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 00:22:06',0,NULL,3,1,3,1,'RA117715225CN ','vitoriasetubal\r圆形柔光棚 50cm   1\r倒影板    1\r45w 220v 灯泡    2\r王'),(9042,669104780001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','rwk40y','richard@ribbons.com.au','Richard Kerslake','91 Westbrook Ave','Wahroonga','New South Wales','AUSTRALIA','2076','0294871881','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 01:08:30',0,NULL,3,0,3,1,'RA117730770CN ','rwk40y\rXXXL(已入库)\r庄'),(9043,669113945001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','designs4fun','desmarsol@aol.com','Paula Spagnuolo','1909 Shippan Ave','Stamford','CT','UNITED STATES','06902','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 01:50:31',0,NULL,3,1,1,1,NULL,'designs4fun\r庄'),(9044,710079163002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',20,'AA1310',109.8,'hermeshine','ruyguerra','ruyguerra1958@hotmail.com','Ruy Guerra','Rua Itapiru, 264 apto 34','Sao Paulo','SP','BRAZIL','04143-010','11-8613-6907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 01:51:29',0,NULL,3,1,3,1,'RA117715171CN ','ruyguerra\r申报：12$；gift\r庄'),(9045,710080430002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','buffy10478','ereynolds104@hotmail.com','Erin Reynolds','636 Amelia Cres','Burlington','ON','CANADA','L7L 6E5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 01:57:42',0,NULL,3,1,3,1,' RA117715168CN','buffy10478\r庄'),(9046,710087158002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','leandro.nemesio','lanemesio@gmail.com','Leandro Nemesio','Rua Ademar de Barros, 847<br>Centro','Artur Nogueira','São Paulo','BRAZIL','13160-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 02:36:21',0,NULL,8,1,17,0,NULL,'leandro.nemesio'),(9047,669121192001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','leandro.nemesio','lanemesio@gmail.com','Leandro Nemesio','Rua Ademar de Barros, 847<br>Centro','Artur Nogueira','São Paulo','BRAZIL','13160-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 02:36:22',0,NULL,3,1,3,1,'RA117715287CN ','leandro.nemesio\r欧标\r柔光箱 50-70cm 单灯头   1\r50-70柔光棚 通用塑料卡口   1\r庄 1.361\r'),(9048,710099610002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','hawthorntoo','cynneath@verizon.net','Kenneth Salewski','1704 Wrightfield Rd','Yardley','PA','UNITED STATES','19067-3131','(215) 321-6288','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 03:23:06',0,NULL,3,1,1,1,NULL,'hawthorntoo\r庄'),(9049,710106475002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','arakure_knight','clannad@tpg.com.au','Daryl Leong','431 Brisbane Corso','Yeronga','Queensland','AUSTRALIA','4104','61738922800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 04:01:31',0,NULL,3,1,3,1,'RA117715432CN','arakure_knight\r王'),(9050,721178233017,270742432910,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',8.88,'photographyacc','dags111','sdaggar@yahoo.com.au','steve   daggar','14 thomas st','tascott','New South Wales','AUSTRALIA','2250','0410513257','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-06 04:30:02',0,NULL,3,1,2,1,' ','dags111\r庄\r77mm 接口环   1\r广角托架    1\r'),(9054,668801286001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','korsar_64','konstantinas@soklys.lt','Konstantinas Samcenko','Svedes 43<br>Ginkunai','Siauliai','','LITHUANIA','81491','+37069827827','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 06:52:46',0,NULL,3,1,5,1,'CP226268885CN ','korsar_64'),(9051,669149999001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','msvenss1','onewheeler@hotmail.com','Mattias Svensson','Svarvaregatan 11','Huskvarna','','SWEDEN','56135','46704856661','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 05:09:40',0,NULL,3,1,3,1,'RA117715446CN ','msvenss1\r庄'),(9052,669157254001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','ranraanana','ranmor84@gmail.com','Ran Mor','Borocohov 22/6','Raanana','','ISRAEL','43433','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 05:56:42',0,NULL,3,1,2,1,NULL,'ranraanana\r庄'),(9053,669053828001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','anato01','smart2bay@yandex.ru','Anatoliy Alekseev','86 Golovatogo Str.','Krasnodar','ru','RUSSIAN FEDERATION','350004','+7(903)4538945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 06:39:41',0,NULL,3,0,3,1,'RA117715494CN ','anato01\r王'),(9055,669170185001,110583278199,'TianYa 58mm CPL filter New 58 Circular Polarizing C-PL',1,'AA2303',5.9,'hermeshine','ob_1969','matha@chello.at','Oliver Matha','Grosse Neugasse 40/9','Wien','','AUSTRIA','1040','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 07:10:16',0,NULL,3,1,2,1,' ','ob_1969\r换发“绿叶 cpl 58mm    1”\r庄'),(9056,781655913015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',125,'hutongstore','inphernomassacro','giuliano.froio@gmail.com','Grandolfo-Froio c/o McCann Erickson','via dei Magazzini Generali 18/20','Roma','RM','ITALY','00154','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-06 09:16:52',0,NULL,3,1,4,1,'YW865907281CN ','inphernomassacro\r再加一块 黑色的背景布  1.6x2.1\r欧标\rlighting kit  $26\r庄'),(9057,765704698016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','inphernomassacro','giuliano.froio@gmail.com','Grandolfo-Froio c/o McCann Erickson','via dei Magazzini Generali 18/20','Roma','RM','ITALY','00154','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 09:16:53',0,NULL,8,0,17,0,NULL,'inphernomassacro'),(9058,710172445002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','rothovius','janne.ruotoistenmaki@pp.inet.fi','Janne Ruotoistenmäki','Luottamusmiehentie 11','Kangasala','','FINLAND','36100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 10:04:19',0,NULL,3,1,2,1,NULL,'rothovius'),(9059,669213999001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',2,'AA1202',5.98,'hermeshine','2010bokertov2010','pasov@012.net.il','Mikhael Pasov','Exodus 7/5','Qiryat Gat','','ISRAEL','82201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 10:48:00',0,NULL,3,1,2,1,NULL,'2010bokertov2010'),(9060,667858241018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','marcaextremadura','marca.extremadura@hotmail.com','Manuel Villafaina V.','C/ Antonio Reyes Huertas, nº7  1ºC','Cáceres','Extremadura','SPAIN','10002','637912461','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-06 11:02:34',0,NULL,3,1,2,1,NULL,'marcaextremadura'),(9061,669217263001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','mcamanda','amanda_mcgrath_91@hotmail.com','amanda mcgrath','182 braidwood drive','prestons','New South Wales','AUSTRALIA','2170','0466694330','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 11:04:04',0,NULL,3,1,4,1,'YW865907270CN ','mcamanda\r白+黑'),(9062,781695671015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','mzarzuelar','manuel-zarzuela@hotmail.com','manuel zarzuela rodríguez','c/francisco de ariño  nº4, 2ºF','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41008','647235845','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 11:31:21',0,NULL,3,1,2,1,NULL,'mzarzuelar'),(9063,710195329002,120499333257,'Flash Softbox Diffuser for external flash SB800 580EX',1,'AB3302',8.8,'hermeshine','dan05myr08','igoumenidis@gmail.com','manolis igoumenidis','kanari 103','thessaloniki','macedonia','GREECE','54453','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 11:40:58',0,NULL,3,1,3,1,'RA117715640CN\r ','dan05myr08'),(9064,781710258015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','djnelio','lionel.ducos@free.fr','DUCOS Lionel - studio pasteur','24 rue pasteur','puteaux','Ile-de-France','FRANCE','92800','01.49.01.95.20','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-06 12:15:43',0,NULL,3,1,4,1,'YW865907362CN ','djnelio\rtripod $25\r王'),(9065,710217026002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','myklikers','redzuanharris@gmail.com','Mohamad Redzuan Harris','MIS TICIS, Legenda Education Group,<br>BUTL, Batu 12,','Mantin','Negeri Sembilan','MALAYSIA','71700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 13:12:07',0,NULL,3,1,2,1,NULL,'myklikers'),(9066,669266754001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','galminas666','ktvarte@yahoo.com','Nilius Galminas','Silutes pl. 22-83','Klaipeda','','LITHUANIA','91175','(370) 68440666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:08:46',0,NULL,3,1,2,1,NULL,'galminas666'),(9067,669268838001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','giuserico','giuchio@yahoo.it','Giuseppe Chierico','via Francesco Scotti 3','Civitavecchia','RM','ITALY','00053','0766546156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:14:23',0,NULL,3,1,2,1,NULL,'giuserico'),(9068,710237409002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','meir_shevach','meshevach@gmail.com','Meir Shevach','P.O.B. 3501','Beer Sheva','','ISRAEL','84135','972546751616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:15:27',0,NULL,3,1,2,1,NULL,'meir_shevach'),(9069,765802409016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','hollysnead100','snead@live.co.uk','Holly  Snead','9 Coniston Road','Bexleyheath ','Kent','UNITED KINGDOM','DA7 6PX','01322339569','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-06 14:25:37',0,NULL,3,1,4,1,' YW865907351CN','hollysnead100\r 英标\rlighting kit $40\r王'),(9070,669275436001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','wiendhof','r.withoff@kpnmail.nl','Rob Withoff','Aperloheve 15','Elburg','','NETHERLANDS','8081JL','0525685091','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 14:33:56',0,NULL,3,1,2,1,NULL,'wiendhof'),(9071,781773596015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','bekig06','beki.gregory@hotmail.co.uk','Beki Gregory','12 Mariners Wharf<br>Grosvenor Wharf Road','Ellesmere Port','Cheshire','UNITED KINGDOM','CH65 4AS','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-06 15:10:35',0,NULL,3,1,4,1,'YW865907384CN ','bekig06\r英标\rlighting kit  $22\r刘'),(9072,669298294001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','alisonpitcher','aliee54@hotmail.com','alison pitcher','305-2727 Princess Street','Kingston','ON','CANADA','K7P3K4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 15:48:45',0,NULL,3,1,2,1,NULL,'alisonpitcher'),(9073,707082582002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','xrobertojosuex','xxrunkenxx@gmail.com','roberto josue naranjo rosario','BB72 CALLE 26<br>LAS VEGAS','catano','PR','UNITED STATES','00962-6428','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-06 15:50:39',0,NULL,7,0,18,0,NULL,'xrobertojosuex'),(9074,669300523001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',2,'AA3315',11.9,'hermeshine','jevgenijast','j_steinbe@yahoo.com','Jevgenija Steinberga','Dzelzavas 35 k1, 49','Riga','','LATVIA','LV-1084','+37126454313','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 15:55:46',0,NULL,3,1,2,1,NULL,'jevgenijast'),(9075,669301181001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','ethh13','etiennethuillier2000@yahoo.fr','Etienne THUILLIER','71 rue ghesquieres','HELLEMMES','Nord-Pas-de-Calais','FRANCE','59260','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 15:57:10',0,NULL,3,1,3,1,'RA117715653CN\r ','ethh13'),(9076,669316137001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','tricia5271','trishandchris@btinternet.com','Mrs T Seymour (Ebay)','Turners Transport Burton Road<br>St Faiths Ind Estate','Norwich','Norfolk','UNITED KINGDOM','NR6 6AU','01603779807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 16:42:02',0,NULL,3,1,2,1,NULL,'tricia5271'),(9077,668872588001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','731700728','hakis@centrum.cz','Josef Haken','SNP - 634','Hradec Králové','','CZECH REPUBLIC','50003','+420728700731','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 18:00:53',0,NULL,3,1,2,1,NULL,'731700728'),(9078,709815550002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','edwardfilm','edward_film@mail.ru','Eduard Filippov','Chilonzar 12-34-4','Tashkent','','UZBEKISTAN','700123','998-712-756131','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 18:03:44',0,NULL,3,1,3,1,'RA117715605CN\r ','edwardfilm'),(9079,668288439001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','pamy03','pamela_betancourt@yahoo.com','pamela betancourt','Metropolis calle 22 p.5','carolina','PR','UNITED STATES','00987','(787) 467-3863','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 18:07:35',0,NULL,7,0,18,0,NULL,'pamy03'),(9080,669348909001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','genproject99','keyla99@yahoo.com','Keyla  Guevara','361 E Sheridan St<br>Apt 301','Dania Beach','FL','UNITED STATES','33004-5549','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 18:10:09',0,NULL,3,1,1,1,NULL,'genproject99'),(9081,709976109002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','javito_67','jasasal@hotmail.com','Javier Sanchez','Ortiz Mena,104-B','Chihuahua','Chihuahua','MEXICO','31203','6142308690','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 18:17:34',0,NULL,3,1,3,1,'RA117715724CN\r RA117715295CN','javito_67\r2个小包'),(9082,669379863001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','xishuaipeng','caopengjia@gmail.com','Pengjia Cao','505 W University Pkwy<br>Apt D11','Baltimore','MD','UNITED STATES','21210-3297','(443) 977-3510','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 19:25:18',0,NULL,8,1,17,0,NULL,'xishuaipeng'),(9083,669379670001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','xishuaipeng','caopengjia@gmail.com','Pengjia Cao','505 W University Pkwy<br>Apt D11','Baltimore','MD','UNITED STATES','21210-3297','(443) 977-3510','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 19:25:19',0,NULL,8,1,17,0,NULL,'xishuaipeng'),(9084,710351376002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','xishuaipeng','caopengjia@gmail.com','Pengjia Cao','505 W University Pkwy<br>Apt D11','Baltimore','MD','UNITED STATES','21210-3297','(443) 977-3510','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 19:25:20',0,NULL,3,1,1,1,NULL,'xishuaipeng\r镜头筒 中号   1\r中号内胆包 无字   1\r绿叶 UV  52mm   1'),(9085,710360029002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',70,'hermeshine','*blackrock*','blackrock111@gmail.com','Mitja Mlakar','Stantetova 26','Maribor','','SLOVENIA','2000','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 19:48:06',0,NULL,3,1,5,1,' CP227022725CN','*blackrock*\r蓝色、绿色背景板\r申报 gift  $20'),(9086,710278685002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','lauradellacasa','lauradel@hotmail.it','alice linardi','via san polo 15a','sassuolo','modena','ITALY','41049','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 20:01:02',0,NULL,3,1,4,1,'YW865907373CN ','lauradellacasa\rbackground support $20\r2m 背景架   白'),(9087,669395947001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',2,'AKT024',9.74,'hermeshine','77148207','e.matveev@mail.ru','Irina Khudzinskaya','Leninsky prospekt, 135-4, apt.41','St. Petersburg','','RUSSIAN FEDERATION','198216','(904)551-0039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 20:06:23',0,NULL,8,1,17,0,NULL,'77148207'),(9088,710369999002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','fordfebe','fordfebe@terra.es','Fernando Bernal Lopez','c/ Fuente Carrantona nº 38 portal A, 4º centro','Madrid','Madrid','SPAIN','28030','669543201','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 20:09:25',0,NULL,3,1,4,1,'YW865907340CN ','fordfebe\r河北背景架   1\r1.6x2.1 白布\rbackground  $20'),(9089,710374092002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',2,'AA2322',14.4,'hermeshine','77148207','e.matveev@mail.ru','Irina Khudzinskaya','Leninsky prospekt, 135-4, apt.41','St. Petersburg','','RUSSIAN FEDERATION','198216','(904)551-0039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 20:20:30',0,NULL,3,1,3,1,'RA117715463CN\r ','77148207\r77mm 环架   2\r渐变灰   2\r刘'),(9090,781926113015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','jolene_1990','jolenebaxter1990@hotmail.co.uk','Jolene Baxter','496 Manchester road<br>Linthwaite','Huddersfield','West Yorkshire','UNITED KINGDOM','hd7 5rd','07927989165','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-06 20:27:32',0,NULL,3,1,4,1,'YW865907336CN ','jolene_1990\r英标\r刘'),(9091,781925569015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','bob2104','robertlobell@aol.com','robert lobell','94 kenilworth court<br>lower richmond road','london','London','UNITED KINGDOM','sw15 1ha','0207895050','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-06 20:33:41',0,NULL,3,1,2,1,NULL,'bob2104'),(9092,710389640002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','minis22','conceptrol@yahoo.com','Dominique Bouchard','2369 Lacordaire','Montreal','QC','CANADA','H1N2M1','(514) 253-5727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 21:01:11',0,NULL,3,1,3,1,'RA117730196CN ','minis22'),(9093,669426048001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','zaki0000','meir1980@yahoo.com','Tomer Meir','45 Hatomer','Zichron Yaakov','','ISRAEL','30900','(054) 462-3515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 21:31:25',0,NULL,3,1,2,1,NULL,'zaki0000'),(9094,669433950001,110609032219,'Redhead Red head 800w w bulb + Spring Cushioned Stand ',1,'AKT057',130,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 21:56:15',0,NULL,3,1,6,1,'EE520583335CN ','princessvideo\r灯头控制在2kg以下发国内挂号， 灯泡是110v的。\r灯架发EMS外地\r王'),(9095,669438883001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','rootfus','rudi@bizwarcho.com','Rudi Meyenburg (buzzer #2706)','3711-608 9th St SW','Calgary','AB','CANADA','T2P2B3','(403) 880-7559','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 22:16:11',0,NULL,3,1,3,1,'RA117715477CN\r ','rootfus'),(9096,766005148016,260660053762,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',2.79,'hutongstore','ialbal','allison@albal.co.uk','Alison Donnellan','52 broadhurst gardens','Burnham on sea','Somerset','UNITED KINGDOM','TA8 1LP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-06 23:22:29',0,NULL,3,1,2,1,NULL,'ialbal'),(9097,781994079015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','mjbarth1977','mike@mikebartholomew.com','Mike Bartholomew','21 Stadium Drive<br>Kingskerswell','Newton Abbot','Devon','UNITED KINGDOM','TQ125HP','01803393061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-06 23:40:39',0,NULL,3,1,2,1,NULL,'mjbarth1977'),(9098,669460314001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','jujusito','emiliomserrano@hotmail.com','Emilio Minguez Serrano','C/ Conde de Casas Rojas, nº7 - 4ºA','Alicante','Comunidad Valenciana','SPAIN','03006','658070512','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 23:50:47',0,NULL,3,1,4,1,'YW865907303CN ','jujusito\r2m 背景架 （白+黑）'),(9099,781998899015,250746713895,'67mm Graduated Neutral Density Filter Gradual Grey 67',1,'AA3319',5.2,'hutongstore','oraclefilms','willsmith1@live.com','Will Smith','Mitcheldene, Malvern Edge Court,<br>Areley Common','Stourport-on-Severn','Worcestershire','UNITED KINGDOM','DY13 0NP','01299825594','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 00:01:16',0,NULL,3,1,2,1,NULL,'oraclefilms'),(9100,669465511001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','bogroll2000','steveliving@gmail.com','Robert Livingston','99 Pinecrest Ave.<br>p.o. box 59','Keene','ON','CANADA','K0L 2G0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 00:35:04',0,NULL,3,1,2,1,NULL,'bogroll2000'),(9101,782009410015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','mattmatt1873','matt.neale@gmail.com','Matthew Neale','25 Edward Road','Leicester','Leicestershire','UNITED KINGDOM','LE2 1TF','07890502854','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 00:45:55',0,NULL,3,1,2,1,NULL,'mattmatt1873'),(9102,710449729002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','grave500','zegrave@netcabo.pt','jose pereira','est. de benfica 447-3ºesq.','lisboa','lisboa','PORTUGAL','1500080','217784574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 01:11:05',0,NULL,3,1,2,1,NULL,'grave500'),(9103,669488678001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','johnkeys','johnnkeys@gmail.com','John Bowditch','p.o box 668','Griffith','New South Wales','AUSTRALIA','2680','0269630676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 02:23:06',0,NULL,3,1,2,1,NULL,'johnkeys'),(9104,669491407001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','berces514','berces514@hotmail.com','Rosa Cardenas','1500 San Remo Ave<br>Ste 140','Coral Gables','FL','UNITED STATES','33146-3041','(305) 666-0200','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-07 02:37:09',0,NULL,3,1,1,1,NULL,'berces514'),(9105,721564480017,270745173616,'New Photo 4 x E27 Sockets Bulb Holder Umbrella holder',1,'AE2203',30,'photographyacc','shanks-185','baileyshanks@hotmail.com','bailey shanks','6 nemesis place<br>golden grove','kalgoorlie','Western Australia','AUSTRALIA','6430','0890919157','PayPalPaymentInProcess','CheckoutComplete','AU_RegisteredParcelPost','0000-00-00 00:00:00',0,NULL,3,0,3,1,'RA117715698CN\r ','shanks-185\r4灯头 棚 伞孔   1\r没有棚的那款\r已减库'),(9106,710491964002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','abdulrahim79','lucky_3abdu@hotmail.com','Zayana Sulaiman  Albimani','P.O BOX NO:74 , P.CODE:122 ,mabellah, seeb<br>Oman','seeb','SEEB','OMAN','968','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 04:57:01',0,NULL,3,1,2,1,NULL,'abdulrahim79'),(9107,669518648001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','truebluesky66','littlewhitehouse@mail.com','valerie pribek','50 Rose Ave','Brantford','ON','CANADA','N3S 2M2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 05:34:47',0,NULL,3,1,2,1,NULL,'truebluesky66'),(9108,766126655016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','daizoff08','carlsand@tpg.com.au','sandra atkinson','15 john st','morphett vale','South Australia','AUSTRALIA','5162','0883824369','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 06:50:18',0,NULL,3,1,2,1,NULL,'daizoff08'),(9109,669536241001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','jsh3d','jsh3d@aol.com','James Hegarty','1134 Culverhill Dr','Saint Louis','MO','UNITED STATES','63119-4938','(314) 954-9019','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 07:26:44',0,NULL,3,1,1,1,NULL,'jsh3d'),(9110,669549261001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','ahmed4g','ahmed2xp@yahoo.com','Ahmed AlMohannadi','P.O. box 60175','AlKhor','','QATAR','60175','974 5584 1133','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-07 08:19:17',0,NULL,3,1,3,1,'RA117715525CN\r ','ahmed4g'),(9111,710551461002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','jsei2539','seijas2000@hotmail.com','jose luis seijas escarti','Forestal del Atlántico<br>punta promontorio, sn','mugardos','Galicia','SPAIN','15620','639890315','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 09:55:25',0,NULL,8,1,17,0,NULL,'jsei2539'),(9112,669574353001,110414476355,'Remote Shutter Release for Canon Rebel XT XTi = RS-60E3',1,'AA3210',6.98,'hermeshine','jsei2539','seijas2000@hotmail.com','jose luis seijas escarti','Forestal del Atlántico<br>punta promontorio, sn','mugardos','Galicia','SPAIN','15620','639890315','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 10:04:06',0,NULL,3,1,2,1,NULL,'jsei2539\rEW-73B   1\r爵影快门线C1    1'),(9113,668260411018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','apichart_062518','apicaht_2518@hotmail.com','apichart kerdchengmeng','100/246 m.3 t.bangkurad s.vodladpladok','nontaburee','abangboutong jnontaburee','THAILAND','11110','089-177-4949','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-07 10:57:08',0,NULL,3,1,2,1,NULL,'apichart_062518'),(9114,710569311002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','recom71','vladislav@recom-km.cz','Vladislav Frantis','Spacilova 3036','Kromeriz','','CZECH REPUBLIC','76701','+420605781297','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 11:04:48',0,NULL,3,1,2,1,NULL,'recom71'),(9115,705397259002,120654651653,'Pro Photo Vest Blue for Nikon D90 D300s D7000 D80  user',1,'AA2117',32,'hermeshine','soloilfatolivinse011','soloilfatolivinse@hotmail.it','massimo stefanelli','strada camporelle 19','nole','TO','ITALY','10076','011 9297991','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-07 11:07:59',0,NULL,3,0,3,1,'RA117715517CN\r ','soloilfatolivinse011\rXXXL（已入库）'),(9116,669597962001,110618888297,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380  user',1,'AA2121',32,'hermeshine','visistudio','visi_photographer@hotmail.com','ERVIS BOSTANXHI','Ave Gjergj Kastrioti no.12<br>Lagja no 12','KORCA','AL','ALBANIA','7000','+355672065800','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-07 11:34:36',0,NULL,3,0,3,1,'RA117715619CN\r ','visistudio\rXXL（已入库）'),(9117,668288113018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE3401',35,'photographyacc','carlomanzatti','c.manzatti@optusnet.com.au','Carlo Manzatti','1/20-22 Cumberland Rd','Ingleburn','New South Wales','AUSTRALIA','2565','0296187930','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-07 12:30:16',0,NULL,3,0,3,1,'RA117715551CN\r ','carlomanzatti\r反光板支架   1'),(9118,710612498002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3304',6.98,'hermeshine','mindbender91402','aMindbender@ca.rr.com','Philip G. Meyerson','7615 Yates St','Tujunga','CA','UNITED STATES','91042','(818) 951-1310','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-07 13:32:47',0,NULL,3,1,1,1,NULL,'mindbender91402'),(9119,710617494002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','winglet604','gilles.morin@vif.com','Gilles Morin','2365 Kensington','Saint-Hubert','QC','CANADA','J3Y 5H9','(450) 926-9767','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-07 13:48:48',0,NULL,3,1,3,1,'RA117715755CN\r ','winglet604'),(9120,710622819002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','kokoryta','koko.ryta@gmail.com','Jennifer Riccardi','51 Hasting App 209','Dollard des Ormeaux','QC','CANADA','H9G 1Y3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 14:11:12',0,NULL,3,1,2,1,NULL,'kokoryta'),(9121,710625299002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','lbuhhunyxl','buhhunyx@yahoo.com','Zgurskiy Oleg','Primorskiy kray<br>Kalinina 23-9','Vladivostok','','RUSSIAN FEDERATION','690035','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 14:15:00',0,NULL,3,1,2,1,NULL,'lbuhhunyxl'),(9122,782250386015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','chris_9486','chris9486@googlemail.com','Chris Scott','16 Granville Place<br>Allerton','Bradford','West Yorkshire','UNITED KINGDOM','BD15 7QD','07900243445','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 14:52:49',0,NULL,3,1,3,1,'RA117715738CN\r ','chris_9486'),(9123,766311918016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','kevfreeflight','kevfreeflight1@aol.com','Kevin Moseley','42 Sharp House Road','Leeds','West Yorkshire','UNITED KINGDOM','LS10 4SD','07584324634','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 15:58:02',0,NULL,3,1,2,1,NULL,'kevfreeflight\r新地址：\r Kevin Moseley \rCustomer Care Manager Premier Foods Limited Fish Dam Lane Carlton Barnsley S71 3HQ \rUNITED KINGDOM'),(9124,669681539001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','dimetras','manyhkin@mail.ru','DMITRY MIRONOV','50 LET OKTYBRY DOM3 KVARTIRA88','GELEZNOVODSK','RU','RUSSIAN FEDERATION','357443','+78793252952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 15:59:49',0,NULL,3,1,2,1,NULL,'dimetras'),(9125,782261097015,250599352972,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',1.58,'hutongstore','rasmus2503','rasmusnes@gmail.com','Rasmus Nes','Paulus Plass 3 C','Oslo','Oslo','NORWAY','0554','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 16:21:56',0,NULL,3,1,2,1,NULL,'rasmus2503\r新地址：\rRasmus Nes\rAkersbakken 35 E\r0172 Oslo\rNorway\r\r'),(9126,782315065015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','susanns1','susanns1@yahoo.co.uk','Susann Schmidt','Interactive Data - BDG<br>13-17 Epworth Street','London','London','UNITED KINGDOM','EC2A 4DL','07786135252','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 17:13:30',0,NULL,3,1,2,1,NULL,'susanns1'),(9127,668726564001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','tinatinamisdameana','tinerbeanerz@gmail.com','Tina Unger','214 little valley trail','Cheyenne','WY','UNITED STATES','82007-3637','(307) 286-8528','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'tinatinamisdameana\r电子支票已结清\r'),(9128,782322078015,250692239997,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',9.98,'hutongstore','jevgenijs2099','javgenijs@mail.ru','Jevgenijs Silava','15 Bronti close','London','London','UNITED KINGDOM','se17 2hd','07786553785','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 17:25:24',0,NULL,3,1,2,1,NULL,'jevgenijs2099'),(9129,669717571001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','1210giro','clupay@gmail.com','Claudio Lupayante Gonzalez','Avenida Valparaiso 363<br>Local 130','Viña del Mar','V Region','CHILE','2571493','(056) 322-9011 ext.: 74','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 17:30:32',0,NULL,3,1,2,1,NULL,'1210giro\r欧标'),(9130,709085954002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','acbustillo0','acbustillo@hotmail.com','Andres Cruz Bustillo','Francisco Canal 327','Veracruz','Veracruz','MEXICO','91700','(229) 150-3950','NoPaymentFailure','CheckoutComplete','Other','2011-05-07 17:38:08',0,NULL,8,1,17,0,NULL,'acbustillo0'),(9131,710691504002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',3,'AB2301',29.85,'hermeshine','acbustillo0','acbustillo@hotmail.com','Andres Cruz Bustillo','Francisco Canal 327','Veracruz','Veracruz','MEXICO','91700','(229) 150-3950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 17:38:09',0,NULL,3,1,3,1,'RA117715715CN\r ','acbustillo0\r2m 灯架  1\rb座   4\r柔光伞   1'),(9132,782359415015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','malliajo','malliaj63@gmail.com','Joseph Mallia','19, \'Agapimu\' Triq In- Newl','Zebbug','','MALTA','ZBG 2653','21464125','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 18:33:28',0,NULL,3,1,2,1,NULL,'malliajo'),(9133,766388706016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','ashleygalea2011','ashleyjgalea@yahoo.co.uk','Ashley Galea','79B St Pauls Court<br>Block F, Door 81','Pioneer Rd','Bugibba','MALTA','SPB','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-07 18:34:46',0,NULL,3,1,5,1,'CP227022708CN\r ','ashleygalea2011\r英标'),(9134,709530899002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','zsofi17','zsofia_babak@yahoo.com','Babak Zsofia','Banffyhunyad u. 1/B','Budapest','','HUNGARY','H-1182','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 19:12:19',0,NULL,3,1,2,1,NULL,'zsofi17'),(9135,669777762001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','mogy3','danbeaton1@shaw.ca','D. Beaton','#110-7428 19th Ave.,<br>(Buzzer #10)','Burnaby','BC','CANADA','V3N1E1','(604) 524-6723','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 19:51:51',0,NULL,8,1,17,0,NULL,'mogy3\r'),(9136,766433912016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','245jenkin','bobjenkin@btinternet.com','Bob Jenkin','Sayers Croft Bungalow<br>The Street','Ewhurst','Surrey','UNITED KINGDOM','GU6 &PX','01483267019','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 19:58:06',0,NULL,3,1,3,1,'RA117715548CN\r ','245jenkin'),(9137,721879801017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','pikkijean','nikki.arena@gmail.com','Nicole Arena','20A Greylock Rd','Allston','MA','UNITED STATES','02134-2506','(732) 500-3603','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-07 20:07:47',0,NULL,3,1,1,1,NULL,'pikkijean'),(9138,669782754001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','rosielinares','rosiesk33t@gmail.com','Rosamaria Linares','551 Walnut St<br>Apt 32','San Carlos','CA','UNITED STATES','94070-2336','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-07 20:11:53',0,NULL,3,1,1,1,NULL,'rosielinares'),(9139,782427937015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','erndal','dalesz100@t-online.hu','Ernő Dalmády','Csongrádi sgt.73.6/33.','Szeged','','HUNGARY','6723','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 20:40:51',0,NULL,3,1,2,1,NULL,'erndal'),(9140,710786729002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','pepepotamo64','marcovadanero@gmail.com','Marco Varela Adanero','Pablo Iglesias 57','Gijón','Asturias','SPAIN','33205','985130752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 21:06:23',0,NULL,3,1,2,1,NULL,'pepepotamo64'),(9141,782440558015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.88,'hutongstore','thaqee90','crossurarms1910@gmail.com','Nurthaqifah Farhani Mujiman','Royal College of Surgeons Ireland,<br>123 St. Stephen\'s Green,','Dublin','Dublin','IRELAND','2','0852426553','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 21:07:45',0,NULL,3,1,2,1,NULL,'thaqee90'),(9142,766473582016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','woodscj2005','chrisjameswoods@gmail.com','Chris Woods','12 Heathfield Mews<br>Martlesham Heath','Ipswich','Suffolk','UNITED KINGDOM','IP5 3UF','01473622446','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 21:21:54',0,NULL,3,1,2,1,'','woodscj2005'),(9143,710813347002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',2,'AA1103',53.6,'hermeshine','xtralars82','xtralars@baluba.org','Lars Kristian Flor','Vektergata 8','Molde','More og Romsdal','NORWAY','N6413','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-07 22:23:47',0,NULL,3,1,3,1,'RA117715707CN\r ','xtralars82'),(9144,782477585015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','bonzowebber','mdwebber@ntlworld.com','Matthew Webber','1 Burnside Drive','HARROGATE','North Yorkshire','UNITED KINGDOM','HG12BH','01423560378','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 22:48:25',0,NULL,3,1,2,1,NULL,'bonzowebber'),(9145,669844474001,110665009924,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',9,'hermeshine','sys2matic328','rlparks@ncsu.edu','Reginald Parks','2001 Kanga Cir','Raleigh','NC','UNITED STATES','27603-2779','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-07 23:13:53',0,NULL,3,1,1,1,NULL,'sys2matic328'),(9146,782501366015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','stevens3876','stevenshiels071@yahoo.co.uk','STEVEN SHIELS','6 VALE VIEW<br>SOUTHSEA','WREXHAM','Wrexham','UNITED KINGDOM','LL116RY','01978721592','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 00:15:15',0,NULL,3,1,2,1,NULL,'stevens3876'),(9147,669869540001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','elected_angel','elected_angel@hotmail.com','Jonathan Massie','279 rue Rosedale','Brownsburg-Chatham','QC','CANADA','J8G 3A6','(450) 407-0505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 01:08:45',0,NULL,3,1,3,1,'RA117715741CN\r ','elected_angel'),(9148,782555371015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3311',5.2,'hutongstore','borg1058','ray.borg@blueyonder.co.uk','Ray Borg','15 Millersgate<br>Cottam','Preston','Lancashire','UNITED KINGDOM','PR4 0AZ','01772768112','NoPaymentFailure','CheckoutIncomplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'borg1058'),(9149,669911953001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','mogy3','danbeaton1@shaw.ca','D. Beaton','#110-7428 19th Ave.,<br>(Buzzer #10)','Burnaby','BC','CANADA','V3N1E1','(604) 524-6723','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 05:08:37',0,NULL,3,1,3,1,'RA117730205CN ','mogy3\r独脚架  WT-1005   1\r独脚架  WT-1007   1\r1.678'),(9150,710914416002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','jockos5','jockos@gmail.com','Joachim Andersson','estlandsgatan 4c','Göteborg','Västra Götaland','SWEDEN','41877','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 06:52:43',0,NULL,3,1,4,1,'YW865907410CN','jockos5\r刘'),(9151,710914427002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','and-all-in-one','gorynych2012@yandex.ru','Andrey Karlov','Berkimbaeva 95/1 190','Ekibastuz','KZ','KAZAKHSTAN','141200','87012258158','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 06:59:56',0,NULL,3,1,2,1,NULL,'and-all-in-one'),(9152,710926060002,120619188563,'NEW 67mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT046',30,'hermeshine','r3ivaxg','xgavalda@gmail.com','Xavier Gavalda','Entreauto (Gasolinera)<br>c. apel·les mestres 44','Reus','Cataluña','SPAIN','43205','615283176','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-08 07:39:52',0,NULL,3,1,3,1,'RA117730960CN ','r3ivaxg'),(9153,782615853015,250599945807,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',2,'AA1202',3.7,'hutongstore','jimjolli','jimjunk1@gmail.com','James R Jolliffe','4 North Worple Way','Mortlake','London','UNITED KINGDOM','SW14 8QG','02083922114','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 08:07:03',0,NULL,3,1,2,1,NULL,'jimjolli'),(9154,669960983001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','janvondeyen','vondeyen@post.tele.dk','Jan von Deyen','Engvej 25',' Nykøbing F','','DENMARK','DK 4800','54822030','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-08 08:48:05',0,NULL,3,0,3,1,'RA117715534CN\r ','janvondeyen\r3XL(已入库）'),(9155,766688004016,260660051940,'New 52mm 52 Ring adapter and Holder for Cokin P Series',1,'AKT018',3.62,'hutongstore','roryollieollie','galvinrory@hotmail.com','Rory Galvin','seafield road','quilty','Clare','IRELAND','default','0851370204','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 10:11:12',0,NULL,8,1,17,0,NULL,'roryollieollie'),(9156,782679525015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.88,'hutongstore','roryollieollie','galvinrory@hotmail.com','Rory Galvin','seafield road','quilty','Clare','IRELAND','default','0851370204','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 10:37:28',0,NULL,3,1,2,1,NULL,'roryollieollie\r方形滤镜接口环 52mm   1\r方形滤镜 镜片卡座    1\r绿叶 CPL 72mm     1'),(9157,782683179015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','yaboo06','styleguru@live.co.uk','Thomas Dick','17 The Granaries, Baker Lane<br>King\'s Lynn','norfolk','Norfolk','UNITED KINGDOM','PE30 1HY','01553782634','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 10:46:00',0,NULL,3,1,2,1,NULL,'yaboo06'),(9158,711024086002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',20.99,'hermeshine','andredm74','andredm71@msn.com','Andre de Mornay','5000N MARINE PARADE ROAD<br>#04-60','default','','SINGAPORE','449295','98529288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 12:26:34',0,NULL,3,1,3,1,'RA117715636CN ','andredm74'),(9159,670041585001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','talanchor','kadavros@gmail.com','Alexander Levshin','Starokachalovskaya street, 1-2-210','Moscow','Moscow','RUSSIAN FEDERATION','117216','+7 495 7110241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 12:37:15',0,NULL,3,1,2,1,NULL,'talanchor'),(9160,670046928001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','brochar-2007','beag8175@hotmail.com','Bea Rocha Rodrigues','Carrer de les Escoles nº13<br>Escala A 1º 1º','Santa Coloma','Andorra la Vella','ANDORRA','AD500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 12:56:35',0,NULL,3,1,2,1,NULL,'brochar-2007'),(9161,711038521002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','moigol','moigol@netzero.net','Moisey Goltseker','2055 Ocean Ave<br>Apt 3H','Brooklyn','NY','UNITED STATES','11230-7307','','NoPaymentFailure','CheckoutComplete','Other','2011-05-08 13:08:41',0,NULL,8,0,17,0,NULL,'moigol\r已入库\r'),(9162,711037515002,120593062257,'New Pro Photo Vest for all DSLR fans  Size: XL',1,'AA1104',26.8,'hermeshine','moigol','moigol@netzero.net','Moisey Goltseker','2055 Ocean Ave<br>Apt 3H','Brooklyn','NY','UNITED STATES','11230-7307','','NoPaymentFailure','CheckoutComplete','Other','2011-05-08 13:08:42',0,NULL,3,1,3,1,'RA117730125CN ','moigol\r摄影背心 黑色厚 无字 3XL    1\r摄影背心 冬夏 XL    1\r1.208\r新地址：\rMoisey Goltseker \rR and B Car Service 1011 Avenue Z Brooklyn NY, 11235 \rUNITED STATES'),(9163,711041058002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','lukp123','lukas.pimper@seznam.cz','Lukas Pimper','Zeleznicaru 1343/17B','Prague 7','','CZECH REPUBLIC','17000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 13:10:14',0,NULL,3,1,2,1,NULL,'lukp123'),(9164,670049112001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-08 13:28:53',0,NULL,3,1,3,1,'RA117715675CN\r RA117730117CN','saud-p\r分2个小包\r布（黑+白）'),(9165,709350338002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','anabojan','anakaiser5@gmail.com','Ana Kajser','D. Gervaisa 14','Zagreb','','CROATIA','10000','00385911512958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 13:49:05',0,NULL,3,1,3,1,'RA117715667CN\r ','anabojan'),(9166,670080497001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','nowell63','noel_carson@hotmail.com','NOEL  CARSON','CARRANTULLA','CLAREMORRIS ','Mayo','IRELAND','default','0949364883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 14:17:01',0,NULL,8,1,17,0,NULL,'nowell63'),(9167,670086166001,110566021586,'TianYa New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','nowell63','noel_carson@hotmail.com','NOEL  CARSON','CARRANTULLA','CLAREMORRIS ','Mayo','IRELAND','default','0949364883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 14:30:26',0,NULL,3,1,2,1,NULL,'nowell63\r天涯方形滤镜系列  星光镜  star6    1\r天涯方形滤镜系列  星光镜  star8    1'),(9168,670099932001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','pecheur76','serge.renou@wanadoo.fr','renou serge','10 rue du merlin','criquetot-l\'ésneval','Haute-Normandie','FRANCE','76280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 15:01:18',0,NULL,3,1,2,1,NULL,'pecheur76'),(9169,710237130002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','charcoal257','ashmail69@gmail.com','Charlie Wan','50 Bridge St<br>Apt 215','Brooklyn','NY','UNITED STATES','11201-1176','(917) 770-1613','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-08 15:28:29',0,NULL,3,1,1,1,NULL,'charcoal257'),(9170,668812805018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','wakkymatty','ohhello@optusnet.com.au','Matthew Stokes','54 Paterson Drive<br>Lynbrook','Melbourne','Victoria','AUSTRALIA','3975','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-08 15:29:01',0,NULL,3,1,4,1,'YW865907292CN ','wakkymatty\r河北的架子 + 1.6x2.1 白色背景布  1\rbackground support   $20\r'),(9171,670148556001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','srbrn1968','srbrn1968srebrev@gmail.com','Srebrin Srebrev','54a, Vasil Drumev Str.','Parvomay','Plovdiv','BULGARIA','4270','+359887519544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 16:32:55',0,NULL,3,1,2,1,NULL,'srbrn1968'),(9172,766893250016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','thomas_bangalter','fatman88_2000@hotmail.com','Andy Brennan','788 Cumbernauld Road (If undelivered don\'t leave with neighbor)<br>Riddrie','Glasgow','North Lanarkshire','UNITED KINGDOM','G33 2EH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 16:46:19',0,NULL,3,1,2,1,NULL,'thomas_bangalter'),(9173,782898662015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','cody-ru','codymail@mail.ru','Stanislav Burenkov','ul Makarenko 22 kv 128','Novosibirsk','','RUSSIAN FEDERATION','630027','+79137006583','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 17:12:19',0,NULL,3,1,3,1,'RA117715684CN\r ','cody-ru\r刘'),(9174,670229230001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',2,'AC1201',9.8,'hermeshine','bkbeaches','b_hoesly@hotmail.com','Barbara Carnahan','5950 Huntington Ave','Lincoln','NE','UNITED STATES','68507-2346','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-08 18:16:38',0,NULL,3,1,1,1,NULL,'bkbeaches'),(9175,711260816002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','olczacek','cyber-world@centrum.cz','Oldrich Mraz','Moskevska 3060/11<br>Most 434 01 Czech Republic','Most','CT','CZECH REPUBLIC','CZE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:05:46',0,NULL,3,1,2,1,NULL,'olczacek'),(9176,670284865001,110523253210,'Pentax 52mm Reverse Adapter Combined shipping discounts',1,'AA1209',3.58,'hermeshine','pa_banach','pa.banach@gmail.com','Paweł Banach','Ul.Chrobrego 40/23','Międzychód','wielkopolskie','POLAND','64400','66 5737917','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:24:56',0,NULL,3,1,2,1,NULL,'pa_banach'),(9177,711281983002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','volaart.m','volaart.m@kpnplanet.nl','M Volaart','Lijterbesweg 50A','Middelharnis','','NETHERLANDS','3241BM','0187669417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:34:20',0,NULL,8,1,17,0,NULL,'volaart.m'),(9178,711277769002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','volaart.m','volaart.m@kpnplanet.nl','M Volaart','Lijterbesweg 50A','Middelharnis','','NETHERLANDS','3241BM','0187669417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:34:20',0,NULL,8,1,17,0,NULL,'volaart.m'),(9179,670288938001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','volaart.m','volaart.m@kpnplanet.nl','M Volaart','Lijterbesweg 50A','Middelharnis','','NETHERLANDS','3241BM','0187669417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:34:21',0,NULL,8,1,17,0,NULL,'volaart.m'),(9180,670288032001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','volaart.m','volaart.m@kpnplanet.nl','M Volaart','Lijterbesweg 50A','Middelharnis','','NETHERLANDS','3241BM','0187669417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:34:22',0,NULL,3,1,2,1,NULL,'volaart.m\r绿叶 UV  52mm    1\rNIKON 镜头盖 52mm    1\r橡胶遮光罩 52mm    2\r'),(9181,783088671015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','cameraman645','sales@promedia.uk.com','Peter Dodgson','24a Park Road<br>Rhosymedre','Wrexham','Clwyd','UNITED KINGDOM','LL14 3YP','01978812930','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 20:20:35',0,NULL,3,1,3,1,'RA117715565CN\r ','cameraman645'),(9182,711340396002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','sarja01','sarja_01@hotmail.com','Jorge Adán Sánchez Reséndiz','Calle Donoso Cortes No. 80, 1º-5','Madrid','Madrid','SPAIN','28015','628763349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:09:54',0,NULL,3,1,2,1,NULL,'sarja01'),(9183,670339034001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','smashvideo','silvestar13@hotmail.com','SMASH VIDEO','LOVCENSKA 53','ZAGREB','','CROATIA','10000','+385915654849','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-08 21:25:22',0,NULL,3,1,5,1,'CP227022699CN ','smashvideo\r王   '),(9184,670354838001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','enk097','tanja.lakic@gmail.com','Tanja Lakic','Zvonimirova 63','Zagreb','Zagreb','CROATIA','10 000','+385 91 560 61 93','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:29:01',0,NULL,3,1,2,1,NULL,'enk097'),(9185,767143771016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','mickjigger','andycom@gmx.co.uk','Andreas Leja','Silverdale<br>Fieldhouse Lane, Hepscott','Morpeth','Northumberland','UNITED KINGDOM','NE61 6LT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 21:32:50',0,NULL,3,1,2,1,NULL,'mickjigger'),(9186,670357804001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','abo-lamees','abo-lamees@hotmail.com','Ahmad Alsaedi','P.O.BOX 42612','Madina','Madina','SAUDI ARABIA','41551','00966503307752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:34:44',0,NULL,3,1,2,1,NULL,'abo-lamees'),(9187,669076327018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',3,'AO0034',23.97,'photographyacc','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-08 21:41:00',0,NULL,3,1,2,1,NULL,'igrom78\r810'),(9188,783152781015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3311',5.2,'hutongstore','shiver_sk','shiver123@gmail.com','Martin Jelen','Martina Benku 2','Presov','','SLOVAK REPUBLIC','08001','00421907990152','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 22:17:48',0,NULL,3,1,2,1,NULL,'shiver_sk\r刘\r62mm 渐变灰   1'),(9189,711383326002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','lo_quemesobra','roger.farrarons@hotmail.com','Roger Farrarons Clusella','C/ Aragó 12-16 Escalera A, 3r piso, 1ª puerta','Castelldefels','Cataluña','SPAIN','08860','617774455','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-08 23:18:40',0,NULL,3,1,4,1,' YW865907395CN\r','lo_quemesobra'),(9190,670400044001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','evo_studio','info@studio-evolution.com','Aleksander Roslavtsev','Pionerskaya st. 5a/62','Odessa','UA','UKRAINE','65009','+380503905902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 23:55:46',0,NULL,3,1,2,1,NULL,'evo_studio\r刘'),(9191,711447442002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','funkista','swanky9883@yahoo.com','Brian Tanchanco','89 magallanes avenue, magallanes village','Makati','Metro Manila','PHILIPPINES','1232','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 02:37:53',0,NULL,3,1,2,1,NULL,'funkista'),(9203,670501379001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','csuzso','csukaszsolt@t-online.hu','Zsolt Csukás','Szója u. 47.','Békéscsaba','Békés','HUNGARY','5600','+36703189099','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 07:47:24',0,NULL,3,1,3,1,'RA117730182CN ','csuzso'),(9192,670455647001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','feramor','fighter666@inbox.ru','Ekaterina Kamaeva','ul. Universitetskaya, dom 20 korpus 1, kv. 109','Cheboksary','','RUSSIAN FEDERATION','428009','8-9603107067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 03:20:36',0,NULL,3,1,2,1,NULL,'feramor'),(9193,711469422002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','xgou1687','the8ears@gmail.com','Xuehong Gou','4812 Baker St','Norman','OK','UNITED STATES','73072-3858','(405) 445-3296','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 04:15:42',0,NULL,3,1,1,1,NULL,'xgou1687'),(9194,670467329001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','canlens','fbougee@gmail.com','Vladimir Podyukov','Uralskaya ul. 23,<br>korpus 4, kvartira 619','Moscow','','RUSSIAN FEDERATION','107065','+7 79175475967','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 04:25:17',0,NULL,3,1,5,1,'CP227022711CN ','canlens'),(9195,667696455018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',71,'photographyacc','asterx22jw','janwillem@moreto.nl','Jan Willem Bloemendaal','Sumatrastraat 22','BAARN','','NETHERLANDS','3742CW','06-51569466','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-09 04:38:27',0,NULL,3,1,4,1,'YW865907406CN ','asterx22jw\r灯架  2m    1\r110cm   5in1   1\r大力夹   2\r一票两件\r'),(9196,670481881001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1304',5,'hermeshine','scscanlon','shawn@scanlonmail.com','Shawn Scanlon','4768 Canary Dr','Pleasanton','CA','UNITED STATES','94566-5302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 05:55:55',0,NULL,3,1,1,1,NULL,'scscanlon'),(9197,711488234002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','palmpang','bujakorn_thana@hotmail.com','Thana Bujakorn','12/174 Mu5 Supalai Orchid Park<br>T. Pantaynorasing','Muang','Samutsakorn','THAILAND','74000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 06:07:42',0,NULL,3,1,11,1,NULL,'palmpang'),(9198,783297159015,250692236486,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','cardyncoke','mr2ste@tiscali.co.uk','stephen horsley','21 lyncroft av.<br>Ripley','Derby','Derbyshire','UNITED KINGDOM','DE53bb','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 06:19:47',0,NULL,3,1,2,1,NULL,'cardyncoke'),(9199,711496406002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',3,'AKT056',158,'hermeshine','qwerty_steve','stephenleeis@gmail.com','Stephen Lee','8 Garfield Avenue<br>Bonnet Bay','Sydney','New South Wales','AUSTRALIA','2226','0402248336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 06:50:50',0,NULL,3,1,4,1,'YW865907432CN ','qwerty_steve\rreflector holder  $30'),(9200,711498074002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','edwardfilm','edward_film@mail.ru','Eduard Filippov','Chilonzar 12-34-4','Tashkent','','UZBEKISTAN','700123','998-712-756131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 06:59:34',0,NULL,3,1,2,1,NULL,'edwardfilm'),(9201,711500138002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','froschotastik','phillip_voigt@yahoo.de','Phillip Voigt','Storchsbrede 12','Bielefeld','','GERMANY','33613','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 07:10:21',0,NULL,3,1,4,1,'YW865907421CN ','froschotastik\rball head  $20'),(9202,670495899001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','pentaprizma','stakac@gmail.com','SERDAL TAKAC','konutkent 2 C6 BLOK B GIRIS DAIRE NO 8<br>CAYYOLU','ANKARA','-','TURKEY','06810','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 07:16:03',0,NULL,3,1,2,1,NULL,'pentaprizma'),(9204,711510515002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','magicdean16','dean@kenscones.com.au','Dean Murray','4 Redman Avenue','Thirroul','New South Wales','AUSTRALIA','2515','0242673477','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 08:02:28',0,NULL,3,1,3,1,'RA117730179CN ','magicdean16\rM（已入库）\r'),(9205,670509814001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','riendi','chochon@gmail.com','Marylise Devoyault','1066 Rang 1 Ouest','Sainte-Christine','QC','CANADA','J0H 1H0','(819) 858-9926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 08:29:28',0,NULL,3,1,2,1,NULL,'riendi'),(9206,711529982002,120598267593,'New Camera shoulder bag nova 4 with raincover 4 7D 5Dii',1,'AD1105',40.99,'hermeshine','michael_and_carina2009','michael_and_carina@yahoo.com','Michael Bethea','Münchener Straße 30','Taufkirchen','','GERMANY','82024','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 09:33:33',0,NULL,3,0,3,1,'RA117730528CN\r ','michael_and_carina2009\rcanon N4 单肩包 （已减库）\r王'),(9207,783354225015,250611184205,'New Wireless Flash Sync Trigger Receiver D700 D90 5D II',1,'AB3322',13.19,'hutongstore','shark_74','andrea.fantacci@tin.it','Andrea Fantacci o Fantacci Virgilio','Via Vecchia Dell\'Arcale, 23','PISTOIA','PT','ITALY','51100','3357225841','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 09:54:19',0,NULL,3,1,2,1,'、 ','shark_74'),(9208,767363719016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','birokornel','birokornel@freemail.hu','Tamás Gerő','Hajó str. 8. IV/15.','Debrecen','Hajdú-Bihar','HUNGARY','4026','0036302920710','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 10:16:55',0,NULL,3,1,2,1,NULL,'birokornel\r庄'),(9209,711541072002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','bertinluca','lucabertin@libero.it','Bertin Luca c/o SEROFFICE SRL','viale Pilone 87/e','Asti','AT','ITALY','14100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 10:21:09',0,NULL,8,0,17,0,NULL,'bertinluca'),(9210,711540611002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','bertinluca','lucabertin@libero.it','Bertin Luca c/o SEROFFICE SRL','viale Pilone 87/e','Asti','AT','ITALY','14100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 10:21:09',0,NULL,3,0,3,1,'RA117730491CN\r ','bertinluca\rXXL    1\rXXXL     1  （已减库）\r王'),(9211,669246328018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',23,'photographyacc','shanepends0412','shanepends@yahoo.com.au','shane pendlebury','62 barondi ave<br>narre warren','melbourne','Victoria','AUSTRALIA','3805','0412682655','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-09 10:48:43',0,NULL,3,1,3,1,'RA117730505CN\r ','shanepends0412\r62mm ring adapter x3 , \r72mm ring adapter x3 \rand filter holder x 1 \r王'),(9212,722403333017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',16.85,'photographyacc','tach-ik','sergey.lagoutine@gmail.com','Sergey Lagoutine','Coniwa I-Dom K-32<br>Belgorod region','Starij Oskol','RI','RUSSIAN FEDERATION','309500','7(4725)426611','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-09 10:49:18',0,NULL,3,1,2,1,NULL,'tach-ik\r庄'),(9213,783373273015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','toby150_0','meonebay17@gmail.com','David Eason','7 Lime Grove','Holbeach','Spalding','UNITED KINGDOM','PE12 7NG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 10:53:48',0,NULL,3,1,3,1,'RA117730430CN\r ','toby150_0\r刘'),(9214,709342088002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bikerbert1','ksslrbert1@aol.com','Roberta Kessler','1985 Sleepy Hollow Rd','Milan','OH','UNITED STATES','44846-9604','(419) 499-4055','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 11:00:01',0,NULL,3,1,1,1,NULL,'bikerbert1\r刘'),(9215,670555766001,110414475072,'16chan Wireless Remote Control Set for OLYMPUS RM-UC1',1,'AA3206',18.5,'hermeshine','myniftybooks','chuck@camroux.com','Chuck Camroux','PO Box 2006','Niagara Falls','NY','UNITED STATES','14302','(905) 356-7336','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 11:40:36',0,NULL,3,1,1,1,NULL,'myniftybooks\r刘'),(9216,783390817015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','gonzila','klocek56@wp.pl','Piotr Kadziolka','2 temple Court<br>Palatine Square','Dublin','Dublin','IRELAND','7','0870928912','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 11:53:25',0,NULL,3,1,2,1,NULL,'gonzila\r庄'),(9217,670559616001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','fendyjo','josf@iinet.net.au','Fendy Jo','29 Treetop Circuit','Quakers Hill','New South Wales','AUSTRALIA','2763','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 11:56:40',0,NULL,3,1,2,1,NULL,'fendyjo\r庄'),(9218,669295970018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','saunanen','aldis23@balticom.lv','Aldis Pirtnieks','Lielvardes 101-9','Riga','Riga','LATVIA','LV-1084','+37129422566','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-09 12:33:55',0,NULL,3,1,2,1,NULL,'saunanen\r庄'),(9219,783410925015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','patbell101','pat@patbell.co.uk','Patrick Bell','1 Saxon Way<br>Lindfield','Haywards Heath','West Sussex','UNITED KINGDOM','RH16 2NT','07795690883','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 12:41:31',0,NULL,3,1,2,1,NULL,'patbell101\r庄'),(9220,711586511002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dekalos','sdekalo@gmail.com','shahar dekalo','hamelaacha 2','ramat hasharon','israel','ISRAEL','47445','0544578957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 13:01:58',0,NULL,3,1,2,1,NULL,'dekalos\r庄'),(9221,783415758015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:06',0,NULL,8,1,17,0,NULL,'jfarenden'),(9222,783417228015,250599406095,'Green.L 62mm 62 Neutral Density ND4 Filter ND 4 New',1,'AE2304',4.1,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:05',0,NULL,8,1,17,0,NULL,'jfarenden'),(9223,783412540015,250599383462,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3304',2.5,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:07',0,NULL,8,1,17,0,NULL,'jfarenden'),(9224,767414617016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:07',0,NULL,8,1,17,0,NULL,'jfarenden'),(9225,767415795016,260661403326,'TianYa 72mm CPL filter New 72 Circular Polarizing C-PL',1,'AA2306',5.2,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:08',0,NULL,8,1,17,0,' ','jfarenden'),(9226,783413953015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3306',2.6,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:09',0,NULL,8,1,17,0,NULL,'jfarenden'),(9227,767417634016,260661403826,'TianYa 72mm ND8 filter New 72 Neutral Density Grey NIB',1,'AA2313',5.78,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:09',0,NULL,8,1,17,0,NULL,'jfarenden'),(9228,767417839016,260661403734,'TianYa 62mm ND8 filter New 62 Neutral Density Grey NIB',1,'AA2311',5.49,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:10',0,NULL,8,1,17,0,NULL,'jfarenden'),(9229,783415996015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3318',5.2,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:11',0,NULL,0,1,3,1,NULL,'jfarenden\r绿叶 渐变镜 62mm   1\r天涯 ND8 62mm    1\r天涯 ND8 72mm    1\r绿叶 UV  72mm\r天涯 cpl 72mm\rlenspen    2\r绿叶 UV  62mm   1\r绿叶 ND4  62mm    1\r绿叶 渐变镜 72mm   1\r绿叶72mm    ND4   1\r绿叶62mm cpl    1\r'),(9230,670584060001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','bjossif','bfinnbogason@gmail.com','Björn Finnbogason','Langafit 14','Garðabær','','ICELAND','210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 13:35:57',0,NULL,8,1,17,0,NULL,'bjossif'),(9231,670583760001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','bjossif','bfinnbogason@gmail.com','Björn Finnbogason','Langafit 14','Garðabær','','ICELAND','210','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 13:35:58',0,NULL,3,1,3,1,'RA117730488CN\r ','bjossif\r天涯方镜   渐变橙+蓝+灰    1\r天涯方镜   ND2+ND4+ND8  1\r6片装滤镜袋    1\r67mm 环+架   1\r王\r'),(9232,667383862018,280666888538,'New Green.L 55mm  Gradual Grey ND4 Filter 2-Stop 55 mm',1,'AA3316',6.2,'photographyacc','scrub_tas','lscrivin@bordernet.com.au','Alex Scrivin','125 Brittains Road','Garden Island Creek','Tasmania','AUSTRALIA','7112','0362978139','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-09 14:03:20',0,NULL,3,1,2,1,' ','scrub_tas\r庄'),(9233,0,110683185674,'Remote Cord Shutter Release for Nikon D200 D3 = MC-30',1,'AA3207',0.99,'hermeshine','jinyong72','sashimi72@hotmail.com','JINYONG WANG','141 S 110th St','OMAHA','NE','UNITED STATES','68154','(402) 850-4543','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 14:50:20',0,NULL,3,1,1,1,NULL,'jinyong72\r刘'),(9234,0,120720079958,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',1.85,'hermeshine','434434','ibrad3000@yahoo.com','ioan brad','5652 W Cullom Ave','chicago','IL','UNITED STATES','60634','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 14:51:45',0,NULL,8,1,17,0,NULL,'434434'),(9235,0,120720079606,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',2.26,'hermeshine','434434','ibrad3000@yahoo.com','ioan brad','5652 W Cullom Ave','chicago','IL','UNITED STATES','60634','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 14:51:46',0,NULL,3,1,1,1,NULL,'434434\rnikon 反接环  52mm    1\rcanon 反接环  52mm   1\r刘'),(9236,711621161002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','yairb','yair999@gmail.com','Yair Bartal','Hanasi Harishon 12','Rehovot','Israel','ISRAEL','76300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 14:53:43',0,NULL,3,1,2,1,NULL,'yairb\r庄'),(9237,670615208001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','gemahenlahen','alojzk@gmail.com','Alojz Kvocic','Balokoviceva 31','Zagreb','','CROATIA','10020','385992299988','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 14:59:25',0,NULL,3,1,2,1,NULL,'gemahenlahen\r庄'),(9238,670624596001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','proton_007','proton11@comcast.net','Gene Arrington','1125 troupe st','augusta','GA','UNITED STATES','30904','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 15:27:42',0,NULL,3,1,1,1,NULL,'proton_007\r刘'),(9239,0,110683184536,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',0.99,'hermeshine','cilonemsw','aphoenixrising@animail.net','Nicole or Dan Piper','1512 Gerald Ave','Lehigh Acres','FL','UNITED STATES','33972-2324','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 15:38:25',0,NULL,3,1,1,1,NULL,'cilonemsw\r刘'),(9240,0,110683184816,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',0.99,'hermeshine','rhoddity218','rhoddity@gmail.com','Ramiro Hernandez','5286 San Bernardo Ter','San Diego','CA','UNITED STATES','92114','(619) 453-4053','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 16:18:35',0,NULL,3,1,1,1,NULL,'rhoddity218\r刘'),(9241,0,110683184889,'62mm CPL Circular Polarizing Filter 62 CPL Green.L ',1,'AA3311',1.29,'hermeshine','wzhou2011','wzhou.yan@gmail.com','wei zhou','17A , Forest Village,<br>3001 south providence RD','columbia','MO','UNITED STATES','65203','(573) 823-4663','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 16:25:13',0,NULL,8,1,17,0,NULL,'wzhou2011'),(9242,0,110683184847,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',1.29,'hermeshine','wzhou2011','wzhou.yan@gmail.com','wei zhou','17A , Forest Village,<br>3001 south providence RD','columbia','MO','UNITED STATES','65203','(573) 823-4663','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 16:25:14',0,NULL,3,1,1,1,NULL,'wzhou2011\r橡胶遮光罩 62mm    1\r绿叶 CPL  62mm     1\r刘'),(9243,767521805016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','oraclefilms','willsmith1@live.com','Will Smith','Mitcheldene, Malvern Edge Court,<br>Areley Common','Stourport-on-Severn','Worcestershire','UNITED KINGDOM','DY13 0NP','01299825594','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 17:07:22',0,NULL,3,1,2,1,' ','oraclefilms\r庄'),(9244,711674864002,120644812085,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0029',27.9,'hermeshine','chef000','eclipse7210@comcast.net','ED Horincewich','9727 Touchton Rd<br>Apt 1907','Jacksonville','FL','UNITED STATES','32246-8285','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-09 17:15:22',0,NULL,3,1,1,1,NULL,'chef000'),(9245,670666565001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','rainsdropz','alanng89@gmail.com','alan ng','2 Angklong lane, #06-02<br>S\'pore 579978','default','','SINGAPORE','579978','93832401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 17:17:12',0,NULL,3,1,11,1,NULL,'rainsdropz'),(9246,711696198002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','teletz','valerian.ramich@web.de','Valerian Ramich','Waldemar-Petersen-Str. 22','Kassel','','GERMANY','34123','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 18:01:14',0,NULL,3,1,2,1,NULL,'teletz\r庄'),(9247,0,110683185240,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.26,'hermeshine','linebleu','phkdk@umich.edu','Per Kjeldsen','3069 N Foxridge Ct','Ann Arbor','MI','UNITED STATES','48105','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 18:02:47',0,NULL,3,1,1,1,NULL,'linebleu\r刘'),(9248,767556759016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',38.99,'hutongstore','jvidalxx','jvidalx@gmail.com','Jose A. Vidal','Turquesa, 53, 3B<br>Urbanizacion Mediterraneo','Cartagena','Murcia','SPAIN','30310','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 18:08:16',0,NULL,3,1,4,1,'YW865907524CN\r ','jvidalxx\r王'),(9249,670693937001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','patou4266','ptremblay40@gmail.com','Patrice Tremblay','3267, St-Jacques','Montréal','QC','CANADA','H4c 1G8','(514) 678-0304','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 18:15:03',0,NULL,3,1,3,1,'RA117730426CN\r ','patou4266\r刘'),(9250,0,110683185354,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',3,'hermeshine','ilistu','weseemail@yahoo.com','Bogdan Melnichuk','6224 Opus Ct','Citrus Heights','CA','UNITED STATES','95621','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 18:21:37',0,NULL,3,1,1,1,NULL,'ilistu\r刘'),(9251,783575623015,250600521662,'Remote Control Cord Shutter Nikon D300/D200/D700​ MC-30',1,'AA3207',2.98,'hutongstore','gragen67','negarg63@hotmail.com','George Ragen','172 Blackburn Road<br>Great Harwood','Blackburn','Lancashire','UNITED KINGDOM','BB67LU','01254889932','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 18:29:31',0,NULL,3,1,2,1,NULL,'gragen67\r庄'),(9252,783594366015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','al999land','sanantoine@eircom.net','Alan Landers','San Antoine','Cahersiveen','Kerry','IRELAND','na','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-09 18:59:27',0,NULL,3,1,3,1,'RA117730602CN\r ','al999land\r刘\r新地址：\rAlan Landers \rSan Antoine\rCahersiveen\rCo Kerry\rIRELAND\r'),(9253,767590491016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','high-pockets83','beasleyj@gmail.com','John Beasley','69 Thornfields<br>Kilbrogan Hill','Bandon','','IRELAND','09','0861651752','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 19:03:28',0,NULL,3,1,2,1,NULL,'high-pockets83\r庄'),(9254,0,110683184476,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',1.3,'hermeshine','mamochka','roman.ginzburg@lausd.net','Roman Ginzburg','1314 N Fuller Ave<br>Apt 207','Los Angeles','CA','UNITED STATES','90046-4842','(323) 980-6459','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 19:40:10',0,NULL,3,1,1,1,NULL,'mamochka\r刘'),(9255,767640818016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','tigertim0101','timharwood1@aol.com','Tim Harwood','39 Hamble Drive','Abingdon','Oxfordshire','UNITED KINGDOM','OX14 3TF','07703554729','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 20:16:45',0,NULL,3,1,2,1,NULL,'tigertim0101\r庄'),(9256,0,110683184666,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',0.99,'hermeshine','thrifty_crystal','puppawuppa@yahoo.com','crystal herrera','14811 West Rd<br>Apt 4107','houston','TX','UNITED STATES','77095-3188','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 20:21:09',0,NULL,3,1,1,1,NULL,'thrifty_crystal\r刘'),(9257,780251777015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',2,'AA1315',4.4,'hutongstore','sriparna1','sriparnamukherjee@yahoo.com','Sriparna Mukherjee','Flat 12<br>1 Tavistock Road','Croydon','Surrey','UNITED KINGDOM','CR0 2AL','02086649388','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 20:27:50',0,NULL,3,1,2,1,' ','sriparna1\r庄'),(9258,711776611002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','ra100n','nemecr@gmail.com','Rastislav Nemec','Kapusianska 3','Bratislava','','SLOVAK REPUBLIC','82102','+421-903-386573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 20:36:52',0,NULL,3,1,2,1,NULL,'ra100n'),(9259,767653395016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',3,'AB1301',6.45,'hutongstore','konusso','lukaszkrawczak@poczta.onet.pl','LUKASZ KRAWCZAK','74 coleridge gardens','LINCOLN','Lincolnshire','UNITED KINGDOM','ln2 4nq','1522873004','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 20:38:27',0,NULL,3,1,2,1,NULL,'konusso\r庄'),(9260,767662300016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','sbresling','s.bresling@mail.dk','Soren Bresling','Klostervej 36','Ry','','DENMARK','8680','+45 24875062','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 20:55:54',0,NULL,3,1,2,1,NULL,'sbresling\r黑\r庄'),(9261,670784269001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','teidepicoviejo','teidepicoguajara@yahoo.es','Manuel Suárez Izquierdo','Sargento Provisional, 51 - 7º I.','Santa Cruz de Tenerife','Canarias','SPAIN','38010','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 21:29:20',0,NULL,3,1,2,1,NULL,'teidepicoviejo\r庄'),(9262,711801830002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','dhubhh','dhubhe@vodafone.es','Jose Manuel Beltran Puig','C/ Clapisa nº32','Benicarló','Castellon','SPAIN','12580','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 21:37:56',0,NULL,3,1,2,1,NULL,'dhubhh\r庄'),(9263,783698391015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','358456326520','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-09 22:00:57',0,NULL,8,1,17,0,NULL,'zuhmia'),(9264,767693516016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',58,'hutongstore','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','358456326520','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-09 22:03:02',0,NULL,3,1,4,1,'YW865907480CN ','zuhmia\r欧标\r灯架  2m   3\r50-70cm 单灯头 柔光箱   3\r斜臂   1\r115w 220v 灯泡   3\r灯架包   1\r庄'),(9265,711812562002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','fr4nt1k','franbaca@yahoo.com','Fran Baća','Pavletićeva 12','Zagreb','','CROATIA','10000','+385 95 8580 218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 22:10:29',0,NULL,8,1,17,0,NULL,'fr4nt1k'),(9266,670799726001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','fr4nt1k','franbaca@yahoo.com','Fran Baća','Pavletićeva 12','Zagreb','','CROATIA','10000','+385 95 8580 218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 22:10:30',0,NULL,3,1,2,1,NULL,'fr4nt1k\r天涯方形滤镜  渐变灰   1\r方形滤镜接口环 77mm   1\r庄\r方形滤镜 镜片卡座    1'),(9267,670825939001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','photoadicted','chavez2jm@hotmail.com','Jose Chavez','2023 Castellana Ct','Livingston','CA','UNITED STATES','95334-1735','(209) 394-7812','NoPaymentFailure','CheckoutComplete','Other','2011-05-09 23:59:17',0,NULL,3,1,3,1,'RA117730457CN\r ','photoadicted\r刘'),(9268,711840511002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','lininhaohara','linaohara@hotmail.com','Lina Ohara','Fujigaoka 1-1-1<br>Konan Danchi 5-302','Konan-shi','Aichi','JAPAN','483-8337','080-3611-9201','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 00:01:37',0,NULL,8,0,17,0,NULL,'lininhaohara'),(9269,711843421002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','lininhaohara','linaohara@hotmail.com','Lina Ohara','Fujigaoka 1-1-1<br>Konan Danchi 5-302','Konan-shi','Aichi','JAPAN','483-8337','080-3611-9201','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 00:11:50',0,NULL,3,1,3,1,'RA117730474CN\r ','lininhaohara\r摄影背心 Canon  老款  M   1\r摄影背心 Canon  老款  3XL   1（已入库）'),(9270,711843767002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','jamesa.0123','jamesagrady@btinternet.com','james grady','12 halifax rd','shortstown','Bedfordshire','UNITED KINGDOM','mk420uu','01234741882','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 00:13:32',0,NULL,3,1,4,1,'YW865907535CN\r ','jamesa.0123\r刘'),(9271,767736502016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','adsayer','adsayer_uk@yahoo.com','Adam Sayer','13AB02 (Enflo Research)<br>University of Surrey','Guildford','Surrey','UNITED KINGDOM','GU2 7XH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 00:26:03',0,NULL,3,1,3,1,'RA117730531CN\r ','adsayer'),(9272,723018661017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','darkwhiterevolution','dj_darkwhite@hotmail.com','Kim Paroz','20 River Vista CRT','Maroochy River','Queensland','AUSTRALIA','4561','0449151184','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-10 00:54:47',0,NULL,3,1,2,1,NULL,'darkwhiterevolution\r庄'),(9273,670839762001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','skanske','gregefalk@bolina.hsb.se','Peter Gregefalk','Annebergsgatan 9c','Malmö','','SWEDEN','214 66','(040)82452','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 01:09:47',0,NULL,3,1,2,1,NULL,'skans\r庄'),(9274,711865974002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','coinman_in_jersey','andrewhager@msn.com','andrew hager','244 regina ave','mercerville','NJ','UNITED STATES','08619','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 01:38:27',0,NULL,3,1,1,1,' ','coinman_in_jersey'),(9275,670854812001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cwehof','chuck@wehofer.com','Charles R. Wehofer','2608 W Irisado Cir','Mesa','AZ','UNITED STATES','85202-5419','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 02:04:27',0,NULL,3,1,1,1,NULL,'cwehof'),(9276,670861308001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','c2thew','pookythebear31@hotmail.com','Crandall Wong','251 E Kempton Pl','monterey park','CA','UNITED STATES','91755','(213) 999-2268','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 02:41:27',0,NULL,8,1,17,0,NULL,'c2thew'),(9277,0,110683185067,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',0.99,'hermeshine','c2thew','pookythebear31@hotmail.com','Crandall Wong','251 E Kempton Pl','monterey park','CA','UNITED STATES','91755','(213) 999-2268','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 02:41:28',0,NULL,3,1,1,1,NULL,'c2thew\rCANON 镜头盖  77mm   1\r77mm 环+架    1'),(9278,711892234002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','barm9762','barry.armstead@grapevine.com.au','Barry Armstead','2 Cope Place','Wanniassa','Australian Capital Territory','AUSTRALIA','2903','610401052548','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 03:26:13',0,NULL,3,1,3,1,'RA117730514CN\r ','barm9762'),(9279,711896138002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 03:49:37',0,NULL,8,1,17,0,NULL,'ishamon'),(9280,711895702002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 03:49:37',0,NULL,8,1,17,0,NULL,'ishamon\r'),(9281,711895962002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 03:49:38',0,NULL,8,1,17,0,NULL,'ishamon'),(9282,670875310001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 03:49:38',0,NULL,8,1,17,0,NULL,'ishamon'),(9283,670875757001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 03:49:39',0,NULL,8,1,17,0,NULL,'ishamon'),(9284,670875566001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 03:49:39',0,NULL,3,1,4,1,'YW865907491CN ','ishamon\r中号内胆包 无字   1\r倒影板（白黑）    1\r圆形柔光棚 40cm  1\r反光板 60cm 2合1   1\r大力夹   1\r柔光伞   1\r1.660\r庄'),(9285,711900622002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','pyochi','pyly@vtr.net','Pilar Ramirez','General Blanche 11465<br>Las Condes','Santiago de Chile','','CHILE','7600061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 04:16:01',0,NULL,3,1,2,1,NULL,'pyochi\r庄'),(9286,711902676002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','mawuchong','mawuchong@hotmail.com','Wuchong (Matthew) Ma','3755 Riverside Drive,P.O. Box 9707, Station T<br>IBM Co.','Ottawa','ON','CANADA','K1G 4K9','(613) 356-6875','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 04:24:15',0,NULL,3,1,2,1,NULL,'mawuchong'),(9287,669626341018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','*sharklady*','sharkey@iinet.net.au','Lori Sharkey','60 Evelyn Street','Gosnells','Western Australia','AUSTRALIA','6110','0893986252','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-10 04:39:26',0,NULL,3,1,3,1,'RA117730806CN ','*sharklady*'),(9288,767828366016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'AC2304',4.5,'hutongstore','ellenorstyf','ellenors_@hotmail.com','Ellenor Styf','Sockenvagen 15','Vilhelmina','','SWEDEN','91234','073-8435780','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 06:48:41',0,NULL,3,1,2,1,NULL,'ellenorstyf'),(9289,670905921001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','golgota8351','galenvp@hotmail.com','parianen veerasamy','gentilly branch road petit verger','st pierre','/','MAURITIUS','no postal co','2307739000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 06:58:39',0,NULL,3,1,3,1,'RA117730797CN ','golgota8351'),(9290,711930581002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT061',73.3,'hermeshine','istokka','admoccia@alice.it','antonio chiacchio','via gramsci 55','frattaminore','NA','ITALY','80020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 07:09:20',0,NULL,3,1,4,1,'YW865907465CN ','istokka'),(9291,765551897016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','bigpeter57','peter.nagy@bredband2.com','PETER NAGY','Linehedsv. 25','HALMSTAD','Halland','SWEDEN','30252','035-122636','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 07:45:40',0,NULL,3,1,2,1,NULL,'bigpeter57'),(9292,723112036017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','maximk1985','viciouskms@mail.ru','Maxim Kurmanov','Свердлова 30-35','Новкузнецк','Кемеровская обл','RUSSIAN FEDERATION','654080','89133117362','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-10 08:17:43',0,NULL,3,1,5,1,'CP227020622CN ','maximk1985\r欧标\r庄'),(9293,711969552002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','javivisteam','javivisteam@terra.es','Javier Mateos Caballero','Avd. Reina Sofía  24, portal 1, 2ºc','Mérida','Extremadura','SPAIN','06800','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 10:22:43',0,NULL,3,1,4,1,'YW865907572CN ','javivisteam\rtripod  $15\r庄'),(9294,670948707001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',3,'AB1302',10.02,'hermeshine','wswswswsgixxer','woschnepf@googlemail.com','schnepf','kernerstrasse 1','Wiernsheim','','GERMANY','75446','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 10:24:32',0,NULL,8,1,17,0,NULL,'wswswswsgixxer'),(9295,711970724002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','wswswswsgixxer','woschnepf@googlemail.com','schnepf','kernerstrasse 1','Wiernsheim','','GERMANY','75446','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 10:25:49',0,NULL,8,1,17,0,NULL,'wswswswsgixxer'),(9296,670948336001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','wswswswsgixxer','woschnepf@googlemail.com','schnepf','kernerstrasse 1','Wiernsheim','','GERMANY','75446','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 10:26:57',0,NULL,8,1,17,0,NULL,'wswswswsgixxer'),(9297,670948128001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','wswswswsgixxer','woschnepf@googlemail.com','schnepf','kernerstrasse 1','Wiernsheim','','GERMANY','75446','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 10:28:06',0,NULL,3,1,3,1,'RA117730987CN ','wswswswsgixxer\r52mm 橡胶罩   1\r58mm 橡胶罩   2\r77mm 橡胶罩   1\r55mm 橡胶罩   3\r刘'),(9298,670797652001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','medi-anna','mediannastudio@gmail.com','Aleksandr Demidov','prospekt Lenina, dom 53, kv.25','Novorossiysk','Krasnodarskiy kray','RUSSIAN FEDERATION','353913','905-494-8478','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 11:00:19',0,NULL,3,1,3,1,'RA117730871CN ','medi-anna\r刘'),(9299,783687305015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','etrader5858','ngng31@excite.com','Mr N Gapp','Russell Cottage<br>Catteshall Lane','Godalming','Surrey','UNITED KINGDOM','GU7 1UT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 11:04:21',0,NULL,3,1,3,1,'RA117730911CN ','etrader5858\r刘'),(9300,783913666015,250599922417,'New 58mm 58 Ring adapter and Holder for Cokin P Series ',1,'AKT020',3.62,'hutongstore','josepinheiroesales','pinheirojose@gmail.com','José Pinheiro','Rua José Monteiro de Castro Portugal 667 Ent B 1º DT','Vila Nova de Gaia','','PORTUGAL','4405-568','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 11:20:20',0,NULL,3,1,2,1,NULL,'josepinheiroesales\r刘'),(9301,711986976002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','bkphotog212','info@pavelshpakphotography.com','Pavel SHPAK','1871 W 5th St','BROOKLYN','NY','UNITED STATES','11223-2630','(917) 533-2308','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 11:27:09',0,NULL,3,1,1,1,NULL,'bkphotog212'),(9302,0,110683185116,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',1.14,'hermeshine','bobcat7677','bobcat7677@yahoo.com','Robert Bachelder','922 Prospect St<br>Apt A','Oregon City','OR','UNITED STATES','97045-3797','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 11:36:51',0,NULL,3,1,1,1,NULL,'bobcat7677\r刘'),(9303,712008386002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','fitzgibbon386','davidfitzgibbon@blueyonder.co.uk','DAVID FITZGIBBON','86,PORTER CLOSE','WEST THURROCK','Essex','UNITED KINGDOM','RM20 4AS','01375409656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 12:45:14',0,NULL,3,1,2,1,NULL,'fitzgibbon386\r刘'),(9304,723179398017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','egapretsel','page555@aanet.com.au','lester page','65  eucalyptus blvd canningvale','perth','Western Australia','AUSTRALIA','6155','0894557696','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-10 12:45:29',0,NULL,8,1,17,0,NULL,'egapretsel'),(9305,723178955017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','egapretsel','page555@aanet.com.au','lester page','65  eucalyptus blvd canningvale','perth','Western Australia','AUSTRALIA','6155','0894557696','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-10 12:47:46',0,NULL,3,1,4,1,'YW865907561CN ','egapretsel\r澳标\r再加一个爵影红外 canon   1\rlighting kit  $30\r庄'),(9306,712012406002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','poziruem','kofoto@mail.ru','Konstantin Semenets','Saratovski pereulok 14','Krasnodar','Krasnodarski kraĭ','RUSSIAN FEDERATION','350020','(918)311-1009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 13:08:34',0,NULL,3,1,3,1,'RA117733285CN ','poziruem\r刘'),(9307,767943949016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','bronwen1963','bronpeek@yahoo.co.uk','Jasmine (PD Services)','Office suite 3.24, QWest<br>Great West Road','Brentford','Middlesex','UNITED KINGDOM','TW8 0GP','02077857210','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 13:34:52',0,NULL,3,1,3,1,'RA117730823CN ','bronwen1963'),(9308,671005852001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','e-world-2010','evmatos2008@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 13:59:13',0,NULL,3,1,1,1,NULL,'e-world-2010\r刘'),(9309,712030392002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','alexeysamokhvalov','samohvalov@gmail.com','Alexey Samokhvalov','27 Engelsa street, apartment 37','Tambov','Tambovskaya oblast','RUSSIAN FEDERATION','392002','+79202341585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 14:01:43',0,NULL,3,1,2,1,NULL,'alexeysamokhvalov'),(9310,707082450002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','xrobertojosuex','xxrunkenxx@gmail.com','roberto josue naranjo rosario','BB72 CALLE 26<br>LAS VEGAS','catano','PR','UNITED STATES','00962-6428','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-10 14:04:46',0,NULL,4,0,0,0,' ','xrobertojosuex'),(9311,767965405016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','deckchairboy','deckchairboy@industrialbuildings.info','Paul Richmond','Holly House<br>28 Belle Vue Gardens','Shrewsbury','Shropshire','UNITED KINGDOM','SY3 7JH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 14:34:06',0,NULL,3,1,2,1,NULL,'deckchairboy'),(9312,671000559001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','enor2006','enorcarvalhousa@hotmail.com','Enor Carvalho','927 BURNSIDE AVE','EAST HARTFORD','CT','UNITED STATES','06108-2710','(860) 206-1458','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 14:43:00',0,NULL,3,1,1,1,NULL,'enor2006\r庄'),(9313,712057762002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','dcandrade','diogo.groselha@gmail.com','Diogo Carvalho de Andrade','Avenida dos Andradas, 430 apto 306 Bloco C<br>Centro','Juiz de Fora','Minas Gerais','BRAZIL','36036000','32 32173974','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 15:27:39',0,NULL,3,1,3,1,'RA117730783CN ','dcandrade\r刘'),(9314,0,110683185149,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',3,'hermeshine','meanbear','delmarvaind@netzero.net','John R Graziani','517 Fox Den Ln','Millersville','MD','UNITED STATES','21108-1467','(410) 987-0524','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 15:29:58',0,NULL,3,1,1,1,NULL,'meanbear\r庄'),(9315,671034952001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','gamepood1300','lurichst@hot.ee','Valeria Lopatina','Tuulemaa 9-13','Tallinn','Eesti','ESTONIA','10312','(372) 5667 1671','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 15:33:01',0,NULL,3,1,3,1,'RA117731007CN ','gamepood1300'),(9316,669788063018,280666902955,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',7.99,'photographyacc','hortam97','tamas125@freemail.hu','Tamás Horváth','Petőfi Sándor utca 16. 1/105','Kecskemét','Bács-Kiskun','HUNGARY','6000','0036706135972','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-10 15:34:47',0,NULL,3,1,2,1,' ','hortam97\r刘'),(9317,671037367001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','bgr881117','bigbuda@freemail.hu','Gergely Budafai','Erzsébet utca 19 IX/55','Budapest','Pest','HUNGARY','1043','0036306574899','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,8,1,17,0,' ','bgr881117'),(9318,671037963001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','njroze12','njroze@yahoo.com','Mr Nigel Rozairo','C/O HSBC<br>24 SIR BARON JAYATILEKE MAWATHA','COLOMBO 1','','SRI LANKA','000','94727116915','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 15:41:59',0,NULL,3,0,3,1,'RA117730810CN ','njroze12\r3XL（已入库）\r刘'),(9319,671041831001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','p373r_p','p373r.p@gmail.com','Peter Polak','Obr. mieru 347/8','Dubnica nad Vahom','Slovakia','SLOVAK REPUBLIC','01841','0903018771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 15:52:06',0,NULL,3,1,2,1,NULL,'p373r_p\r刘'),(9320,712067326002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','bgr881117','bigbuda@freemail.hu','Gergely Budafai','Erzsébet utca 19 IX/55','Budapest','Pest','HUNGARY','1043','0036306574899','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 15:55:04',0,NULL,3,1,4,1,'YW865907550CN','bgr881117\r圆形柔光棚 40cm   1\r2B柔   2\r灯架包   1\r庄'),(9321,0,120720079386,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',1.04,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 16:07:39',0,NULL,8,1,17,0,NULL,'zeroone12345'),(9322,0,120720079828,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',0.99,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 16:07:39',0,NULL,8,1,17,0,NULL,'zeroone12345'),(9323,0,110683185418,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',0.99,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 16:07:40',0,NULL,8,1,17,0,NULL,'zeroone12345'),(9324,0,110683184992,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',1.04,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 16:07:41',0,NULL,8,1,17,0,NULL,'zeroone12345'),(9325,0,120720080138,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',2.25,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 16:07:41',0,NULL,3,1,1,1,' ','zeroone12345\r爵影快门线C1   1\r方形滤镜接口环 67mm   1\r方形滤镜 镜片卡座    1\r眼罩 40D/50D    1\r眼罩 450D/500D   1\r绿叶 UV  67mm   1'),(9326,712073504002,120555973963,'Light Stand 80cm / 32\" for back light studio',2,'AE3501',44,'hermeshine','amnon064','amnon64@gmail.com','Amnon Ziv','Doar Na Chalutza','Kibutz Mashabe Sade','','ISRAEL','85510','972-0507254189','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 16:12:43',0,NULL,3,1,3,1,'RA117730995CN ','amnon064'),(9327,671051907001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','bsa7mmrm','m.miana@virgilio.it','Massimo Miana','via Monte Cresto ,8<br>Fraz. Vaglio di Biella','Biella','BI','ITALY','13900','338-8424082','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 16:22:45',0,NULL,3,0,3,1,'RA117730908CN ','bsa7mmrm\r3XL-已入库\r申报 photo vest  $10\r刘'),(9328,712083014002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','d_autohaus','d.autohaus@mail.ru','Evgeny Volkov','Konstitutsyi str. 17-139','Krasnoyarsk','Krasnoyarsky kray','RUSSIAN FEDERATION','660049','+79135345525','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 16:39:54',0,NULL,3,1,2,1,NULL,'d_autohaus\r刘'),(9329,784042736015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','turboteddy67','turboted@gmx.de','Hans-Peter tenthoff','Auf dem Rüggen 15','Bochum','','GERMANY','44892','Invalid Request','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 16:52:40',0,NULL,3,1,2,1,NULL,'turboteddy67\r刘'),(9330,671074438001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','mpie8004','magiamagia.it@gmail.com','massimiliano pierini','via zuccari 270-a','bagnaia (viterbo ) Italy','VT','ITALY','01100','3473723548','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 17:20:11',0,NULL,3,1,2,1,NULL,'mpie8004'),(9331,671076477001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','h_art_4eb','h-art@yandex.ru','Artur Khabibullin','R.Zorge 38/1-20','Ufa','Bashkortostan','RUSSIAN FEDERATION','450059','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 17:25:50',0,NULL,3,1,3,1,'RA117730925CN ','h_art_4eb\r刘'),(9332,712102421002,120578649319,'10 NEW UV filters Green.L 52mm - 77mm ',1,'AKT032',40,'hermeshine','andresc813','andrescab2003@yahoo.com','andres cabrera','6214 greenwich dr','tampa','FL','UNITED STATES','33647-1142','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 17:28:46',0,NULL,3,0,3,1,'RA117730956CN ','andresc813\r绿叶UV  58mm   10 (注意，是58mm！)\r已入库\r刘'),(9333,712168758002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','moniqueonishi','thais_onishi@hotmail.com','Ana thais onishi','rua: jesuino de brito, 303<br>apartamento 35','são paulo','são paulo','BRAZIL','02925-140','55-011-89645098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 19:46:01',0,NULL,3,1,2,1,NULL,'moniqueonishi\r庄'),(9334,668822639001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','petruchioo10','petruchioo@gmail.com','Petar Cholakov','Hristo Maksimov 16<br>floor 1','Sofia','Sofia','BULGARIA','1111','+35928717506','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 19:47:12',0,NULL,3,1,3,1,'RA117730899CN ','petruchioo10\r刘'),(9335,671150397001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','pagluca','yamato71@libero.it','Luca Paglialonga','Via Cesare Battisti, 21','Legnano','MI','ITALY','20025','+393355787806','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:13:46',0,NULL,3,1,3,1,'RA117730766CN ','pagluca\r刘\rclamp   $10'),(9336,768145933016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','ogg78','oleg.gritsinevich@gmail.com','Oleg Grytsynevych','Webersgade 1, 4 th','Copenhagen','O','DENMARK','2100','4531955419','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 20:26:10',0,NULL,8,1,17,0,NULL,'ogg78'),(9337,712189359002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','rafaelzuc','rafazuc@hotmail.com','Rafael Zuccolotto','Rua Rio Guaiba, No 02, Hélio Ferraz<br>Ponto de referencia: Drograria Norte-Sul','Serra','Espirito Santo','BRAZIL','29160540','55-27-33370577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:28:36',0,NULL,3,1,2,1,NULL,'rafaelzuc\r刘'),(9338,768147142016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','ogg78','oleg.gritsinevich@gmail.com','Oleg Grytsynevych','Webersgade 1, 4 th','Copenhagen','O','DENMARK','2100','4531955419','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 20:28:53',0,NULL,3,1,3,1,'RA117730942CN ','ogg78\r申报：9$\r笔   2\r刘'),(9339,671170617001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','erhan_deniz','erhancagiral@hotmail.com','Erhan Deniz Cagiral','530 sokak no:23 Kat:4 Sirinyer','Izmir','','TURKEY','35150','+902324879222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:50:35',0,NULL,3,1,2,1,NULL,'erhan_deniz\r庄\r'),(9340,671175044001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','green_dream_sky','volya.dzemka@gmail.com','Anna Karptsova','3000 Royal Hills Dr SE<br>Apt 9H','Renton','WA','UNITED STATES','98058-3856','(206) 370-1567','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 21:01:16',0,NULL,3,1,1,1,NULL,'green_dream_sky\r美标\r刘'),(9341,784203348015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3306',2.6,'hutongstore','mollerjensen','krause@post8.tele.dk','Ib Krause-Kjaer','Alrovej 380<br>Alro','Odder','','DENMARK','DK-8300','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 21:29:55',0,NULL,3,1,2,1,NULL,'mollerjensen\r刘'),(9342,668664335018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','d-hargarten','d.hargarten@web.de','Dorian Hargarten','Wickenpfädchen 25','Bergisch Gladbach','','GERMANY','51427','Invalid Request','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-10 21:43:44',0,NULL,3,1,2,1,NULL,'d-hargarten\r刘'),(9343,671190122001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','barsgo','barsgo@hotmail.com','BÁRBARA SERRANO GÓMEZ','C/ ABEJAR 22 B','CORDOBA','Andalucía Ceuta y Melilla','SPAIN','14002','680426252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 21:47:39',0,NULL,3,1,2,1,NULL,'bars\r庄'),(9344,711950028002,120458029512,'Marco O Flash o-flash Ring Light For SB800 SB600 F160 ',1,'AO0026',89.99,'hermeshine','mg3putt','mg3putt@sympatico.ca','Mark J Grottoli','3709 St. Laurent Court','Mississauga','ON','CANADA','L5L 4T3','(905) 828-4009','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 22:54:27',0,NULL,3,1,3,1,'RA117733201CN ','mg3putt\r闪光的柔光箱   60cm   1（已入库）\rO形闪光灯160    1\r'),(9345,784245511015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',125,'hutongstore','squidonius','pf224@bath.ac.uk','Paolo Ferla','22 oldfield Road','Bath','Avon','UNITED KINGDOM','BA2 3NF','39095494706','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-10 23:30:33',0,NULL,3,1,4,1,'YW865907546CN ','squidonius\r英标\r王'),(9346,784248703015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','cristovaoabreu','cristo2007@sapo.pt','Cristóvão Abreu','Rua da Azenha, nº1<br>Rio de Moinhos','Esposende, Marinhas','Portugal','PORTUGAL','4740-577','969014297','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 23:41:20',0,NULL,3,1,3,1,'RA117730868CN ','cristovaoabreu\r刘'),(9347,671234656001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','kokimk','snkoki83@yahoo.com','Nikola Spasenoski','bul J.N.A. 23/27<br>vlez4 stan10','Skopje','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','1000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 00:55:20',0,NULL,3,1,3,1,'RA117730939CN ','kokimk\r刘'),(9348,784292356015,250600315434,'Flash Softbox Diffuser for internal flash for D500 D90',1,'AB3304',6.8,'hutongstore','luissantos2006','luisig@sapo.pt','Luis Santos','Rua Vale do Lobo','Ourém','Santarém','PORTUGAL','2490-307','00351916036909','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 02:14:43',0,NULL,3,1,2,1,NULL,'luissantos2006\r刘'),(9349,671251772001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',37.59,'hermeshine','brooklynking469','jacob@appleguyofdallas.com','Brook King','13423 Juneau Dr','Frisco','TX','UNITED STATES','75034','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-11 02:42:20',0,NULL,3,0,3,1,'RA117730837CN ','brooklynking469\r2.1x1.6m 背景布   4（绿+黄+蓝+粉）\r77mm Nikon镜头盖  1（已入库）\r\r\r'),(9350,712306422002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',5,'AC2304',31.2,'hermeshine','gorrionsudaca','juanotesone@gmail.com','Juan Tesone','Av. Libertador 886<br>Piso 8 Dpto E','Vicente Lopez','Buenos Aires','ARGENTINA','1638','+5411 4718 3175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 03:43:14',0,NULL,3,1,3,1,'RA117730845CN ','gorrionsudaca\r刘'),(9351,712309641002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','dirtisgood','robertspendlove@gmail.com','Robert Spendlove','2164 S 1730 W','Syracuse','UT','UNITED STATES','84075-8558','(801) 543-9244','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 04:02:54',0,NULL,3,1,3,1,'RA117730854CN ','dirtisgood'),(9352,784197971015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','szilard-ns','nsnagyszilard@gmail.com','Szilard Nagy','21 Decembrie, nr.148, ap.76','Cluj-Napoca','Cluj','ROMANIA','400604','+4 0740 414 449','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-11 05:28:00',0,NULL,3,0,5,1,'CP227020619CN ','szilard-ns'),(9353,671286271001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','admirolas','parkingas@gmail.com','Alenas Fainsteinas','K.Donelaicio 42-5','Kaunas','LT','LITHUANIA','44241','+37061066799','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 05:28:07',0,NULL,3,1,2,1,NULL,'admirolas'),(9354,712328451002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',111.98,'hermeshine','cntrygrl749','jrdeacon1976@roadrunner.com','Jaime Deacon','7439 W Wright st','Rathdrum','ID','UNITED STATES','83858-8452','','NoPaymentFailure','CheckoutComplete','Other','2011-05-11 05:51:31',0,NULL,3,1,4,1,'YW865907538CN ','cntrygrl749\rlight stand  $30'),(9355,712330408002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','juster737','petrovecvlad@gmail.com','Petrov Vladimir','Tekstilshchikov prospekt<br>dom 5b kv.49','Ivanovo','','RUSSIAN FEDERATION','153040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 06:03:47',0,NULL,3,0,2,1,NULL,'juster737'),(9356,712336829002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','poziruem','kofoto@mail.ru','Konstantin Semenets','Saratovski pereulok 14','Krasnodar','Krasnodarski kraĭ','RUSSIAN FEDERATION','350020','(918)311-1009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 06:40:27',0,NULL,8,1,17,0,NULL,'poziruem'),(9357,784352794015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','z6lsd','ebay@rsskov.dk','Lars Skov','Hedeparken 1, 5. D<br>Døgnposten 635 / 42404020','Ballerup','','DENMARK','2750','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 06:43:05',0,NULL,3,1,2,1,NULL,'z6lsd'),(9358,712341039002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','norgesmann','trond.oliversen@gmail.com','Trond Oliversen','Gamle Prestveien 38 C','Stavanger','Rogaland','NORWAY','4025','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 07:01:06',0,NULL,8,1,17,0,NULL,'norgesmann'),(9359,712341019002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','norgesmann','trond.oliversen@gmail.com','Trond Oliversen','Gamle Prestveien 38 C','Stavanger','Rogaland','NORWAY','4025','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 07:01:06',0,NULL,8,1,17,0,NULL,'norgesmann'),(9360,671302117001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','norgesmann','trond.oliversen@gmail.com','Trond Oliversen','Gamle Prestveien 38 C','Stavanger','Rogaland','NORWAY','4025','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 07:01:07',0,NULL,8,1,17,0,NULL,'norgesmann'),(9361,712341028002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',16.99,'hermeshine','norgesmann','trond.oliversen@gmail.com','Trond Oliversen','Gamle Prestveien 38 C','Stavanger','Rogaland','NORWAY','4025','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 07:01:07',0,NULL,3,1,4,1,'YW865907620CN ','norgesmann\r2B柔   1\r2m灯架+ 单灯头 欧标  +反光伞  1\r反光板支架  1\r防雨罩   1\rlight stand  $25'),(9362,768330944016,260660051619,'Medium size Neoprene Lens Pouch fit 17-85mm 18-70mm M',1,'AC1202',2.48,'hutongstore','yogi_gypsy','mrfoto2010@hotmail.com','Izam M R','Blk 709 Yishun Ave 5 # 04-64','default','','SINGAPORE','760709','91171044','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 07:23:02',0,NULL,3,1,11,1,NULL,'yogi_gypsy'),(9363,670765155001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','eoin.galtee','eoin@galteewood.net','Eoin Ryan','Cork Rd','Ballylanders','Limerick','IRELAND','','0879212509','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 07:49:30',0,NULL,3,1,4,1,'YW865907616CN ','eoin.galtee\r英标\rlighting kit   $40\r庄'),(9364,784381601015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','tinsunlee','tinsunglee@yahoo.com','Kevin Wright','7 Upavon Garth, Bransholme,','Hull','East Riding of Yorkshire','UNITED KINGDOM','Hu7 4rj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 08:36:08',0,NULL,3,1,2,1,NULL,'tinsunlee'),(9365,768351293016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','norad100','mj12templar@gmail.com','Oliver Galea','Blk 1, Flat 7, Appt. 21-09-1964,<br>Triq tal-Fieres,','Kirkop','','MALTA','KKP 1541','(356) 99062891','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 08:55:12',0,NULL,3,1,2,1,NULL,'norad100'),(9366,671324991001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','xxx-kuklus','kuklused@gmail.com','Yuriy Pechenkin','Arktika 6/1-40','Bilibino','','RUSSIAN FEDERATION','689450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 09:01:18',0,NULL,8,1,17,0,NULL,'xxx-kuklus'),(9367,712363542002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','xxx-kuklus','kuklused@gmail.com','Yuriy Pechenkin','Arktika 6/1-40','Bilibino','','RUSSIAN FEDERATION','689450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 09:01:18',0,NULL,3,1,3,1,'RA117730465CN ','xxx-kuklus\r40cm 棚   1\rlenspen  2'),(9368,671329751001,110316941375,'Remote Shutter Release for Canon PowerShot G10 =RS-60E3',1,'AA3210',4.3,'hermeshine','montresor_123','alain.crozemarie@orange.fr','alain crozemarie','23 rue braniky','montresor','Centre','FRANCE','37460','0679700268','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 09:20:31',0,NULL,1,1,2,1,NULL,'montresor_123'),(9369,671335843001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','noralyb','noraly_blaazer@hotmail.com','Noraly Blaazer','Cedrusstraat 3','Boskoop','','NETHERLANDS','2771 ZK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 09:54:22',0,NULL,3,1,2,1,NULL,'noralyb\r庄'),(9370,671350141001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','ibico1974','kenneth.augdal@gmail.com','Kenneth Augdal','Ishavsvegen 69B','Tromsø','Troms','NORWAY','9010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 10:46:48',0,NULL,3,1,2,1,NULL,'ibico1974\r庄'),(9371,671352901001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','elmotjuuh','alyssa.westhoek@live.nl','Alyssa Westhoek','Doelensteeg 2','LEIDEN','','NETHERLANDS','2311VL','0625088176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 10:58:43',0,NULL,3,1,2,1,NULL,'elmotjuuh\r庄'),(9372,712402649002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','norrland_quattro','audi_cab@hotmail.com','mattias nyström','björkvägen 31','79340 insjön','','SWEDEN','79340','+46706508751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 11:41:16',0,NULL,3,1,2,1,NULL,'norrland_quattro\r庄'),(9373,712404417002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','keiyin77','angelkproducciones@gmail.com','Angel Cabrera Sánchez','AVDA. PUERTA DEL SUR 29, EL ESTRIBO<br>BLOQUE 2 BAJO D','JEREZ','Andalucía Ceuta y Melilla','SPAIN','11408','615916068','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 11:47:57',0,NULL,3,1,2,1,NULL,'keiyin77\r庄'),(9374,671007135001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',2,'AA1214',15.96,'hermeshine','2010rocker2010','meine-fotos24@web.de','Magnus Kühn','Poststr. 8c','Bochum','','GERMANY','44809','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 12:10:25',0,NULL,3,1,2,1,NULL,'2010rocker2010\r庄'),(9375,671379556001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','farhun','fatih.arhun@nyc.rr.com','Fatih Arhun','4141 46th St<br>Apt 6B','Sunnyside','NY','UNITED STATES','11104-1815','(718) 482-8834','NoPaymentFailure','CheckoutComplete','Other','2011-05-11 12:38:59',0,NULL,3,1,1,1,NULL,'farhun\rXL   王'),(9376,671380194001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','gyllitz465','edgar.hellwig@online.de','Edgar Hellwig','Taubenstr. 23b','Dinslaken','','GERMANY','D-46539','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 12:42:37',0,NULL,3,1,3,1,'RA117731506CN ','gyllitz465\r刘'),(9377,671381678001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',12,'AE3103',117.6,'hermeshine','chrisxx178','csengel.krisztian@chello.hu','Krisztián Csengel','Kisfaludy u. 32.','Budapest','','HUNGARY','1047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 12:47:05',0,NULL,3,1,3,1,'RA117732679CN\rRA117731639CN\rRA117731642CN','chrisxx178\r客户要求：申报gift，9$,\r分成3票发，每票4个\r'),(9378,712433985002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','tadi226','pusnik.tadej@gmail.com','Tadej Pušnik','cvetkova 23','murska sobota','','SLOVENIA','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 13:31:41',0,NULL,3,1,3,1,'RA117731554CN ','tadi226'),(9379,784493368015,250599945807,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',1.85,'hutongstore','2ndfusilier','ttj375@hotmail.com','Terence Jones','49 Langwood Court<br>Castle Bromwich','Birmingham','West Midlands','UNITED KINGDOM','B36 9DN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 14:15:19',0,NULL,3,1,2,1,NULL,'2ndfusilier\r庄'),(9380,710588280002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jormo_corporation','jormocorporation@gmail.com','Manuel Peláez Pezzi','Armuñesa, 36','Monterrubio de Armuña','Castilla y León','SPAIN','37798','923288699','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 13:51:49',0,NULL,3,1,4,1,'YW865907605CN ','jormo_corporation\r庄\rtripod $15'),(9381,671410269001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','sachaagr31','grandstudio78290@yahoo.fr','Alexandre GRANDREMY','Lieu dit Cantonnier','Montesquieu Volvestre','Midi-Pyrénées','FRANCE','31310','0561976291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 14:29:27',0,NULL,3,1,2,1,' ','sachaagr31\r庄'),(9382,671414015001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','0792*ayres','henry@ayres9.wanadoo.co.uk','henry ayres','48 tylacoch<br>llanharry','pontyclun','Rhondda Cynon Taff','UNITED KINGDOM','cf72 9lt','01443449724','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-05-11 14:39:13',0,NULL,8,1,17,0,NULL,'0792*ayres'),(9383,671416324001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','0792*ayres','henry@ayres9.wanadoo.co.uk','henry ayres','48 tylacoch<br>llanharry','pontyclun','Rhondda Cynon Taff','UNITED KINGDOM','cf72 9lt','01443449724','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 14:45:33',0,NULL,3,1,3,1,'RA117731599CN\r ','0792*ayres\r天涯方形滤镜系列  CPL   1\r天涯方形滤镜系列  星光镜  star8    1\r庄'),(9384,712459667002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','bailey72379','jasonhewitt1979@hotmail.com','jason hewitt','8815 old number six hwy','santee','SC','UNITED STATES','29142','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-11 14:55:35',0,NULL,3,1,1,1,' ','bailey72379\r庄'),(9385,712459203002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','mma_79','phantomax@mail.ru','Maxim Alexandrovich Misovets','mikrorayon Gorsky 3-66','Novosibirsk','','RUSSIAN FEDERATION','630073','+7-913-949-07-49','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 14:56:14',0,NULL,3,1,2,1,NULL,'mma_79\r庄'),(9386,671422552001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','noisnaaria','superphillipe10@gmail.com','Phillipe Santos','Av. São João Batista, 638 - ed. sabará 101','Aracaju','Sergipe','BRAZIL','49097000','557932594957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:05:19',0,NULL,3,1,2,1,NULL,'noisnaaria\r庄'),(9387,666387692001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',3,'AA3310',47.16,'hermeshine','andrush85','progr_and@mail.ru','Sidorchenko Alexandr','40 let Pobedy 14 / 8','Nigniy Novgorod','','RUSSIAN FEDERATION','603137','+7(908)-75-743-29','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:11:38',0,NULL,3,1,3,1,'RA117731497CN ','andrush85\r(已入库)\r绿叶 52mm CPL   5\r绿叶 58mm UV     2\r绿叶 58mm CPL   3'),(9388,768481729016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7.99,'hutongstore','liamcoe8gac','liam.coe@gmail.com','Liam Coe','8 Gort an Chlochair<br>YJT-73-6VN','Portlaw','Waterford','IRELAND','','0861719902','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 15:19:15',0,NULL,3,1,2,1,NULL,'liamcoe8gac\r庄'),(9389,668726564001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','tinatinamisdameana','tinerbeanerz@gmail.com','Tina Unger','214 little valley trail','Cheyenne','WY','UNITED STATES','82007-3637','(307) 286-8528','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-11 16:07:04',0,NULL,7,1,18,0,' ','tinatinamisdameana\r庄'),(9390,669630798001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','jagebbo','gellingdale@gmail.com','Julie Gebbing','PO Box 212','Woori Yallock','Victoria','AUSTRALIA','3139','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 16:46:51',0,NULL,8,1,17,0,NULL,'jagebbo'),(9391,669623712001,110469599833,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',13.99,'hermeshine','jagebbo','gellingdale@gmail.com','Julie Gebbing','PO Box 212','Woori Yallock','Victoria','AUSTRALIA','3139','','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-05-11 16:50:41',0,NULL,3,1,3,1,'RA117731483CN ','jagebbo\r肩架    1\r柔光伞   1'),(9392,784562791015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','lionhart9990','comeupandseem6@hotmail.com','Brian  Lyons','Flat 19<br>47 Cherrywood Close','London','London','UNITED KINGDOM','E3 2DQ','02089833965','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 16:53:22',0,NULL,8,1,17,0,NULL,'lionhart9990'),(9393,784563620015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24.99,'hutongstore','lionhart9990','comeupandseem6@hotmail.com','Brian  Lyons','Flat 19<br>47 Cherrywood Close','London','London','UNITED KINGDOM','E3 2DQ','02089833965','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 16:55:15',0,NULL,3,1,3,1,'RA117731523CN ','lionhart9990\r115w   220v   2\r45w   220v    2\r1.266'),(9394,712496015002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','jameball','chitpong_ball@hotmail.com','Siripach Mahagitsiri','411/173 Pracha Utit Road','Huaykwang','Bangkok','THAILAND','10310','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-05-11 17:03:23',0,NULL,3,1,11,1,NULL,'jameball\r庄'),(9395,671483786001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','lrmiranda','leomiranda@gmail.com','Leonardo Miranda','Rua Michel Salomani, 288<br>Mosela','Petrópolis','RJ','BRAZIL','25675-321','+55 21 81180502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 17:50:00',0,NULL,3,1,2,1,NULL,'lrmiranda\r庄'),(9396,671493305001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','zigras','zigras52@msn.com','chris zigras','GRAVIAS 18','KARDITSA','','GREECE','43100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 18:10:19',0,NULL,8,1,17,0,NULL,'zigras'),(9397,712555181002,120555973963,'Light Stand 80cm / 32\" for back light studio',2,'AE3501',44,'hermeshine','glowingstar71','tommycuellar@gmail.com','Thomas Cuellar','261 10th St<br>Ste 302','Oakland','CA','UNITED STATES','94607-4465','','NoPaymentFailure','CheckoutComplete','Other','2011-05-11 18:52:35',0,NULL,3,1,3,1,'RA117731470CN ','glowingstar71\r刘'),(9398,768609601016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','mr_c_s','mrcleanshave@gmail.com','Mr G Pritchard','10 Laurel Mews<br>Garden Hedge','Leighton Buzzard','Bedfordshire','UNITED KINGDOM','LU7 1FR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 19:25:36',0,NULL,3,1,2,1,NULL,'mr_c_s\r庄'),(9399,671552869001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','journeyman_gr','pcloukas@yahoo.gr','Loukas Kalantzis','Averof 20','Egaleo','Athenes','GREECE','12244','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 20:14:20',0,NULL,3,1,2,1,NULL,'journeyman_gr\r庄'),(9400,768641088016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','zigras','zigras52@msn.com','chris zigras','GRAVIAS 18','KARDITSA','','GREECE','43100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 20:16:05',0,NULL,3,1,2,1,NULL,'zigras\rEW-73B    1\rlenspen    1\r庄'),(9401,784685327015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0005',15.98,'hutongstore','moyleattic2011','my_orders4avon@yahoo.com','Vanessa Long','29 Moyle Park<br>Hilperton','Trowbridge','Wiltshire','UNITED KINGDOM','BA14 7UE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 20:17:00',0,NULL,3,1,3,1,'RA117731510CN ','moyleattic2011\r2.1x1.6m  2(黑+白)\r庄'),(9402,768672957016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','surek.peter','surek.peter@gmail.com','Peter Šúrek','Gercenova 6/B<br>Petržalka','Bratislava','Bratislava','SLOVAK REPUBLIC','85101','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 21:20:54',0,NULL,3,1,5,1,'CP227020605CN','surek.peter'),(9403,712638893002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','luchouf','luchouf@hotmail.com','luis uechi','22527 Crenshaw Blvd<br>Ste 200','Torrance','CA','UNITED STATES','90505-3069','','NoPaymentFailure','CheckoutComplete','Other','2011-05-11 22:03:08',0,NULL,3,0,1,1,NULL,'luchouf\r3XL（已入库）\r753'),(9404,768695155016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',38.99,'hutongstore','7jax','jacqwilkinson2002@yahoo.co.uk','Jacqueline Wilkinson','21, Stoney Croft<br>Hoyland','Barnsley','South Yorkshire','UNITED KINGDOM','S74 0LZ','01226748838','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-11 22:15:43',0,NULL,3,1,4,1,'YW865907594CN ','7jax\rlight stand  $20'),(9405,670393852018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','krzykjn2005','krzykjn@sbcglobal.net','Monique Pedersen','112 Rock Creek Rd','Morrilton','AR','UNITED STATES','72110','(501) 208-7212','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-11 22:21:07',0,NULL,3,1,3,1,'RA117731466CN ','krzykjn2005\r刘 '),(9406,712657302002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','xdonald85','fylki@hotmail.com','Ole Erik Fylkesnes','Tormodsveg 4A','Haugesund','Haugesund','NORWAY','5518','+4793410061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 23:31:49',0,NULL,3,1,2,1,NULL,'xdonald85\r庄'),(9407,671616215001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','thesolarcenter','ramimataev@gmail.com','Rami Mataev','Rambam ST<br>Number 10','Or Akiva','HaSharon','ISRAEL','30600','(972) 0544225995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 23:36:19',0,NULL,3,1,3,1,'RA117731608CN\r ','thesolarcenter\r庄'),(9408,721564480017,270745173616,'New Photo 4 x E27 Sockets Bulb Holder Umbrella holder',1,'AE2202',30,'photographyacc','shanks-185','baileyshanks@hotmail.com','bailey shanks','6 nemesis place<br>golden grove','kalgoorlie','Western Australia','AUSTRALIA','6430','0890919157','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-11 23:40:38',0,NULL,7,1,18,0,NULL,'shanks-185\r刘\recheck的，已经发过了'),(9409,670413016018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','minhtuan1986','mr_handsome1986@yahoo.com','Tuan Phuong','4/14<br>Wattle Valley Rd','Canterbury','Victoria','AUSTRALIA','3126','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-11 23:41:23',0,NULL,3,1,3,1,'RA117731792CN ','minhtuan1986\r庄'),(9410,671623530001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',29.12,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 00:10:59',0,NULL,3,1,2,1,NULL,'arnorolf10\r刘'),(9411,670426895018,280667740626,'New IR Wireless Remote Control for Sony a230 a330 a550',1,'AA2203',5.48,'photographyacc','wendy140975','wendy141625@hotmail.com','wendy stevenson','4 merion crt','banora point','New South Wales','AUSTRALIA','2486','0755246783','NoPaymentFailure','CheckoutComplete','AU_Other','2011-05-12 00:46:36',0,NULL,3,1,2,1,NULL,'wendy140975\r庄'),(9412,712678924002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','tonytone1969','tonylewis2001@hotmail.com','Anthony Lewis','13313 - 122 Ave','Edmonton','AB','CANADA','T5L 2V4','(780) 709-9560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 01:14:56',0,NULL,3,1,2,1,NULL,'tonytone1969\r庄'),(9413,671640656001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',92,'hermeshine','photazimaginationproduction','photazimagination@gmail.com','khalid said','no:14 spg 1496 kg telisai','bsb','','BRUNEI DARUSSALAM','tc 1145','8161113','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 01:31:37',0,NULL,3,1,3,1,'RA117731775CN\rRA117731789CN ','photazimaginationproduction\r分2个小包发\r英标'),(9414,671645575001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','iodelbuono','maximilianoastetemillan@yahoo.com.ar','Maximiliano Astete Millán','Moreno 1337','Tandil','Buenos Aires','ARGENTINA','7000','+54 02293 15351386','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 01:51:19',0,NULL,3,1,2,1,NULL,'iodelbuono\r庄'),(9415,712719039002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','bagum.h','bagum_h@rambler.ru','Ильин Алексей','ул.Куйбышева, д.27/1, кв.99','Омск','','RUSSIAN FEDERATION','644070','+7(962) 044-1680','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 03:56:20',0,NULL,3,1,2,1,NULL,'bagum.h'),(9416,712731554002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','green_dream_sky','volya.dzemka@gmail.com','Anna Karptsova','3000 Royal Hills Dr SE<br>Apt 9H','Renton','WA','UNITED STATES','98058-3856','(206) 370-1567','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 05:08:27',0,NULL,3,1,3,1,'RA117731625CN ','green_dream_sky'),(9417,712737733002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','yuxia1986','yuxia@usc.edu','yu xia','365 A <br>S Atlantic','Monterey Park','CA','UNITED STATES','91754','(626) 382-9302','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 05:50:46',0,NULL,3,1,1,1,NULL,'yuxia1986'),(9418,712749422002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','osu1472','cl_komodo@hotmail.com','Khalil El Hamdani','C. Doctor Ferrán nº 70 , 3º/ 1ª','Terrassa','Barcelona','SPAIN','08226','628747090','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 06:55:54',0,NULL,3,1,3,1,'RA117731801CN ','osu1472'),(9419,712749952002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','jan_oto','evgeny.oto@gmail.com','Evgeny Otovchyts','Ruven and Bat Sheva 1/25','Rishon Lezion','','ISRAEL','75357','972544449382','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 06:58:56',0,NULL,3,1,2,1,' ','jan_oto'),(9420,784870418015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','iban1974iban','iban_g_g@yahoo.es','Iban Gonzalez','C/ Alfons Sala, 33-39, 4º-2ª','Sabadell','Cataluña','SPAIN','08202','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 07:00:04',0,NULL,3,1,2,1,NULL,'iban1974iban'),(9421,712753170002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',3,'AA1305',7.4,'hermeshine','ron512','ronald.nuzzolese@att.net','Ronald Nuzzolese','1495 Ashcroft Ave','Clovis','CA','UNITED STATES','93611','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 07:16:46',0,NULL,3,1,1,1,NULL,'ron512'),(9422,671714959001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','brandcj2','brandcj2@telkomsa.net','Cornelis Brand','P.O Box 3241','Pretoria','Gauteng','SOUTH AFRICA','0001','+27823713736','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 08:14:05',0,NULL,3,1,3,1,'RA117731979CN ','brandcj2'),(9423,671351956001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','athula_wijerathna','athulawijerathna@gmail.com','Athula Wijerathna','Homagama, Kelanigama,','Ginigathhena','Central Province','SRI LANKA','20688','094776552944','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 09:17:54',0,NULL,3,1,2,1,NULL,'athula_wijerathna\r庄'),(9424,712403998002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','aka_paulo','aka_paulo1@bk.ru','Pavel Polyakov','Bogorodizerogdestvenskaya str. 17','Tver','Tverskaya oblast\'','RUSSIAN FEDERATION','170007','0079109390129','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 10:06:52',0,NULL,3,1,2,1,' ','aka_paulo\r庄'),(9425,712795359002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','iban1974iban','iban_g_g@yahoo.es','Iban Gonzalez','C/ Alfons Sala, 33-39, 4º-2ª','Sabadell','Cataluña','SPAIN','08202','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 10:37:11',0,NULL,3,1,2,1,NULL,'iban1974iban\r庄'),(9426,671749420001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','antonkharchenko','a-har4enko@ya.ru','Anton Kharchenko','50 let SSSR, dom 17, kvartira 26','Sochi','Krasnodarsky krai','RUSSIAN FEDERATION','354037','+79654697268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 10:53:33',0,NULL,3,1,2,1,NULL,'antonkharchenko\r庄'),(9427,671754648001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','eliavb88','yehiel_h@netvision.net.il','eliav bitton','Rachel  Emeno 66/15','Beer-Sheba','','ISRAEL','84513','972508212990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:13:18',0,NULL,3,1,2,1,' ','eliavb88\r庄'),(9428,784940104015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','amilmand','nagyszulejman@hotmail.com','Ádám Szabó','Budapest Ferenc krt 27 fsz 3.','Budapest','','HUNGARY','1094','+36303348522','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 11:15:45',0,NULL,1,1,2,1,NULL,'amilmand'),(9429,712804803002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','daovutruongson','vtsdao@civileng.kindai.ac.jp','Vu Truong Son Dao','Hishiya Nishi 1-15-26<br>Shine Hishiya Nishi # 506','Higashi-Osaka','Osaka','JAPAN','5770807','+819099947642','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:17:10',0,NULL,3,1,2,1,NULL,'daovutruongson'),(9430,712808995002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','scufitulrosu','dcioba@yahoo.com','Dany Cioba','fundeni 237<br>bl.112, sc B, et 10, ap 87','BUCURESTI','sector 2','ROMANIA','022322','0723550492','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:32:38',0,NULL,3,1,3,1,'RA117731863CN ','scufitulrosu\r刘'),(9431,712809026002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','rescognita','rescognita@rescognita.com','JOSE ROMAN MONTESINOS LOPEZ','Rafael Alberti 1 5C<br>Fonteculler','Culleredo','A Coruna','SPAIN','15174','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:32:48',0,NULL,3,1,3,1,'RA117731877CN ','rescognita\r欧标'),(9432,712815207002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','7760corinne','corinnemansill@wol.co.za','CORINNE MANSILL','PO BOX 55279<br>EERSTEMYN','WELKOM','FREE STATE','SOUTH AFRICA','9466','+27573525907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:59:06',0,NULL,3,0,3,1,'RA117731996CN ','7760corinne\r1.955'),(9433,784957701015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','20magnum07','m.purslow@ntlworld.com','Marc Purslow','Llamedos<br>3 Gaskell Avenue','Warrington','Cheshire','UNITED KINGDOM','WA4 1PB','01925480781','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 12:06:18',0,NULL,3,1,2,1,NULL,'20magnum07\r庄'),(9434,712830928002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kin-kan','abibaud@videotron.ca','alain bibaud','4465 des messanges','st-catherine','QC','CANADA','j5c 1p9','(450) 638-5139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 12:53:25',0,NULL,3,1,2,1,NULL,'kin-kan\r庄'),(9435,784979637015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','2010kingj','kingj97@hotmail.co.uk','James King','Hurst bank<br>Charing heath road','Ashford','Kent','UNITED KINGDOM','Tn270au','01233712999','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 13:06:58',0,NULL,3,1,2,1,NULL,'2010kingj\r庄'),(9436,670588800018,280666834436,'New Small Camera bag lens case D2 for Canon 500D 450D ',3,'AO0033',24,'photographyacc','digitalmaster.rs','gustavodigital@terra.com.br','Gustavo Silveira Garcia','Rua Vitor Hugo, n. 37, sala 504','Porto Alegre','Rio Grande do Sul','BRAZIL','90630070','(51)33982593','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-12 13:07:14',0,NULL,3,1,3,1,'RA117731829CN ','digitalmaster.rs\r364'),(9437,671788244001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','stev05163','shockey@iinet.net.au','Stephen Hockey','Health Sciences Clinic Bldg<br>Via Car Park 9','La Trobe University','Victoria','AUSTRALIA','3086','0394795747','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 13:30:33',0,NULL,3,1,4,1,'YW865907664CN ','stev05163\r2m 弹簧灯架   2\r灯架  2m    1\r斜臂   1\r庄'),(9438,671787722001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',2,'AE3403',74.9,'hermeshine','stev05163','shockey@iinet.net.au','Stephen Hockey','Health Sciences Clinic Bldg<br>Via Car Park 9','La Trobe University','Victoria','AUSTRALIA','3086','0394795747','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 13:30:33',0,NULL,8,1,17,0,NULL,'stev05163'),(9439,671796968001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','flyparente','fparente@predileto.ind.br','FLEURY SILVA','RUA JANSEN, 50-VILA MARIANA<br>SÃO PAULO','SP','SÃO PAULO/SP','BRAZIL','04115070','55.11.8941.3510','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 13:48:18',0,NULL,8,1,17,0,NULL,'flyparente'),(9440,671798198001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',4,'AC2302',24.84,'hermeshine','flyparente','fparente@predileto.ind.br','FLEURY SILVA','RUA JANSEN, 50-VILA MARIANA<br>SÃO PAULO','SP','SÃO PAULO/SP','BRAZIL','04115070','55.11.8941.3510','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 13:52:05',0,NULL,3,1,3,1,'RA117731832CN ','flyparente\r小号内胆包 Nikon    5'),(9441,768946887016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'AA1310',7.56,'hutongstore','4wdcelica','hegedus14@gmail.com','Hegedűs Zoltán','COCA-COLA HBC<br>Szív utca 17.','Zalaszentgrót','','HUNGARY','8790','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 14:08:11',0,NULL,3,0,2,1,' ','4wdcelica\r庄'),(9442,671802735001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','moebius1984','moebius@etxea.net','jon latorre martinez','bagatza 13, 6º A','barakaldo','Vizcaya','SPAIN','48902','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 14:09:09',0,NULL,3,1,3,1,'RA117731846CN ','moebius1984'),(9443,671307133001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','asaymirus','asad@thundi.com','Ibrahim Asad','Hirimaagoalhi<br>Hirimaage','Fuvahmulah','Southern Procince','MALDIVES','10350','9607781088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 14:31:48',0,NULL,3,1,2,1,NULL,'asaymirus\r庄'),(9444,710757244002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','marranca2007','josemar@libero.it','jose marranca','via san maurizio 49<br>alpignano','torino','TO','ITALY','10091','0119672478','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 14:54:40',0,NULL,1,1,3,1,NULL,'marranca2007\rM'),(9445,785027591015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','angryrock123','mark_w_fisher@boltblue.com','mark fisher','37 greenlaw cresant','glenrothes','fife','UNITED KINGDOM','ky6 1jq','07709454471','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 15:12:18',0,NULL,3,1,3,1,'RA117731850CN ','angryrock123'),(9446,670130264001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',21.58,'hermeshine','nikitos333','nikita_nisenbaum@hotmail.com','Nikita Nisenbaum','Vorovskogo street 21-20','Murmansk','ru','RUSSIAN FEDERATION','183025','07 921 1523954','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 15:46:01',0,NULL,3,1,2,1,NULL,'nikitos333\r防雨罩   1\r58mm Canon 镜头盖   1\r普通热靴保护盖    1\r庄\r'),(9447,0,120722456780,'New Lens Cleaning Cloth for Pentax DSLR',1,'AA1312',0.01,'hermeshine','kohelet_son_of_david','kullyev@yandex.ru','Andrey Kullyev','2930 N Pine Grove Ave<br>Apt 403','Chicago','IL','UNITED STATES','60657-5742','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 16:04:29',0,NULL,3,1,1,1,NULL,'kohelet_son_of_david\r庄'),(9448,671843000001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','ktelectronicrepair','ktelectronicsales@gmail.com','Adam @ KT Electronicrepair','1640 alum rock ave','San jose','CA','UNITED STATES','95116-2429','(408) 641-9548','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 16:12:55',0,NULL,3,1,1,1,NULL,'ktelectronicrepair\r尽量控制在300g以内\r庄\r270'),(9449,0,120722456596,'New Lens Cleaning Cloth for Canon 40D 60D 7D 5D',1,'AA1312',0.22,'hermeshine','chevyman185','vlandino@gmail.com','Vincenzo M. Landino','48 Line Rd','Northford','CT','UNITED STATES','06472-1076','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 16:56:44',0,NULL,3,1,1,1,NULL,'chevyman185\r庄'),(9450,0,120722456563,'New Lens Cleaning Cloth for Nikon D80 D90 D300',1,'AA1312',0.06,'hermeshine','diamondsbyday','angiedayy@yahoo.com','Angela Yaun','10590 High Hollows Dr<br>Apt 287','Dallas','TX','UNITED STATES','75230-4717','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 16:57:15',0,NULL,3,1,1,1,NULL,'diamondsbyday\r庄'),(9451,785081019015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','ratboyab','ratboyab@hotmail.com','Adam Brown','4 Salisbury Road','Gravesend','Kent','UNITED KINGDOM','DA117DE','07817672368','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 17:30:16',0,NULL,3,1,2,1,NULL,'ratboyab\r庄'),(9452,712937376002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','charly_853603','carlos-leguizamon@argentina.com','carlos leguizamon','Av Jose Maria Moreno 797 12 A','Capital Federal','buenos aires','ARGENTINA','1424','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 18:07:59',0,NULL,3,1,2,1,NULL,'charly_853603\r庄'),(9453,712939343002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','rlm5815','bmurphy72@tampabay.rr.com','Bob Murphy','5815 Kumquat Ct','Tampa','FL','UNITED STATES','33625-1951','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 18:10:06',0,NULL,3,1,1,1,NULL,'rlm5815\r庄'),(9454,712946996002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','kalderaro','liorkk@gmail.com','Lior Kalderaro','Nurok Rabi 3/36','Ashkelon','Ashkelon','ISRAEL','888888','972-52-6095317','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 18:27:53',0,NULL,3,1,3,1,'RA117715579CN ','kalderaro'),(9455,785139544015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'AC2302',4.2,'hutongstore','sadgom1950','sfj100@btinternet.com','Stephen Jones','Old School, Snods Edge<br>Shotley Bridge','Consett','Durham','UNITED KINGDOM','DH8 9LE','01207255437','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 18:52:25',0,NULL,3,1,2,1,NULL,'sadgom1950\r庄'),(9456,712963173002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','stephanieeisentrout7','stephanieeisentrout@gmail.com','Steph Eisentrout','1211 N Shenandoah Ave','Front Royal','VA','UNITED STATES','22630-3531','(202) 316-0858','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 19:04:06',0,NULL,3,1,1,1,NULL,'stephanieeisentrout7\r庄'),(9457,671916856001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','itiarado','itiracook@yahoo.co.uk','Intira Cook','287/35 CHARAN SANITWONG 31<br>Bangkok Noi','Bangkok','','THAILAND','10700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 19:06:55',0,NULL,3,1,11,1,NULL,'itiarado\r庄'),(9458,712969960002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','gmclub','glm.email@email.it','Gianluca Montalbano','via Rorine 63','Alba','CN','ITALY','12051','0173975006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 19:16:58',0,NULL,3,1,3,1,'RA117732002CN ','gmclub'),(9459,785161176015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','louiseppurple','louise_p_home@hotmail.com','Louise Piotrowski','14 South View<br>Off Widmore Road','Bromley','Kent','UNITED KINGDOM','BR1 3DP','07983005870','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 19:26:33',0,NULL,3,1,2,1,NULL,'louiseppurple\r庄'),(9460,769110623016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','jmseccon','joegermoroney@eircom.net','Joseph Moroney','70. Heathervue<br>Riverstown, Glanmire','Cork','Cork','IRELAND','default','0857709401','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 19:52:34',0,NULL,3,1,3,1,'RA117731951CN ','jmseccon\r1.6x3m 背景布  2（黑+白）'),(9461,769114877016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','jmseccon','joegermoroney@eircom.net','Joseph Moroney','70. Heathervue<br>Riverstown, Glanmire','Cork','Cork','IRELAND','default','0857709401','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 19:55:19',0,NULL,8,1,17,0,NULL,'jmseccon'),(9462,671951946001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','dean.peace','dejansp@gmail.com','Dejan Mir','Šempas 127','Šempas','Šempas','SLOVENIA','5261','0038641365725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 20:21:48',0,NULL,3,1,2,1,NULL,'dean.peace\r庄'),(9463,713015578002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','aleksey1617','belonogov74@mail.ru','Aleksey Belonogov','Kaslinskaya 19b-116','Chelyabinsk','','RUSSIAN FEDERATION','454084','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 20:52:49',0,NULL,3,1,2,1,NULL,'aleksey1617\r庄'),(9464,0,120722456729,'New Lens Cleaning Cloth for Sony',1,'AA1312',0.01,'hermeshine','fpsboston10','fpsboston@gmail.com','Steve Thomas','216 Rumney Rd','Revere','MA','UNITED STATES','02151-5624','(781) 629-2337','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 20:54:49',0,NULL,8,1,17,0,NULL,'fpsboston10'),(9465,0,120722456891,'New Lens Cleaning Cloth for  Nikon DSLR',1,'AA1312',0.01,'hermeshine','fpsboston10','fpsboston@gmail.com','Steve Thomas','216 Rumney Rd','Revere','MA','UNITED STATES','02151-5624','(781) 629-2337','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 20:54:54',0,NULL,3,1,1,1,NULL,'fpsboston10\r麂皮   2\r庄'),(9466,713017204002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','m0rtag0n','arte@zopov.com','Yuri Zopov','Alcalde Porqueres 56, Piso 7','LLEIDA','Cataluña','SPAIN','25005','973831657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 20:56:37',0,NULL,3,1,2,1,NULL,'m0rtag0n\r庄'),(9467,785217398015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','goodtrader1000','trudy.barry@sky.com','trudy barry','32 windsor cresent','harrow','Middlesex','UNITED KINGDOM','ha2 8qw','02088646319','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 21:04:25',0,NULL,3,1,2,1,NULL,'goodtrader1000\r庄'),(9468,713035360002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','chemapucela','josemaria.alvar@gmail.com','José María Alvarez Aparicio','C/ Miño Nº 1 Esc. Dcha. 3º A','Laguna de Duero (Valladolid)','Castilla y León','SPAIN','47140','670661368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 21:46:20',0,NULL,3,1,2,1,NULL,'chemapucela\r庄'),(9469,713053047002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','theliftoftheyear','gcarsonau@gmail.com','Carson Au','1300 Boblett St<br>Unit A--3971','Blaine','WA','UNITED STATES','98230','(778) 882-0367','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 22:47:35',0,NULL,3,1,2,1,NULL,'theliftoftheyear\r新地址：\rCarson Au\rFaculty of Education, SFU,\r8888 University Drive,\rBurnaby, BC\rV5A 7E5\rCanada\r778-885-0367\r庄\r'),(9470,713052725002,120480630193,'New YONGNUO LCD Timer Remote Control  for Sony RM-S1AM',1,'AA3223',48.9,'hermeshine','7mila8','nimrodmilovich@mail.ru','Hrytsuk Anton','ul. Gamarnika 28-34','Minsk','','BELARUS','220131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 22:47:48',0,NULL,3,1,3,1,'RA117731885CN ','7mila8'),(9471,0,120722456639,'New Lens Cleaning Cloth',1,'AA1312',0.01,'hermeshine','chunkeih','thewesthk@hotmail.com','Chun Kei Ho','300 N Valencia St','Alhambra','CA','UNITED STATES','91801-2750','(626) 607-4587','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 23:26:36',0,NULL,8,1,17,0,NULL,'chunkeih'),(9472,0,120722456682,'New Lens Cleaning Cloth for Pentax',1,'AA1312',0.01,'hermeshine','chunkeih','thewesthk@hotmail.com','Chun Kei Ho','300 N Valencia St','Alhambra','CA','UNITED STATES','91801-2750','(626) 607-4587','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 23:26:36',0,NULL,8,1,17,0,NULL,'chunkeih'),(9473,0,120722456822,'New Lens Cleaning Cloth for Sony DSLR',1,'AA1312',0.01,'hermeshine','chunkeih','thewesthk@hotmail.com','Chun Kei Ho','300 N Valencia St','Alhambra','CA','UNITED STATES','91801-2750','(626) 607-4587','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 23:26:35',0,NULL,3,1,1,1,NULL,'chunkeih\r麂皮   3\r庄'),(9474,672017405001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',6,'AC2302',37.26,'hermeshine','diogodrigo2009','diogodrigo@hotmail.com','Diogo Drigo','Av Padre Manoel da Nobrega, 620<br>apto. 161','Santo Andre','Sao Paulo','BRAZIL','09080-140','11 83690999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 00:03:35',0,NULL,3,1,3,1,'RA117731903CN ','diogodrigo2009\r刘'),(9475,0,120722456854,'New Lens Cleaning Cloth for Canon DSLR',1,'AA1312',0.06,'hermeshine','luerasa','sandyluera@wavecable.com','Sandra Luera','1008 Elliot St','West Sacramento','CA','UNITED STATES','95605-2129','(916) 607-4208','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 00:13:05',0,NULL,3,1,1,1,NULL,'luerasa\r庄'),(9476,713074948002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',2,'AA1216',27.8,'hermeshine','mosqintal','cimenk_3@yahoo.com','kevin rusli','mappanyuki street no. 31<br>makassar city','default','SN','INDONESIA','90141','081343637333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 00:27:00',0,NULL,3,1,3,1,'RA117731948CN ','mosqintal\r庄'),(9477,713083683002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','starsea122','alexchai80@gmail.com','Sing Hai Chai','12 Barrett Lennard PDE','Perth','Western Australia','AUSTRALIA','6150','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-13 01:07:13',0,NULL,3,1,3,1,'RA117731917CN ','starsea122\r刘'),(9478,769230661016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','crankyboots','markclehane@hotmail.com','Mark Clehane','37 Silverheights Drive,<br>Silversprings','Cork','Cork','IRELAND','1','0833911359','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 01:17:23',0,NULL,3,1,2,1,NULL,'crankyboots\r庄'),(9479,672040689001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','lindsaymichellecoffman','linzee777@hotmail.com','lindsay coffman','403 N Romig St','uhrichsville','OH','UNITED STATES','44683-2065','(740) 922-1715','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 01:53:59',0,NULL,3,1,1,1,NULL,'lindsaymichellecoffman\r庄'),(9480,672031766001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','jansun1','janicesun@aol.com','Janice Farr','PO Box 949','Grandy','NC','UNITED STATES','27939','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 02:00:34',0,NULL,3,1,1,1,NULL,'jansun1\r庄'),(9481,670651031018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','frost_bolt','husky.01@optusnet.com.au','daniel nycyk','96 rawlinson street','murrarie ,brisbane','Queensland','AUSTRALIA','4172','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-13 02:41:26',0,NULL,3,1,4,1,'YW865907653CN ','frost_bolt\r河北的架子+1.6x2.1白色布+夹子\rbackgournd support @$0\r王'),(9482,712420287002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','2010bousosheila','bousosheila@gmail.com','Carlos Alberto Bouso','Ecuador 318 1 Piso Departamento A','Capital Federal','Buenos Aires','ARGENTINA','C1214ACD','011 48657042','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-13 02:58:02',0,NULL,3,1,3,1,'RA117731894CN ','2010bousosheila\r申报 $10'),(9483,713123767002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','nikonisti','arifyantow@yahoo.com','Arifyanto Wirawan Tjioe','Jl. Bangka Raya no. 27 unit B<br>Pela Mampang','Jakarta Selatan','DKI Jakarta','INDONESIA','12720','+62816801079','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 04:12:09',0,NULL,3,1,2,1,NULL,'nikonisti'),(9484,713129477002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','gorbva','gorbva@mail.ru','Vladimir Gorbanev','Kominterna str. 8-92','Khanty-Mansiysk','Khanty-Mansy Autonomos Okrug','RUSSIAN FEDERATION','628011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 04:49:29',0,NULL,3,0,3,1,'RA117727016CN ','gorbva欧标'),(9485,672073797001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',61,'hermeshine','fotofilia','sngfotografia@gmail.com','María Teresa Godoy León','Alonso de Córdova 3773, Vitacura','Santiago','Región Metropolitana','CHILE','7630492','(56) 6-8499240','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-13 04:55:07',0,NULL,3,1,3,1,'RA117727104CN ','fotofilia'),(9486,0,120722456933,'New Lens Cleaning Cloth for UV CPL',1,'AA1312',0.07,'hermeshine','wvashug1939','wvashug@hotmail.com','Robert F Cummings','1171 Epling Hollow Rd','Ashford','WV','UNITED STATES','25009','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 05:15:04',0,NULL,3,1,1,1,NULL,'wvashug1939\r麂皮    2'),(9487,672086793001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','cttuan','ngtu2009@yahoo.com','CHAU, Tuan Thanh','Marikoji kaikan, #219<br>6-2 Yoshida Izumidono-cho, Sakyo-ku','Kyoto','Kyoto','JAPAN','606-8301','+818040135999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 06:11:06',0,NULL,3,1,2,1,NULL,'cttuan'),(9488,713158863002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','via_23','pierste@free.fr','Pierre Sassaro','50 rue de la chapelle','paris','Île-de-France','FRANCE','75018','0660160955','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 07:39:30',0,NULL,3,1,2,1,NULL,'via_23'),(9489,713169697002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ytrio77','fermionjr@yahoo.es','Javier Rivas Ascondo','C/Lapurdi 3 1ºH','Leioa','País Vasco','SPAIN','48940','944631555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 08:33:12',0,NULL,3,1,2,1,NULL,'ytrio77'),(9490,669310206018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','tristravels','tristangautrey@gmail.com','tristan gautrey','IML, Level 4<br>60 Carrington Street','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-13 08:52:27',0,NULL,3,1,2,1,NULL,'tristravels'),(9491,712455489002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','lenalena2007','lena2002@aon.at','Kozlova Elena','Sunshine House, POBox 274<br>Providence','Victoria','Mahe','SEYCHELLES','0000','2482525283','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 09:25:49',0,NULL,0,1,3,0,' ','lenalena2007'),(9492,783414741015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',8.02,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','c/o Mark Garland<br>Moonfleet, North End Lane','Louth','Lincs','UNITED KINGDOM','LN11 7SP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 09:33:17',0,NULL,8,0,17,0,NULL,'jfarenden'),(9493,785421585015,250615147105,'YongNuo Flash Battery Pack 8*AA for Nikon Flash SB900',4,'AB3311',131.96,'hutongstore','mek8957','martin.keene@pa.press.net','Martin Keene','2 Clarence Road','Richmond','Surrey','UNITED KINGDOM','TW9 3NL','07815788817','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 09:42:27',0,NULL,0,1,3,0,NULL,'mek8957'),(9494,670957674018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','doogen09','becandbrett01@dodo.com.au','Rebecca Duler','708 Latrobe Street','Ballarat','Victoria','AUSTRALIA','3350','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-13 09:46:13',0,NULL,0,1,4,0,NULL,'doogen09\r背景架河北 +1.6x2.1 白+ 夹子\rbackground support  $25'),(9495,785432630015,250606687616,'IR Remote Control 4 Canon RC-5 EOS 500D 350D 400D 450D',1,'AA2206',3.5,'hutongstore','kookykiwibird','niamh.parker@sky.com','Niamh Parker','C/- Level 6 - Stockley House<br>130 Wilton Road','London','London','UNITED KINGDOM','SW1V 9LQ','07885722399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:30:45',0,NULL,8,1,17,0,NULL,'kookykiwibird'),(9496,769353909016,260660053303,'New Neoprene Reversible Cover for Stand-DSLR Camera M',1,'AC1301',4.5,'hutongstore','kookykiwibird','niamh.parker@sky.com','Niamh Parker','C/- Level 6 - Stockley House<br>130 Wilton Road','London','London','UNITED KINGDOM','SW1V 9LQ','07885722399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:30:46',0,NULL,8,1,17,0,NULL,'kookykiwibird'),(9497,785430947015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','kookykiwibird','niamh.parker@sky.com','Niamh Parker','C/- Level 6 - Stockley House<br>130 Wilton Road','London','London','UNITED KINGDOM','SW1V 9LQ','07885722399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:30:47',0,NULL,8,1,17,0,NULL,'kookykiwibird'),(9498,785431860015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',3.72,'hutongstore','kookykiwibird','niamh.parker@sky.com','Niamh Parker','C/- Level 6 - Stockley House<br>130 Wilton Road','London','London','UNITED KINGDOM','SW1V 9LQ','07885722399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:30:47',0,NULL,8,1,17,0,NULL,'kookykiwibird'),(9499,769354273016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','kookykiwibird','niamh.parker@sky.com','Niamh Parker','C/- Level 6 - Stockley House<br>130 Wilton Road','London','London','UNITED KINGDOM','SW1V 9LQ','07885722399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:30:48',0,NULL,0,1,3,0,NULL,'kookykiwibird\r红外遥控canon 白盒的那个（就一个了应该是）   1\r中号内胆包 无字   1\r绿叶58mm cpl   1\r绿叶62mm cpl   1\r58mm 镜头盖  canon   1'),(9500,769364524016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','paulhodgson','paul@pihpropertyservice.co.uk','Paul Hodgson','24a Montague Road','Sale','Cheshire','UNITED KINGDOM','M33 3BU','01619692675','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:37:12',0,NULL,0,1,2,0,NULL,'paulhodgson'),(9501,785445539015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','mike1001101','binarek@gmail.com','Miroslav Šenkýř - ELNET-MOBIL','Lidická 43','Havířov','Moravskoslezský','CZECH REPUBLIC','73601','605071818','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-13 11:08:17',0,NULL,0,1,5,0,NULL,'mike1001101'),(9502,672147882001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','mamaschnackel','pearlmam@web.de','Marion Perl','Haunswieserstrasse 5','Aichach','','GERMANY','86551','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 11:09:10',0,NULL,0,1,2,0,NULL,'mamaschnackel'),(9503,671747569001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',5,'AA3310',63.84,'hermeshine','nord975','rid75@ukr.net','Mykhaylo Degtyarenko','p.o.box 701','Sumy','','UKRAINE','40003','+38 066 217-54-62','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 12:19:16',0,NULL,0,1,0,0,NULL,'nord975\r绿叶52mm uv  10\r绿叶67mm cpl   1\r绿叶58mm cpl   5\r红外遥控for olympus    1\r\r'),(9504,769398675016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','limmess','limmes@zebra.lt','Linas Pečkauskas','Šarkuvos 32-37','Kaunas','','LITHUANIA','48167','37061441448','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 12:24:51',0,NULL,0,1,2,0,NULL,'limmess'),(9505,672166625001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','tiper3x','lesny.jozef@gmail.com','Dagmar Semanová','Sokoľany 19','Haniska','','SLOVAK REPUBLIC','04457','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 12:25:31',0,NULL,0,1,2,0,NULL,'tiper3x'),(9506,785478501015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','lumen_art','remi.vimont@gmail.com','Rémi Vimont','30, square Nungesser et Coli','Wimereux','Nord-Pas-de-Calais','FRANCE','62930','06.17.10.72.23','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-13 12:43:45',0,NULL,0,1,4,0,NULL,'lumen_art\r新地址：\rREMI VIMONT\r34 RUE DE PARIS\r59800 LILLE\rFRANCE METROPOLITAINE\r'),(9507,671014359018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','leo_guevarra32','leoguevarra32@yahoo.com','LEO GUEVARRA','1590 Buckeye Dr','MILPITAS','CA','UNITED STATES','95035-7418','(408) 564-1971','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-13 13:17:06',0,NULL,0,1,1,0,NULL,'leo_guevarra32'),(9508,769427244016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',3,'AA1212',7.56,'hutongstore','w_a_r_r_e_n','warren.gomez@gmail.com','Clayton Gomez','26 Miami Court<br>Harbour Views','GIBRALTAR (EUROPE)','','GIBRALTAR','GB11ZZ','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 13:45:04',0,NULL,0,1,2,0,NULL,'w_a_r_r_e_n'),(9509,672204331001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','billbrach','bill@soundideasstereo.com','Sound Ideas - Glas Kats Studio','3215 NW 13th St<br>Attn: Bill Brachhold','Gainesville','FL','UNITED STATES','32609-2174','(352) 378-0192 ext.: 315','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 14:28:40',0,NULL,0,1,1,0,NULL,'billbrach'),(9510,713260110002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','snoopy91671','dhonma91671@yahoo.com','David Honma','1031 Wheatland Ave','Lancaster','PA','UNITED STATES','17603-3120','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 14:29:57',0,NULL,0,1,1,0,NULL,'snoopy91671'),(9511,712191262002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','hlynurkr','hlynur.kr@gmail.com','Hlynur Kristjánsson','Silfurgata 11','Isafjordur','','ICELAND','400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 14:39:17',0,NULL,0,1,2,0,NULL,'hlynurkr'),(9512,672227320001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','lockstock2006','kozich@gmail.com','A. Kozich','Vostochnaja 28/2-43','Minsk','','BELARUS','220013','+375296173247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 15:47:29',0,NULL,0,1,2,0,NULL,'lockstock2006'),(9513,785564820015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.49,'hutongstore','gerrym9225','gmcl@eircom.net','Gerry McLoughlin','Silverspruce, Lake Road, Cobh, Co. Cork','Cork','Cork','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 16:19:54',0,NULL,0,1,2,0,NULL,'gerrym9225'),(9514,785567311015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',6,'hutongstore','billkou','billpckalamata@gmail.com','bill koutsouropoulos','agion anargyron petalo 21','kalamata','messhnia','GREECE','24100','6944664121','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 16:24:24',0,NULL,0,1,2,0,NULL,'billkou'),(9515,713299854002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','jabollo','stundex@hotmail.com','Martin Jablonski','Dreieichstr. 21','Dietzenbach','','GERMANY','63128','Invalid Request','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-13 16:32:11',0,NULL,0,1,4,0,NULL,'jabollo\r欧标'),(9516,713303067002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','gnic4248','meestes@gmail.com','Michael Estes','121 N Mountain St','Blue Mountain','MS','UNITED STATES','38610','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 16:40:21',0,NULL,0,1,1,0,NULL,'gnic4248'),(9517,713326288002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','flemblue21','revhabutler@hotmail.com','Ray Butler','7412 Girard St','Omaha','NE','UNITED STATES','68122-1766','','NoPaymentFailure','CheckoutComplete','Other','2011-05-13 17:40:34',0,NULL,0,1,19,0,NULL,'flemblue21'),(9518,713323345002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lx_likes_to_smile','lx.dang.it@gmail.com','Alex Dang','14027 110th PL NE','Kirkland','WA','UNITED STATES','98034','(425) 445-5183','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 17:45:01',0,NULL,0,1,1,0,NULL,'lx_likes_to_smile'),(9519,713327351002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','filiplucin','filip@filiplucin.com','Filip Lucin','Dr. I. Novaka 20/1','Cakovec','Medjimurje','CROATIA','40000','0913902166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 17:56:27',0,NULL,0,1,2,0,NULL,'filiplucin'),(9520,713362798002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','spencer-creative','budspencer@mac.com','Robert Spencer','5057 Morning Dew Dr','Salt Lake City','UT','UNITED STATES','84123-4527','(801) 792-1052','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 19:15:38',0,NULL,8,1,17,0,NULL,'spencer-creative'),(9521,672305665001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','spencer-creative','budspencer@mac.com','Robert Spencer','5057 Morning Dew Dr','Salt Lake City','UT','UNITED STATES','84123-4527','(801) 792-1052','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 19:15:38',0,NULL,0,1,1,0,NULL,'spencer-creative\r绿叶 52mm uv   1\r52mm 橡胶罩   1'),(9522,724706008017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','mgt2710','miketyler@optusnet.com.au','Michael Tyler','45 Morehead Avenue, Norman Park','Brisbane','Queensland','AUSTRALIA','4170','0733957989','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-13 21:51:03',0,NULL,0,1,2,0,NULL,'mgt2710'),(9523,785733057015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','bladerunnervoidcomp2019','ramajayjay_69@yahoo.co.uk','Jason Crick','107 Kingsly Avenue','Kettering','Northamptonshire','UNITED KINGDOM','nn169es','01536515938','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,0,1,2,0,NULL,'bladerunnervoidcomp2019'),(9524,785739878015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','mikekidwelly','mikedavid@dragontv.fsnet.co.uk','michael   David','94 Priory Street','Kidwelly','Carmarthenshire','UNITED KINGDOM','SA174TY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 22:26:42',0,NULL,0,1,2,0,NULL,'mikekidwelly'),(9525,672382513001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','roseyranger','roseyranger@yahoo.com','Roosevelt','623 Pope Dr<br>Apt A','Vallejo','CA','UNITED STATES','94591','(707) 552-5254','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 22:46:52',0,NULL,8,1,17,0,NULL,'roseyranger'),(9526,713450006002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','kosowar7','clirim@uskana.com','Clirim Ramadani','Rr. Bill Clinton SU5/8E Nr.41','Pristina','Kosovo','ALBANIA','10090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 23:13:54',0,NULL,0,1,2,0,NULL,'kosowar7'),(9527,769676035016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',2,'AE2501',43,'hutongstore','nkbanks51','nick@nicklory.com','Leo Claussen','Kösterbergstr. 62c','Hamburg','','GERMANY','22587','447984023163','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 23:37:20',0,NULL,0,1,4,0,NULL,'nkbanks51\rreflector holder $20'),(9528,672396428001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','gaenari','jokdimbar@gmail.com','Kyung Sang Kim','21187 Ambushers St','Diamond Bar','CA','UNITED STATES','91765','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 23:52:34',0,NULL,0,1,1,0,NULL,'gaenari'),(9529,713463147002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','airwavesport1','info@heiho.be','Hedwig Ceulemans','Doornaardstraat 72','Wommelgem','','BELGIUM','2160','0475820458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 00:15:47',0,NULL,0,1,2,0,NULL,'airwavesport1'),(9530,785773696015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','iris_wan2003','iris_wan2003@yahoo.com.sg','Chan Wei Yee','Blk 72 Telok Blangah Heights #08-321','Singapore','','SINGAPORE','100072','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-14 00:33:08',0,NULL,0,1,11,0,NULL,'iris_wan2003'),(9531,671254952018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','puzzzl3r','puzzl3r1@hotmail.com','Alison Banister-Jones','po Box 496','Willetton','Western Australia','AUSTRALIA','6155','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-14 00:44:33',0,NULL,0,1,2,0,NULL,'puzzzl3r'),(9532,672409696001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','cookie.ns','lucyandroscoe2005@ns.sympatico.ca','jeff giles','489 alexander mackenzie rd','south farmington','NS','CANADA','b0p 1w0','(902) 840-3879','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 01:02:25',0,NULL,0,1,3,0,NULL,'cookie.ns'),(9533,672418926001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','klimshelf','r.klimesh@horsekeeping.com','Richard Klimesh','PO Box 140','Livermore','CO','UNITED STATES','80536','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-14 01:59:44',0,NULL,0,1,1,0,NULL,'klimshelf'),(9534,672424124001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','gomes30','gomes_27desouza@yahoo.com.br','balbino gomes de souza','rua joenville n° 5363   8° rua<br>setor 09','Ariquemes','Rondonia','BRAZIL','76876200','0216984177514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 02:19:52',0,NULL,0,1,2,0,NULL,'gomes30'),(9535,713493699002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','syphlix','gregorytran@gmail.com','Greg Tran','17 Stuyvesant St<br>Apt 12A','New York','NY','UNITED STATES','10003-7573','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-14 02:43:42',0,NULL,0,1,1,0,NULL,'syphlix'),(9536,713505269002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','nsaenko','nikita.saenko@gmail.com','Никита Саенко','проезд Репина, дом 28, кв. 248','Краснодар','Краснодарский край','RUSSIAN FEDERATION','350051','+7 (928) 201 1259','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 03:51:36',0,NULL,0,1,2,0,NULL,'nsaenko'),(9537,713516826002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','roseyranger','roseyranger@yahoo.com','Roosevelt','623 Pope Dr<br>Apt A','Vallejo','CA','UNITED STATES','94591','(707) 552-5254','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-14 05:03:57',0,NULL,0,1,1,0,NULL,'roseyranger\r橡胶遮光罩 52mm   1\rHB-7 花瓣     1'),(9538,713517486002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','bijps2shtr','bijps2shtr@gmail.com','Bijan Dosi','1 Pike','irvine','CA','UNITED STATES','92620-2541','(949) 232-6179','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-14 05:05:37',0,NULL,0,1,1,0,NULL,'bijps2shtr'),(9539,769756269016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','ikkuvaljo','ikkuvaljo@gmail.com','Tuomas Mäkynen','Nisulankatu 21 B 2','Jyväskylä','','FINLAND','40720','+358440430043','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-14 05:52:27',0,NULL,0,1,3,0,NULL,'ikkuvaljo'),(9540,713558081002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','albeeday','abidee001@hotmail.com','Alexandre Bidée','Kosterstraat 93','DIEGEM','','BELGIUM','1831','485692211','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 08:44:19',0,NULL,0,1,2,0,NULL,'albeeday'),(9541,672493942001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.99,'hermeshine','rak200909','rsvitok@zvzapad.sk','Roman Svitok','Strazska cesta 1139/33','Zvolen','','SLOVAK REPUBLIC','960 01','Invalid Request','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 08:54:58',0,NULL,0,1,2,0,NULL,'rak200909'),(9542,671381197018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','orwen98','orwenmari@yahoo.com','orwen  maribao','2/41 coolangatta road ','kirra','Queensland','AUSTRALIA','4225','0402145359','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-14 10:50:22',0,NULL,0,1,4,0,NULL,'orwen98\rlight kit  $20'),(9543,713591112002,120461006671,'Digital SLR Camera Raincover rain cover for Nikon Canon',1,'AA3101',16.99,'hermeshine','ridux76','bhormo@hotmail.com','Bjørn-Henrik Ormo','Rosslyngveien 16B','Bronnoysund','','NORWAY','8900','+4795703065','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 10:57:06',0,NULL,0,1,2,0,NULL,'ridux76'),(9544,672537232001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','9262.broker69','verybroke66@yahoo.com.sg','chan serene','22 eunos crescent<br>#08-3007','singapore','singapore','SINGAPORE','400022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 11:40:57',0,NULL,0,1,11,0,NULL,'9262.broker69'),(9545,713604113002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','rodrigoslater76','slater76@gmail.com','Rodrigo Souza','Av. Emb. Abelardo Bueno 3350<br>Bl 2 apt 503 Barra dda Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22775040','97030309','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 11:43:01',0,NULL,0,1,2,0,NULL,'rodrigoslater76'),(9546,672566795001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','jennifers5890','jennifer.shu@optusnet.com.au','Jennifer Shu','15 Stotts Ave','Bardwell Park','New South Wales','AUSTRALIA','2207','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 13:18:28',0,NULL,0,1,2,0,NULL,'jennifers5890'),(9547,672577934001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','tkincl','kincl_tomas@centrum.cz','Tomas Kincl','Jarosovska 1117','Jindrichuv Hradec','','CZECH REPUBLIC','37701','+420384417241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 15:07:22',0,NULL,0,1,2,0,NULL,'tkincl');
/*!40000 ALTER TABLE `hmsh_ebay_transaction` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2011-05-14  9:57:43
